   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *                  BASELINE                                            *
   *               MASTER DO_FILE                                         *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      This master do file run all the cleaning and construction do files for the Baseline survey was conducted in person prior to the intervention from February to April 2016 

       ** OUTLINE:      PART 0: Standardize settings and install packages
                        PART 1: Preparing folder path globals
                        PART 2: Run the master do files for each high level task

       ** IDS VAR:       hhid       //Uniquely identifies households

       ** NOTES:

       ** WRITEN BY:    Camila Ayala (mayalaguerrero@worldbank.org)
						Thomas Escande (tescande@worldbank.org)

       */

*iefolder*0*StandardSettings****************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 0:  INSTALL PACKAGES AND STANDARDIZE SETTINGS
   *
   *           -Install packages needed to run all dofiles called
   *            by this master dofile.
   *           -Use ieboilstart to harmonize settings across users
   *
   * ******************************************************************** *


   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           -Set the global box to point to the project folder
   *            on each collaborators computer.
   *           -Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *

*iefolder*1*FolderGlobals*master************************************************
*iefolder will not work properly if the line above is edited

   global mastData               "$dataWorkFolder/MasterData" 

*iefolder*1*FolderGlobals*rawData***********************************************
*iefolder will not work properly if the line above is edited

   global encryptFolder          "$dataWorkFolder/EncryptedData" 

*iefolder*1*FolderGlobals*Baseline**********************************************
*iefolder will not work properly if the line above is edited

   *Baseline folder globals
   global Baseline               "$dataWorkFolder/Baseline" 
   global Baseline_dt            "$Baseline/DataSets" 
   global Baseline_do            "$Baseline/Dofiles" 
   global Baseline_out           "$Baseline/Output" 

   *Encrypted round sub-folder globals
   global Baseline_encrypt       "$encryptFolder/Round Baseline Encrypted" 
   global Baseline_dtRaw         "$Baseline_encrypt/Raw Identified Data" 
   global Baseline_doImp         "$Baseline_encrypt/Dofiles Import" 
   global Baseline_HFC           "$Baseline_encrypt/High Frequency Checks" 

   *DataSets sub-folder globals
   global Baseline_dtInt         "$Baseline_dt/Intermediate" 
   global Baseline_dtFin         "$Baseline_dt/Final" 

   *Dofile sub-folder globals
   global Baseline_doCln         "$Baseline_do/Cleaning" 
   global Baseline_doCon         "$Baseline_do/Construct" 
   global Baseline_doAnl         "$Baseline_do/Analysis" 

   *Output sub-folder globals
   global Baseline_outRaw        "$Baseline_out/Raw" 
   global Baseline_outFin        "$Baseline_out/Final" 

   *Questionnaire sub-folder globals
   global Baseline_prld          "$Baseline_quest/PreloadData" 
   global Baseline_doc           "$Baseline_quest/Questionnaire Documentation" 

*iefolder*1*End_FolderGlobals***************************************************
*iefolder will not work properly if the line above is edited


*iefolder*2*StandardGlobals*****************************************************
*iefolder will not work properly if the line above is edited

   * Set all non-folder path globals that are constant accross
   * the project. Examples are conversion rates used in unit
   * standardization, differnt set of control variables,
   * ado file paths etc.

   do "$dataWorkFolder/global_setup.do" 


*iefolder*2*End_StandardGlobals*************************************************
*iefolder will not work properly if the line above is edited


*iefolder*3*RunDofiles**********************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 3: - RUN DOFILES CALLED BY THIS MASTER DO FILE
   *
   *           -A task master dofile has been created for each high
   *            level task (cleaning, construct, analyze). By 
   *            running all of them all data work associated with the 
   *            Baseline should be replicated, including output of 
   *            tablets, graphs, etc.
   *           -Feel free to add to this list if you have other high
   *            level tasks relevant to your project.
   *
   * ******************************************************************** *

********************************************************************************
********************************************************************************
	** BASELINE DO FILES
********************************************************************************
********************************************************************************
 
* For all baseline do files, we use the dataset clean by Rebecca and Min before.
* We do some additional cleaning, but we don't start form the raw datasets.
 
* Questionnaires:
* ${Baseline}/Questionnaire/Questionnaire Final 
 
*-------------------------*
* A. PREPARE - DO NOT RUN * 
*-------------------------*

* These do files should be run only once (at the end of data collection) UNLESS 
* something went wrong during the import of the do files or the preparation.

	* 1. Prepare LHH, MHHH, Targeting.
	*	 Makes corrections based on field reports and anonymize data
	*	do "${Baseline_do}/Cleaning/LHH_prepare_bl.do"
 	*	do "${Baseline_do}/Cleaning/MHHH_prepare_bl.do"
	*	do "${Baseline_do}/Cleaning/Targeting_prepare_bl.do"

/*------------------------*
* B. CLEANING - BASELINE * 
*------------------------*

	*------------------*
	* 1. Market Survey *
	*------------------*

		* Do file
			do "${Baseline_do}/Cleaning/market_survey_clean_bl.do"

		* Outputs
			* 1. Market dataset cleaned
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/market_clean_bl.dta", clear
   
 	*-------------------*
	* 2. Village Survey *
	*-------------------*
  
		* Do file
			do "${Baseline_do}/Cleaning/village_survey_clean_bl.do"
			
		* Outputs
			* 1. Village dataset cleaned
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/village_clean_bl.dta", clear
			
	*-----------------------*
	* 3. Households Surveys *
	*-----------------------*
   
		* Cleaning
			do "${Baseline_do}/Cleaning/LHH_MHHH_Targ_clean_bl.do"
			
		* This do file also runs:
			
			* 1. Individual cleaning
			*	do "${Baseline_do}/Cleaning/LHH_clean_bl.do"
			* 	do "${Baseline_do}/Cleaning/MHHH_clean_bl.do"
			*	do "${Baseline_do}/Cleaning/Targeting_clean_bl.do"
											
			* 2. Preparing and cleaning rosters
			*	do "${Baseline_do}/Cleaning/preparing_and_cleaning_rosters_bl.do"
			
		* Outputs
			* 1. All HHs (Targeting + Ultra-Poor) cleaned, no PII data
			* 	use "${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
			
			* At this point this will be the MDC published dataset		*/
 
*----------------------------*
* C. CONSTRUCTION - BASELINE * 
*----------------------------*
  
 	*---------------*
	* Village Survey *
	*---------------*
			do "${Baseline_do}/Construct/village_survey_construct_bl.do"
			
	*---------------*
	* Market Survey *
	*---------------*
  
		* Do file
			do "${Baseline_do}/Construct/market_survey_construct_bl.do"

		* Outputs
			* Market dataset with imputations
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/market_imputed_bl.dta", clear  
  
  		
	*-------------------*
	* Roster *
	*-------------------*
		
		* Do file
			do "${Baseline_do}/Construct/roster_final_bl.do"
			
		* Outputs
			* 1. Roster for Balance
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta", clear
  
	*-------------*
	* Consumption *
	*-------------*

		* Do file
			do "${Baseline_do}/Construct/consumption_construct_bl.do"
			
		* Outputs
			* 1. Total expenditure variables 
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/total_expenditure_bl.dta", clear
	  
	*-----------------------------------------*
	* Political involvement and food security *
	*-----------------------------------------*
		
		* Do file
			do "${Baseline_do}/Construct/polinvolvement_foodsecurity_construct_bl.do"
			
		* Outputs
			* 1. Political involvement index
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/political_involvement_index_bl.dta", clear
				
			* 2. Food security index
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/food_security_index_bl.dta", clear
			
 	*-------*
	* Labor *
	*-------*
  
 	* Do file
		do "${Baseline_do}/Construct/labor_construct_bl.do"
		
	* Outputs
		* 1. Labor dataset
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/labor_bl.dta", clear			
			
 	*---------------------*
	* Woman's empowerment *
	*---------------------*
	 
		* Do file
			do "${Baseline_do}/Construct/female_empowerment_construct_bl.do"
			
		* Outputs
			* 1. Political involvement index
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta", clear
			
	*-------------------*
	* Productive assets *
	*-------------------*
	
		* Do file
			do "${Baseline_do}/Construct/productive_assests_construct_bl.do"
			
		* Outputs
			* 1. Value of livestock
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/livestock_assets_index_bl.dta", clear
			
			* 2. Revenue from livestock
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/livestock_revenue_index_bl.dta", clear
			
			* 3. Revenue from crops (agricultural revenue)
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/crop_production_index_bl.dta", clear
			
			* 4. Revenue from non-agricultural businesses
			* use "${TUP_DB}/Baseline/DataSets/Intermediate/business_revenue_earnings_bl.dta", clear

		
	*------------------*
	* Psych well-being *
	*------------------*
  
	* Do file
		do "${Baseline_do}/Construct/psych_well_being_bl.do"
		
	* Outputs
		* 1. Psych well-being index
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta", clear
		
	*--------------*
	* Assets index *
	*--------------*
	
	* Do file
		do "${Baseline_do}/Construct/asset_index_construct_bl.do"
		
	* Outputs
		* 1. Assets index SES (UP vs. Non-UP)
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/asset_index_ses_bl.dta", clear
		
		* 2. Assets index UP (treatment vs. Control)
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/asset_index_up_bl.dta", clear
		
		
	*------------------------*
	* Entrepreneurship index *
	*------------------------*
	
	* Do file
		do "${Baseline_do}/Construct/entrepreneurship_index_bl.do"
		
	* Outputs
		* 1. Entrepeneurship index UP (treatment vs. Control)
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/entrepreneur_index_up.dta", clear
			
 	*-----------------*
	* Financial index *
	*-----------------*
	
	* Do file
		do "${Baseline_do}/Construct/Financial_index_construct_bl.do"
		
	* Outputs
		* 1. Financial index SES (UP vs. Non-UP)
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/finance_index_ses_bl.dta", clear
		
		* 2. Financial index UP (treatment vs. Control)
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/finance_index_up_bl.dta", clear
  

 
	*--------*
	* Health *
	*--------*

	* Do file
		do "${Baseline_do}/Construct/health_construct_bl.do"

	* Outputs
		* 1. Children's health outcomes
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/health_bl.dta", clear 
		
	*-----------*
	* Schooling *
	*-----------*
		
		do "${Baseline_do}/Construct/schooling_construct_bl.do"
		
	* Outputs
		* 1. Children's schooling outcomes
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta", clear
 
 	*----------------------------------------*
	* Data for analysis --> COMPILED DATASET *
	*----------------------------------------*
   
	* Do file
		do "${Baseline_do}/Construct/data_for_analysis_bl.do"
		
	* Outputs
		* 1. data_for_analysis_bl: compiled dataset for analysis
		* use "${TUP_DB}/Baseline/DataSets/Intermediate/data_for_analysis_bl.dta", clear
		   
*iefolder*3*End_RunDofiles******************************************************
*iefolder will not work properly if the line above is edited

