/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Oct 18, 2016
Last udpate on: Nov 15, 2019

Written by:  	Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com) and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Merges and appends LHH, MHHH and Targeting Survey.


CONTENT:		
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/	

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

/*
Explanation on the matching of LHH and MHHH surveys. We have three possible cases:
	(1) Head of household is male
		(a) There is a lady of the household
			---> Lady of the household fills LHH, male head fills out MHHH
		(b) There is no lady of the household
			---> Male HHH fills out LHH,there is no MHHH
	(2) Head of the household is female
		(a)	---> Female HHH fills out LHH, there is no MHHH
*/

* Inputs 
	* LHH, MHHH and Targeting cleaned datasets 
		gl LHH_interm_bl_nopii "${TUP_DB}/Baseline/DataSets/Intermediate/LHH_interm_bl_nopii.dta"			 
		gl MHHH_interm_bl_nopii "${TUP_DB}/Baseline/DataSets/Intermediate/MHHH_interm_bl_nopii.dta"			 
		gl Targ_interm_bl_nopii "${TUP_DB}/Baseline/DataSets/Intermediate/Targ_interm_bl_nopii.dta"			 
 
	* Profile info 
		gl profile_info 	"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta" 
	 
		 
* Outputs 
	* Merged and appended dataset 
		gl all_HH_interm_nopii_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_interm_nopii_bl.dta" 
		gl all_HH_nopii_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta" 
 
********************************************************************************
	** Part 1: Running cleaning do files of LHH, MHHH and Targeting surveys
********************************************************************************
		
		do "${Baseline_do}/Cleaning/LHH_clean_bl.do"
		do "${Baseline_do}/Cleaning/MHHH_clean_bl.do"
		do "${Baseline_do}/Cleaning/Targeting_clean_bl.do"

********************************************************************************
	** Part 2: Merging and Appending LHH, MHHH and Targeting surveys
********************************************************************************
	
* The MHHH survey was thus administered only if the HHH was male and there was a LHH survey
* Each MHHH survey must correspond to a LHH survey. We ensure this is true with "assert":
		
	* Declare macros of HH status. They will be used to generate flags for matching results that are not consistent with survey administration protocols
	* Define when MHHH surveys should and should not been administered
		loc	LHH_MHHH	LHH_available==1 & hh_head_gender==1 // HHH is male and LHH exists (should have both LHH and MHHH)
		loc	LHH_only	LHH_available==0 | hh_head_gender==2 // HHH is female or LHH does not exist (should only have LHH)
		
*--------------------------------------------------*
* 1. Drop extra MHHH survey responses before merge *
*--------------------------------------------------*
		
	* There are households who should have filled out LHH only, but filled out MHHH as well by mistake. For those extra MHHH survey, we decided to drop them.
		
		use		"${MHHH_interm_bl_nopii}", clear
		merge	1:1 bl_hhid using "${LHH_interm_bl_nopii}", ///
				keepusing(bl_hhid LHH_available hh_head_gender) gen(merge_mhhh) //assert(2 3) keep(3) // keep matched observations only
		keep if merge_mhhh==3
			/*
			Merge with previous datasets
		    Result                           # of obs.
			-----------------------------------------
			not matched                           294
				from master                         0  (merge_mhhh==1)
				from using                        294  (merge_mhhh==2)

			matched                             1,107  (merge_mhhh==3)
			-----------------------------------------
	
			* This is the merge I (Camila) got
			    Result                           # of obs.
			-----------------------------------------
			not matched                           298
				from master                         2  (merge_mhhh==1)
				from using                        296  (merge_mhhh==2)

			matched                             1,105  (merge_mhhh==3)
			-----------------------------------------
			*/
					
					
		count	if	merge_mhhh==3 & `LHH_only'
		assert	r(N)==25	// There must be 25 observation with extra MHHH survey, based on Feb 13, 2017 data
		drop	if	merge_mhhh==3 & `LHH_only'
		rename (a8_m a9_m) (a8_m_m a9_m_m)
		drop merge_mhhh
			
		* Save it as a separate file, which will be merged with LHH survey from now on
			tempfile	MHHH_extra_dropped
			save		`MHHH_extra_dropped'
	
		
*-----------------------------------------------------------------*
* 2. Merge LHH with MHHH (where extra MHHH responses are dropped) *
*-----------------------------------------------------------------*

	use		"${LHH_interm_bl_nopii}", clear
	merge	1:1 bl_hhid using `MHHH_extra_dropped', ///
			 gen(merge_mhhh) assert(1 3) // HHID_usedin_MHHH
		/*
			Result                           # of obs.
			-----------------------------------------
			not matched                           321
				from master                       321  (merge_mhhh==1)
				from using                          0  (merge_mhhh==2)

			matched                             1,080  (merge_mhhh==3)
			-----------------------------------------
		*/
		
	
	label var merge_mhhh "Result of matching LHH (master) with MHHH (using)"
	
	* Generate an indicator which we should have MHHH survey responses but missing.
		loc	var	MHHH_missing
		gen		`var'=1	if	(merge_mhhh==1 & `LHH_MHHH')
		replace `var'=0	if	(merge_mhhh==1 & (`LHH_only')) 
		replace `var'=0	if	(merge_mhhh==3 & `LHH_MHHH')
		lab	var	`var'	"MHHH survey is missing (HHH is male and LHH exists)"
		note	`var':	gen	`var'=1	if	(merge_mhhh==1 & `LHH_MHHH')
		tab MHHH_missing
		* Result: there are 49 missing MHHH surveys
	
*----------------------------------*
* Replace info from module K and J *
*----------------------------------*
	
	* If there are two different responses from LHH and MHHH, we prioritize LHH response (discussed in 2017-2-2)	

	* This module was asked in the LHH for households that:
	* 	a) Have no LHH (a9 == 2)
	*	b) Household head was female
		mdesc k6_1
		mdesc k6_1 if (hh_head_gender == 2 | a9 == 2) // 272 
		
	* For the rest of the households, the info of module K is in the MHHH survey (i.e. variables with prefix "_m")
		mdesc k6_1_m
		mdesc k6_1_m if hh_head_gender == 1  & a8 == 1 // the 49 households without MHHH survey
	
	* Gen variable for respondent of that section
		gen replace_modules = (hh_head_gender==1 & !mi(k6_1_m))
		
		gen 	respondent_productive_act = 1 if replace_modules==1
		replace respondent_productive_act = 2 if hh_head_gender==2
		replace respondent_productive_act = 2 if hh_head_gender==1 & (mi(k6_1_m) & !mi(k6_1)) 
		replace respondent_productive_act = 1 if hh_head_gender == 1  & a8 == 1 // 49 missing MHHH surveys 
		lab var respondent_productive_act "Respondent of the productive activities module"
		lab def respondent_productive_act_l 1 "MHHH" 2 "LHH"
		lab val respondent_productive_act respondent_productive_act_l
		order 	respondent_productive_act, before(k6_1)
		drop 	replace_modules
		tab 	respondent_productive_act
	
	* Replace variables when needed
		qui ds	k6_1-k30_2_9_19
		loc	ModuleK_LHH 	`r(varlist)'	
		
		* Livestock
			qui ds k6_1 - k8_15
			loc livestock_replace `r(varlist)'
			
		* Products	
			qui ds k9_1 - k14
			loc product_replace `r(varlist)'
		
		* Crops
			qui ds k15_1 - k22
			loc crop_replace `r(varlist)'
			
		* Businesses
			qui ds k23_a_1 - h27_15
			loc biz_replace `r(varlist)'
			
		* Labor - respondent 
			qui ds k1_1_1 - k4_1_9 
			loc labor_replace `r(varlist)'
			
		* Module J: Entrepeneurship
			qui ds j6 - j5
			loc modulej `r(varlist)'
			
		* Replace
			foreach	var	of varlist `livestock_replace' `product_replace' `crop_replace' `biz_replace' `labor_replace' `modulej'	{
				di "`var'"
				assert !(!mi(`var') & !mi(`var'_m))
				replace	`var'=`var'_m	if	mi(`var') & !mi(`var'_m)
				drop	`var'_m
			}	

*--------------------*
* Credit and savings *
*--------------------*

	* For this module we have responses of both the LHH and the MHHH. 
	* Male responses are prioritized (as in Baseline do files in Line 1078 of dofile "TUP_Afghanistan/Data Analysis/TUP Baseline/Dofiles/Construction/bl_compile.do").
	* Vars with suffix _f will be LHH responses, _m will be MHHH responses, and 
	* no suffix will be the ones used for analysis (i.e. when male responses are prioritized).
	
	* Rename LHH variables with suffix
		foreach var of varlist m21_1- m32__99 {
			rename `var' `var'_f
		}
		
	* List of variables for which we have both female and male responses	
		local modulem_list m21_1 m21_2 m21_3 m21_4 m21_5 m21_6 m21__97 m21__99 /*m21_o*/ m23 m24_1 m24_2 m24__97 m22_0 m22_1 m22_2 m22_3 m22_4 m22_5 m22_6 m22_7 m22_8 m22_9 m22__97 m22__98 m22__99 /*m22_o*/ m1 m1_a /*mloan_relation_formal*/ m5 m6_1 m6_2 m6_3 m6_4 m6_5 m6__98 m6__99 /*m6_o*/ m6_a_1 m6_a_2 m6_a_3 m6_a_4 m6_a_5 m6_a_6 m6_a_7 m6_a_8 m6_a_9 m6_a__97 m6_a__98 m6_a__99 /*m6_a_o*/ m10 m11_1 m11_2 m11__97 m11__98 m11__99 /*m11_o*/ m12_1 m12_2 m12_3 m12_4 m12_5 m12__97 m12__98 /*m12_o*/ m12_h_1 m12_h_2 m12_h_3 m12_h_4 m12_h_5 m12_h__97 m12_h__98 /*m12_h_o*/ m12_other_1 m12_other_2 m12_other_3 m12_other_4 m12_other_5 m12_other__97 m12_other__98 /*m12_other_o*/ m13_1 m13_2 m13_3 m13_4 m13_5 m13_6 m13_7 m13_8 m13_9 m13__97 m13__98 m13__99 /*m13_o*/ m16 m17_1 m17_2 m17_3 m17_4 m17_5 m17_6 m17__97 m17__99 /*m17_o*/ m19 m20_a m20 /*mhaveacct*/ m25_y m25_m m26_y m26_m m27_0 m27_1 m27_2 m27_3 m27_4 m27_5 m27__97 /*m27_o*/ m28_0 m28_1 m28_2 m28_3 m28_4 m28_5 m28__97 /*m28_o*/ m29 m30 m30_a m31 m31_a m31_a_a m32_1 m32_2 m32_3 m32_4 m32_5 m32_6 m32_7 m32_8 m32_9 m32__97 m32__99 /*m32_o mloans_count*/
		
		foreach var of local modulem_list {
				di "`var'"
				clonevar `var' = `var'_m // Copy male response
				cap	confirm	numeric	variable	`var'	
					if	_rc==7	{	// string
						replace		`var'=`var'_f	if	(mi(`var'_m) & !mi(`var'_f)) // Copy female response if male response is missing
					}
					else	{	// numeric. The reason for not using the code above is to preserve extended missing values in numeric variables (ex. .d, .r)
						replace		`var'=`var'_f	if	((`var'_m==.) & (`var'_f!=.)) // Copy female response if male response is missing
					}		
			}
		
	* Now for the loans roster
		loc loan_roster_list  /*loan_id*/ m2_ /*m2_o loan_relation*/ m3_1_ m3_2_ m3_3_ m3_4_ m3_5_ m3_6_ m3_7_ m3_8_ m3_9_ m3_10_ m3_11_ /*m3_o*/ m4_
		
		* For the LHH we only have until 9 loans, we create the rest of the empty variables
			foreach loan of numlist 10(1)15 {
				foreach var of local loan_roster_list {
						di "`var'`loan'"
							clonevar `var'`loan'_f = `var'`loan'_m 
							* replace to missing
								cap	confirm	numeric	variable	`var'`loan'_f
								if	_rc==7	{	// string
									replace		`var'`loan'_f=""
								}
								else	{	// numeric. 
									replace		`var'`loan'_f=.
								}					
						}
					}	

		order m2_10_f-m4_15_f, after(m4_9_f)
		
		foreach loan of numlist 1(1)15 {
			foreach var of local loan_roster_list {
					di "`var'`loan'"
					clonevar `var'`loan' = `var'`loan'_m 
						cap	confirm	numeric	variable	`var'`loan'
						if	_rc==7	{	// string
							replace		`var'`loan'=`var'`loan'_f	if	(mi(`var'`loan'_m) & !mi(`var'`loan'_f)) // Copy female response if male response is missing
						}
						else	{	// numeric. The reason for not using the code above is to preserve extended missing values in numeric variables (ex. .d, .r)
							replace		`var'`loan'=`var'`loan'_f	if	((`var'`loan'_m==.) & (`var'`loan'_f!=.)) // Copy female response if male response is missing
						}		
				}				
					
			}

		* Order variables
		order m2_1 - m4_15, after(m1_a)
		order m21_1 - m32__99, before(m21_1_f)

*--------------------------------------------------*
* Replace variables when respondent of LHH is male *
*--------------------------------------------------*
		
* Psychological well-being
	foreach	var	of varlist i5 - i47	{
		di	"current var is `var'"
		replace	`var'_m	=	`var'	if	respondent_gender == 1
			
		cap	confirm	numeric	variable	`var'
			if	_rc==7	{
				replace	`var'	=	""	if	respondent_gender == 1
			}
			else	{
				replace	`var'	=	.	if	respondent_gender == 1
			}
		}	

	tempfile	LHH_MHHH_flagmerged
	save		`LHH_MHHH_flagmerged'
			
*-------------------------*
* Append targeting survey *
*-------------------------*
	append using "${Targ_interm_bl_nopii}"
	order b5_20-b14_b_month31, after(b14_b_month19)
	
	
********************************************************************************
* Creating Primary male and female variables
********************************************************************************	
*	This section is designed to run additional cleaning which could not be done in previous parts.
*	For example, cleaning labor module requires the information of primary male & female, which need to be done after appending targeting data	
	
* Camila, 17Nov2019: This was done by SML a long time ago. I'm just checking the code but
* 					 not modified a lot since there was a long discussion at the moment.	
* Changes made by Camila on 17Nov2019 wrt original code:
* 1. Do not create name variables since this is nopii data
* 2. Fix issue with opposite_gender local because it was not working for the primary female
	
		* Declare macros for loop below.
			loc	gender1	male
			loc	gender2	female
			
		/* Number of spouses
			egen 	number_of_spouse = anycount(b5_? b5_1? b5_2? b5_3?), values(1)	// Number of family members who are listed as "spouse"
			lab	var	number_of_spouse	"Number of spouses household head has"*/
			
						
		* Labeling primary male/female status
			lab	define	primary_member_status	0	"No primary male"	///
												1	"Household head"	///
												2	"Spouse of household head"	///
												3	"Daughter/Son of household head"	///
												4	"Mother/Father of household head"	///
												5	"Others"
			
			loc	opposite_gender1=2	//	In the loop below, the first loop is male(==1), thus the opposite gender should be female(==2)
			loc	opposite_gender2=1
			loc	opposite_gender=1
			
			forval	gcode=1/2	{	// gender
			
				*gen	str		primary_`gender`gcode''_name=""			// Name of primary male
				gen	byte	primary_`gender`gcode''_status=.		// Status of primary male (ex. household head, spouse, son, father, ...)
				lab	value	primary_`gender`gcode''_status	primary_member_status
				gen	byte	primary_`gender`gcode''_age=.			// Age of primary male/female
				gen	byte	primary_`gender`gcode''_position=.		// Position of primary male/female (i.e. primary male is xth member in household roster)
				gen	byte	primary_`gender`gcode''_schoolyear=.	// Schooling year of primary male/female
				gen	byte	primary_`gender`gcode''_literacy=.		// Literacy of primary male/female
				
				*lab	var		primary_`gender`gcode''_name		"Name of primary `gender`gcode''"
				lab	var		primary_`gender`gcode''_age			"Age of primary `gender`gcode''"
				lab	var		primary_`gender`gcode''_status		"Status of primary `gender`gcode''"
				lab	var		primary_`gender`gcode''_position	"Position of primary `gender`gcode''"
				lab	var		primary_`gender`gcode''_schoolyear	"Schooling year of primary `gender`gcode''"
				lab	var		primary_`gender`gcode''_literacy	"Can primary `gender`gcode'' read and write?"
			
				
				* 1) If HH head is male/female and at least 15-year-old, he/she is likely to be the primary male/female
				*replace	primary_`gender`gcode''_name		=	hhhead_name	if	(hhhead_gender==`gcode') & (b8_1>=15)
					di "CASE 1: HH Head is primary male/female if at least 15yo"
					di "Primary `gender`gcode''"
					replace	primary_`gender`gcode''_age			=	b8_1		if	(hh_head_gender==`gcode') & (b8_1>=15)
					replace	primary_`gender`gcode''_status		=	1			if	(hh_head_gender==`gcode') & (b8_1>=15)
					replace	primary_`gender`gcode''_position	=	1			if	(hh_head_gender==`gcode') & (b8_1>=15)

				* 2) If HH head is female/male, her/his spouse (15-year-old or older) is likely to be the primary male/female.
					di "CASE 2: HH Head's spouse is primary male/female if at least 15yo"
					di "Primary `gender`gcode''"
					forval	rosternum=2/31	{
						*replace	primary_`gender`gcode''_name	=	HH_member_name_`rosternum'	///
						*	if	((b5_`rosternum'==1) & (b6_`rosternum'==`gcode') & (hh_head_gender==`opposite_gender') & (b8_`rosternum'>=15) & mi(primary_`gender`gcode''_name)) // Some HH has more than one spouses. In this case, we take only the first spouse appears in the survey.
						replace	primary_`gender`gcode''_age = b8_`rosternum' ///
							if 	((b5_`rosternum'==1) & (b6_`rosternum'==`gcode') & (hh_head_gender==`opposite_gender`gcode'') & (b8_`rosternum'>=15) & mi(primary_`gender`gcode''_age)) 
						replace	primary_`gender`gcode''_status = 2 ///
							if 	((b5_`rosternum'==1) & (b6_`rosternum'==`gcode') & (hh_head_gender==`opposite_gender`gcode'') & (b8_`rosternum'>=15) & mi(primary_`gender`gcode''_status))
						replace	primary_`gender`gcode''_position = `rosternum'	///
							if 	((b5_`rosternum'==1) & (b6_`rosternum'==`gcode') & (hh_head_gender==`opposite_gender`gcode'') & (b8_`rosternum'>=15) & mi(primary_`gender`gcode''_position))
					}
	
				* 3) If there's no spouse in HH with female/male head, then her father/his mother as primary male/female.
					di "CASE 3: HH Head's father/mother is primary male/female"
					di "Primary `gender`gcode''"
					forval	rosternum=2/31	{
						*replace	primary_`gender`gcode''_name	=	HH_member_name_`rosternum'	///
						*	if	((b5_`rosternum'==8) & (b6_`rosternum'==`gcode') & (hhhead_gender==`opposite_gender') & mi(primary_`gender`gcode''_name)) // Some HH has more than one spouses. In this case, we take only the first spouse appears in the survey.
						replace	primary_`gender`gcode''_age = b8_`rosternum'	///
							if	((b5_`rosternum'==8) & (b6_`rosternum'==`gcode') & (hh_head_gender==`opposite_gender`gcode'') & (mi(primary_`gender`gcode''_age)))
						replace	primary_`gender`gcode''_status = 4	///
							if	((b5_`rosternum'==8) & (b6_`rosternum'==`gcode') & (hh_head_gender==`opposite_gender`gcode'') & (mi(primary_`gender`gcode''_status)))
						replace	primary_`gender`gcode''_position = `rosternum'	///
							if	((b5_`rosternum'==8) & (b6_`rosternum'==`gcode') & (hh_head_gender==`opposite_gender`gcode'') & (mi(primary_`gender`gcode''_position)))
					}
				/* SML: For now (2016-11-7), we don't regard sons/daughters as primary male/female.
				* 4) If female/male head has neither spouse nor parents, then assume son/daugher (15-year-old or older) could be primary male/female..
				forval	rosternum=2/31	{
					replace	primary_`gender`gcode''_name	=	HH_member_name_`rosternum'	///
						if	((b5_`rosternum'==2) & (b6_`rosternum'==`gcode') & (hhhead_gender==`opposite_gender') & (b8_`rosternum'>=15) & mi(primary_`gender`gcode''_name)) // Some HH has more than one spouses. In this case, we take only the first spouse appears in the survey.
					replace	primary_`gender`gcode''_age = b8_`rosternum'	///
						if	((b5_`rosternum'==2) & (b6_`rosternum'==`gcode') & (hhhead_gender==`opposite_gender') & (b8_`rosternum'>=15) & (primary_`gender`gcode''_name==HH_member_name_`rosternum') & (mi(primary_`gender`gcode''_age)))
					replace	primary_`gender`gcode''_status = 3	///
						if	((b5_`rosternum'==2) & (b6_`rosternum'==`gcode') & (hhhead_gender==`opposite_gender') & (b8_`rosternum'>=15) & (primary_`gender`gcode''_name==HH_member_name_`rosternum') & (mi(primary_`gender`gcode''_status)))
					replace	primary_`gender`gcode''_position = `rosternum'	///
						if	((b5_`rosternum'==2) & (b6_`rosternum'==`gcode') & (hhhead_gender==`opposite_gender') & (b8_`rosternum'>=15) & (primary_`gender`gcode''_name==HH_member_name_`rosternum') & (mi(primary_`gender`gcode''_position)))
				}
				*
				*/
				
				* 5) If none of the above applies, then primary male/female must be someone else
					qui	replace	primary_`gender`gcode''_status	=	5	if	mi(primary_`gender`gcode''_status)
							
				* Education
					forval	rosternum=1/31	{
						qui	replace	primary_`gender`gcode''_schoolyear	=	b16_`rosternum'	if	(`rosternum'==primary_`gender`gcode''_position)
					}
					
				* Literacy
					forval	rosternum=1/31	{
						qui	replace	primary_`gender`gcode''_literacy	=	b13_`rosternum'	if	(`rosternum'==primary_`gender`gcode''_position)
					}
					recode	primary_`gender`gcode''_literacy (3=1) (0 1 2=0) // Consider someone as "literate" only if s/he can read AND write
					
			}
			
	* If household head is female, then there is no primary male.
	** (SML, 2017-2-21): I added a new condition - hhhead is male but younger than 15-year-old. Can ask Lupe for clarification
		*replace	primary_male_name		=	"(Not Applicable)"	if ((hhhead_gender==2) | (hhhead_gender==1 & b8_1<15))
		replace	primary_male_age		=.n						if ((hh_head_gender==2) | (hh_head_gender==1 & b8_1<15))
		replace	primary_male_status		=0						if ((hh_head_gender==2) | (hh_head_gender==1 & b8_1<15))
		replace	primary_male_position	=.n						if ((hh_head_gender==2) | (hh_head_gender==1 & b8_1<15))
		replace	primary_male_schoolyear	=.n						if ((hh_head_gender==2) | (hh_head_gender==1 & b8_1<15))
		replace	primary_male_literacy	=.n						if ((hh_head_gender==2) | (hh_head_gender==1 & b8_1<15))
		
	* Added by Camila, 17Nov2019: If there is no LHH, then there is no primary female	
		replace	primary_female_age			=.n						if respondent_gender == 1
		replace	primary_female_status		=0						if respondent_gender == 1
		replace	primary_female_position		=.n						if respondent_gender == 1
		replace	primary_female_schoolyear	=.n						if respondent_gender == 1
		replace	primary_female_literacy		=.n						if respondent_gender == 1
			
	* Rename primary_male and primary_female to have "_pm" and "_pf" suffix
		rename (primary_male_* primary_female_*)	(*_pm *_pf)
		
	* Save dataset and keep correct households (i.e. !mi(hhid))
		drop if mi(hhid)
		
*---------------------------*
* Dropping wrong households *
*---------------------------*		
		
	preserve
	
	* Prepare profile info
		use "${profile_info}", clear
		drop if mi(bl_hhid) & mi(bl_key)
		isid bl_key
		keep bl_key bl_oth_hh bl_oth_hh_why treatment bl_key pweight ultra_poor CDCID PRA_lottery WealthRankingCategory_v pweight_CWR pweight
		tempfile profile
		save	`profile'
		
	restore
	
	* Merge flags from baseline
		merge 1:1 bl_key using `profile', assert(2 3) keep(3) nogen
		drop bl_key KEY_m
		
	* Drop wrong HHs
		tab bl_oth_hh ultra_poor 
		count if bl_oth_hh==1 & ultra_poor == 1
		assert r(N) == 9
		drop if bl_oth_hh==1 & ultra_poor == 1
		assert _N == 2852		
			
			
	if	`c(stata_version)'>=14	{
		saveold "${all_HH_interm_nopii_bl}", replace v(13)
	}
	else {
		save "${all_HH_interm_nopii_bl}", replace
	}		

	
********************************************************************************
	** Part 4: Additional cleaning
********************************************************************************
		
* Clean rosters
	do "${Baseline_do}/Cleaning/preparing_and_cleaning_rosters_bl.do"
		
	use "${all_HH_interm_nopii_bl}", clear		
		
* Drop roster variables
	* Module B: Household Roster (B)
		drop b3 b5_* b6_*  b8_* b9_* b11_* b12_* b16_* b13_* b15_* b15_b* b14_* b14_a* b14_a_month* b14_b*
			 
	* Module K: Productive Activities and Assets (K)
		drop k15* k16* k17* k19* k20* k21*
		drop k23_a* k24* k26_m* k26_y* k27* k28* k29* k31* k32* k33* k34* k35* k25*
		drop k6* k7* k8* k14
		drop k9* k10* k12* k13*
		drop k30_?_1 k30_?_2  k30_?_3  k30_?_4  k30_?_5  k30_?_6  k30_?_7  k30_?_8  k30_?_9  k30_?_10  k30_?_11  k30_?_12  k30_?_13  k30_?_14  k30_?_15  k30_?_16  k30_?_17  k30_?_18  k30_?_19 /*k30_o*/ ///
				 k30_1_?_1 k30_1_?_2 k30_1_?_3 k30_1_?_4 k30_1_?_5 k30_1_?_6 k30_1_?_7 k30_1_?_8 k30_1_?_9 k30_1_?_10 k30_1_?_11 k30_1_?_12 k30_1_?_13 k30_1_?_14 k30_1_?_15 k30_1_?_16 k30_1_?_17 k30_1_?_18 k30_1_?_19 ///
				 k30_2_?_1 k30_2_?_2 k30_2_?_3 k30_2_?_4 k30_2_?_5 k30_2_?_6 k30_2_?_7 k30_2_?_8 k30_2_?_9 k30_2_?_10 k30_2_?_11 k30_2_?_12 k30_2_?_13 k30_2_?_14 k30_2_?_15 k30_2_?_16 k30_2_?_17 k30_2_?_18 k30_2_?_19 k30_10_* k30_11_* k30_12_* k5_1*
		drop k1_1_* k2_1_* k2_1_hr* k3_1_* k3_1o* k4_1_*
		
	* Module 3: Consumption (C)
		drop c3* c4* c5* c6* c7* c8* c9* c10* c11* c12* c13*
			
	* Module L: and Other Asset Ownership (L)
		drop l1* l2* l3* l4* l5*
		
	* Module M: Credit and Savings (M)
		drop m1_a* m2_* m3_* m4_*
		replace m5 = .d if m5 == 99 //There are many 99 which looks like a mistake for a -99
		
		* Drop _m variables since they are incorporated in those w/o a suffix; keep _f variables to retain LHH values
		unab emm: m*_m
		local dontdrop m26_m m25_m
		local todrop: list emm - dontdrop
		di "`todrop'"
		drop `todrop'
	
	* Module D: Transfers and Shocks (G)
		drop d2* d3* d8* d9* d10*
		
		unab dee: d1*
		local dontdrop d13
		local todrop: list dee - dontdrop
		di "`todrop'"
		drop `todrop'
		
		drop g1* g2* 
		
	*Looking at outliers for total loans (m5 variable) and saving variable
		qui do "${Baseline_do}/Cleaning/saving_outliers_bl.do"
	
	* Drop flags from loans
		drop flag_outlier
		
		preserve 
			use "$loans_bl", clear
			drop flag_diff flag_outlier
			
			save, replace
		restore
		
	/* Re-order variables such that they match the new alphabetical order of the survey
		
			MODULE 2: HOUSEHOLD ROSTER (B)
			MODULE 3: CONSUMPTION (C): c1 - c14_7, after(a8_m_notav_perm)
			MODULE 4: TRANSFERS AND SAFETY NETS (D): 
			MODULE 5: HOUSING CHARACTERISTICS (E): ec - e16, after(e11) 
			MODULE 6: HEALTH AND HEALTH-SEEKING (F)
			MODULE 7: SHOCKS (G)
			MODULE 8: WOMEN'S DECISION MAKING ON HOUSEHOLD EXPENDITURES (H)
			MODULE 9: ASPIRATIONS, PERCEPTIONS AND PSYCHOLOGICAL WELL-BEING (I)
			MODULE 10: ENTREPRENEURSHIP (J) (IF HOUSEHOLD HEAD IS FEMALE OR HH DOES NOT HAVE A LADY OF THE HH): j6 - j5, after(i47) 
			MODULE 11: PRODUCTIVE ACTIVITIES (K): k22 - k14, after(j5)
			MODULE 12: OTHER ASSET OWNERSHIP (L)
			MODULE 13: CREDIT AND SAVINGS (M): m37 - m32__98, after(k14)
			MODULE 14: SOCIAL PARTICIPATION AND AWARENESS (N), CONFLICT AND VIOLENCE (O): n1 n2, after(m32__98) o1 - o3__99, after(n2)
			MODULE 16: FRAGILITY (S), MIGRATION (T), RELIGION (U-1) AND COMMUNITY & EMOTIONS (U-2): u1 - u4, after(t11)	 */

			* LHH, Targeting re-ordering
			order time, after(date)
			order survey, after(time)
			order c1 - c14_7, after(a11)
			order d6, after(c14_7)
			order e12 - e16, after(e11)
			order consent_direct_obs, before(e12)
			order j1 - j5, after(i47) 
			order respondent_productive_act k22, after(j26)
			order h25_1 - h27_15, after(h24)
			
			order time_m, after(date_m)
			order survey_m, after(time_m)
			order treatment ultra_poor, after(bl_hhid)
			
			order hh_head_gender respondent_gender *_pm *_pf, last
			
			drop q7 q7_m // potentially PII
			drop resp_not_present_m
			drop MHHH_available LHH_available
			
			* Apply codebook
			iecodebook apply using "${TUP_DB}\Baseline\Documentation\template_bl.xlsx"
		
			* Save data 
			save "${all_HH_nopii_bl}", replace
	
		
		