/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Sep 12, 2016
Last udpate on: Nov 8, 2019

Written by:  	Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com) and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans Lady of the Household, Baseline survey. 


CONTENT:		
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/	


********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* LHH Household Survey
		global LHH_allsvys_raw_bl_nopii "${TUP_DB}/Baseline/DataSets/Raw/LHH_allsvys_raw_bl_nopii.dta"

* Outputs

	* Wide format
		global LHH_interm_bl_nopii "${TUP_DB}/Baseline/DataSets/Intermediate/LHH_interm_bl_nopii.dta"			


********************************************************************************
	** Part 1: Module Data Cleaning
********************************************************************************
	
use "${LHH_allsvys_raw_bl_nopii}", clear

*----------------*
* Basic cleaning *
*----------------*

	* Survey respondent present
		loc	var		resp_not_present
		gen	byte	`var'=0		
		order 		`var'
		/* gen `var'=1	if (a8!=1 & a9!=2) // SML: This is Garima's previous code, but it is different from SurveyCTO code. */
		replace		`var'=1	if	(a8!=1 & a8_m!=1)	// SML: This is how SurveyCTO is programmed
		lab	var		`var'	"No respondent (LHH or MHHH) available. If NOT, survey was not done."
		note		`var':	gen	`var'=1	if	(a8!=1 & a8_m!=1)
		
	* LHH available
		loc	var		LHH_available
		gen	byte	`var'=0													
		order 		`var', after(a9_o)
		replace		`var'=1	if	a8==1
		lab	var		`var'	"HH has Lady of Household and available"
		note		`var':	This variable is generated by `name_do'.do
		
	* MHHH available (when LHH is not available)
		loc	var		MHHH_available
		gen byte	`var'=a8_m
		*replace	`var'=.b	if	(LHH_available==0 & mi(a8_m)) 
		order		`var',after(a9_o_m)
		lab	var		`var'	"Male HH head is available for survey (if LHH is not available)"

	* Labels
		lab	var	a10	"What is your primary language?"
		lab	var	a11	"Please select the language that is used to conduct this interview."

	* Survey
		gen survey = 1
			lab define survey 1 "LHH" 2 "MHHH" 3 "Targeting" 
			lab val survey survey
			lab var survey "Type of survey administered"
	
	* Enumerator ID, name, and gender
			lab var a2 "Interviewer ID"
			assert !mi(a2)

	* Supervisor ID and name
			lab var a3 "Supervisor ID"
			assert !mi(a3)
	
	* Date
		gen		temp=date(date_f,"DMY") 
		order	temp,after(date_f) 
		drop	date_f
		rename	temp	date_f
		format	date_f	%td
		drop if	date_f < 20512
			
		drop		date
		clonevar	date	=	date_f
		replace		date	=	date_a	if	date_v==0
		lab	var		date	"Survey Date"
	
	* Consent vars
		lab var a12 "Survey was consented"
	
	* Survey complete
		gen complete = (a12==1)
			lab var complete "Survey was completed"
			lab val complete yesno
				
	* Respondent gender
		gen respondent_gender = . 
			lab var respondent_gender "Respondent gender (calculated)"
			lab def gender 1 "Male" 2 "Female"
			lab val respondent_gender gender
			replace respondent_gender = 2 if (a8==1 | a9==1) // if LHH is available or not at home
			replace respondent_gender = 1 if (a8_m==1 | a9_m==1) // if MHHH is available or not at home
 
	* Time vars
	
		* Survey time
			gen	double	time_final	=	clock(time,"hms")
			replace		time_final	=	time_a	if	time_v==0
			format		time_final %tcHH:MM:SS
			replace		time_final	=	time_final	+	(date*24*60*60*1000)
			drop		time
			rename		time_final	time
			lab	var		time	"Survey Time"
		
		* Time after consent	&	time after the last question
			gen double	time_start	=	clock(time_startinteraction,"YMD hms")
			gen	double	time_end	=	clock(qtime_end_q,"YMD hms")
			
			format		time_start	time_end %tcHH:MM:SS
			lab	var		time_start	"Time after consent"
			lab	var		time_end	"Time after the last question"
				
	* Household Head gender
		loc	var		hh_head_gender
		gen	byte	`var'=bhh_head_gender										
		lab	var		`var'	"HH head gender (from LHH roster, SurveyCTO-captured)"
		lab val hh_head_gender b6_1
		drop bhh_head_gender		
		
*--------------------*
* Cleaning by module *
*--------------------*			

	* B: Household Roster 
	
		* Modify prefix
		rename	age_all*			*
		rename	length_of_stay*		*
		rename	madrassa_duration*	*
		rename	mosque_duration*	*
		rename  bb3 				b3

	* K. Productive Activities and Assets
	
		* Modify Prefix
		rename	kk*			k*
		rename	LabOth_act*	*
		rename	kLabResp*	*
		rename	Labor*		*
		rename	ktime_begin_k	time_begin_k
		rename	busilength*	*
			
		* Label & Rename variables
		lab	var	livestock	"HH owns any livestock"
		lab	var	crop		"HH cultivates any crop"
		lab	var	business	"HH owns or operates any business"
		
		rename	(livestock		crop	business)	///
				(k_livestock	k_crop	k_business)
				
		*	Livestock
			rename k6_* k6_temp_*
			forval	livestock_num=1/15	{
				egen	k6_`livestock_num'	=	anymatch(k6_temp_? k6_temp_1?), value(`livestock_num')
				replace	k6_`livestock_num'	=.	if	hh_head_gender!=2 & a9!=2
			}
			egen	k6__98	=	anymatch(k6_temp_? k6_temp_1?), value(-98)
			egen	k6__99	=	anymatch(k6_temp_? k6_temp_1?), value(-99)
			
			replace	k6__98	=.	if	hh_head_gender!=2 & a9!=2
			replace	k6__99	=.	if	hh_head_gender!=2 & a9!=2
			
			lab	var	k6_1	"Livestock household owns includes: Cows"
			lab	var	k6_2	"Livestock household owns includes: Bulls"
			lab	var	k6_3	"Livestock household owns includes: Horses"
			lab	var	k6_4	"Livestock household owns includes: Donkeys"
			lab	var	k6_5	"Livestock household owns includes: Goats"
			lab	var	k6_6	"Livestock household owns includes: Sheep"
			lab	var	k6_7	"Livestock household owns includes: Chickens"
			lab	var	k6_8	"Livestock household owns includes: Ducks"
			lab	var	k6_9	"Livestock household owns includes: Turkeys"
			lab	var	k6_10	"Livestock household owns includes: Gooses"
			lab	var	k6_11	"Livestock household owns includes: Rabbits"
			lab	var	k6_12	"Livestock household owns includes: Guinea fowl"
			lab	var	k6_13	"Livestock household owns includes: Bee hives"
			lab	var	k6_14	"Livestock household owns includes: Other animal 1 (please specify)"
			lab	var	k6_15	"Livestock household owns includes: Other animal 2 (please specify)"
			lab	var	k6__98	"Livestock household owns includes: None"
			lab	var	k6__99	"Livestock household owns includes: Don't know"
			
			rename	(k6_temp_o1 k6_temp_o2)	(k6_o1	k6_o2)
			lab	var	k6_o1	"If other, please specify (1)"
			lab	var	k6_o2	"If other, please specify (2)"
			lab	val	k6_1-k6__99	yesno

			drop	k6_temp_*
			order	k6_1-k6__99, before(k6_o1)		

		*	Household product
		
			rename k9_* k9_temp_*

			forval	HHproduct_num=1/8	{
				egen	k9_`HHproduct_num'	=	anymatch(k9_temp_? k9_temp_10), value(`HHproduct_num')
				replace	k9_`HHproduct_num'	=.	if	hh_head_gender!=2 & a9!=2
			}
			egen	k9__98	=	anymatch(k9_temp_? k9_temp_10), value(-98)
			egen	k9__99	=	anymatch(k9_temp_? k9_temp_10), value(-99)
			
			replace	k9__98	=.	if	hh_head_gender!=2 & a9!=2
			replace	k9__99	=.	if	hh_head_gender!=2 & a9!=2
			
			lab	var	k9_1	"Household product includes: Milk"
			lab	var	k9_2	"Household product includes: Egg"
			lab	var	k9_3	"Household product includes: Honey"
			lab	var	k9_4	"Household product includes: Butter"
			lab	var	k9_5	"Household product includes: Yogurt"
			lab	var	k9_6	"Household product includes: Meat"
			lab	var	k9_7	"Household product includes: Other 1 (please specify)"
			lab	var	k9_8	"Household product includes: Other 2 (please specify)"
			lab	var	k9__98	"Household product owns includes: None"
			lab	var	k9__99	"Household product owns includes: Don't know"
			
			rename (k9_temp_o1 k9_temp_o2) (k9_o1 k9_o2) 
			lab	var	k9_o1	"If other, please specify (1)"
			lab	var	k9_o2	"If other, please specify (2)"
			lab	val	k9_1-k9__99	yesno

			drop	k9_temp_1-k9_temp_10 kdkna_produce
			order	k9_1-k9__99, before(k9_o1)			
				
		*	Crops
		
			rename k15_* k15_temp_*

			forval	crop_num=1/27	{
				egen	k15_`crop_num'	=	anymatch(k15_temp_? k15_temp_1? k15_temp_2?), value(`crop_num')
				replace	k15_`crop_num'	=.	if	hh_head_gender!=2 & a9!=2
			}
			
			egen	k15__98	=	anymatch(k15_temp_? k15_temp_1? k15_temp_2?), value(-98)
			egen	k15__99	=	anymatch(k15_temp_? k15_temp_1? k15_temp_2?), value(-99)
			
			replace	k15__98	=.	if	hh_head_gender!=2 & a9!=2
			replace	k15__99	=.	if	hh_head_gender!=2 & a9!=2
			
			lab	var	k15_1	"Crop cultivated includes: Wheat"
			lab	var	k15_2	"Crop cultivated includes: Vetch"
			lab	var	k15_3	"Crop cultivated includes: Maize"
			lab	var	k15_4	"Crop cultivated includes: Barely"
			lab	var	k15_5	"Crop cultivated includes: Rice"
			lab	var	k15_6	"Crop cultivated includes: Weed"
			lab	var	k15_7	"Crop cultivated includes: Sesame"
			lab	var	k15_8	"Crop cultivated includes: Clover"
			lab	var	k15_9	"Crop cultivated includes: Millet"
			lab	var	k15_10	"Crop cultivated includes: Sharsham"
			lab	var	k15_11	"Crop cultivated includes: Sugarcane"
			lab	var	k15_12	"Crop cultivated includes: Cotton"
			lab	var	k15_13	"Crop cultivated includes: Caraway-seed"
			lab	var	k15_14	"Crop cultivated includes: Potato"
			lab	var	k15_15	"Crop cultivated includes: Cereal"
			lab	var	k15_16	"Crop cultivated includes: Eggplant"
			lab	var	k15_17	"Crop cultivated includes: Tomato"
			lab	var	k15_18	"Crop cultivated includes: Onion"
			lab	var	k15_19	"Crop cultivated includes: Okra"
			lab	var	k15_20	"Crop cultivated includes: Fruits from a tree"
			lab	var	k15_21	"Crop cultivated includes: Grape"
			lab	var	k15_22	"Crop cultivated includes: Mellon"
			lab	var	k15_23	"Crop cultivated includes: Opium"
			lab	var	k15_24	"Crop cultivated includes: Zaghar"
			lab	var	k15_25	"Crop cultivated includes: Saffron"
			lab	var	k15_26	"Crop cultivated includes: Other 1 (please specify)"
			lab	var	k15_27	"Crop cultivated includes: Other 2 (please specify)"
			lab	var	k15__98	"Crop cultivated includes: None"
			lab	var	k15__99	"Crop cultivated includes: Don't know"
			
			rename (k15_temp_o1 k15_temp_o2) (k15_o1 k15_o2)
			lab	var	k15_o1	"If other, please specify (1)"
			lab	var	k15_o2	"If other, please specify (2)"
			lab	val	k15_1-k15__99	yesno

			drop	k15_temp_1-k15_temp_29 kdkna_crop
			order	k15_1-k15__99, before(k15_o1)		
		
		* Business
			rename k23_a* k23_a_temp_*
			forval	biz_num=1/15	{
				egen	k23_a_`biz_num'	=	anymatch(k23_a_temp_? k23_a_temp_1?), value(`biz_num')
				replace	k23_a_`biz_num'	=.	if	hh_head_gender!=2 & a9!=2
			}
			egen	k23_a__98	=	anymatch(k23_a_temp_? k23_a_temp_1?), value(-98)
			egen	k23_a__99	=	anymatch(k23_a_temp_? k23_a_temp_1?), value(-99)
			
			replace	k23_a__98	=.	if	hh_head_gender!=2 & a9!=2
			replace	k23_a__99	=.	if	hh_head_gender!=2 & a9!=2
			
			lab	var	k23_a_1		"Business includes: Selling crafts (baskets, pots, etc.)"
			lab	var	k23_a_2		"Business includes: Repairing bicycles"
			lab	var	k23_a_3		"Business includes: Selling prepared foods/run restaurant"
			lab	var	k23_a_4		"Business includes: Selling raw produce (NOT cultivated by respondent but purchased elsewhere)"
			lab	var	k23_a_5		"Business includes: Providing transportation"
			lab	var	k23_a_6		"Business includes: Making bricks"
			lab	var	k23_a_7		"Business includes: Butchering"
			lab	var	k23_a_8		"Business includes: Doing carpentry"
			lab	var	k23_a_9		"Business includes: Selling clothes and sheets"
			lab	var	k23_a_10	"Business includes: Building thatch or iron sheet roofs"
			lab	var	k23_a_11	"Business includes: Constructing houses/buildings"
			lab	var	k23_a_12	"Business includes: Drilling boreholes/building latrines"
			lab	var	k23_a_13	"Business includes: Collecting and selling firewood"
			lab	var	k23_a_14	"Business includes: Other 1 (please specify)"
			lab	var	k23_a_15	"Business includes: Other 2 (please specify)"
			lab	var	k23_a__98	"Business includes: None"
			lab	var	k23_a__99	"Business includes: Don't know"
			
			rename	(k23_a_temp__o1 k23_a_temp__o2) (k23_a_o1 k23_a_o2)
			lab	var	k23_a_o1	"If other, please specify (1)"
			lab	var	k23_a_o2	"If other, please specify (2)"
			lab	val	k23_a_1-k23_a__99	yesno

			drop	k23_a_temp_1-k23_a_temp_17 kdkna_business
			order	k23_a_1-k23_a__99, before(k23_a_o1)
			
		* Activities for other household members
		
				/*
					(1) In male headed HHs with a LHH available:
						- Module K is not asked
						- LHHs were administered a subset of questions from the LHH survey 
						  and MHHHs were administered the MHHH survey.
							---> both LHH and MHHH surveys
					
					(2) Female headed households and HHs without a LHH available:
						- answered all questions through the complete LHH survey 
						- Module K is asked
						- Question for activities are identified with "_m" suffix
						  to distinguish them from the same questions answered by HHs which 
						  have LHH available and HHH is male.
						   ----> LHH survey only
					
					*** There are HHs which answered all the questions in LHH survey AND answered 
						questions in MHHH survey, which should not have happened.
						In this case, we prioritize LHH survey responses and discard MHHH responses.
					
					Here's the merging process of Module K
						0) Fix position for labor_m questions
						    For the way the survey was programmed, the position in the roster of labor_m repeat group starts
						    with household memeber number 2. We should fix the subindex so it matches the roster.
						1)	Import all the (non-missing) answers of the subset of question variables 
							(with _m suffix) into the same question variables (without _m suffix) 
							within LHH survey, so the variables without _m suffix have complete 
							responses from both type of HHs.
						2)	Drop the variables with _m suffix in LHH survey, since their responses 
							are imported into the variables without _m suffix
						3)	Import the (non-missing) responses of the rest of the questions from 
							MHHH survey into LHH survey, but DO NOT REPLACE if LHH responses are 
							non-missing (since we prioritize LHH survey responses)

				*/
			
			* 0) Fix position for labor_m questions
			* 	 For the way the survey was programmed, the position in the roster of labor_m repeat group starts
			* 	 with household memeber number 2. We should fix the subindex so it matches the roster.
			
				* This can be seen here
				* br nameofagecalcfield_m1 nameofagecalcfield1 b8_1 b8_2

				* First, we rename all variables with one number more 
					forval	Knum=1/11	{
						local i = `Knum' + 1
						rename nameofagecalcfield_m`Knum'  	nameofagecalcfield_m`i'_temp
						*rename labor_name_m`Knum' 			labor_name_m`i'_temp
						rename k5_1_m`Knum' 				k5_1_m`i'_temp
						rename k30_o_m`Knum' 				k30_o_m`i'_temp	
						
							forval	actnum=1/12	{
								rename k30_m`actnum'_`Knum'  k30_m`actnum'_`i'_temp
							}
					
							forval	actnum=1/9	{
								rename act_2_id_m`actnum'_`Knum'	act_2_id_m`actnum'_`i'_temp
								rename act_2_name_m`actnum'_`Knum' 	act_2_name_m`actnum'_`i'_temp
								rename k30_1_m`actnum'_`Knum' 		k30_1_m`actnum'_`i'_temp
								rename k30_2_m`actnum'_`Knum' 		k30_2_m`actnum'_`i'_temp
						}
					}
					rename *_temp *

				* Generate empty variables for member 1 
					gen nameofagecalcfield_m1 = .
					gen labor_name_m1 = .
					gen k5_1_m1 = .
					gen k30_o_m1 = .
	
					forval	actnum=1/12	{
						gen k30_m`actnum'_1 = .
					}	
				
					forval	actnum=1/9	{
						gen act_2_id_m`actnum'_1 = .
						gen act_2_name_m`actnum'_1 = ""
						gen k30_1_m`actnum'_1 = .
						gen k30_2_m`actnum'_1 = .
					}
						
					loc hhhead_kvars nameofagecalcfield_m1 labor_name_m1 k5_1_m1 k30_m1_1 k30_m2_1 k30_m3_1 ///
							k30_m4_1 k30_m5_1 k30_m6_1 k30_m7_1 k30_m8_1 k30_m9_1 k30_m10_1 k30_m11_1 ///
							k30_m12_1 k30_o_m1 act_2_id_m1_1 act_2_name_m1_1 k30_1_m1_1 k30_2_m1_1 act_2_id_m2_1 ///
							act_2_name_m2_1 k30_1_m2_1 k30_2_m2_1 act_2_id_m3_1 act_2_name_m3_1 k30_1_m3_1 k30_2_m3_1 ///
							act_2_id_m4_1 act_2_name_m4_1 k30_1_m4_1 k30_2_m4_1 act_2_id_m5_1 act_2_name_m5_1 ///
							k30_1_m5_1 k30_2_m5_1 act_2_id_m6_1 act_2_name_m6_1 k30_1_m6_1 k30_2_m6_1 act_2_id_m7_1 ///
							act_2_name_m7_1 k30_1_m7_1 k30_2_m7_1 act_2_id_m8_1 act_2_name_m8_1 k30_1_m8_1 k30_2_m8_1 ///
							act_2_id_m9_1 act_2_name_m9_1 k30_1_m9_1 k30_2_m9_1
						
					order 	`hhhead_kvars', after(position_plus1)				
				
				* For these households, we know that the answers in k1_1 - k4_1 correspond to the household head, who is 
				* member 1 in the roster. We replace the empty variables with this info.
				
					forval	actnum=1/12	{
						loca l_`actnum': variable label k30_m`actnum'_2
						replace k30_m`actnum'_1 = k1_1_`actnum'
						lab var k30_m`actnum'_1 "`l_`actnum''"
						lab val k30_m`actnum'_1 act_2
					}
					

					forval	actnum=1/9	{
						loc l_act_id_`actnum': variable label act_2_id_m`actnum'_2
						replace act_2_id_m`actnum'_1 = act_id`actnum'
						lab var act_2_id_m`actnum'_1 "`l_act_id_`actnum''"
						
						loc l_act_name_`actnum': variable label act_2_name_m`actnum'_2
						replace act_2_name_m`actnum'_1 = act_name`actnum'
						lab var act_2_name_m`actnum'_1 "`l_act_name_`actnum''"
						
						loc l_k30_1_`actnum': variable label k30_1_m`actnum'_2
						replace k30_1_m`actnum'_1 = k3_1_`actnum'
						lab var k30_1_m`actnum'_1  "`l_k30_1_`actnum''"
						
						loc l_k30_2_`actnum': variable label k30_2_m`actnum'_2
						replace k30_2_m`actnum'_1 = k4_1_`actnum'
						lab var k30_2_m`actnum'_1 "l_k30_2_`actnum'"
					}
							
			* 1) Import all the (non-missing) answers of the subset of question variables 
			*	 (with “_m” suffix) into the same question variables (without “_m” suffix) within LHH survey
				
					forval	Knum=1/11	{
					
						* Age
						replace	nameofagecalcfield`Knum'	=	nameofagecalcfield_m`Knum'	if	(nameofagecalcfield`Knum'==. & nameofagecalcfield_m`Knum'!=.)
						
						/*
						* Position variable used in SurveyCTO programming
						* SML: I decided to keep them here since two scenarios used two different position variables (plus, minus)
						* This variable is not needed in analysis, but can be useful when referring HH member
						order	position_plus`Knum', after(position_minus`Knum')
						*/
						
						* Other labor variables
						replace	k5_1_`Knum'	=	k5_1_m`Knum' if (k5_1_`Knum'==. & k5_1_m`Knum'!=.)
						
						forval	actnum=1/12	{
							replace	k30_`actnum'_`Knum'	=	k30_m`actnum'_`Knum'	if	((k30_`actnum'_`Knum'==.) & (k30_m`actnum'_`Knum'!=.))
						}
						replace	k30_o`Knum'	=	k30_o_m`Knum' if ((k30_o`Knum'==.) & (k30_o_m`Knum'!=.))
						
						* Labor activities
						forval	actnum=1/9	{
							
							replace	act_2_id`actnum'_`Knum'	=	act_2_id_m`actnum'_`Knum'	///
								if	((act_2_id`actnum'_`Knum'==.) & (act_2_id_m`actnum'_`Knum'!=.))
							replace	act_2_name`actnum'_`Knum'	=	act_2_name_m`actnum'_`Knum'	///
								if	(mi(act_2_name`actnum'_`Knum') & !mi(act_2_name_m`actnum'_`Knum'))
							replace	k30_1_`actnum'_`Knum'	=	k30_1_m`actnum'_`Knum'	///
								if	((k30_1_`actnum'_`Knum'==.) & (k30_1_m`actnum'_`Knum'!=.))
							replace	k30_2_`actnum'_`Knum'	=	k30_2_m`actnum'_`Knum'	///
								if	((k30_2_`actnum'_`Knum'==.) & (k30_2_m`actnum'_`Knum'!=.))
						}
					}
					
			* Activities (cleaning)
			rename k1_1_* k1_1_temp_*
			forval	act_num=1/9	{
				egen	k1_1_`act_num'	=	anymatch(k1_1_temp_? k1_1_temp_1?), value(`act_num')
				replace	k1_1_`act_num'	=.	if	hh_head_gender!=2 & a9!=2
			}
			egen	k1_1_0		=	anymatch(k1_1_temp_? k1_1_temp_1?), value(0)
			egen	k1_1__98	=	anymatch(k1_1_temp_? k1_1_temp_1?), value(-98)
			egen	k1_1__99	=	anymatch(k1_1_temp_? k1_1_temp_1?), value(-99)
			
			replace	k1_1_0		=.	if	hh_head_gender!=2 & a9!=2
			replace	k1_1__98	=.	if	hh_head_gender!=2 & a9!=2
			replace	k1_1__99	=.	if	hh_head_gender!=2 & a9!=2
			
			lab	var	k1_1_1		"Activity includes: Tend any animals owned or leased by the household"
			lab	var	k1_1_2		"Activity includes: Farm land owned or sharecropped by the household"
			lab	var	k1_1_3		"Activity includes: Work on business owned by household other than farm/animals (e.g. shop, crafts)"
			lab	var	k1_1_4		"Activity includes: Work as an agricultural laborer outside household"
			lab	var	k1_1_5		"Activity includes: Do housework in someone else's home"
			lab	var	k1_1_6		"Activity includes: Work as a non-agricultural laborer outside the household (other than housework)"
			lab	var	k1_1_7		"Activity includes: Work in salaried/formal employment"
			lab	var	k1_1_8		"Activity includes: Do any other work for pay  (money or in-kind)"
			lab	var	k1_1_9		"Activity includes: Work on household chores (e.g. collecting water, cooking, cleaning) in your household"
			lab	var	k1_1_0		"Activity includes: None"
			lab	var	k1_1__98	"Activity includes: Don't answer"
			lab	var	k1_1__99	"Activity includes: Don't know"
			
			lab	val	k1_1_1-k1_1__99	yesno
			drop	k1_1_temp_1-k1_1_temp_12
			order	k1_1_1-k1_1__99, before(k2_1_1)	
			
			* 2) Drop the variables with “_m” suffix in LHH survey, since their responses are imported into the variables without “_m” suffix
					drop nameofagecalcfield_m1-k30_2_m9_12
		
	* C. Consumption	
		rename	cc*		c*
		rename	c14*	*
		rename	c12*	*
		rename	c13*	*
		rename	ctime_begin_c	time_begin_c
		
			* Locals for names
				local c3_type "Bread"
				local c4_type "Meat"
				local c5_type "Dairy"
				local c6_type "Oils"
				local c7_type "Vegetables"
				local c8_type "Fruits"
				local c9_type "Sweets"
				local c10_type "Beverages"
				local c11_type "Spices"
				
			* Locals for counter	
				local c3_counter 13
				local c4_counter 10
				local c5_counter 12
				local c6_counter 4
				local c7_counter 25
				local c8_counter 20
				local c9_counter 5
				local c10_counter 5
				local c11_counter 7
				
			* Create correct variables
				* Rename variables
					foreach var in c3 c4 c5 c6 c7 c8 c9 c10 c11 {
						* Renames
						forval productnum=1/``var'_counter' {
							rename  `var'_`productnum' `var'_`productnum'_old
							}
						* Create var
						forval productnum=1/``var'_counter' {
							egen 	`var'_`productnum' = anymatch(`var'_1_old-`var'_``var'_counter'_old), value(`productnum')			
						}
						drop `var'_``var'_counter' 
						egen 	`var'_100 = anymatch(`var'_1_old-`var'_``var'_counter'_old), value(-100)
						order `var'_1-`var'_100, before(`var'_1_old)
					}
					drop *_old	
				
				
			* Labels
			lab	var	c3_1	"Bread consumed includes: Rice (high quality)"
			lab	var	c3_2	"Bread consumed includes: Rice (low quality)"
			lab	var	c3_3	"Bread consumed includes: Wheat flour"
			lab	var	c3_4	"Bread consumed includes: Naan not made at home"
			lab	var	c3_5	"Bread consumed includes: Barley"
			lab	var	c3_6	"Bread consumed includes: Maize"
			lab	var	c3_7	"Bread consumed includes: Beans"
			lab	var	c3_8	"Bread consumed includes: Mung"
			lab	var	c3_9	"Bread consumed includes: Chickpeas"
			lab	var	c3_10	"Bread consumed includes: Lentils"
			lab	var	c3_11	"Bread consumed includes: Pasta"
			lab	var	c3_12	"Bread consumed includes: Other bread and/or cereal"
			lab	var	c3_100	"Bread consumed includes: None"
					
			lab	var	c4_1	"Meat consumed includes: Beef"
			lab	var	c4_2	"Meat consumed includes: Veal"
			lab	var	c4_3	"Meat consumed includes: Mutton"
			lab	var	c4_4	"Meat consumed includes: Goat"
			lab	var	c4_5	"Meat consumed includes: Chicken"
			lab	var	c4_6	"Meat consumed includes: Liver"
			lab	var	c4_7	"Meat consumed includes: Dried Meat"
			lab	var	c4_8	"Meat consumed includes: Fish"
			lab	var	c4_9	"Meat consumed includes: Other meat and/or fish"
			lab	var	c4_100	"Meat consumed includes: None"				
		
			lab	var	c5_1	"Dairy consumed includes: Milk (fresh)"
			lab	var	c5_2	"Dairy consumed includes: Milk (powdered)"
			lab	var	c5_3	"Dairy consumed includes: Yogurt"
			lab	var	c5_4	"Dairy consumed includes: Curd (chaka)"
			lab	var	c5_5	"Dairy consumed includes: Krut (dried)"
			lab	var	c5_6	"Dairy consumed includes: Dogh"
			lab	var	c5_7	"Dairy consumed includes: Ghee"
			lab	var	c5_8	"Dairy consumed includes: Butter"
			lab	var	c5_9	"Dairy consumed includes: Cheese"
			lab	var	c5_10	"Dairy consumed includes: Eggs"
			lab	var	c5_11	"Dairy consumed includes: Other dairy products"
			lab	var	c5_100	"Dairy consumed includes: None"
					
			lab	var	c6_1	"Oil consumed includes: Vegetable oil, cotton oil or sesame oil"
			lab	var	c6_2	"Oil consumed includes: Animal fat"
			lab	var	c6_3	"Oil consumed includes: Other oils and fat"
			lab	var	c6_100	"Oil consumed includes: None"	
			
			lab	var	c7_1	"Vegetables consumed includes: Potato"
			lab	var	c7_2	"Vegetables consumed includes: Sweet potato"
			lab	var	c7_3	"Vegetables consumed includes: Onion"
			lab	var	c7_4	"Vegetables consumed includes: Tomato"
			lab	var	c7_5	"Vegetables consumed includes: Okra"
			lab	var	c7_6	"Vegetables consumed includes: Spinach"
			lab	var	c7_7	"Vegetables consumed includes: Cauliflower"
			lab	var	c7_8	"Vegetables consumed includes: Eggplant"
			lab	var	c7_9	"Vegetables consumed includes: Carrots"
			lab	var	c7_10	"Vegetables consumed includes: Pumpkin, squash"
			lab	var	c7_11	"Vegetables consumed includes: Cucumber"
			lab	var	c7_12	"Vegetables consumed includes: Radish"
			lab	var	c7_13	"Vegetables consumed includes: Turnip"
			lab	var	c7_14	"Vegetables consumed includes: Cabbage"
			lab	var	c7_15	"Vegetables consumed includes: Leek"
			lab	var	c7_16	"Vegetables consumed includes: Hot pepper"
			lab	var	c7_17	"Vegetables consumed includes: Wild leafy vegetables"
			lab	var	c7_18	"Vegetables consumed includes: Coriander"
			lab	var	c7_19	"Vegetables consumed includes: Mint"
			lab	var	c7_20	"Vegetables consumed includes: Dried tomatoes"
			lab	var	c7_21	"Vegetables consumed includes: Dried vegetables"
			lab	var	c7_22	"Vegetables consumed includes: Pickled vegetables"
			lab	var	c7_23	"Vegetables consumed includes: Green beans"
			lab	var	c7_24	"Vegetables consumed includes: Other vegetables"
			lab	var	c7_100	"Vegetables consumed includes: None"		

			lab	var	c8_1	"Fruits consumed includes: Apple"
			lab	var	c8_2	"Fruits consumed includes: Grapes"
			lab	var	c8_3	"Fruits consumed includes: Melon/watermelon"
			lab	var	c8_4	"Fruits consumed includes: Peach"
			lab	var	c8_5	"Fruits consumed includes: Fresh apricots"
			lab	var	c8_6	"Fruits consumed includes: Dried apricots"
			lab	var	c8_7	"Fruits consumed includes: Orange/citrus"
			lab	var	c8_8	"Fruits consumed includes: Plum"
			lab	var	c8_9	"Fruits consumed includes: Pomegranate"
			lab	var	c8_10	"Fruits consumed includes: Pear"
			lab	var	c8_11	"Fruits consumed includes: Banana"
			lab	var	c8_12	"Fruits consumed includes: Raisins"
			lab	var	c8_13	"Fruits consumed includes: Fresh mulberries"
			lab	var	c8_14	"Fruits consumed includes: Dried mulberries"
			lab	var	c8_15	"Fruits consumed includes: Mangoes"
			lab	var	c8_16	"Fruits consumed includes: Walnuts"
			lab	var	c8_17	"Fruits consumed includes: Pistachio"
			lab	var	c8_18	"Fruits consumed includes: Almonds"
			lab	var	c8_19	"Fruits consumed includes: Other fruit and/or nuts"
			lab	var	c8_100	"Fruits consumed includes: None"
				
			lab	var	c9_1	"Sweets consumed includes: White sugar"
			lab	var	c9_2	"Sweets consumed includes: Brown sugar"
			lab	var	c9_3	"Sweets consumed includes: Honey"
			lab	var	c9_4	"Sweets consumed includes: Chocolates, candy, sherinigack"
			lab	var	c9_100	"Sweets consumed includes: None"	
		
			lab	var	c10_1	"Beverages consumed includes: Black teas"
			lab	var	c10_2	"Beverages consumed includes: Green teas"
			lab	var	c10_3	"Beverages consumed includes: Bottled/canned beverages, Mineral waters"
			lab	var	c10_4	"Beverages consumed includes: Other beverages"
			lab	var	c10_100	"Beverages consumed includes: None"
		
			lab	var	c11_1	"Spices consumed includes: Salt"
			lab	var	c11_2	"Spices consumed includes: Black pepper"
			lab	var	c11_3	"Spices consumed includes: Ginger and garlic"
			lab	var	c11_4	"Spices consumed includes: Tomato sauce"
			lab	var	c11_5	"Spices consumed includes: Mixed spices"
			lab	var	c11_6	"Spices consumed includes: Other spices"
			lab	var	c11_100	"Spices consumed includes: None"		
	
	* D. Transfer and safety nets
		rename	dd*	d*
	
		* D1
				
			forval	gift_num=1/10	{
				egen	d1_temp_`gift_num'	=	anymatch(d1_1-d1_13), value(`gift_num')
				replace	d1_temp_`gift_num'	=.	if	a12!=1
			}
			egen	d1_temp__98	=	anymatch(d1_1-d1_13), value(-98)
			egen	d1_temp__99	=	anymatch(d1_1-d1_13), value(-99)
			egen	d1_temp_0	=	anymatch(d1_1-d1_13), value(0)
			
			replace	d1_temp__98	=.	if	a12!=1
			replace	d1_temp__99	=.	if	a12!=1
			replace	d1_temp_0	=.	if	a12!=1
			
			drop	d1_1-d1_13
			rename	d1_temp_*	d1_*
			
			lab	var	d1_1	"Gift item includes: Money"
			lab	var	d1_2	"Gift item includes: Clothes, pots, pans, pails, etc."
			lab	var	d1_3	"Gift item includes: Uncooked produce"
			lab	var	d1_4	"Gift item includes: Meals"
			lab	var	d1_5	"Gift item includes: Work materials"
			lab	var	d1_6	"Gift item includes: Dowry/bride price"
			lab	var	d1_7	"Gift item includes: Wedding gift"
			lab	var	d1_8	"Gift item includes: Livestock"
			lab	var	d1_9	"Gift item includes: Land"
			lab	var	d1_10	"Gift item includes: Other (please specify)"
			lab	var	d1__98	"Gift item includes: Don't Answer"
			lab	var	d1__99	"Gift item includes: Don’t know"
			lab	var	d1_0	"Gift item includes: None"

			lab	val	d1_1-d1_0	yesno
			order	d1_1-d1_0, before(d1_o)
			
	* d8
		
		rename d8_* d8_temp_*
		forval	gifttaken_num=1/19	{
			egen	d8_`gifttaken_num'	=	anymatch(d8_temp_1-d8_temp_22), value(`gifttaken_num')
			replace	d8_`gifttaken_num'	=.	if	a12!=1
		}
		egen	d8__98	=	anymatch(d8_temp_1-d8_temp_22), value(-98)
		egen	d8__99	=	anymatch(d8_temp_1-d8_temp_22), value(-99)
		egen	d8_0	=	anymatch(d8_temp_1-d8_temp_22), value(0)
		
		replace	d8__98	=.	if	a12!=1
		replace	d8__99	=.	if	a12!=1
		replace	d8_0	=.	if	a12!=1
			
		rename d8_temp_o d8_o	
		drop	d8_temp_1-d8_temp_22
		order	d8_1-d8_0, before(d8_o)
		lab	val	d8_1-d8_0	yesno
		
		lab	var	d8_1		"Gift received includes: Money"
		lab	var	d8_2		"Gift received includes: Clothes, pots, pans, pails, etc."
		lab	var	d8_3		"Gift received includes: Uncooked produce"
		lab	var	d8_4		"Gift received includes: Meals"
		lab	var	d8_5		"Gift received includes: Work materials"
		lab	var	d8_6		"Gift received includes: Dowry/bride price"
		lab	var	d8_7		"Gift received includes: Wedding gift"
		lab	var	d8_8		"Gift received includes: Livestock"
		lab	var	d8_9		"Gift received includes: Land"
		lab	var	d8_10		"Gift received includes: Construction/building material"
		lab	var	d8_11		"Gift received includes: Water and/or sanitation"
		lab	var	d8_12		"Gift received includes: Agricultural input assistance (tools, seeds, fertilizer, etc.)"
		lab	var	d8_13		"Gift received includes: Training and technical assistance in improved agricultural/livestock practices"
		lab	var	d8_14		"Gift received includes: Fish ponds"
		lab	var	d8_15		"Gift received includes: Veterinary services"
		lab	var	d8_16		"Gift received includes: For education (e.g. school materials)"
		lab	var	d8_17		"Gift received includes: Medical services"
		lab	var	d8_18		"Gift received includes: Pension payment"
		lab	var	d8_19		"Gift received includes: Other (please specify)"
		lab	var	d8__99		"Gift received includes: Don’t know"
		lab	var	d8__98		"Gift received includes: Don't Answer"
		lab	var	d8_0		"Gift received includes: None"
		
	* E. Housing Characteristics 
	
		* Correct variable names
		rename	ee*	e*
		
	* L. Other Asset Ownership
	
		rename	ll*	l*

			
		* L1
		
			forval	asset_num=1/20	{
				egen	l1_temp_`asset_num'	=	anymatch(l1_1-l1_23), value(`asset_num')
				replace	l1_temp_`asset_num'	=.	if	a12!=1
			}
			egen	l1_temp_0	=	anymatch(l1_1-l1_23), value(0)
			egen	l1_temp__98	=	anymatch(l1_1-l1_23), value(-98)
			egen	l1_temp__99	=	anymatch(l1_1-l1_23), value(-99)
			
			replace	l1_temp_0	=.	if	a12!=1
			replace	l1_temp__98	=.	if	a12!=1
			replace	l1_temp__99	=.	if	a12!=1
			
			order	l1_temp_1-l1_temp__99, before(l1_o)
			drop	l1_1-l1_23
			rename	l1_temp_*	l1_*
			
			lab	val	l1_1-l1__99	yesno			
			
			lab	var	l1_1	"Asset includes: Radios/CDs/Cassettes"
			lab	var	l1_2	"Asset includes: Televisions"
			lab	var	l1_3	"Asset includes: Dish TVs"
			lab	var	l1_4	"Asset includes: VCRs/DVD players"
			lab	var	l1_5	"Asset includes: Land on which your home is built"
			lab	var	l1_6	"Asset includes: Other land(s) (excluding land on which your home is built)"
			lab	var	l1_7	"Asset includes: Other houses/buildings"
			lab	var	l1_8	"Asset includes: Refrigerators"
			lab	var	l1_9	"Asset includes: Generators"
			lab	var	l1_10	"Asset includes: Mattresses"
			lab	var	l1_11	"Asset includes: Cell (mobile) phones"
			lab	var	l1_12	"Asset includes: Non-mobile phones"
			lab	var	l1_13	"Asset includes: Clothes irons"
			lab	var	l1_14	"Asset includes: Bed frames"
			lab	var	l1_15	"Asset includes: Pieces of jewelry (gold, silver, etc.)"
			lab	var	l1_16	"Asset includes: Mosquito nets"
			lab	var	l1_17	"Asset includes: Mosquito-repellant candles"
			lab	var	l1_18	"Asset includes: Fans"
			lab	var	l1_19	"Asset includes: Cameras"
			lab	var	l1_20	"Asset includes: Other (please specify)"
			lab	var	l1_0	"Asset includes: None"
			lab	var	l1__98	"Asset includes: Don't Answer"
			lab	var	l1__99	"Asset includes: Don't know"
			
	* F. Health and Health Seeking
	
		rename	fphys*	*
		rename	ff*		f*
		rename	fless5*	*
		rename	imz*	*
		rename	fmathth*	*
		
		* f3_a
		
			forval	limbs_num=1/4	{
				egen	f3_a_`limbs_num'	=	anymatch(f3_a1-f3_a6), value(`limbs_num')
				replace	f3_a_`limbs_num'	=.	if	a12!=1
			}
			egen	f3_a_0	=	anymatch(f3_a1-f3_a6), value(0)
			egen	f3_a__99	=	anymatch(f3_a1-f3_a6), value(-99)
			
			replace	f3_a_0		=.	if	a12!=1
			replace	f3_a__99	=.	if	a12!=1
			
			order	f3_a_1-f3_a__99, before(oldname_less5)
			drop	f3_a1-f3_a6
			
			lab	val	f3_a_1-f3_a__99	yesno			
			
			lab	var	f3_a_1	"Limb not functioning includes: Right Arm"
			lab	var	f3_a_2	"Limb not functioning includes: Left Arm"
			lab	var	f3_a_3	"Limb not functioning includes: Right Leg"
			lab	var	f3_a_4	"Limb not functioning includes: Left Leg"
			lab	var	f3_a_0	"Limb not functioning includes: None"
			lab	var	f3_a__99	"Limb not functioning includes: Can't be assessed"					
			
	* Child Health
			
		lab	var	f6	"Has the oldest child (5 years old or less) had diarrhea in the last 2 weeks?"
		
			
		* f8
			rename f8_* f8_temp_*
			forval	advice_num=1/7	{
				egen	f8_`advice_num'	=	anymatch(f8_temp_1-f8_temp_9), value(`advice_num')
				replace	f8_`advice_num'	=.	if	f7!=1
			}
			egen	f8__97	=	anymatch(f8_temp_1-f8_temp_9), value(-97)
			egen	f8__99	=	anymatch(f8_temp_1-f8_temp_9), value(-99)
			
			replace	f8__97	=.	if	f7!=1
			replace	f8__99	=.	if	f7!=1
			
			order	f8_1-f8__99, before(f8_temp_1)
			drop	f8_temp_1-f8_temp_9
			rename	f8_temp_o	f8_o
			
			lab	val	f8_1-f8__99	yesno			
			
			lab	var	f8_1	"Advice for diarrhea treatment includes: Public sector, government hospital, health center health post, mobile clinic"
			lab	var	f8_2	"Advice for diarrhea treatment includes: Private sector, private hospital, clinic, mobile clinic"
			lab	var	f8_3	"Advice for diarrhea treatment includes: Pharmacy/shop/market"
			lab	var	f8_4	"Advice for diarrhea treatment includes: Traditional practitioner"
			lab	var	f8_5	"Advice for diarrhea treatment includes: Fieldworker"
			lab	var	f8_6	"Advice for diarrhea treatment includes: Family"
			lab	var	f8_7	"Advice for diarrhea treatment includes: Friend"
			lab	var	f8__97	"Advice for diarrhea treatment includes: Other (please specify)"
			lab	var	f8__99	"Advice for diarrhea treatment includes: Don't know"
		
		* f9
			rename f9_* f9_temp_*
			forval	noadvice_num=1/10	{
				egen	f9_`noadvice_num'	=	anymatch(f9_temp_1-f9_temp_13), value(`noadvice_num')
				replace	f9_`noadvice_num'	=.	if	f7!=0
			}
			egen	f9__97	=	anymatch(f9_temp_1-f9_temp_13), value(-97)
			egen	f9__98	=	anymatch(f9_temp_1-f9_temp_13), value(-98)
			egen	f9__99	=	anymatch(f9_temp_1-f9_temp_13), value(-99)
			
			replace	f9__97	=.	if	f7!=0
			replace	f9__98	=.	if	f7!=0
			replace	f9__99	=.	if	f7!=0
			
			order	f9_1-f9__99, before(f9_temp_1)
			drop	f9_temp_1-f9_temp_13
			rename	f9_temp_o	f9_o
			
			lab	val	f9_1-f9__99	yesno			
			
			lab	var	f9_1	"Reason for not seeking advice includes: Could not afford the cost of visit"
			lab	var	f9_2	"Reason for not seeking advice includes: No transport"
			lab	var	f9_3	"Reason for not seeking advice includes: Coud not afford the cost of transport"
			lab	var	f9_4	"Reason for not seeking advice includes: The health care provider's drugs and quipment are inadequate"
			lab	var	f9_5	"Reason for not seeking advice includes: The health care provider's skills are inadequate"
			lab	var	f9_6	"Reason for not seeking advice includes: You were previously badly treated"
			lab	var	f9_7	"Reason for not seeking advice includes: Could not take time off work or had other commitments"
			lab	var	f9_8	"Reason for not seeking advice includes: You did not know where to go"
			lab	var	f9_9	"Reason for not seeking advice includes: You thought they were not sick enough"
			lab	var	f9_10	"Reason for not seeking advice includes: You tried but were denied healthcare"
			lab	var	f9__97	"Reason for not seeking advice includes: Other (please specify)"
			lab	var	f9__98	"Reason for not seeking advice includes: Don't Answer"
			lab	var	f9__99	"Reason for not seeking advice includes: Don't know"

		* f10
			lab var	f10	"Has the oldest child (5 years old or less) been ill with fever in the last 2 weeks?"

		* f12
			rename f12_* f12_temp_*
			forval	advice_num=1/7	{
				egen	f12_`advice_num'	=	anymatch(f12_temp_1-f12_temp_9), value(`advice_num')
				replace	f12_`advice_num'	=.	if	f11!=1
			}
			egen	f12__97	=	anymatch(f12_temp_1-f12_temp_9), value(-97)
			egen	f12__99	=	anymatch(f12_temp_1-f12_temp_9), value(-99)
			
			replace	f12__97	=.	if	f11!=1
			replace	f12__99	=.	if	f11!=1
			
			order	f12_1-f12__99, before(f12_temp_1)
			drop	f12_temp_1-f12_temp_9
			rename	f12_temp_o	f12_o
			
			lab	val	f12_1-f12__99	yesno			
			
			lab	var	f12_1	"Advice for fever treatment includes: Public sector, government hospital, health center health post, mobile clinic"
			lab	var	f12_2	"Advice for fever treatment includes: Private sector, private hospital, clinic, mobile clinic"
			lab	var	f12_3	"Advice for fever treatment includes: Pharmacy/shop/market"
			lab	var	f12_4	"Advice for fever treatment includes: Traditional practitioner"
			lab	var	f12_5	"Advice for fever treatment includes: Fieldworker"
			lab	var	f12_6	"Advice for fever treatment includes: Family"
			lab	var	f12_7	"Advice for fever treatment includes: Friend"
			lab	var	f12__97	"Advice for fever treatment includes: Other (please specify)"
			lab	var	f12__99	"Advice for fever treatment includes: Don't know"
	
		* f13
			rename f13_* f13_temp_*
			forval	noadvice_num=1/10	{
				egen	f13_`noadvice_num'	=	anymatch(f13_temp_1-f13_temp_13), value(`noadvice_num')
				replace	f13_`noadvice_num'	=.	if	f11!=0
			}
			egen	f13__97	=	anymatch(f13_temp_1-f13_temp_13), value(-97)
			egen	f13__98	=	anymatch(f13_temp_1-f13_temp_13), value(-98)
			egen	f13__99	=	anymatch(f13_temp_1-f13_temp_13), value(-99)
			
			replace	f13__97	=.	if	f11!=0
			replace	f13__98	=.	if	f11!=0
			replace	f13__99	=.	if	f11!=0
			
			order	f13_1-f13__99, before(f13_temp_1)
			drop	f13_temp_1-f13_temp_13
			rename	f13_temp_o	f13_o
			
			lab	val	f13_1-f13__99	yesno			
			
			lab	var	f13_1	"Reason for not seeking advice includes: Could not afford the cost of visit"
			lab	var	f13_2	"Reason for not seeking advice includes: No transport"
			lab	var	f13_3	"Reason for not seeking advice includes: Coud not afford the cost of transport"
			lab	var	f13_4	"Reason for not seeking advice includes: The health care provider's drugs and quipment are inadequate"
			lab	var	f13_5	"Reason for not seeking advice includes: The health care provider's skills are inadequate"
			lab	var	f13_6	"Reason for not seeking advice includes: You were previously badly treated"
			lab	var	f13_7	"Reason for not seeking advice includes: Could not take time off work or had other commitments"
			lab	var	f13_8	"Reason for not seeking advice includes: You did not know where to go"
			lab	var	f13_9	"Reason for not seeking advice includes: You thought they were not sick enough"
			lab	var	f13_10	"Reason for not seeking advice includes: You tried but were denied healthcare"
			lab	var	f13__97	"Reason for not seeking advice includes: Other (please specify)"
			lab	var	f13__98	"Reason for not seeking advice includes: Don't Answer"
			lab	var	f13__99	"Reason for not seeking advice includes: Don't know"
		
		* f4
			rename f4_* f4_temp_*
			forval	reason_num=1/4	{
				egen	f4_`reason_num'	=	anymatch(f4_temp_1-f4_temp_7), value(`reason_num')
				replace	f4_`reason_num'	=.	if	mi(f6)
			}
			egen	f4__97	=	anymatch(f4_temp_1-f4_temp_7), value(-97)
			egen	f4__98	=	anymatch(f4_temp_1-f4_temp_7), value(-98)
			egen	f4__99	=	anymatch(f4_temp_1-f4_temp_7), value(-99)
			
			replace	f4__97	=.	if	mi(f6)
			replace	f4__98	=.	if	mi(f6)
			replace	f4__99	=.	if	mi(f6)
			
			order	f4_1-f4__99, before(f4_temp_1)
			drop	f4_temp_1-f4_temp_7
			rename	f4_temp_o	f4_o
			
			lab	val	f4_1-f4__99	yesno			
			
			lab	var	f4_1	"Causes of diarrhea includes: Mosquitoes"
			lab	var	f4_2	"Causes of diarrhea includes: Drinking contaminated water"
			lab	var	f4_3	"Causes of diarrhea includes: Too much sunlight"
			lab	var	f4_4	"Causes of diarrhea includes: Contact with contaminated feces"
			lab	var	f4__97	"Causes of diarrhea includes: Other (please specify)"
			lab	var	f4__98	"Causes of diarrhea includes: Don't Answer"
			lab	var	f4__99	"Causes of diarrhea includes: Don't know"
				
		* Vaccination
			lab	var	f14	"Is there a vaccination card or any other document with oldest child (5 years old or less) vaccination record on it?"
			lab	var	f14_b	"Is there a vaccination card or any other document with the vaccination record of any of your children <5 years of age?"	

			* f15 & f16
				loc	f15_lab	Options on immunization card
				loc	f16_lab	Immunization the oldest child (5 years old or less) received
				
				forval	varnum=15/16	{
					forval	option_num=1/15	{
						egen	f`varnum'_`option_num'_temp	=	anymatch(f`varnum'_1-f`varnum'_17), value(`option_num')
						if	`varnum'==15	{
							replace	f`varnum'_`option_num'_temp	=.	if	f15_a!=1
						}
						else	{
							replace	f`varnum'_`option_num'_temp	=.	if	!(inlist(f14,0,-99) | inlist(f14_b,0,-99) | f15_a==0)
						}
					}
					egen	f`varnum'__98_temp	=	anymatch(f`varnum'_1-f`varnum'_17), value(-98)
					egen	f`varnum'__99_temp	=	anymatch(f`varnum'_1-f`varnum'_17), value(-99)
					
					if	`varnum'==15	{
						replace	f`varnum'__98_temp	=.	if	f15_a!=1
						replace	f`varnum'__99_temp	=.	if	f15_a!=1
					}
					else	{
						replace	f`varnum'__98_temp	=.	if	!(inlist(f14,0,-99) | inlist(f14_b,0,-99) | f15_a==0)
						replace	f`varnum'__99_temp	=.	if	!(inlist(f14,0,-99) | inlist(f14_b,0,-99) | f15_a==0)
					}
					
					
					order	f`varnum'_1_temp-f`varnum'__99_temp, before(f`varnum'_1)
					drop	f`varnum'_1-f`varnum'_17
					rename	f`varnum'_*_temp	f`varnum'_*
					
					lab	val	f`varnum'_1-f`varnum'__99	yesno	
					
					lab	var	f`varnum'_1	"`f`varnum'_lab' includes: BCG"
					lab	var	f`varnum'_2	"`f`varnum'_lab' includes: POLIO 1"
					lab	var	f`varnum'_3	"`f`varnum'_lab' includes: POLIO 2"
					lab	var	f`varnum'_4	"`f`varnum'_lab' includes: POLIO 3"
					lab	var	f`varnum'_5	"`f`varnum'_lab' includes: DPT 1"
					lab	var	f`varnum'_6	"`f`varnum'_lab' includes: DPT 2"
					lab	var	f`varnum'_7	"`f`varnum'_lab' includes: DPT 3"
					lab	var	f`varnum'_8	"`f`varnum'_lab' includes: MEASLES"
					lab	var	f`varnum'_9	"`f`varnum'_lab' includes: VITAMIN A"
					lab	var	f`varnum'_10	"`f`varnum'_lab' includes: HEPATITIS A"
					lab	var	f`varnum'_11	"`f`varnum'_lab' includes: HEP B (1st dose)"
					lab	var	f`varnum'_12	"`f`varnum'_lab' includes: HEP B (2nd dose)"
					lab	var	f`varnum'_13	"`f`varnum'_lab' includes: HEP B (3rd dose)"
					lab	var	f`varnum'_14	"`f`varnum'_lab' includes: Booster shot DPT"
					lab	var	f`varnum'_15	"`f`varnum'_lab' includes: Booster dose polio"
					lab	var	f`varnum'__98	"`f`varnum'_lab' includes: Don't Answer"
					lab	var	f`varnum'__99	"`f`varnum'_lab' includes: Don't know"
				}
						
		* Maternal health
		
			* f19
			forval	who_num=1/5	{
				egen	f19_`who_num'_temp	=	anymatch(f19_1-f19_8), value(`who_num')
				replace	f19_`who_num'_temp	=.	if	f18!=1
			}
			egen	f19__97_temp	=	anymatch(f19_1-f19_8), value(-97)
			egen	f19__98_temp	=	anymatch(f19_1-f19_8), value(-98)
			egen	f19__99_temp	=	anymatch(f19_1-f19_8), value(-99)
			
			replace	f19__97_temp	=.	if	f18!=1
			replace	f19__98_temp	=.	if	f18!=1
			replace	f19__99_temp	=.	if	f18!=1
			
			order	f19_1_temp-f19__99_temp, before(f19_1)
			drop	f19_1-f19_8
			rename	f19_*_temp	f19_*
			
			lab	val	f19_1-f19__99	yesno			
			
			lab	var	f19_1	"Prenatal care person includes: Doctor"
			lab	var	f19_2	"Prenatal care person includes: Unofficial Midwife"
			lab	var	f19_3	"Prenatal care person includes: Official Midwife"
			lab	var	f19_4	"Prenatal care person includes: Nurse"
			lab	var	f19_5	"Prenatal care person includes: Community Health Worker"
			lab	var	f19__97	"Prenatal care person includes: Other (please specify)"
			lab	var	f19__98	"Prenatal care person includes: Don't know"
			lab	var	f19__99	"Prenatal care person includes: Don't Answer"
	
	* H: Household Decision-Making	
		rename	hh_general*	*
		rename	(hh_accessfinh28 hh_accessfinh31 hh_accessfinh24 hh_ppth29 hh_ppth30)	///
				(h28	h31	h24	h29	h30)
				
	* I: Aspirations & Psychological Well-being	
		rename	ii*	i*	
	
		* Youngest son (12 years old or less)
		
		lab	var	i1_s	"What is the highest education level that you would like the youngest son (12 years old or less) to complete?"
		
		*	i2_s
			forval	help_num=1/4	{
				egen	i2_s`help_num'_temp	=	anymatch(i2_s1-i2_s7), value(`help_num')
				replace	i2_s`help_num'_temp	=.	if	mi(i1_s)
			}
			egen	i2_s97_temp	=	anymatch(i2_s1-i2_s7), value(-97)
			egen	i2_s98_temp	=	anymatch(i2_s1-i2_s7), value(-98)
			egen	i2_s99_temp	=	anymatch(i2_s1-i2_s7), value(-99)
			
			replace	i2_s97_temp	=.	if	mi(i1_s)
			replace	i2_s98_temp	=.	if	mi(i1_s)
			replace	i2_s99_temp	=.	if	mi(i1_s)
			
			order	i2_s1_temp-i2_s99_temp, before(i2_s1)
			drop	i2_s1-i2_s7
			rename	i2_s*_temp	i2_s*
			
			lab	val	i2_s1-i2_s99	yesno
			
			lab	var	i2_s1	"What education will help includes: Get job/earn money"
			lab	var	i2_s2	"What education will help includes: Make him/her wiser"
			lab	var	i2_s3	"What education will help includes: GWill not help"
			lab	var	i2_s4	"What education will help includes: Enhance marriage prospects"
			lab	var	i2_s97	"What education will help includes: Other (please specify)" // Due to programming error in eQuestionnaire, NOT all responses who answered "Other (please specify)" answered i2_s_o
			lab	var	i2_s98	"What education will help includes: Don't Answer"
			lab	var	i2_s99	"What education will help includes: Don’t know"
			
		lab	var	i3_s	"What occupation would you like the youngest son (12 years old or less) to be doing when he/she grows up?"
		lab	var	i4_s	"At what age would you like to see the youngest son (12 years old or less) marry?"

		*  Youngest daughter (12 years old or less)
		lab	var	i1_d	"What is the highest education level that you would like the youngest daughter (12 years old or less) to complete?"
		
		*	i2_d
			forval	help_num=1/4	{
				egen	i2_d`help_num'_temp	=	anymatch(i2_d1-i2_d7), value(`help_num')
				replace	i2_d`help_num'_temp	=.	if	mi(i1_d)
			}
			egen	i2_d97_temp	=	anymatch(i2_d1-i2_d7), value(-97)
			egen	i2_d98_temp	=	anymatch(i2_d1-i2_d7), value(-98)
			egen	i2_d99_temp	=	anymatch(i2_d1-i2_d7), value(-99)
			
			replace	i2_d97_temp	=.	if	mi(i1_d)
			replace	i2_d98_temp	=.	if	mi(i1_d)
			replace	i2_d99_temp	=.	if	mi(i1_d)
			
			order	i2_d1_temp-i2_d99_temp, before(i2_d1)
			drop	i2_d1-i2_d7
			rename	i2_d*_temp	i2_d*
			
			lab	val	i2_d1-i2_d99	yesno
			
			lab	var	i2_d1	"What education will help includes: Get job/earn money"
			lab	var	i2_d2	"What education will help includes: Make him/her wiser"
			lab	var	i2_d3	"What education will help includes: GWill not help"
			lab	var	i2_d4	"What education will help includes: Enhance marriage prospects"
			lab	var	i2_d97	"What education will help includes: Other (please specify)" // Due to programming error in eQuestionnaire, NOT all responses who answered "Other (please specify)" answered i2_s_o
			lab	var	i2_d98	"What education will help includes: Don't Answer"
			lab	var	i2_d99	"What education will help includes: Don’t know"
		
		lab	var	i3_d	"What occupation would you like the youngest daughter (12 years old or less) to be doing when he/she grows up?"
		lab	var	i4_d	"At what age would you like to see the youngest daughter (12 years old or less) marry?"	
		
	* Issue for age to marry, enter 98 or 99 instead of -98 or -98 (frequency too high and value too high)	
		replace i4_d = .o if i4_d == 98 | i4_d == 99
		replace i4_s = .o if i4_s == 98 | i4_s == 99
		
	*	Life satisfaction
		rename	ipsychwellai*	i*
		rename	ipsychwellbi*	i*
		rename	ipsychwellci*	i*			
		rename	ipsychwelldi*	i*			
		
	* J: Entrepreneurship
		rename jentrepj* j*
		rename jj* j*
		rename jtime_begin_j time_begin_j
		
	*	M-1: Credit and Savings (If Household Head is female or HH does NOT have a Lady of the HH)
		
		*	m21
			forval	acc_num=1/6	{
				egen	m21_`acc_num'	=	anymatch(mm21_1-mm21_8), value(`acc_num')
				replace	m21_`acc_num'	=.	if	!(a9==2	|	hh_head_gender==2) 	| a12!=1
			}
			egen	m21__97	=	anymatch(mm21_1-mm21_8), value(-97)
			egen	m21__99	=	anymatch(mm21_1-mm21_8), value(-99)
			
			replace	m21__97	=.	if	!(a9==2	|	hh_head_gender==2) 	| a12!=1
			replace	m21__99	=.	if	!(a9==2	|	hh_head_gender==2) 	| a12!=1
			
			order	m21_1-m21__99, before(mm21_1)
			drop	mm21_1-mm21_8
			rename	mm21_o m21_o
			
			lab	val	m21_1-m21__99	yesno
			
			lab	var	m21_1	"Saving places includes: In formal bank"
			lab	var	m21_2	"Saving places includes: At home"
			lab	var	m21_3	"Saving places includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m21_4	"Saving places includes: With Microfinance institution"
			lab	var	m21_5	"Saving places includes: At post office"
			lab	var	m21_6	"Saving places includes: With another individual (not a formal bank)"
			lab	var	m21__97	"Saving places includes: Other (specify)"
			lab	var	m21__99	"Saving places includes: Don't know"		
		
		rename mm23 m23
		
		* m24
			egen	m24_1	=	anymatch(mm24_1 mm24_2 mm24_3), value(1)
			egen	m24_2	=	anymatch(mm24_1 mm24_2 mm24_3), value(2)	
			egen	m24__97	=	anymatch(mm24_1 mm24_2 mm24_3), value(-97)	
			
			replace	m24_1	=.	if	m23!=1
			replace	m24_2	=.	if	m23!=1
			replace	m24__97	=.	if	m23!=1
			
			order	m24_1-m24__97, before(mm24_1)
			drop	mm24_1 mm24_2 mm24_3
			rename	mm24_o	m24_o
			
			lab	val	m24_1-m24__97	yesno
			
			lab	var	m24_1	"Account having includes: Formal bank"
			lab	var	m24_2	"Account having includes: Microfinance institution"
			lab	var	m24__97	"Account having includes: Other (please specify)"
		
		* m22
			forval	loan_num=0/9	{
				egen	m22_`loan_num'	=	anymatch(mm22_1-mm22_13), value(`loan_num')
				replace	m22_`loan_num'	=.	if	!(a9==2	|	hh_head_gender==2) 	| a12!=1
			}
			egen	m22__97	=	anymatch(mm22_1-mm22_13), value(-97)
			egen	m22__98	=	anymatch(mm22_1-mm22_13), value(-98)
			egen	m22__99	=	anymatch(mm22_1-mm22_13), value(-99)
			
			replace	m22__97	=.	if	!(a9==2	|	hh_head_gender==2) 	| a12!=1
			replace	m22__98	=.	if	!(a9==2	|	hh_head_gender==2) 	| a12!=1
			replace	m22__99	=.	if	!(a9==2	|	hh_head_gender==2) 	| a12!=1
			
			order	m22_0-m22__99, before(mm22_1)
			drop	mm22_1-mm22_13
			rename	mm22_o m22_o
			
			lab	val	m22_0-m22__99	yesno
			
			lab	var	m22_0	"Available loan includes: I would not be able to get a loan"
			lab	var	m22_1	"Available loan includes: Formal banks"
			lab	var	m22_2	"Available loan includes: Microfinance institution"
			lab	var	m22_3	"Available loan includes: Landlord"
			lab	var	m22_4	"Available loan includes: Employer"
			lab	var	m22_5	"Available loan includes: Relative"
			lab	var	m22_6	"Available loan includes: Friend"
			lab	var	m22_7	"Available loan includes: Local money lender"
			lab	var	m22_8	"Available loan includes: ROSCA/chit fund/merry-go-round"
			lab	var	m22_9	"Available loan includes: I would not need a loan as I would draw on my savings/sell an asset"
			lab	var	m22__97	"Available loan includes: Other (please specify)"
			lab	var	m22__98	"Available loan includes: Don't Answer"
			lab	var	m22__99	"Available loan includes: Don’t know"		
	
		* m5
			rename (mm1 mm1_a mm5) (m1 m1_a m5)
	
		* m6
			forval	loan_num=1/5	{
				egen	m6_`loan_num'	=	anymatch(mm6_1-mm6_7), value(`loan_num')
				replace	m6_`loan_num'	=.	if	m1!=0
			}
			egen	m6__98	=	anymatch(mm6_1-mm6_7), value(-98)
			egen	m6__99	=	anymatch(mm6_1-mm6_7), value(-99)
			
			replace	m6__98	=.	if	m1!=0
			replace	m6__99	=.	if	m1!=0
			
			order	m6_1-m6__99, before(mm6_1)
			drop	mm6_1-mm6_7
			rename	mm6_o	m6_o
			
			lab	val	m6_1-m6__99	yesno
			
			lab	var	m6_1	"Reason for no loan includes: Didn’t need it"
			lab	var	m6_2	"Reason for no loan includes: Asked for a loan but was denied"
			lab	var	m6_3	"Reason for no loan includes: No available source of credit"
			lab	var	m6_4	"Reason for no loan includes: Lenders not willing to lend to people like me"
			lab	var	m6_5	"Reason for no loan includes: It's too risky to borrow"
			lab	var	m6__98	"Reason for no loan includes: Don't Answer"
			lab	var	m6__99	"Reason for no loan includes: Don’t know"		
	
		* m6_a
			forval	loan_num=1/9	{
				egen	m6_a_`loan_num'	=	anymatch(mm6_a1-mm6_a12), value(`loan_num')
				replace	m6_a_`loan_num'	=.	if	m6_2!=1
			}
			egen	m6_a__97	=	anymatch(mm6_a1-mm6_a12), value(-97)
			egen	m6_a__98	=	anymatch(mm6_a1-mm6_a12), value(-98)
			egen	m6_a__99	=	anymatch(mm6_a1-mm6_a12), value(-99)
			
			replace	m6_a__97	=.	if	m6_2!=1
			replace	m6_a__98	=.	if	m6_2!=1
			replace	m6_a__99	=.	if	m6_2!=1
			
			order	m6_a_1-m6_a__99, before(mm6_a1)
			drop	mm6_a1-mm6_a12
			rename	mm6_a_o	m6_a_o
			
			lab	val	m6_a_1-m6_a__99	yesno
			
			lab	var	m6_a_1	"Loan rejected includes: Formal banks"
			lab	var	m6_a_2	"Loan rejected includes: Microfinance institution"
			lab	var	m6_a_3	"Loan rejected includes: Landlord"
			lab	var	m6_a_4	"Loan rejected includes: Employer"
			lab	var	m6_a_5	"Loan rejected includes: Relative"
			lab	var	m6_a_6	"Loan rejected includes: Friend"
			lab	var	m6_a_7	"Loan rejected includes: Local money lender"
			lab	var	m6_a_8	"Loan rejected includes: ROSCA/chit fund/merry-go-round"
			lab	var	m6_a_9	"Loan rejected includes: Grocery shop"
			lab	var	m6_a__97	"Loan rejected includes: Other (please specify)"
			lab	var	m6_a__98	"Loan rejected includes: Don't Answer"
			lab	var	m6_a__99	"Loan rejected includes: Don’t know"
		
		rename	mm10	m10
	
		* m11
			egen	m11_1	=	anymatch(mm11_1-mm11_5), value(1)
			egen	m11_2	=	anymatch(mm11_1-mm11_5), value(2)
			egen	m11__97	=	anymatch(mm11_1-mm11_5), value(-97)
			egen	m11__98	=	anymatch(mm11_1-mm11_5), value(-98)
			egen	m11__99	=	anymatch(mm11_1-mm11_5), value(-99)
			
			replace	m11_1	=.	if	m10!=1
			replace	m11_2	=.	if	m10!=1
			replace	m11__97	=.	if	m10!=1
			replace	m11__98	=.	if	m10!=1
			replace	m11__99	=.	if	m10!=1
			
			order	m11_1-m11__99, before(mm11_1)
			drop	mm11_1-mm11_5
			rename	mm11_o	m11_o
			
			lab	val	m11_1-m11__99	yesno
			
			lab	var	m11_1	"In-kind loan purpose includes: Provide input for business"
			lab	var	m11_2	"In-kind loan purpose includes: Provide support to household"
			lab	var	m11__97	"In-kind loan purpose includes: Other (please specify)"
			lab	var	m11__98	"In-kind loan purpose includes: Don't Answer"
			lab	var	m11__99	"In-kind loan purpose includes: Don't know"	
	
		* m12
			forval	biz_num=1/5	{
				egen	m12_`biz_num'	=	anymatch(mm12_1-mm12_7), value(`biz_num')
				replace	m12_`biz_num'	=.	if	m11_1!=1
			}
			egen	m12__97	=	anymatch(mm12_1-mm12_7), value(-97)
			egen	m12__98	=	anymatch(mm12_1-mm12_7), value(-98)
			
			replace	m12__97	=.	if	m11_1!=1
			replace	m12__98	=.	if	m11_1!=1
			
			order	m12_1-m12__98, before(mm12_1)
			drop	mm12_1-mm12_7
			rename	mm12_o	m12_o
			
			lab	val	m12_1-m12__98	yesno
			
			lab	var	m12_1	"Purchased for business includes: Work materials"
			lab	var	m12_2	"Purchased for business includes: Clothes, pots, pans, pails, etc."
			lab	var	m12_3	"Purchased for business includes: Uncooked produce"
			lab	var	m12_4	"Purchased for business includes: Meals"
			lab	var	m12_5	"Purchased for business includes: Livestock"
			lab	var	m12__97	"Purchased for business includes: Other (please specify)"
			lab	var	m12__98	"Purchased for business includes: Don't Answer"
			
		* m12_h
			forval	hh_num=1/5	{
				egen	m12_h_`hh_num'	=	anymatch(mm12_h1-mm12_h7), value(`hh_num')
				replace	m12_h_`hh_num'	=.	if	m11_2!=1
			}
			egen	m12_h__97	=	anymatch(mm12_h1-mm12_h7), value(-97)
			egen	m12_h__98	=	anymatch(mm12_h1-mm12_h7), value(-98)
			
			replace	m12_h__97	=.	if	m11_2!=1
			replace	m12_h__98	=.	if	m11_2!=1
			
			order	m12_h_1-m12_h__98, before(mm12_h1)
			drop	mm12_h1-mm12_h7
			rename	mm12_h_o	m12_h_o
			
			lab	val	m12_h_1-m12_h__98	yesno
			
			lab	var	m12_h_1	"Purchased for household includes: Work materials"
			lab	var	m12_h_2	"Purchased for household includes: Clothes, pots, pans, pails, etc."
			lab	var	m12_h_3	"Purchased for household includes: Uncooked produce"
			lab	var	m12_h_4	"Purchased for household includes: Meals"
			lab	var	m12_h_5	"Purchased for household includes: Livestock"
			lab	var	m12_h__97	"Purchased for household includes: Other (please specify)"
			lab	var	m12_h__98	"Purchased for household includes: Don't Answer"	
	
		* m12_other
			forval	other_num=1/5	{
				egen	m12_other_`other_num'	=	anymatch(mm12_other1-mm12_other7), value(`other_num')
				replace	m12_other_`other_num'	=.	if	m11__97!=1
			}
			egen	m12_other__97	=	anymatch(mm12_other1-mm12_other7), value(-97)
			egen	m12_other__98	=	anymatch(mm12_other1-mm12_other7), value(-98)
			
			replace	m12_other__97	=.	if	m11__97!=1
			replace	m12_other__98	=.	if	m11__97!=1
			
			order	m12_other_1-m12_other__98, before(mm12_other1)
			drop	mm12_other1-mm12_other7
			rename	mm12_other_o	m12_other_o
			
			lab	val	m12_other_1-m12_other__98	yesno
			
			lab	var	m12_other_1	"Purchased for other purpose includes: Work materials"
			lab	var	m12_other_2	"Purchased for other purpose includes: Clothes, pots, pans, pails, etc."
			lab	var	m12_other_3	"Purchased for other purpose includes: Uncooked produce"
			lab	var	m12_other_4	"Purchased for other purpose includes: Meals"
			lab	var	m12_other_5	"Purchased for other purpose includes: Livestock"
			lab	var	m12_other__97	"Purchased for other purpose includes: Other (please specify)"
			lab	var	m12_other__98	"Purchased for other purpose includes: Don't Answer"

		* m13
			forval	other_num=1/9	{
				egen	m13_`other_num'	=	anymatch(mm13_1-mm13_12), value(`other_num')
				replace	m13_`other_num'	=.	if	m10!=1
			}
			egen	m13__97	=	anymatch(mm13_1-mm13_12), value(-97)
			egen	m13__98	=	anymatch(mm13_1-mm13_12), value(-98)
			egen	m13__99	=	anymatch(mm13_1-mm13_12), value(-99)
			
			replace	m13__97	=.	if	m10!=1
			replace	m13__98	=.	if	m10!=1
			replace	m13__99	=.	if	m10!=1

			order	m13_1-m13__99, before(mm13_1)
			drop	mm13_1-mm13_12
			rename	mm13_o	m13_o
			
			lab	val	m13_1-m13__99	yesno
			
			lab	var	m13_1	"In-kind loan source includes: Formal banks"
			lab	var	m13_2	"In-kind loan source includes: Microfinance institution"
			lab	var	m13_3	"In-kind loan source includes: Landlord"
			lab	var	m13_4	"In-kind loan source includes: Employer"
			lab	var	m13_5	"In-kind loan source includes: Relative"
			lab	var	m13_6	"In-kind loan source includes: Friend"
			lab	var	m13_7	"In-kind loan source includes: Local money lender"
			lab	var	m13_8	"In-kind loan source includes: ROSCA/chit fund/merry-go-round"
			lab	var	m13_9	"In-kind loan source includes: Grocery shop"
			lab	var	m13__97	"In-kind loan source includes: Other (please specify)"
			lab	var	m13__98	"In-kind loan source includes: Don't Answer"
			lab	var	m13__99	"In-kind loan source includes: Don’t know"
		
		rename	mm16	m16
	
		* m17
			forval	save_num=1/6	{
				egen	m17_`save_num'	=	anymatch(mm17_1-mm17_8), value(`save_num')
				replace	m17_`save_num'	=.	if	m16!=1
			}
			egen	m17__97	=	anymatch(mm17_1-mm17_8), value(-97)
			egen	m17__99	=	anymatch(mm17_1-mm17_8), value(-99)
			
			replace	m17__97	=.	if	m16!=1
			replace	m17__99	=.	if	m16!=1

			order	m17_1-m17__99, before(mm17_1)
			drop	mm17_1-mm17_8
			rename	mm17_o	m17_o
			
			lab	val	m17_1-m17__99	yesno
			
			lab	var	m17_1	"Saving money includes: In formal bank"
			lab	var	m17_2	"Saving money includes: At home"
			lab	var	m17_3	"Saving money includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m17_4	"Saving money includes: With Microfinance institution"
			lab	var	m17_5	"Saving money includes: At post office"
			lab	var	m17_6	"Saving money includes: With another individual (not a formal bank)"
			lab	var	m17__97	"Saving money includes: Other (specify)"
			lab	var	m17__99	"Saving money includes: Don't know"
				
		rename	(mm19 mm20_a mm20)	(m19 m20_a m20)
		replace	m20=.	if	m20_a<=0	
	
		* Formal account
		
		rename (mexperienceBankm25_y mexperienceBankm25_m mexperienceMFIm26_y mexperienceMFIm26_m) ///
				(m25_y m25_m m26_y m26_m)
		lab	var	m25_y	"For how long have you been in a relationship with the formal bank? (years)"
		lab	var	m25_m	"For how long have you been in a relationship with the formal bank? (months)"
		lab	var	m26_y	"For how long have you been in a relationship with MFI? (years)"
		lab	var	m26_m	"For how long have you been in a relationship with MFI? (months)"
	
			* m27
				forval	acc_num=0/5	{
					egen	m27_`acc_num'	=	anymatch(mexperiencem27_1-mexperiencem27_7), value(`acc_num')
					replace	m27_`acc_num'	=.	if	(mi(m25_y) & mi(m26_y))
				}
				egen	m27__97	=	anymatch(mexperiencem27_1-mexperiencem27_7), value(-97)
				
				replace	m27__97	=.	if	(mi(m25_y) & mi(m26_y))

				order	m27_0-m27__97, before(mexperiencem27_1)
				drop	mexperiencem27_1-mexperiencem27_7
				rename	mexperiencem27_o	m27_o
				
				lab	val	m27_0-m27__97	yesno
				
				lab	var	m27_0	"Saving benefit includes: No benefits"
				lab	var	m27_1	"Saving benefit includes: Encouraged to save"
				lab	var	m27_2	"Saving benefit includes: Received better management of savings"
				lab	var	m27_3	"Saving benefit includes: Aided in sending remittances"
				lab	var	m27_4	"Saving benefit includes: Aided in receiving remittances"
				lab	var	m27_5	"Saving benefit includes: Aided in obtaining a loan"
				lab	var	m27__97	"Saving benefit includes: Other (please specify)"
		
			* m28
				forval	imp_num=0/5	{
					egen	m28_`imp_num'	=	anymatch(mexperiencem28_1-mexperiencem28_7), value(`imp_num')
					replace	m28_`imp_num'	=.	if	(mi(m25_y) & mi(m26_y))
				}
				egen	m28__97	=	anymatch(mexperiencem28_1-mexperiencem28_7), value(-97)
				
				replace	m28__97	=.	if	(mi(m25_y) & mi(m26_y))

				order	m28_0-m28__97, before(mexperiencem28_1)
				drop	mexperiencem28_1-mexperiencem28_7
				rename	mexperiencem28_o	m28_o
				
				lab	val	m28_0-m28__97	yesno
				
				lab	var	m28_0	"Things to be improved includes: No improvement"
				lab	var	m28_1	"Things to be improved includes: Simpler application procedure (for deposit and loans)"
				lab	var	m28_2	"Things to be improved includes: Reduced application processing time (for deposit and loans)"
				lab	var	m28_3	"Things to be improved includes: Easier access to bank branch"
				lab	var	m28_4	"Things to be improved includes: Easier access to ATM"
				lab	var	m28_5	"Things to be improved includes: Reduced fees for transactions"
				lab	var	m28__97	"Things to be improved includes: Other (please specify)"
		
			rename	(mexperiencem29 mexperiencem30 mexperiencem30_a)	(m29 m30 m30_a)
		
		* Business Opportunity
			rename	(mm31 mm31_a mm31_a_a)	(m31 m31_a m31_a_a)
			
			*	m32
			forval	reason_num=1/9	{
				egen	m32_`reason_num'	=	anymatch(mm32_1-mm32_11), value(`reason_num')
				replace	m32_`reason_num'	=.	if	mi(mm32_1)
			}
			egen	m32__97	=	anymatch(mm32_1-mm32_11), value(-97)
			egen	m32__99	=	anymatch(mm32_1-mm32_11), value(-99)
			
			replace	m32__97	=.	if	mi(mm32_1)
			replace	m32__99	=.	if	mi(mm32_1)

			order	m32_1-m32__99, before(mm32_1)
			drop	mm32_1-mm32_11
			rename	mm32_o	m32_o
			
			lab	val	m32_1-m32__99	yesno
			
			lab	var	m32_1	"Reason for not having account includes: financial institutions are too far away"
			lab	var	m32_2	"Reason for not having account includes: financial services are too expensive"
			lab	var	m32_3	"Reason for not having account includes: don't have the necessary documentation (id card, wage slip, etc.)"
			lab	var	m32_4	"Reason for not having account includes: don't trust financial institutions"
			lab	var	m32_5	"Reason for not having account includes: religious reasons"
			lab	var	m32_6	"Reason for not having account includes: don't have enough money to use financial institutions"
			lab	var	m32_7	"Reason for not having account includes: someone else in the family already has an account"
			lab	var	m32_8	"Reason for not having account includes: cannot get an account"
			lab	var	m32_9	"Reason for not having account includes: no need for financial services at a formal institution"
			lab	var	m32__97	"Reason for not having account includes: other (please specify)"
			lab	var	m32__99	"Reason for not having account includes: don't answer"		

	*	M-2: Credit and Savings (If Household Head is male AND Lady of the Household is available)		
	
		*	m21_m
			forval	acc_num=1/6	{
				egen	m21_m_`acc_num'	=	anymatch(m_mm21_m1-m_mm21_m8), value(`acc_num')
				replace	m21_m_`acc_num'	=.	if	(a8==0	|	hh_head_gender==2)
			}
			egen	m21_m__97	=	anymatch(m_mm21_m1-m_mm21_m8), value(-97)
			egen	m21_m__99	=	anymatch(m_mm21_m1-m_mm21_m8), value(-99)
			
			replace	m21_m__97	=.	if	(a8==0	|	hh_head_gender==2)
			replace	m21_m__99	=.	if	(a8==0	|	hh_head_gender==2)
			
			order	m21_m_1-m21_m__99, before(m_mm21_m1)
			drop	m_mm21_m1-m_mm21_m8
			rename	m_mm21_o_m m21_m_o
			
			lab	val	m21_m_1-m21_m__99	yesno
			
			lab	var	m21_m_1		"Saving places includes: In formal bank"
			lab	var	m21_m_2		"Saving places includes: At home"
			lab	var	m21_m_3		"Saving places includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m21_m_4		"Saving places includes: With Microfinance institution"
			lab	var	m21_m_5		"Saving places includes: At post office"
			lab	var	m21_m_6		"Saving places includes: With another individual (not a formal bank)"
			lab	var	m21_m__97	"Saving places includes: Other (specify)"
			lab	var	m21_m__99	"Saving places includes: Don't know"
			
		rename	m_mm23_m	m23_m			
			
		* m22_m
			forval	loan_num=0/9	{
				egen	m22_m_`loan_num'	=	anymatch(m_mm22_m1-m_mm22_m13), value(`loan_num')
				replace	m22_m_`loan_num'	=.	if	(a8==0	|	hh_head_gender==2)
			}
			egen	m22_m__97	=	anymatch(m_mm22_m1-m_mm22_m13), value(-97)
			egen	m22_m__98	=	anymatch(m_mm22_m1-m_mm22_m13), value(-98)
			egen	m22_m__99	=	anymatch(m_mm22_m1-m_mm22_m13), value(-99)
			
			replace	m22_m__97	=.	if	(a8==0	|	hh_head_gender==2)
			replace	m22_m__98	=.	if	(a8==0	|	hh_head_gender==2)
			replace	m22_m__99	=.	if	(a8==0	|	hh_head_gender==2)
			
			order	m22_m_0-m22_m__99, before(m_mm22_m1)
			drop	m_mm22_m1-m_mm22_m13
			rename	m_mm22_o_m m22_m_o
			
			lab	val	m22_m_0-m22_m__99	yesno
			
			lab	var	m22_m_0		"Available loan includes: I would not be able to get a loan"
			lab	var	m22_m_1		"Available loan includes: Formal banks"
			lab	var	m22_m_2		"Available loan includes: Microfinance institution"
			lab	var	m22_m_3		"Available loan includes: Landlord"
			lab	var	m22_m_4		"Available loan includes: Employer"
			lab	var	m22_m_5		"Available loan includes: Relative"
			lab	var	m22_m_6		"Available loan includes: Friend"
			lab	var	m22_m_7		"Available loan includes: Local money lender"
			lab	var	m22_m_8		"Available loan includes: ROSCA/chit fund/merry-go-round"
			lab	var	m22_m_9		"Available loan includes: I would not need a loan as I would draw on my savings/sell an asset"
			lab	var	m22_m__97	"Available loan includes: Other (please specify)"
			lab	var	m22_m__98	"Available loan includes: Don't Answer"
			lab	var	m22_m__99	"Available loan includes: Don’t know"		
	
		* Cash loan
			rename	(m_mm1_m m_mm1_a_m	m_mm5_m) (m1_m m1_a_m m5_m)
				*	Treat mis-entered answers
				replace	m1_a_m	=	5		if	bl_key	==	"uuid:761ce0e2-3d2a-493e-aeb4-650a5d8e365f"	//	HH entered values in the opposite order
				replace	m5_m	=	20000	if	bl_key	==	"uuid:761ce0e2-3d2a-493e-aeb4-650a5d8e365f"	//	HH entered values in the opposite order
				replace	m1_a_m	=	-99		if	inlist(bl_key, "uuid:ba8ff471-74f1-4dfc-9dd9-8eb20563041b",	///
															"uuid:82e7de00-92a3-4045-a66e-687fa4994420",	///
															"uuid:e21d593a-fc2a-4074-8cde-0aeae67888ce",	///
															"uuid:e9bacbfd-7ee4-414c-a787-60141814fd86",	///
															"uuid:6838c795-e37c-42c3-9175-6e9eb7d07032")	//	HH entered loan value instead of the number of loans. Replace with "don't know"
	
		*	m16_m, m17_m
			rename	m_mm16_m	m16_m
			
			forval	save_num=1/6	{
				egen	m17_m_`save_num'	=	anymatch(m_mm17_m1-m_mm17_m8), value(`save_num')
				replace	m17_m_`save_num'	=.	if	m16_m!=1
			}
			egen	m17_m__97	=	anymatch(m_mm17_m1-m_mm17_m8), value(-97)
			egen	m17_m__99	=	anymatch(m_mm17_m1-m_mm17_m8), value(-99)
			
			replace	m17_m__97	=.	if	m16_m!=1
			replace	m17_m__99	=.	if	m16_m!=1

			order	m17_m_1-m17_m__99, before(m_mm17_m1)
			drop	m_mm17_m1-m_mm17_m8
			rename	m_mm17_o_m	m17_m_o
			
			lab	val	m17_m_1-m17_m__99	yesno
			
			lab	var	m17_m_1			"Saving money includes: In formal bank"
			lab	var	m17_m_2			"Saving money includes: At home"
			lab	var	m17_m_3			"Saving money includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m17_m_4			"Saving money includes: With Microfinance institution"
			lab	var	m17_m_5			"Saving money includes: At post office"
			lab	var	m17_m_6			"Saving money includes: With another individual (not a formal bank)"
			lab	var	m17_m__97		"Saving money includes: Other (specify)"
			lab	var	m17_m__99		"Saving money includes: Don't know"
		
		*	m21_m, m22_m
			rename	(m_mm20_a_m m_mm20_m)	(m20_a_m m20_m)
	
		*	Merge M-1 with M-2
		/* 	This section is asked to only one respondent if LHH is not available (so it is
			only asked to the male HHH) or	the HHH female (so it is only asked to the female
			HHH).
			In the most common case where HHH is male and there is a LHH, the LHH (female)
			answered a subset of questions in LHH survey and the HHH (male) answered the complete
			set of questions in MHHH surevey.
			In the LHH survey, those common questions appear twice: (1) with "_m" suffix if 
			answered by LHH of a male-headed household; and (2) without "_m" suffix
			if they  are answered by either male HHH with no available LHH (male response)
			or by female HHH (female response).
			In order to correctly assign gender responses, I followed the steps below.
				
			** Step 1 & 2 are done in this file.
				1.	Since in LHH survey we either have questions stored under "_m" variables
					or with no suffix, I imported both under the variable without
					suffix: so the variables without "_m" suffix have complete responses from 
					both type of HHs.
				2.	Drop the variables with "_m" suffix in LHH survey, since their 
					responses are imported into the variables without "_m" suffix.
			*/
		
		
			rename (m21_m_* m22_m_* m17_m_*) (m21_*_m m22_*_m m17_*_m)

			loc	Mvars_tobemerged	m21_1 m21_2 m21_3 m21_4 m21_5 m21_6 m21__97 m21__99 m21_o m23 m22_0 m22_1 m22_2 m22_3 ///
									m22_4 m22_5 m22_6 m22_7 m22_8 m22_9 m22__97 m22__98 m22__99 m22_o m1 m1_a m5 m16 m17_1 m17_2 ///
									m17_3 m17_4 m17_5 m17_6 m17__97 m17__99 m17_o m20_a m20
									
			tostring	m17_o, replace
			
			foreach	var	of	loc	Mvars_tobemerged	{
				replace	`var'=`var'_m	if	a8==1	&	hh_head_gender==1 
				drop	`var'_m
			}	

	* N: Social Participation and Awareness	
	
		* n1 - n4
		rename	(nn1 nn2	nn3	nn4)	(n1	n2	n3	n4)
		
		* n5
		forval	loan_num=0/5	{
			egen	n5_`loan_num'	=	anymatch(nn5_1-nn5_6), value(`loan_num')
			replace	n5_`loan_num'	=.	if	a12!=1
		}
		
		order	n5_0-n5_5, before(nn5_1)
		drop	nn5_1-nn5_6
		rename	nn5_o n5_o
		
		lab	val	n5_0-n5_5	yesno
		
		lab	var	n5_0	"Participating group includes: None"
		lab	var	n5_1	"Participating group includes: CDC"
		lab	var	n5_2	"Participating group includes: Self-help group/ROSCA"
		lab	var	n5_3	"Participating group includes: Women's organization"
		lab	var	n5_4	"Participating group includes: Religious group"
		lab	var	n5_5	"Participating group includes: Other, please specify"
		
	* G: Shocks	
		
		* g1
		forval	shock_num=0/28	{
			egen	g1_`shock_num'	=	anymatch(gg1_1-gg1_31), value(`shock_num')
			replace	g1_`shock_num'	=.	if	a12!=1
		}
		egen	g1__98	=	anymatch(gg1_1-gg1_31), value(-98)
		egen	g1__99	=	anymatch(gg1_1-gg1_31), value(-99)
		
		replace	g1__98	=.	if	gg1_1!=1
		replace	g1__99	=.	if	gg1_1!=1

		order	g1_0-g1__99, before(gg1_1)
		drop	gg1_1-gg1_31
		
		lab	val	g1_0-g1__99	yesno
		
		lab	var	g1_0		"Shocks happend includes: None"
		lab	var	g1_1		"Shocks happend includes: Reduced drinking water quantity"
		lab	var	g1_2		"Shocks happend includes: Reduced drinking water quality"
		lab	var	g1_3		"Shocks happend includes: Reduced agricultural water quality or quantity"
		lab	var	g1_4		"Shocks happend includes: Unusually high level of crop pests or diseases"
		lab	var	g1_5		"Shocks happend includes: Opium eradication"
		lab	var	g1_6		"Shocks happend includes: Unusually high livestock diseases"
		lab	var	g1_7		"Shocks happend includes: Reduced availability of grazing areas"
		lab	var	g1_8		"Shocks happend includes: Reduced availability of Kuchi migration routes"
		lab	var	g1_9		"Shocks happend includes: Earthquakes"
		lab	var	g1_10		"Shocks happend includes: Landslides and avalanches"
		lab	var	g1_11		"Shocks happend includes: Flooding"
		lab	var	g1_12		"Shocks happend includes: Late damaging frosts"
		lab	var	g1_13		"Shocks happend includes: Heavy rains preventing work"
		lab	var	g1_14		"Shocks happend includes: Severe winter conditions"
		lab	var	g1_15		"Shocks happend includes: Hailstorms"
		lab	var	g1_16		"Shocks happend includes: Unusually high level of human disease"
		lab	var	g1_17		"Shocks happend includes: Large influx of returnee households"
		lab	var	g1_18		"Shocks happend includes: Unusually high increases in food prices"
		lab	var	g1_19		"Shocks happend includes: Unusual decrease in farm gate prices"
		lab	var	g1_20		"Shocks happend includes: Loss of employment by a household member"
		lab	var	g1_21		"Shocks happend includes: Reduced salary of a household member"
		lab	var	g1_22		"Shocks happend includes: Bankruptcy of family business"
		lab	var	g1_23		"Shocks happend includes: Serious illness or accident of working household member"
		lab	var	g1_24		"Shocks happend includes: Death of a working household member"
		lab	var	g1_25		"Shocks happend includes: Death or serious illness of other household member"
		lab	var	g1_26		"Shocks happend includes: Theft"
		lab	var	g1_27		"Shocks happend includes: Involuntary loss of house or land"
		lab	var	g1_28		"Shocks happend includes: Loss of livestock"
		lab	var	g1__98		"Shocks happend includes: Don't know"
		lab	var	g1__99		"Shocks happend includes: Don't answer"
				
		* o1 o2
		rename	(go1 go1_a go1_b go1_b_o go2)	(o1 o1_a o1_b o1_b_o o2)
		
		* o3
		forval	reason_num=0/14	{
			egen	o3_`reason_num'	=	anymatch(go3_1-go3_18), value(`reason_num')
			replace	o3_`reason_num'	=.	if	o2!=1 | o1!=1
		}
		
		egen	o3__97	=	anymatch(go3_1-go3_18), value(-97)
		egen	o3__98	=	anymatch(go3_1-go3_18), value(-98)
		egen	o3__99	=	anymatch(go3_1-go3_18), value(-99)
		
		replace	o3__97	=.	if	o2!=1 | o1!=1
		replace	o3__98	=.	if	o2!=1 | o1!=1
		replace	o3__99	=.	if	o2!=1 | o1!=1

		order	o3_0-o3__99, before(go3_1)
		drop	go3_1-go3_18
		rename	go3_o	o3_o
		
		lab	val	o3_0-o3__99	yesno
		
		lab	var	o3_0	"Reason for income loss includes: None"
		lab	var	o3_1	"Reason for income loss includes: Lack of Employment opportunities"
		lab	var	o3_2	"Reason for income loss includes: Loss of necessary assets or inputs/destruction of dwellings"
		lab	var	o3_3	"Reason for income loss includes: Loss of access to input markets"
		lab	var	o3_4	"Reason for income loss includes: Loss of access to output markets"
		lab	var	o3_5	"Reason for income loss includes: No credit available"
		lab	var	o3_6	"Reason for income loss includes: Lack of manpower"
		lab	var	o3_7	"Reason for income loss includes: Vandalism or crime in the area"
		lab	var	o3_8	"Reason for income loss includes: Discrimination"
		lab	var	o3_9	"Reason for income loss includes: Military service"
		lab	var	o3_10	"Reason for income loss includes: Forced military service/abduction"
		lab	var	o3_11	"Reason for income loss includes: Security/landmines"
		lab	var	o3_12	"Reason for income loss includes: Had to pay money to the warring parties"
		lab	var	o3_13	"Reason for income loss includes: Inflation; volatility of prices"
		lab	var	o3_14	"Reason for income loss includes: Setbacks in terms of health caused by violence"
		lab	var	o3__97	"Reason for income loss includes: Other, please specify"
		lab	var	o3__98	"Reason for income loss includes: Don't Answer"
		lab	var	o3__99	"Reason for income loss includes: Don't know"
	
		* o4
		forval	asset_num=1/20	{
			egen	o4_`asset_num'	=	anymatch(go4_1-go4_23), value(`asset_num')
			replace	o4_`asset_num'	=.	if	o1!=1
		}
		egen	o4__97	=	anymatch(go4_1-go4_23), value(-97)
		egen	o4__98	=	anymatch(go4_1-go4_23), value(-98)
		egen	o4__99	=	anymatch(go4_1-go4_23), value(-99)
		
		replace	o4__97	=.	if	o1!=1
		replace	o4__98	=.	if	o1!=1
		replace	o4__99	=.	if	o1!=1
	
		order	o4_1-o4__99, before(go4_1)
		drop	go4_1-go4_23
		rename	go4_o	o4_o
		
		lab	val	o4_1-o4__99	yesno
		
		lab	var	o4_1	"Asset damaged includes: Livestock"
		lab	var	o4_2	"Asset damaged includes: Cultivable land"
		lab	var	o4_3	"Asset damaged includes: Your household's dwelling"
		lab	var	o4_4	"Asset damaged includes: Cultivation tools such as hoe, plough, etc."
		lab	var	o4_5	"Asset damaged includes: Assets for business (e.g. sewing machine, shop premises)"
		lab	var	o4_6	"Asset damaged includes: Mattress"
		lab	var	o4_7	"Asset damaged includes: Bicycle"
		lab	var	o4_8	"Asset damaged includes: Motorcycle/car"
		lab	var	o4_9	"Asset damaged includes: Radio/TV"
		lab	var	o4_10	"Asset damaged includes: Clothes"
		lab	var	o4_11	"Asset damaged includes: Jewelry"
		lab	var	o4_12	"Asset damaged includes: Cell phone"
		lab	var	o4_13	"Asset damaged includes: Blankets"
		lab	var	o4_14	"Asset damaged includes: Rifle/machete"
		lab	var	o4_15	"Asset damaged includes: Tractor"
		lab	var	o4_16	"Asset damaged includes: Torch/flashlight"
		lab	var	o4_17	"Asset damaged includes: Equipment for education"
		lab	var	o4_18	"Asset damaged includes: Shelter material"
		lab	var	o4_19	"Asset damaged includes: Computer"
		lab	var	o4_20	"Asset damaged includes: Documents/certificates"
		lab	var	o4__97	"Asset damaged includes: Other"
		lab	var	o4__98	"Asset damaged includes: Don't Answer"
		lab	var	o4__99	"Asset damaged includes: Don't know"

		*	o5
		rename	go5	o5

		*	o6
		rename	go6o6_*	o6_*
		
		*	o7
		rename	(go7 go7_1 go7_2 go7_2_1o7_2_2 go7_3 go7_3_o)	(o7 o7_1 o7_2 o7_2_2 o7_3 o7_3_o)	
	
	* Direct observation questions
		rename doec consent_direct_obs
		rename do* *	
		
	* Q. Interview summary
		rename	qq*	q*
	
		*	q5
		forval	relat_num=1/30	{
			egen	q5_`relat_num'_temp	=	anymatch(q5_1-q5_30), value(`relat_num')
			replace	q5_`relat_num'_temp	=.	if	q4!=1
		}

		order	q5_1_temp-q5_30_temp, before(q5_1)
		drop	q5_1-q5_30
		rename	q5_*_temp	q5_*
		
		lab	val	q5_1-q5_30	yesno
		
		lab	var	q5_1	"Relative observing interview includes: Grandson"
		lab	var	q5_2	"Relative observing interview includes: Granddaughter"
		lab	var	q5_3	"Relative observing interview includes: Son"
		lab	var	q5_4	"Relative observing interview includes: Son-in-law"
		lab	var	q5_5	"Relative observing interview includes: Daughter"
		lab	var	q5_6	"Relative observing interview includes: Daughter-in-law"
		lab	var	q5_7	"Relative observing interview includes: Brother"
		lab	var	q5_8	"Relative observing interview includes: Brother-in-law"
		lab	var	q5_9	"Relative observing interview includes: Sister"
		lab	var	q5_10	"Relative observing interview includes: Sister-in-law"
		lab	var	q5_11	"Relative observing interview includes: Father"
		lab	var	q5_12	"Relative observing interview includes: Father-in-law"
		lab	var	q5_13	"Relative observing interview includes: Mother"
		lab	var	q5_14	"Relative observing interview includes: Mother-in-law"
		lab	var	q5_15	"Relative observing interview includes: Grandfather"
		lab	var	q5_16	"Relative observing interview includes: Grandmother"
		lab	var	q5_17	"Relative observing interview includes: Uncle"
		lab	var	q5_18	"Relative observing interview includes: Aunt"
		lab	var	q5_19	"Relative observing interview includes: Husband"
		lab	var	q5_20	"Relative observing interview includes: Wife"
		lab	var	q5_21	"Relative observing interview includes: Nephew"
		lab	var	q5_22	"Relative observing interview includes: Niece"
		lab	var	q5_23	"Relative observing interview includes: First cousin (male)"
		lab	var	q5_24	"Relative observing interview includes: First cousin (female)"
		lab	var	q5_25	"Relative observing interview includes: Other male relative"
		lab	var	q5_26	"Relative observing interview includes: Other female relative"
		lab	var	q5_27	"Relative observing interview includes: Other male relatives"
		lab	var	q5_28	"Relative observing interview includes: Other female relatives"
		lab	var	q5_29	"Relative observing interview includes: Female non-relative(s)"
		lab	var	q5_30	"Relative observing interview includes: Male non-relative(s)"
		
	* Rename vars to match the survey
		rename village a6
		
	* Save intermediate dataset
		order 	hhid bl_hhid date a2 a3 hh_head_gender respondent_gender ///
				a12 complete a6, first		
	
	* Recode extended missing
		
		* Variables that are integers or decimals (according to surveyCTO)
		ds b3 b8_year* b8_month* b8_month_to_year* b8_* b11_y* b11_m* b14_a* b14_b* k8* k10* k12* k13* ///
		   k14 k16* k17* k19* k20* k21* k22* k26_* k28_* k32* k33* k34* k3_1_* k4_1_* c*_a* c1 c2 c12_* d2_* ///
		   d9_* e3 e11 l3_* l5_* i4_s i4_d m1_a m4_* m5 m19 m20 m25_* m26_* n6_* o1_a o7_1 o7_2_2 e13 
		loc	integer_list `r(varlist)' 
		
		* Variables that are select_one, but not the ones that are rosters
		ds a10 d13 e1 e2 e4 e5 e6 e7 e9 e8 e10 f1 f2 f3 f6 f7 f10 f11 f14 f14_b f17 f18 f20 ///
			f21 f22 h1 h2 h3 h4 h5 h6 h7 h8 h9 h10 h11 h12 h13 h14 h28 h31 h24 h29 h30 i1_s /// 
			i3_s i1_d i3_d i7 i10 i11 i12 i16 i23 i25 i28_a i28_b i28_c i28_d i28_e i28_f ///
			i28_g i28_h i28_i i28_j i34 i35 i37 i38 i39 i43 i44 i45 i46 i47 j6 j7 j8 j9 ///
			j10 j11 j12 j13 j14 j15 j16 j17 j18 j19 j20 j21 j22 j23 j24 j25 j26 j1 j2 ///
			j3 j4 j5 m23 m1 m10 m16 m20_a m29 m30 m31 m31_a m23 m1 m16 m20_a ///
			n1 n2 n3 n4 o1 o1_b o2 o5 o6_1 o6_2 o6_3 o6_4 o6_5 o6_6 o6_7 o6_8 o6_9 ///
			o6_10 o6_11 o6_12 o6_13 o7 o7_2 o7_3 e12 e14 e15 e16 q2 q4
		loc	selectone_list `r(varlist)' 


		foreach var in `integer_list'  `selectone_list' {
			di "`var'"
			replace `var' = .d if inlist(`var', -99)
			replace `var' = .r if inlist(`var', -98)
		}

		
*** New MDC code starts here

	* Destring all numeric variables 
		qui: destring *, replace
		
	* Back to string
		tostring	m17_o, replace
		tostring a7_o m24_o m6_a_o m12_o m12_other_o  m27_o m28_o c8_s_o* c9_s_o* m17_o i7_da i34_da a9_o_m a11_o c9_s_o* e12_o, replace

	* Drop GPS 
		drop a1Accuracy q8Accuracy

	* Drop SCTO-generated variables not used: _cal_, index, repeat, count, timebegin, etc.
		** Keep: hh_mem_left_* - used to reshape data long for rosters 
		drop *roster* *_cal* *repeat* *count* *_id* *time_begin* *time_end* *time_start* device* SubmissionDate subscriberid starttime endtime ///
			simid namenumber* nameofagecalcfield* oldname_less5 metainstance* *position* formdef_version *_less5_* *_less5* *age* ///
			b8_month_to_year* b8_final* kdkna_livestock dkna_act k_* *loan_relation* imm_t1 imm_t0 time_f kown_business iname_youngest_son iname_youngest_daughter date_f _merge mhaveacct
		
		unab  name : *_name*
		local name_keep "confirm_name confirm_name_2"
		local name_drop : list local name - local name_keep
		drop `name_drop'
	
	* Drop "Other, specify values" in Dari (drop *_o strings)
		drop a11_o b5_o* d1_o b15_o* k6_o* k15_o* k23_a_o* k30_o1 c*_o c*_s_o* d1_o d3_o_r* d6_o d8_o d10_o_r* d3_o_u* d13_o e1_o e4_o e5_o e6_o ///
			e7_o e9_o e8_o l1_o f8_o f9_o f12_o f13_o f4_o f19_o f21_o f22_o i1_s_o i2_s_o i3_s_o i1_d_o i2_d_o i3_d_o j2_o m21_o m24_o m22_o ///
			m2_o* m3_o* m6_o m6_a_o m11_o m12_o m12_h_o m13_o m17_o m27_o m28_o m32_o n5_o g2_o* o1_b_o o3_o o4_o o7_3_o e12_o e14_o e15_o e16_o ///
			m12_other_o a9_o a9_o_m k9_o* k30_o*
	
	label drop enum supname district  
	
	* Save
		keep if complete == 1
			drop complete resp_not_present
		

		if	`c(stata_version)'>=14	{
			saveold "${LHH_interm_bl_nopii}", replace v(13)
		}
		else {
			save "${LHH_interm_bl_nopii}", replace 
		}

				
