/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Sep 12, 2016
Last udpate on: Nov 8, 2019

Written by:  	Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com) and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Prepares the Lady of the Household baseline survey for cleaning. This includes doing modification and corrections based on field reports.


CONTENT:		
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/	


********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* LHH Household Survey ("odkmeta" applied, wide format)
		global	LHH_raw	"${TUP_DB_PII}/Baseline/DataSets/Raw/Lady Household/Baseline_LHH_Dari_training.dta"

	* Duplicates
		global duplicates_bl "${TUP_DB_PII}/EncryptedData\Round Baseline Encrypted\High Frequency Checks"

	* District and village anonymized
		global village_anonymized "${TUP_DB_PII}/Profile_and_merging/DataSets/Intermediate/village_anonymized.dta"
		
	* Profile info
		global profile_info_PII "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/fl1_profile_info.dta"
		
* Outputs

	* Wide format		
		* Cleaned LHH, not including PII
			global LHH_allsvys_raw_bl_nopii "${TUP_DB}/Baseline/DataSets/Raw/LHH_allsvys_raw_bl_nopii.dta"


********************************************************************************
	** Part 1: Data Cleaning
********************************************************************************


use	"${LHH_raw}", clear

	* HH ID
		assert	hh_id	==	hh_id_2
		
		* Fixing use of wrong household ids (according to VAU update on missing hh from 9th April)
			replace hh_id	=	"100381"	if	hh_id	==	"100380"
			replace hh_id	=	"1000120"	if	hh_id	==	"10001120"
			replace hh_id	=	"N300373"	if	hh_id	==	"N300313"	&	a2	==	7
			replace hh_id	=	"300546"	if	hh_id	==	"300547"	&	srpsrcbb3	==	11
		
		* Drop wrong/old survey 
			drop if	hh_id=="N11001186"	&	a2==2				// Garima: as per Hakim's email on March 24
			drop if	hh_id=="300327"		&	!mi(a1Latitude)		// "All_survey_verification_with all comments_June16.xlsx"
			drop if	hh_id=="1000522"	&	date=="4-Apr-2016"	// "All_survey_verification_with all comments_June16.xlsx"
			drop if	hh_id=="1000656"	&	date=="8-Mar-2016"	// "All_survey_verification_with all comments_June16.xlsx"
			drop if	hh_id=="N100338"	&	date=="31-Mar-2016"	// "All_survey_verification_with all comments_June16.xlsx"
			drop if hh_id=="100381"		&	date=="28-Feb-2016"	//	SML: Dropped this since this one was done two months before the next one was done. Can be double-checked
			drop if hh_id=="N1100140"	&	date=="22-Mar-2016"	// "All_survey_verification_with all comments_June16.xlsx"
			drop if hh_id=="N3007611"	&	KEY=="uuid:59bcdc92-eecc-445c-8579-b4e404275ce8"	// This observations seems less complete, but still not sure whether this is the one should be dropped...

		* Fixing household ids for hh where one person interviewed using pre-10Mar ids and the other person using post-10Mar ids
			replace hh_id="N4001619" 	if hhhead_name_file=="Gulbodin" & father_spouse_name_file== "Gul Mohammad"
			replace hh_id="N4001628" 	if hhhead_name_file=="Hajji Mohmmad" & father_spouse_name_file== "Hajji Barfi"
			replace hh_id="N400163"		if hhhead_name_file=="Kabir" & father_spouse_name_file== "Sultan Mohammad"
			replace hh_id="N4001618" 	if hhhead_name_file=="Malim Qudos" & father_spouse_name_file== "Nazar Mohammad"
			replace hh_id="N4001633" 	if hhhead_name_file=="Mohammad Nahim" & father_spouse_name_file== "Ali Ahmad"
			replace hh_id="N400168" 	if hhhead_name_file=="Widow/saied mohammad" & father_spouse_name_file== "Abdul mohammad"
		
		* Update hh_id_2
			replace	hh_id_2=hh_id		
			clonevar bl_hhid = hh_id //  HH id
			lab var bl_hhid "Household ID (Baseline)"
			assert !mi(bl_hhid)
			drop hh_id hh_id_2

	* Rename variables
		rename	hhhead_name_file		hhhead_name
		rename	father_spouse_name_file	father_spouse_name
		rename	srpsrc*					*
		rename	srp*					*
	
	* Additional corrections made before by SML, Garima or RdG: 
		replace	father_spouse_name	=	"Ghulam Ali"	if	father_spouse_name	==	"Ghula Ali"
	
	* Modify village label
		* For unknown reason "village" label in SurveyCTO format has missing label for "1" and "31"
		* From another source ("${data_analysis}/Randomization/Data/Raw/TUP Eligibility/Village_sample_TUP.dta") we could find "1" means "Qezel abad". We will add this village to "village" label
		* RdG (Rebecca) found that "31" indicates "Amin Husain".  a6==31
		lab define village 	1	"Qezel abad" ///
							31	"Amin Husain", add						
							
		* Fixing a6 (village code) for Qazalabad
			replace a6 = 1 if bl_hhid =="N4000224"
			replace a6 = 1 if bl_hhid =="N400028"
			replace a6 = 1 if bl_hhid =="N4000214"
			replace a6 = 1 if bl_hhid =="N4000219"
			replace a6 = 1 if bl_hhid =="N400025"
			replace a6 = 1 if bl_hhid =="N400029"
			replace a6 = 1 if bl_hhid =="N4000222"
			replace a6 = 1 if bl_hhid =="N4000213"
			replace a6 = 1 if bl_hhid =="N400026"
			replace a6 = 1 if bl_hhid =="N400023"
			replace a6 = 1 if bl_hhid =="N4000220"
			replace a6 = 1 if bl_hhid =="N4000218"
			replace a6 = 1 if bl_hhid =="N400024"
			replace a6 = 1 if bl_hhid =="N4000216"
			replace a6 = 1 if bl_hhid =="N400027"
			replace a6 = 1 if bl_hhid =="N4000221"
			replace a6 = 1 if bl_hhid =="N4000215"
			replace a6 = 1 if bl_hhid =="N4000211"
			replace a6 = 1 if bl_hhid =="N400021"
			replace a6 = 1 if bl_hhid =="N4000212"
			replace a6 = 1 if bl_hhid =="N4000210"
			replace a6 = 1 if bl_hhid =="N400022"
			replace a6 = 1 if bl_hhid =="N4000217"
			replace a6 = 1 if bl_hhid =="N4000223"							

	* Correction of duplicates in hhid: Done by SML, explanation in the file
		rename (bl_hhid KEY) (HHID_survey key) //temporaly rename so we can use SML's file
		ieduplicates HHID_survey, folder("${duplicates_bl}") uniquevars(key) keepvars(SubmissionDate starttime endtime hhhead_name b4_1 father_spouse_name a2 a7 a8) suffix(LHH) nodaily
		rename (HHID_survey key) (bl_hhid KEY)
		isid bl_hhid

	* Village
		* Change qezel Abad so it matches village_anonymized dataset
		replace a6 = 89 if a6 == 1
		merge m:1 a6 using "${village_anonymized}", assert(1 3)
		codebook a6 if _merge == 1 // two villages that we don't have
		drop _merge
		label drop village
		
	* Drop unnecessary variables
		drop	*gnn*		
			
	* Merge final HHID using survey key
		isid KEY
		preserve
			use "${profile_info_PII}", clear
			drop if mi(bl_key)
			rename (bl_hhid father_spouse_name hhhead_name) (bl_hhid_prof father_spouse_name_prof hhhead_name_prof)
			isid bl_key
			tempfile profile
			save	`profile'
		restore		
		
		rename KEY bl_key
		isid bl_key
		merge 1:1 bl_key using `profile', keepus(hhid bl_hhid_prof bl_key ultra_poor father_spouse_name_prof hhhead_name_prof)		
		tab ultra_poor _merge, m
		drop if _merge == 2
		
			* Check merge: it seems ok for most of the cases
			*gen tag = 1 if (father_spouse_name_prof != father_spouse_name) | (hhhead_name_prof != hhhead_name)
		
			/*
			Result                           # of obs.
			-----------------------------------------
			not matched                         1,911
				from master                       230  (_merge==1)
				from using                      1,680  (_merge==2)

			matched                             1,182  (_merge==3)
			-----------------------------------------
			

				 HH is |              _merge
			ultra-poor | master on  using onl  matched ( |     Total
			-----------+---------------------------------+----------
					 0 |         0      1,680          0 |     1,680 
					 1 |         0          0      1,181 |     1,181 
					 . |       231          0          0 |       231 
			-----------+---------------------------------+----------
				 Total |       231      1,680      1,181 |     3,092 
			*/

		drop ultra_poor father_spouse_name hhhead_name bl_hhid_prof
		rename (father_spouse_name_prof hhhead_name_prof) (father_spouse_name hhhead_name)
		
		lab var hhhead_name	"Household head name (pre-loaded)"
		lab	var	father_spouse_name	"Father/spouse name (pre-loaded)"
		lab	var	hhhead_name	"Household name (Dari)"		
		
	* GPS coordinates
		gen	double	latitude	=	a1Latitude
		replace		latitude	=	qq8Latitude	if	mi(a1Latitude)
		
		gen	double	longitude	=	a1Longitude
		replace	longitude	=	qq8Longitude	if	mi(a1Longitude)
			
		lab	var	latitude	"Latitude"
		lab	var	longitude	"Longitude"
		
	*----------------*
	* Anonymize data * 
	*----------------*
	
	drop a1Altitude qq8Altitude a6 hhhead_name b4_* namefromearlier* father_spouse_name hhhead_name labor_name* bhhhead_name a1Latitude qq8Latitude a1Longitude qq8Longitude latitude longitude
	
	* Save

		if	`c(stata_version)'>=14	{
			saveold "${LHH_allsvys_raw_bl_nopii}", replace v(13)
		}
		else {
			save "${LHH_allsvys_raw_bl_nopii}", replace
		}