/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Sep 12, 2016
Last udpate on: Nov 13, 2019

Written by:  	Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com) and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the Male Head of the Household baseline survey.


CONTENT:		
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/	


********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* MHHH Household Survey
		global MHHH_allsvys_raw_bl_nopii "${TUP_DB}/Baseline/DataSets/Raw/MHHH_allsvys_raw_bl_nopii.dta"			
		
* Outputs

	* Wide format
		* Cleaned MHHH, not including PII
			global MHHH_interm_bl_nopii "${TUP_DB}/Baseline/DataSets/Intermediate/MHHH_interm_bl_nopii.dta"			
		
********************************************************************************
	** Part 1: Module Data Cleaning
********************************************************************************

use	"${MHHH_allsvys_raw_bl_nopii}", clear

*----------------*
* Basic cleaning *
*----------------*
	
	* Survey respondent present
		loc	var		resp_not_present
		gen	byte	`var'=0											
		replace	`var'=1	if	(a8==0)	
		lab	var	`var'	"No HH respondent available. If NOT available, survey was not done."
			
	* Survey
		gen survey = 2
			lab define survey 1 "LHH" 2 "MHHH" 3 "Targeting" 
			lab val survey survey
			lab var survey "Type of survey administered"
	
	* Enumerator ID, name, and gender
		lab var a2  "Interviewer ID"

	* Supervisor ID and name
		lab var a3 "Supervisor ID"
			
	* Date
		gen		temp=date(date_f,"DMY") 
		order	temp,after(date_f) 
		drop	date_f
		rename	temp	date_f
		format	date_f	%td
		drop if	date_f < 20512
			
		drop		date
		clonevar	date	=	date_f
		replace		date	=	date_a	if	date_v==0
		lab	var		date	"Survey Date"
	
	* Consent vars
		lab var a12 "Survey was consented"	
	
	* Survey complete
		gen complete = (a12==1)
			lab var complete "Survey was completed"
			lab val complete yesno
			
	* Time vars
	
		* Survey time
			gen	double	time_final	=	clock(time,"hms")
			replace		time_final	=	time_a	if	time_v==0
			format		time_final %tcHH:MM:SS
			replace		time_final	=	time_final	+	(date*24*60*60*1000)
			drop		time
			rename		time_final	time
			lab	var		time	"Survey Time"
		
		* Time after consent	&	time after the last question
			gen double	time_start	=	clock(time_startinteraction,"YMD hms")
			gen	double	time_end	=	clock(qtime_end_q,"YMD hms")
		
			format		time_start	time_end %tcHH:MM:SS
			lab	var		time_start	"Time after consent"
			lab	var		time_end	"Time after the last question"
		
*--------------------*
* Cleaning by module *
*--------------------*		
	
	* K. Productive Activities and Assets
	
		* Modify Prefix
		rename	kk*			k*
		rename	ktime_begin_k	time_begin_k
		rename	busilength*	*
		rename	LabResp*	*

			
		* Label & Rename variables
		lab	var	livestock	"HH owns any livestock"
		lab	var	crop		"HH cultivates any crop"
		lab	var	business	"HH owns or operates any business"
		
		rename	(livestock		crop	business)	///
				(k_livestock	k_crop	k_business)
				
		*	Livestock
			rename k6_* k6_temp_*
			forval	livestock_num=1/15	{
				egen	k6_`livestock_num'	=	anymatch(k6_temp_? k6_temp_1?), value(`livestock_num')
				replace	k6_`livestock_num'	=.	if	a12!=1
			}
			egen	k6__98	=	anymatch(k6_temp_? k6_temp_1?), value(-98)
			egen	k6__99	=	anymatch(k6_temp_? k6_temp_1?), value(-99)
			
			replace	k6__98	=.	if	a12!=1
			replace	k6__99	=.	if	a12!=1
			
			lab	var	k6_1	"Livestock household owns includes: Cows"
			lab	var	k6_2	"Livestock household owns includes: Bulls"
			lab	var	k6_3	"Livestock household owns includes: Horses"
			lab	var	k6_4	"Livestock household owns includes: Donkeys"
			lab	var	k6_5	"Livestock household owns includes: Goats"
			lab	var	k6_6	"Livestock household owns includes: Sheep"
			lab	var	k6_7	"Livestock household owns includes: Chickens"
			lab	var	k6_8	"Livestock household owns includes: Ducks"
			lab	var	k6_9	"Livestock household owns includes: Turkeys"
			lab	var	k6_10	"Livestock household owns includes: Gooses"
			lab	var	k6_11	"Livestock household owns includes: Rabbits"
			lab	var	k6_12	"Livestock household owns includes: Guinea fowl"
			lab	var	k6_13	"Livestock household owns includes: Bee hives"
			lab	var	k6_14	"Livestock household owns includes: Other animal 1 (please specify)"
			lab	var	k6_15	"Livestock household owns includes: Other animal 2 (please specify)"
			lab	var	k6__98	"Livestock household owns includes: None"
			lab	var	k6__99	"Livestock household owns includes: Don't know"
			
			rename	(k6_temp_o1 k6_temp_o2)	(k6_o1	k6_o2)
			lab	var	k6_o1	"If other, please specify (1)"
			lab	var	k6_o2	"If other, please specify (2)"
			lab	val	k6_1-k6__99	yesno

			drop	k6_temp_*
			order	k6_1-k6__99, before(k6_o1)		

		*	Household product
		
			rename k9_* k9_temp_*

			forval	HHproduct_num=1/8	{
				egen	k9_`HHproduct_num'	=	anymatch(k9_temp_? k9_temp_10), value(`HHproduct_num')
				replace	k9_`HHproduct_num'	=.	if	a12!=1
			}
			egen	k9__98	=	anymatch(k9_temp_? k9_temp_10), value(-98)
			egen	k9__99	=	anymatch(k9_temp_? k9_temp_10), value(-99)
			
			replace	k9__98	=.	if	a12!=1
			replace	k9__99	=.	if	a12!=1
			
			lab	var	k9_1	"Household product includes: Milk"
			lab	var	k9_2	"Household product includes: Egg"
			lab	var	k9_3	"Household product includes: Honey"
			lab	var	k9_4	"Household product includes: Butter"
			lab	var	k9_5	"Household product includes: Yogurt"
			lab	var	k9_6	"Household product includes: Meat"
			lab	var	k9_7	"Household product includes: Other 1 (please specify)"
			lab	var	k9_8	"Household product includes: Other 2 (please specify)"
			lab	var	k9__98	"Household product owns includes: None"
			lab	var	k9__99	"Household product owns includes: Don't know"
			
			rename (k9_temp_o1 k9_temp_o2) (k9_o1 k9_o2) 
			lab	var	k9_o1	"If other, please specify (1)"
			lab	var	k9_o2	"If other, please specify (2)"
			lab	val	k9_1-k9__99	yesno

			drop	k9_temp_1-k9_temp_10 kdkna_produce
			order	k9_1-k9__99, before(k9_o1)			
				
		*	Crops
		
			rename k15_* k15_temp_*

			forval	crop_num=1/27	{
				egen	k15_`crop_num'	=	anymatch(k15_temp_? k15_temp_1? k15_temp_2?), value(`crop_num')
				replace	k15_`crop_num'	=.	if	a12!=1
			}
			
			egen	k15__98	=	anymatch(k15_temp_? k15_temp_1? k15_temp_2?), value(-98)
			egen	k15__99	=	anymatch(k15_temp_? k15_temp_1? k15_temp_2?), value(-99)
			
			replace	k15__98	=.	if	a12!=1
			replace	k15__99	=.	if	a12!=1
			
			lab	var	k15_1	"Crop cultivated includes: Wheat"
			lab	var	k15_2	"Crop cultivated includes: Vetch"
			lab	var	k15_3	"Crop cultivated includes: Maize"
			lab	var	k15_4	"Crop cultivated includes: Barely"
			lab	var	k15_5	"Crop cultivated includes: Rice"
			lab	var	k15_6	"Crop cultivated includes: Weed"
			lab	var	k15_7	"Crop cultivated includes: Sesame"
			lab	var	k15_8	"Crop cultivated includes: Clover"
			lab	var	k15_9	"Crop cultivated includes: Millet"
			lab	var	k15_10	"Crop cultivated includes: Sharsham"
			lab	var	k15_11	"Crop cultivated includes: Sugarcane"
			lab	var	k15_12	"Crop cultivated includes: Cotton"
			lab	var	k15_13	"Crop cultivated includes: Caraway-seed"
			lab	var	k15_14	"Crop cultivated includes: Potato"
			lab	var	k15_15	"Crop cultivated includes: Cereal"
			lab	var	k15_16	"Crop cultivated includes: Eggplant"
			lab	var	k15_17	"Crop cultivated includes: Tomato"
			lab	var	k15_18	"Crop cultivated includes: Onion"
			lab	var	k15_19	"Crop cultivated includes: Okra"
			lab	var	k15_20	"Crop cultivated includes: Fruits from a tree"
			lab	var	k15_21	"Crop cultivated includes: Grape"
			lab	var	k15_22	"Crop cultivated includes: Mellon"
			lab	var	k15_23	"Crop cultivated includes: Opium"
			lab	var	k15_24	"Crop cultivated includes: Zaghar"
			lab	var	k15_25	"Crop cultivated includes: Saffron"
			lab	var	k15_26	"Crop cultivated includes: Other 1 (please specify)"
			lab	var	k15_27	"Crop cultivated includes: Other 2 (please specify)"
			lab	var	k15__98	"Crop cultivated includes: None"
			lab	var	k15__99	"Crop cultivated includes: Don't know"
			
			rename (k15_temp_o1 k15_temp_o2) (k15_o1 k15_o2)
			lab	var	k15_o1	"If other, please specify (1)"
			lab	var	k15_o2	"If other, please specify (2)"
			lab	val	k15_1-k15__99	yesno

			drop	k15_temp_1-k15_temp_29 kdkna_crop
			order	k15_1-k15__99, before(k15_o1)		
		
		* Business
			rename k23_a* k23_a_temp_*
			forval	biz_num=1/15	{
				egen	k23_a_`biz_num'	=	anymatch(k23_a_temp_? k23_a_temp_1?), value(`biz_num')
				replace	k23_a_`biz_num'	=.	if	a12!=1
			}
			egen	k23_a__98	=	anymatch(k23_a_temp_? k23_a_temp_1?), value(-98)
			egen	k23_a__99	=	anymatch(k23_a_temp_? k23_a_temp_1?), value(-99)
			
			replace	k23_a__98	=.	if	a12!=1
			replace	k23_a__99	=.	if	a12!=1
			
			lab	var	k23_a_1		"Business includes: Selling crafts (baskets, pots, etc.)"
			lab	var	k23_a_2		"Business includes: Repairing bicycles"
			lab	var	k23_a_3		"Business includes: Selling prepared foods/run restaurant"
			lab	var	k23_a_4		"Business includes: Selling raw produce (NOT cultivated by respondent but purchased elsewhere)"
			lab	var	k23_a_5		"Business includes: Providing transportation"
			lab	var	k23_a_6		"Business includes: Making bricks"
			lab	var	k23_a_7		"Business includes: Butchering"
			lab	var	k23_a_8		"Business includes: Doing carpentry"
			lab	var	k23_a_9		"Business includes: Selling clothes and sheets"
			lab	var	k23_a_10	"Business includes: Building thatch or iron sheet roofs"
			lab	var	k23_a_11	"Business includes: Constructing houses/buildings"
			lab	var	k23_a_12	"Business includes: Drilling boreholes/building latrines"
			lab	var	k23_a_13	"Business includes: Collecting and selling firewood"
			lab	var	k23_a_14	"Business includes: Other 1 (please specify)"
			lab	var	k23_a_15	"Business includes: Other 2 (please specify)"
			lab	var	k23_a__98	"Business includes: None"
			lab	var	k23_a__99	"Business includes: Don't know"
			
			rename	(k23_a_temp__o1 k23_a_temp__o2) (k23_a_o1 k23_a_o2)
			lab	var	k23_a_o1	"If other, please specify (1)"
			lab	var	k23_a_o2	"If other, please specify (2)"
			lab	val	k23_a_1-k23_a__99	yesno

			drop	k23_a_temp_1-k23_a_temp_17 kdkna_business
			order	k23_a_1-k23_a__99, before(k23_a_o1)
		
		
		* Activities
			rename k1_1_* k1_1_temp_*
			forval	act_num=1/9	{
				egen	k1_1_`act_num'	=	anymatch(k1_1_temp_? k1_1_temp_1?), value(`act_num')
				replace	k1_1_`act_num'	=.	if	a12!=1
			}
			egen	k1_1_0		=	anymatch(k1_1_temp_? k1_1_temp_1?), value(0)
			egen	k1_1__98	=	anymatch(k1_1_temp_? k1_1_temp_1?), value(-98)
			egen	k1_1__99	=	anymatch(k1_1_temp_? k1_1_temp_1?), value(-99)
			
			replace	k1_1_0		=.	if	a12!=1
			replace	k1_1__98	=.	if	a12!=1
			replace	k1_1__99	=.	if	a12!=1
			
			lab	var	k1_1_1		"Activity includes: Tend any animals owned or leased by the household"
			lab	var	k1_1_2		"Activity includes: Farm land owned or sharecropped by the household"
			lab	var	k1_1_3		"Activity includes: Work on business owned by household other than farm/animals (e.g. shop, crafts)"
			lab	var	k1_1_4		"Activity includes: Work as an agricultural laborer outside household"
			lab	var	k1_1_5		"Activity includes: Do housework in someone else's home"
			lab	var	k1_1_6		"Activity includes: Work as a non-agricultural laborer outside the household (other than housework)"
			lab	var	k1_1_7		"Activity includes: Work in salaried/formal employment"
			lab	var	k1_1_8		"Activity includes: Do any other work for pay  (money or in-kind)"
			lab	var	k1_1_9		"Activity includes: Work on household chores (e.g. collecting water, cooking, cleaning) in your household"
			lab	var	k1_1_0		"Activity includes: None"
			lab	var	k1_1__98	"Activity includes: Don't answer"
			lab	var	k1_1__99	"Activity includes: Don't know"
			
			lab	val	k1_1_1-k1_1__99	yesno
			drop	k1_1_temp_1-dkna_act
			order	k1_1_1-k1_1__99, before(act_id1)						
					
	* I: Aspirations & Psychological Well-being	
		rename	ii*	i*	
		rename	ipsychwellai*	i*
		rename	ipsychwellbi*	i*
		rename	ipsychwellci*	i*			
		rename	ipsychwelldi*	i*	
		
		lab var i27 "Taking all things together, would you say you are.."
		
	* J: Entrepreneurship
		rename jentrepj* j*
		rename jj* j*
		rename jtime_begin_j time_begin_j
	
		lab var j17 "It is important for me to do whatever I’m doing as well as I can.."
		
	*	M-1: Credit and Savings 
		
		*	m21
			forval	acc_num=1/6	{
				egen	m21_`acc_num'	=	anymatch(mm21_1-mm21_8), value(`acc_num')
				replace	m21_`acc_num'	=.	if	(a8==0	|	a12==0)
			}
			egen	m21__97	=	anymatch(mm21_1-mm21_8), value(-97)
			egen	m21__99	=	anymatch(mm21_1-mm21_8), value(-99)
			
			replace	m21__97	=.	if	(a8==0	|	a12==0)
			replace	m21__99	=.	if	(a8==0	|	a12==0)
			
			order	m21_1-m21__99, before(mm21_1)
			drop	mm21_1-mm21_8
			rename	mm21_o m21_o
			
			lab	val	m21_1-m21__99	yesno
			
			lab	var	m21_1	"Saving places includes: In formal bank"
			lab	var	m21_2	"Saving places includes: At home"
			lab	var	m21_3	"Saving places includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m21_4	"Saving places includes: With Microfinance institution"
			lab	var	m21_5	"Saving places includes: At post office"
			lab	var	m21_6	"Saving places includes: With another individual (not a formal bank)"
			lab	var	m21__97	"Saving places includes: Other (specify)"
			lab	var	m21__99	"Saving places includes: Don't know"		
		
		rename mm23 m23
		
		* m24
			egen	m24_1	=	anymatch(mm24_1 mm24_2 mm24_3), value(1)
			egen	m24_2	=	anymatch(mm24_1 mm24_2 mm24_3), value(2)	
			egen	m24__97	=	anymatch(mm24_1 mm24_2 mm24_3), value(-97)	
			
			replace	m24_1	=.	if	m23!=1
			replace	m24_2	=.	if	m23!=1
			replace	m24__97	=.	if	m23!=1
			
			order	m24_1-m24__97, before(mm24_1)
			drop	mm24_1 mm24_2 mm24_3
			rename	mm24_o	m24_o
			
			lab	val	m24_1-m24__97	yesno
			
			lab	var	m24_1	"Account having includes: Formal bank"
			lab	var	m24_2	"Account having includes: Microfinance institution"
			lab	var	m24__97	"Account having includes: Other (please specify)"
		
		* m22
			forval	loan_num=0/9	{
				egen	m22_`loan_num'	=	anymatch(mm22_1-mm22_13), value(`loan_num')
				replace	m22_`loan_num'	=.	if	(a8==0	|	a12==0)
			}
			egen	m22__97	=	anymatch(mm22_1-mm22_13), value(-97)
			egen	m22__98	=	anymatch(mm22_1-mm22_13), value(-98)
			egen	m22__99	=	anymatch(mm22_1-mm22_13), value(-99)
			
			replace	m22__97	=.	if	(a8==0	|	a12==0)
			replace	m22__98	=.	if	(a8==0	|	a12==0)
			replace	m22__99	=.	if	(a8==0	|	a12==0)
			
			order	m22_0-m22__99, before(mm22_1)
			drop	mm22_1-mm22_13
			rename	mm22_o m22_o
			
			lab	val	m22_0-m22__99	yesno
			
			lab	var	m22_0	"Available loan includes: I would not be able to get a loan"
			lab	var	m22_1	"Available loan includes: Formal banks"
			lab	var	m22_2	"Available loan includes: Microfinance institution"
			lab	var	m22_3	"Available loan includes: Landlord"
			lab	var	m22_4	"Available loan includes: Employer"
			lab	var	m22_5	"Available loan includes: Relative"
			lab	var	m22_6	"Available loan includes: Friend"
			lab	var	m22_7	"Available loan includes: Local money lender"
			lab	var	m22_8	"Available loan includes: ROSCA/chit fund/merry-go-round"
			lab	var	m22_9	"Available loan includes: I would not need a loan as I would draw on my savings/sell an asset"
			lab	var	m22__97	"Available loan includes: Other (please specify)"
			lab	var	m22__98	"Available loan includes: Don't Answer"
			lab	var	m22__99	"Available loan includes: Don’t know"		
	
		* m5
			rename (mm1 mm1_a mm5) (m1 m1_a m5)
	
		* m6
			forval	loan_num=1/5	{
				egen	m6_`loan_num'	=	anymatch(mm6_1-mm6_7), value(`loan_num')
				replace	m6_`loan_num'	=.	if	m1!=0
			}
			egen	m6__98	=	anymatch(mm6_1-mm6_7), value(-98)
			egen	m6__99	=	anymatch(mm6_1-mm6_7), value(-99)
			
			replace	m6__98	=.	if	m1!=0
			replace	m6__99	=.	if	m1!=0
			
			order	m6_1-m6__99, before(mm6_1)
			drop	mm6_1-mm6_7
			rename	mm6_o	m6_o
			
			lab	val	m6_1-m6__99	yesno
			
			lab	var	m6_1	"Reason for no loan includes: Didn’t need it"
			lab	var	m6_2	"Reason for no loan includes: Asked for a loan but was denied"
			lab	var	m6_3	"Reason for no loan includes: No available source of credit"
			lab	var	m6_4	"Reason for no loan includes: Lenders not willing to lend to people like me"
			lab	var	m6_5	"Reason for no loan includes: It's too risky to borrow"
			lab	var	m6__98	"Reason for no loan includes: Don't Answer"
			lab	var	m6__99	"Reason for no loan includes: Don’t know"		
	
		* m6_a
			forval	loan_num=1/9	{
				egen	m6_a_`loan_num'	=	anymatch(mm6_a1-mm6_a12), value(`loan_num')
				replace	m6_a_`loan_num'	=.	if	m6_2!=1
			}
			egen	m6_a__97	=	anymatch(mm6_a1-mm6_a12), value(-97)
			egen	m6_a__98	=	anymatch(mm6_a1-mm6_a12), value(-98)
			egen	m6_a__99	=	anymatch(mm6_a1-mm6_a12), value(-99)
			
			replace	m6_a__97	=.	if	m6_2!=1
			replace	m6_a__98	=.	if	m6_2!=1
			replace	m6_a__99	=.	if	m6_2!=1
			
			order	m6_a_1-m6_a__99, before(mm6_a1)
			drop	mm6_a1-mm6_a12
			rename	mm6_a_o	m6_a_o
			
			lab	val	m6_a_1-m6_a__99	yesno
			
			lab	var	m6_a_1	"Loan rejected includes: Formal banks"
			lab	var	m6_a_2	"Loan rejected includes: Microfinance institution"
			lab	var	m6_a_3	"Loan rejected includes: Landlord"
			lab	var	m6_a_4	"Loan rejected includes: Employer"
			lab	var	m6_a_5	"Loan rejected includes: Relative"
			lab	var	m6_a_6	"Loan rejected includes: Friend"
			lab	var	m6_a_7	"Loan rejected includes: Local money lender"
			lab	var	m6_a_8	"Loan rejected includes: ROSCA/chit fund/merry-go-round"
			lab	var	m6_a_9	"Loan rejected includes: Grocery shop"
			lab	var	m6_a__97	"Loan rejected includes: Other (please specify)"
			lab	var	m6_a__98	"Loan rejected includes: Don't Answer"
			lab	var	m6_a__99	"Loan rejected includes: Don’t know"
		
		rename	mm10	m10
	
		* m11
			egen	m11_1	=	anymatch(mm11_1-mm11_5), value(1)
			egen	m11_2	=	anymatch(mm11_1-mm11_5), value(2)
			egen	m11__97	=	anymatch(mm11_1-mm11_5), value(-97)
			egen	m11__98	=	anymatch(mm11_1-mm11_5), value(-98)
			egen	m11__99	=	anymatch(mm11_1-mm11_5), value(-99)
			
			replace	m11_1	=.	if	m10!=1
			replace	m11_2	=.	if	m10!=1
			replace	m11__97	=.	if	m10!=1
			replace	m11__98	=.	if	m10!=1
			replace	m11__99	=.	if	m10!=1
			
			order	m11_1-m11__99, before(mm11_1)
			drop	mm11_1-mm11_5
			rename	mm11_o	m11_o
			
			lab	val	m11_1-m11__99	yesno
			
			lab	var	m11_1	"In-kind loan purpose includes: Provide input for business"
			lab	var	m11_2	"In-kind loan purpose includes: Provide support to household"
			lab	var	m11__97	"In-kind loan purpose includes: Other (please specify)"
			lab	var	m11__98	"In-kind loan purpose includes: Don't Answer"
			lab	var	m11__99	"In-kind loan purpose includes: Don't know"	
	
		* m12
			forval	biz_num=1/5	{
				egen	m12_`biz_num'	=	anymatch(mm12_1-mm12_7), value(`biz_num')
				replace	m12_`biz_num'	=.	if	m11_1!=1
			}
			egen	m12__97	=	anymatch(mm12_1-mm12_7), value(-97)
			egen	m12__98	=	anymatch(mm12_1-mm12_7), value(-98)
			
			replace	m12__97	=.	if	m11_1!=1
			replace	m12__98	=.	if	m11_1!=1
			
			order	m12_1-m12__98, before(mm12_1)
			drop	mm12_1-mm12_7
			rename	mm12_o	m12_o
			
			lab	val	m12_1-m12__98	yesno
			
			lab	var	m12_1	"Purchased for business includes: Work materials"
			lab	var	m12_2	"Purchased for business includes: Clothes, pots, pans, pails, etc."
			lab	var	m12_3	"Purchased for business includes: Uncooked produce"
			lab	var	m12_4	"Purchased for business includes: Meals"
			lab	var	m12_5	"Purchased for business includes: Livestock"
			lab	var	m12__97	"Purchased for business includes: Other (please specify)"
			lab	var	m12__98	"Purchased for business includes: Don't Answer"
			
		* m12_h
			forval	hh_num=1/5	{
				egen	m12_h_`hh_num'	=	anymatch(mm12_h1-mm12_h7), value(`hh_num')
				replace	m12_h_`hh_num'	=.	if	m11_2!=1
			}
			egen	m12_h__97	=	anymatch(mm12_h1-mm12_h7), value(-97)
			egen	m12_h__98	=	anymatch(mm12_h1-mm12_h7), value(-98)
			
			replace	m12_h__97	=.	if	m11_2!=1
			replace	m12_h__98	=.	if	m11_2!=1
			
			order	m12_h_1-m12_h__98, before(mm12_h1)
			drop	mm12_h1-mm12_h7
			rename	mm12_h_o	m12_h_o
			
			lab	val	m12_h_1-m12_h__98	yesno
			
			lab	var	m12_h_1	"Purchased for household includes: Work materials"
			lab	var	m12_h_2	"Purchased for household includes: Clothes, pots, pans, pails, etc."
			lab	var	m12_h_3	"Purchased for household includes: Uncooked produce"
			lab	var	m12_h_4	"Purchased for household includes: Meals"
			lab	var	m12_h_5	"Purchased for household includes: Livestock"
			lab	var	m12_h__97	"Purchased for household includes: Other (please specify)"
			lab	var	m12_h__98	"Purchased for household includes: Don't Answer"	
	
		* m12_other
			forval	other_num=1/5	{
				egen	m12_other_`other_num'	=	anymatch(mm12_other1-mm12_other7), value(`other_num')
				replace	m12_other_`other_num'	=.	if	m11__97!=1
			}
			egen	m12_other__97	=	anymatch(mm12_other1-mm12_other7), value(-97)
			egen	m12_other__98	=	anymatch(mm12_other1-mm12_other7), value(-98)
			
			replace	m12_other__97	=.	if	m11__97!=1
			replace	m12_other__98	=.	if	m11__97!=1
			
			order	m12_other_1-m12_other__98, before(mm12_other1)
			drop	mm12_other1-mm12_other7
			rename	mm12_other_o	m12_other_o
			
			lab	val	m12_other_1-m12_other__98	yesno
			
			lab	var	m12_other_1	"Purchased for other purpose includes: Work materials"
			lab	var	m12_other_2	"Purchased for other purpose includes: Clothes, pots, pans, pails, etc."
			lab	var	m12_other_3	"Purchased for other purpose includes: Uncooked produce"
			lab	var	m12_other_4	"Purchased for other purpose includes: Meals"
			lab	var	m12_other_5	"Purchased for other purpose includes: Livestock"
			lab	var	m12_other__97	"Purchased for other purpose includes: Other (please specify)"
			lab	var	m12_other__98	"Purchased for other purpose includes: Don't Answer"

		* m13
			forval	other_num=1/9	{
				egen	m13_`other_num'	=	anymatch(mm13_1-mm13_12), value(`other_num')
				replace	m13_`other_num'	=.	if	m10!=1
			}
			egen	m13__97	=	anymatch(mm13_1-mm13_12), value(-97)
			egen	m13__98	=	anymatch(mm13_1-mm13_12), value(-98)
			egen	m13__99	=	anymatch(mm13_1-mm13_12), value(-99)
			
			replace	m13__97	=.	if	m10!=1
			replace	m13__98	=.	if	m10!=1
			replace	m13__99	=.	if	m10!=1

			order	m13_1-m13__99, before(mm13_1)
			drop	mm13_1-mm13_12
			rename	mm13_o	m13_o
			
			lab	val	m13_1-m13__99	yesno
			
			lab	var	m13_1	"In-kind loan source includes: Formal banks"
			lab	var	m13_2	"In-kind loan source includes: Microfinance institution"
			lab	var	m13_3	"In-kind loan source includes: Landlord"
			lab	var	m13_4	"In-kind loan source includes: Employer"
			lab	var	m13_5	"In-kind loan source includes: Relative"
			lab	var	m13_6	"In-kind loan source includes: Friend"
			lab	var	m13_7	"In-kind loan source includes: Local money lender"
			lab	var	m13_8	"In-kind loan source includes: ROSCA/chit fund/merry-go-round"
			lab	var	m13_9	"In-kind loan source includes: Grocery shop"
			lab	var	m13__97	"In-kind loan source includes: Other (please specify)"
			lab	var	m13__98	"In-kind loan source includes: Don't Answer"
			lab	var	m13__99	"In-kind loan source includes: Don’t know"
		
		rename	mm16	m16
	
		* m17
			forval	save_num=1/6	{
				egen	m17_`save_num'	=	anymatch(mm17_1-mm17_8), value(`save_num')
				replace	m17_`save_num'	=.	if	m16!=1
			}
			egen	m17__97	=	anymatch(mm17_1-mm17_8), value(-97)
			egen	m17__99	=	anymatch(mm17_1-mm17_8), value(-99)
			
			replace	m17__97	=.	if	m16!=1
			replace	m17__99	=.	if	m16!=1

			order	m17_1-m17__99, before(mm17_1)
			drop	mm17_1-mm17_8
			rename	mm17_o	m17_o
			
			lab	val	m17_1-m17__99	yesno
			
			lab	var	m17_1	"Saving money includes: In formal bank"
			lab	var	m17_2	"Saving money includes: At home"
			lab	var	m17_3	"Saving money includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m17_4	"Saving money includes: With Microfinance institution"
			lab	var	m17_5	"Saving money includes: At post office"
			lab	var	m17_6	"Saving money includes: With another individual (not a formal bank)"
			lab	var	m17__97	"Saving money includes: Other (specify)"
			lab	var	m17__99	"Saving money includes: Don't know"
				
		rename	(mm19 mm20_a mm20)	(m19 m20_a m20)
		replace	m20=.	if	m20_a<=0	
	
		* Formal account
		
		rename (mexperienceBankm25_y mexperienceBankm25_m mexperienceMFIm26_y mexperienceMFIm26_m) ///
				(m25_y m25_m m26_y m26_m)
		lab	var	m25_y	"For how long have you been in a relationship with the formal bank? (years)"
		lab	var	m25_m	"For how long have you been in a relationship with the formal bank? (months)"
		lab	var	m26_y	"For how long have you been in a relationship with MFI? (years)"
		lab	var	m26_m	"For how long have you been in a relationship with MFI? (months)"
	
			* m27
				forval	acc_num=0/5	{
					egen	m27_`acc_num'	=	anymatch(mexperiencem27_1-mexperiencem27_7), value(`acc_num')
					replace	m27_`acc_num'	=.	if	(mi(m25_y) & mi(m26_y))
				}
				egen	m27__97	=	anymatch(mexperiencem27_1-mexperiencem27_7), value(-97)
				
				replace	m27__97	=.	if	(mi(m25_y) & mi(m26_y))

				order	m27_0-m27__97, before(mexperiencem27_1)
				drop	mexperiencem27_1-mexperiencem27_7
				rename	mexperiencem27_o	m27_o
				
				lab	val	m27_0-m27__97	yesno
				
				lab	var	m27_0	"Saving benefit includes: No benefits"
				lab	var	m27_1	"Saving benefit includes: Encouraged to save"
				lab	var	m27_2	"Saving benefit includes: Received better management of savings"
				lab	var	m27_3	"Saving benefit includes: Aided in sending remittances"
				lab	var	m27_4	"Saving benefit includes: Aided in receiving remittances"
				lab	var	m27_5	"Saving benefit includes: Aided in obtaining a loan"
				lab	var	m27__97	"Saving benefit includes: Other (please specify)"
		
			* m28
				forval	imp_num=0/5	{
					egen	m28_`imp_num'	=	anymatch(mexperiencem28_1-mexperiencem28_7), value(`imp_num')
					replace	m28_`imp_num'	=.	if	(mi(m25_y) & mi(m26_y))
				}
				egen	m28__97	=	anymatch(mexperiencem28_1-mexperiencem28_7), value(-97)
				
				replace	m28__97	=.	if	(mi(m25_y) & mi(m26_y))

				order	m28_0-m28__97, before(mexperiencem28_1)
				drop	mexperiencem28_1-mexperiencem28_7
				rename	mexperiencem28_o	m28_o
				
				lab	val	m28_0-m28__97	yesno
				
				lab	var	m28_0	"Things to be improved includes: No improvement"
				lab	var	m28_1	"Things to be improved includes: Simpler application procedure (for deposit and loans)"
				lab	var	m28_2	"Things to be improved includes: Reduced application processing time (for deposit and loans)"
				lab	var	m28_3	"Things to be improved includes: Easier access to bank branch"
				lab	var	m28_4	"Things to be improved includes: Easier access to ATM"
				lab	var	m28_5	"Things to be improved includes: Reduced fees for transactions"
				lab	var	m28__97	"Things to be improved includes: Other (please specify)"
		
			rename	(mexperiencem29 mexperiencem30 mexperiencem30_a)	(m29 m30 m30_a)
		
		* Business Opportunity
			rename	(mm31 mm31_a mm31_a_a)	(m31 m31_a m31_a_a)
			
			*	m32
			forval	reason_num=1/9	{
				egen	m32_`reason_num'	=	anymatch(mm32_1-mm32_11), value(`reason_num')
				replace	m32_`reason_num'	=.	if	mi(mm32_1)
			}
			egen	m32__97	=	anymatch(mm32_1-mm32_11), value(-97)
			egen	m32__99	=	anymatch(mm32_1-mm32_11), value(-99)
			
			replace	m32__97	=.	if	mi(mm32_1)
			replace	m32__99	=.	if	mi(mm32_1)

			order	m32_1-m32__99, before(mm32_1)
			drop	mm32_1-mm32_11
			rename	mm32_o	m32_o
			
			lab	val	m32_1-m32__99	yesno
			
			lab	var	m32_1	"Reason for not having account includes: financial institutions are too far away"
			lab	var	m32_2	"Reason for not having account includes: financial services are too expensive"
			lab	var	m32_3	"Reason for not having account includes: don't have the necessary documentation (id card, wage slip, etc.)"
			lab	var	m32_4	"Reason for not having account includes: don't trust financial institutions"
			lab	var	m32_5	"Reason for not having account includes: religious reasons"
			lab	var	m32_6	"Reason for not having account includes: don't have enough money to use financial institutions"
			lab	var	m32_7	"Reason for not having account includes: someone else in the family already has an account"
			lab	var	m32_8	"Reason for not having account includes: cannot get an account"
			lab	var	m32_9	"Reason for not having account includes: no need for financial services at a formal institution"
			lab	var	m32__97	"Reason for not having account includes: other (please specify)"
			lab	var	m32__99	"Reason for not having account includes: don't answer"				
			
			
	* Q. Interview summary
		rename	qq*	q*
	
		*	q5
		forval	relat_num=1/30	{
			egen	q5_`relat_num'_temp	=	anymatch(q5_1-q5_30), value(`relat_num')
			replace	q5_`relat_num'_temp	=.	if	q4!=1
		}

		order	q5_1_temp-q5_30_temp, before(q5_1)
		drop	q5_1-q5_30
		rename	q5_*_temp	q5_*
		
		lab	val	q5_1-q5_30	yesno
		
		lab	var	q5_1	"Relative observing interview includes: Grandson"
		lab	var	q5_2	"Relative observing interview includes: Granddaughter"
		lab	var	q5_3	"Relative observing interview includes: Son"
		lab	var	q5_4	"Relative observing interview includes: Son-in-law"
		lab	var	q5_5	"Relative observing interview includes: Daughter"
		lab	var	q5_6	"Relative observing interview includes: Daughter-in-law"
		lab	var	q5_7	"Relative observing interview includes: Brother"
		lab	var	q5_8	"Relative observing interview includes: Brother-in-law"
		lab	var	q5_9	"Relative observing interview includes: Sister"
		lab	var	q5_10	"Relative observing interview includes: Sister-in-law"
		lab	var	q5_11	"Relative observing interview includes: Father"
		lab	var	q5_12	"Relative observing interview includes: Father-in-law"
		lab	var	q5_13	"Relative observing interview includes: Mother"
		lab	var	q5_14	"Relative observing interview includes: Mother-in-law"
		lab	var	q5_15	"Relative observing interview includes: Grandfather"
		lab	var	q5_16	"Relative observing interview includes: Grandmother"
		lab	var	q5_17	"Relative observing interview includes: Uncle"
		lab	var	q5_18	"Relative observing interview includes: Aunt"
		lab	var	q5_19	"Relative observing interview includes: Husband"
		lab	var	q5_20	"Relative observing interview includes: Wife"
		lab	var	q5_21	"Relative observing interview includes: Nephew"
		lab	var	q5_22	"Relative observing interview includes: Niece"
		lab	var	q5_23	"Relative observing interview includes: First cousin (male)"
		lab	var	q5_24	"Relative observing interview includes: First cousin (female)"
		lab	var	q5_25	"Relative observing interview includes: Other male relative"
		lab	var	q5_26	"Relative observing interview includes: Other female relative"
		lab	var	q5_27	"Relative observing interview includes: Other male relatives"
		lab	var	q5_28	"Relative observing interview includes: Other female relatives"
		lab	var	q5_29	"Relative observing interview includes: Female non-relative(s)"
		lab	var	q5_30	"Relative observing interview includes: Male non-relative(s)"
	
	* Rename vars to match the survey
		rename village a6

	* Recode extended missing
		
		* Variables that are integers or decimals (according to surveyCTO)
		ds k8* k10* k12* k13* ///
		   k14 k16* k17* k19* k20* k21* k22* k26_* k28_* k32* k33* k34* k3_1_* k4_1_*  ///
		   m1_a m4_* m5 m19 m20 m25_* m26_* 
		loc	integer_list `r(varlist)' 
		
		* Variables that are select_one, but not the ones that are rosters
		ds a10 i7 i10 i11 i12 i16 i23 i25 i28_a i28_b i28_c i28_d i28_e i28_f ///
			i28_g i28_h i28_i i28_j i34 i35 i37 i38 i39 i43 i44 i45 i46 i47 j6 j7 j8 j9 ///
			j10 j11 j12 j13 j14 j15 j16 j17 j18 j19 j20 j21 j22 j23 j24 j25 j26 j1 j2 ///
			j3 j4 j5 m23 m1 m10 m16 m20_a m29 m30 m31 m31_a m23 m1 m16 m20_a ///
			q2 q4
		loc	selectone_list `r(varlist)' 

		foreach var in `integer_list'  `selectone_list' {
			di "`var'"
			replace `var' = .d if inlist(`var', -99) //, 99)
			replace `var' = .r if inlist(`var', -98) // , 98)
		}	
	
	
*** New MDC code starts here

	* Destring all numeric variables 
		qui: destring *, replace
		
	* Fix some variables
		 tostring i7_da i28_da i34_da, replace
		 rename hh_id bl_hhid
		 
	* Drop GPS 
		drop a1Accuracy q8Accuracy

	* Drop SCTO-generated variables not used: _cal_, index, repeat, count, timebegin, etc.
		** Keep: hh_mem_left_* - used to reshape data long for rosters 
		drop *_cal* *repeat* *_id* *count* *time_begin* *time_end* *time_start* device* SubmissionDate subscriberid starttime endtime ///
			 simid metainstance* formdef_version kdkna_livestock *loan_relation* time_f kown_business tag* date_f mhaveacct
			 
		unab  name : *_name*
		local name_keep "confirm_name confirm_name_2"
		local name_drop : list local name - local name_keep
		drop `name_drop'
	
	* Drop "Other, specify values" in Dari (drop *_o strings)
		drop a11_o k6_o* k15_o* k23_a_o* j2_o m21_o m24_o m22_o m2_o* m3_o* m6_o m6_a_o m11_o m12_o m12_h_o m13_o m17_o m27_o m28_o m32_o ///
			m12_other_o a9_o k9_o*
	
		label drop enum supname district  
	
	* Save intermediate dataset
		rename * *_m
		rename bl_hhid_m bl_hhid
		order  bl_hhid date_m a2_m a3_m ///
				a12_m complete_m a6_m, first		
				
		keep if complete_m == 1
			drop complete_m

		if	`c(stata_version)'>=14	{
			saveold "${MHHH_interm_bl_nopii}", replace v(13)
		}
		else {
			save "${MHHH_interm_bl_nopii}", replace
		}			
			
