/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Sep 12, 2016
Last udpate on: Nov 13, 2019

Written by:  	Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com) and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Prepares the Male Head of the Household baseline survey for cleaning. 
				This includes doing modification and corrections based on field reports.

CONTENT:		
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/	


********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* LHH Household Survey ("odkmeta" applied, wide format)
		global	MHHH_raw	"${TUP_DB_PII}/Baseline/DataSets/Raw/Male Household Head/Baseline_MALEHead_Dari_training.dta"

	* Duplicates
		global duplicates_bl "${TUP_DB_PII}/Baseline/DataSets/Intermediate/Duplicates"
		
	* District and village anonymized
		global village_anonymized "${TUP_DB_PII}/Profile_and_merging/DataSets/Intermediate/village_anonymized.dta"
		
	* Profile info
		global profile_info_PII "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/fl1_profile_info.dta"
		
* Outputs

	* Wide format		
		* Cleaned MHHH, not including PII
			global MHHH_allsvys_raw_bl_nopii "${TUP_DB}/Baseline/DataSets/Raw/MHHH_allsvys_raw_bl_nopii.dta"			
		
********************************************************************************
	** Part 1: Data Cleaning
********************************************************************************


use	"${MHHH_raw}", clear

	* Drop surveys which couldn't be conducted as respondent not present, but later HH was re-visited and conducted
		drop	if	inlist(KEY, "uuid:3e723c44-cfbb-4beb-81fb-0a01fcdf2c21",	///
								"uuid:9dd91e89-cb6c-4b02-858a-b98835fba07b",	///
								"uuid:cb04eb7b-6649-44ba-85e5-3ed44974d407",	///
								"uuid:df90ee10-5687-4f3c-9774-1d6f11ad8a24",	///
								"uuid:726c8b08-295f-48e1-b935-b68b41612163")

	* HH ID
		assert	hh_id	==	hh_id_2
						
		* Duplicates & wrong ids
		duplicates tag hh_id, gen(tag2)
		/*replace hh_id = "300343-2" if hh_id=="300343" & /* k6=="7" */ srpsrckk6_1==7*/ // Garima's code
		drop	if	hh_id=="300343"	&	KEY=="uuid:21a55c63-c6e7-418a-b236-59bd52e2a60c"	// SML: This obs is the 1st submission (the other is the second), has less answers, missing hhhead name, and submitted 9 days after suvery was done 
		
		/*replace hh_id="N1100176-2" if hh_id=="N1100176" & a2==6*/	//	Garima's code
		drop	if	hh_id=="N1100176"	&	date!="23-Apr-2016"	// SML: According to Mohommad's comment, April 23 is noted as a survey date.
		
		replace tag2=0 if inlist(hh_id,"300343","300343-2","N1100176","N1100176-2")
			
		* Before we clean hh_id, we confirm that hh_id==hh_id_2, so we can update hh_id_2 after making all changes to hh_id
		*assert	hh_id==hh_id_2
		*rename	hh_id	hhid
		
		*Fixing household ids for hh where one person interviewed using pre-10Mar ids and the other person using post-10Mar ids
		replace hh_id="N4001619" if hhhead_name_file=="Gulbodin" & father_spouse_name_file== "Gul Mohammad"
		replace hh_id="N4001628" if hhhead_name_file=="Hajji Mohmmad " & father_spouse_name_file== "Hajji Barfi"
		replace hh_id="N400163" if hhhead_name_file=="Kabir " & father_spouse_name_file== "Sultan Mohammad "
		replace hh_id="N4001618" if hhhead_name_file=="Malim Qudos" & father_spouse_name_file== "Nazar Mohammad"
		replace hh_id="N4001633" if hhhead_name_file=="Mohammad Nahim" & father_spouse_name_file== "Ali Ahmad "
		replace hh_id="N400168" if hhhead_name_file=="Widow/saied mohammad" & father_spouse_name_file== "Abdul mohammad"
		
		* Keep only the latest visit for households which were visited multiple times
		drop if (hh_id=="N1004227" & a7==2)
		drop if (hh_id=="N1100155" & a7==1)			
		
		* Fixing use of wrong household ids (according to VAU update on missing hh from 9th April)
		replace hh_id	=	"100381"	if	hh_id	==	"100380"
		replace hh_id	=	"1000120"	if	hh_id	==	"10001120"
		replace hh_id	=	"N300373"	if	hh_id	==	"N300313"	&	a2	==	7
		*replace hh_id	=	"300546"	if	hh_id	==	"300547"	&	srpsrcbb3	==	11
			
		* Drop wrong/old survey 
		drop if	hh_id=="N11001186"	&	a2==2				// Garima: as per Hakim's email on March 24
		drop if	hh_id=="300327"		&	!mi(a1Latitude)		// "All_survey_verification_with all comments_June16.xlsx"
		drop if	hh_id=="1000522"	&	date=="4-Apr-2016"	// "All_survey_verification_with all comments_June16.xlsx"
		drop if	hh_id=="1000656"	&	date=="8-Mar-2016"	// "All_survey_verification_with all comments_June16.xlsx"
		drop if	hh_id=="N100338"	&	date=="31-Mar-2016"	// "All_survey_verification_with all comments_June16.xlsx"
		drop if hh_id=="100381"		&	date=="28-Feb-2016"	// SML: Dropped this since this one was done two months before the next one was done. Can be double-checked
		drop if hh_id=="N1100140"	&	date=="22-Mar-2016"	// "All_survey_verification_with all comments_June16.xlsx"
		drop if hh_id=="103812"								// SML: There's no such HH with this ID. No HHHead/spouse info to assume further.
		drop if hh_id=="1000653"							// SML: VAU confirmed that only Male HH survey was done without doing LHH. Please refer to "MissingDetail_VAU_apr25" variable for detail
		drop if hh_id=="3003910"							// SML: This household is rejected after verified by project Manager. Please refer to "PRA_remarks" variable in PRA data.
		
			
		*Fixing household ids for hh where one person interviewed using pre-10Mar ids and the other person using post-10Mar ids
		replace hh_id="N4001619" if hhhead_name_file=="Gulbodin" & father_spouse_name_file== "Gul Mohammad"
		replace hh_id="N4001628" if hhhead_name_file=="Hajji Mohmmad" & father_spouse_name_file== "Hajji Barfi"
		replace hh_id="N400163" if hhhead_name_file=="Kabir" & father_spouse_name_file== "Sultan Mohammad"
		replace hh_id="N4001618" if hhhead_name_file=="Malim Qudos" & father_spouse_name_file== "Nazar Mohammad"
		replace hh_id="N4001633" if hhhead_name_file=="Mohammad Nahim" & father_spouse_name_file== "Ali Ahmad"
		replace hh_id="N400168" if hhhead_name_file=="Widow/saied mohammad" & father_spouse_name_file== "Abdul mohammad"
	
		*	Confirm household ID uniquely distinguishes observations
		isid	hh_id
		
		* Update hh_id_2
		replace	hh_id_2=hh_id
										
	* Rename variables
		rename	hhhead_name_file		hhhead_name
		rename	father_spouse_name_file	father_spouse_name
		rename	srpsrc*					*
		rename	srp*					*

	* Fix household head name
	replace	father_spouse_name	=	"Ghulam Ali"	if	father_spouse_name	==	"Ghula Ali"
		
	* Modify village label
		* For unknown reason "village" label in SurveyCTO format has missing label for "1" and "31"
		* From another source ("${data_analysis}/Randomization/Data/Raw/TUP Eligibility/Village_sample_TUP.dta") we could find "1" means "Qezel abad". We will add this village to "village" label
		* RdG (Rebecca) found that "31" indicates "Amin Husain".  a6==31
		lab define village 	1	"Qezel abad" ///
							31	"Amin Husain", add
							
		* Fixing a6 (village code) for Qazalabad
			replace a6 = 1 if hh_id =="N4000224"
			replace a6 = 1 if hh_id =="N400028"
			replace a6 = 1 if hh_id =="N4000214"
			replace a6 = 1 if hh_id =="N4000219"
			replace a6 = 1 if hh_id =="N400025"
			replace a6 = 1 if hh_id =="N400029"
			replace a6 = 1 if hh_id =="N4000222"
			replace a6 = 1 if hh_id =="N4000213"
			replace a6 = 1 if hh_id =="N400026"
			replace a6 = 1 if hh_id =="N400023"
			replace a6 = 1 if hh_id =="N4000220"
			replace a6 = 1 if hh_id =="N4000218"
			replace a6 = 1 if hh_id =="N400024"
			replace a6 = 1 if hh_id =="N4000216"
			replace a6 = 1 if hh_id =="N400027"
			replace a6 = 1 if hh_id =="N4000221"
			replace a6 = 1 if hh_id =="N4000215"
			replace a6 = 1 if hh_id =="N4000211"
			replace a6 = 1 if hh_id =="N400021"
			replace a6 = 1 if hh_id =="N4000212"
			replace a6 = 1 if hh_id =="N4000210"
			replace a6 = 1 if hh_id =="N400022"
			replace a6 = 1 if hh_id =="N4000217"
			replace a6 = 1 if hh_id =="N4000223"
					
	* Village
		* Change qezel Abad so it matches the village_anonymized dataset
		replace a6 = 89 if a6 == 1
		merge m:1 a6 using "${village_anonymized}", keep(1 3)
		codebook a6 if _merge == 1 // two villages that we don't have
		drop _merge
		label drop village
		
	* Drop unnecessary variables
		drop	*gnn*		
		
	* GPS coordinates
		gen	double	latitude	=	a1Latitude
		replace		latitude	=	qq8Latitude	if	mi(a1Latitude)
		
		gen	double	longitude	=	a1Longitude
		replace	longitude	=	qq8Longitude	if	mi(a1Longitude)
			
		lab	var	latitude	"Latitude"
		lab	var	longitude	"Longitude"
		
	*----------------*
	* Anonymize data * 
	*----------------*
	
	* Short label so we can save databases
	lab var ii27 "Taking all things together, would you say you are.."
	lab var jentrepj17 "It is important for me to do whatever I’m doing as well as I can.."

	drop a1Altitude qq8Altitude a6 hhhead_name father_spouse_name hhhead_name a1Latitude qq8Latitude a1Longitude qq8Longitude latitude longitude

	* Save
		if	`c(stata_version)'>=14	{
			saveold "${MHHH_allsvys_raw_bl_nopii}", replace v(13)
		}
		else {
			save "${MHHH_allsvys_raw_bl_nopii}", replace
		}			
			
