/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 19, 2020
Last udpate on: Mar 23, 2020

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans food consumption from gross outliers

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 1: Food items
********************************************************************************
	
*use "${consumption_bl}", clear
	
* Bring ultra-poor variable 
	merge m:1 hhid using "${all_HH_interm_nopii_bl}", assert(3) nogen keepus(ultra_poor a2)

* Get number of HH members
	preserve
		use "${current_roster_bl}", clear
		keep hhid b3
		duplicates drop hhid, force
		tempfile b3
		save	`b3'
	restore
	merge m:1 hhid using `b3', assert(3) nogen	
	
* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""
	
*--------------------------*
* Graph quantities by item *
*--------------------------*
	/*
		local value_label_item: value label item
		levelsof item, local(item_num)
		foreach item of local item_num {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0
			if `r(N)' != 0 {
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1
			if `r(N)' != 0 {
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1, percent name("up_`item'", replace)title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		   } 
		}
	*/
	
	
*------------------------------------------------------------------------*
* Check big values to identify if they're gross outliers / typing errors *
*------------------------------------------------------------------------*		
		
* 1) Rice (high quality)
	
	local i = 1
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 1 & hhid == 2196 // 700 kgs for a 7-member HH 
		replace c_a = .o if item == 1 & hhid == 2196
	
* 2) Rice (low quality)
	
	local i = 2
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 2 & hhid == 5237
		replace flag_outlier = 3 if item == 2 & inlist(hhid, 2119, 1727, 1913, 1334)
		replace c_a = .o if item == 2 & hhid == 5237 // 400 Kgs for 5-member household 
		replace c_a = .o if item == 2 & inlist(hhid, 2119, 1727, 1913, 1334) // Same enumerator (Sajeda Shultan Aziz) with implausible values over 600

* 3) Wheat flour
	
	local i = 3
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 3 & inlist(hhid, 1584, 1238, 5544)
		replace c_a = .o if item == 3 & inlist(hhid, 1584, 1238, 5544)
		
* 4) Naan not made at home
	
	local i = 4
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 4 & inlist(hhid, 1910)
		replace c_a = .o if item == 4 & inlist(hhid, 1910)
		
* 5) Barley
	
	local i = 5
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
	
* 6) Maize

	local i = 6
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers
	
* 7) Beans

	local i = 7
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3 if item == 7 & inlist(hhid, 6466, 6620) // Fatema Chaman Shah with values of 500 and 700 kgs, extremely high compared to others
		replace c_a = .o if item == 7 & inlist(hhid, 6466, 6620)
		replace flag_outlier = 3 if item == 7 & inlist(hhid, 1853, 1290, 1696, 1149, 1684, 1988, 1251, 1244, 1940, 2100, 1734) // 11 surveys: Sajeda Shultan Aziz with values >=450
		replace c_a = .o if item == 7 & inlist(hhid, 1853, 1290, 1696, 1149, 1684, 1988, 1251, 1244, 1940, 2100, 1734)
	
* 8) Mung

	local i = 8
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 8 & inlist(hhid, 5975, 6100, 6267, 1086, 1940) 
		replace c_a = .o if item == 8 & inlist(hhid, 5975, 6100, 6267, 1086, 1940) 
	
* 9) Chickpeas

	local i = 9
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 9 & inlist(hhid, 6096, 5511, 1940) 
		replace flag_outlier = 3 if item == 9 & inlist(hhid, 2100, 2170, 1290, 1716, 1180) // Sajeda Shultan Aziz: 5 surveys with values >=200 
		replace c_a = .o if item == 9 & inlist(hhid, 6096, 5511, 1940, 2100, 2170, 1290, 1716, 1180)

* 10) Lentils

	local i = 10
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 10 & inlist(hhid, 1787) 
		replace c_a = .o if item == 10 & inlist(hhid, 1787) 
		
* 11) Pasta

	local i = 11
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3  if item == 11 & inlist(hhid, 6096, 5700, 6519, 5271) // Zahra Sadad, 4 surveys
		replace c_a = .o if item == 11 & inlist(hhid, 6096, 5700, 6519, 5271) 
		replace flag_outlier = 3  if item == 11 & inlist(hhid, 5526, 6345) // Zohra Ab.Hussain, 4 surveys
		replace c_a = .o if item == 11 & inlist(hhid, 5526, 6345)
		replace flag_outlier = 1  if item == 11 & inlist(hhid, 6087, 6100) 
		replace c_a = .o if item == 11 & inlist(hhid, 6087, 6100) 
		replace flag_outlier = 3  if item == 11 & inlist(hhid, 1251, 1457, 1290, 1684, 1046, 1244, 1682, 1722, 1574, 1048, 1734, 1235, 1788) // Sajeda Shultan Aziz, 13 surveys
		replace c_a = .o if item == 11 & inlist(hhid, 1251, 1457, 1290, 1684, 1046, 1244, 1682, 1722, 1574, 1048, 1734, 1235, 1788)

* 12) Other bread and/or cereal

	local i = 12
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1  if item == 12 & inlist(hhid, 6267)
		replace c_a = .o if item == 12 & inlist(hhid, 6267)
		replace flag_outlier = 3  if item == 12 & inlist(hhid, 1978, 1787) // Sajeda Shultan Aziz, 2 surveys
		replace c_a = .o if item == 12 & inlist(hhid, 1978, 1787)
		
* 14) Beef

	local i = 14
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1  if item == 14 & inlist(hhid, 5047)
		replace c_a = .o if item == 14 & inlist(hhid, 5047)
		
* 15) Veal

	local i = 15
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
		
* 16) Mutton

	local i = 16
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing
		replace flag_outlier = 1  if item == 16 & inlist(hhid, 6224)
		replace c_a = .o if item == 16 & inlist(hhid, 6224)
		
* 17) Goat

	local i = 17
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers
	
* 18) Chicken

	local i = 18
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing
		replace flag_outlier = 1  if item == 18 & inlist(hhid, 5339, 6348)
		replace c_a = .o if item == 18 & inlist(hhid, 5339, 6348)
		replace flag_outlier = 3  if item == 18 & inlist(hhid, 1871, 1048, 1684, 1788) // Sajeda Shultan Aziz, 4 surveys 
		replace c_a = .o if item == 18 & inlist(hhid, 1871, 1048, 1684, 1788) 

* 19) Liver

	local i = 19
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers	
	
* 20) Dried Meat

	local i = 20
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers		
	
* 21) Fish

	local i = 21
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers		
	
* 22) Other meat and/or fish

	local i = 22
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers		
	
* 24) Milk (fresh)

	local i = 24
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3  if item == 24 & inlist(hhid, 5339, 5704, 5849, 5037) // Khoshbo Wakil Ahmad
		replace c_a = .o if item == 24 & inlist(hhid, 5339, 5704, 5849, 5037)
		replace flag_outlier = 1  if item == 24 & inlist(hhid, 5955, 1787) 
		replace c_a = .o if item == 24 & inlist(hhid, 5955, 1787) 
	
* 25) Milk (powdered)

	local i = 25
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers. 			
	
* 26) Yogurt

	local i = 26
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3  if item == 26 & inlist(hhid, 5904, 6100) // Fatema Chaman Shah
		replace c_a = .o if item == 26 & inlist(hhid, 5904, 6100)
		replace flag_outlier = 1  if item == 26 & inlist(hhid, 5628, 2029)
		replace c_a = .o if item == 26 & inlist(hhid, 5628, 2029)
		replace flag_outlier = 3  if item == 26 & inlist(hhid, 1361, 1554, 1684, 1727, 1582, 1227, 1696, 1220, 1251, 1036, 1235, 1046, 1871, 1788, 1048, 1457, 1913, 1460, 2092) // Sajeda Shultan Aziz
		replace c_a = .o if item == 26 & inlist(hhid, 1361, 1554, 1684, 1727, 1582, 1227, 1696, 1220, 1251, 1036, 1235, 1046, 1871, 1788, 1048, 1457, 1913, 1460, 2092) 
		
* 27) Curd (chaka)

	local i = 27
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3  if item == 27 & inlist(hhid, 6428, 5610, 5097, 5939, 6466) // Fatema Chaman Shah, 5 surveys
		replace c_a = .o if item == 27 & inlist(hhid, 6428, 5610, 5097, 5939, 6466)
		replace flag_outlier = 3  if item == 27 & inlist(hhid, 1149, 1787, 1465, 1251, 1244, 2119) // Sajeda Shultan Aziz, 6 surveys
		replace c_a = .o if item == 27 & inlist(hhid, 1149, 1787, 1465, 1251, 1244, 2119)
		replace flag_outlier = 1  if item == 27 & inlist(hhid, 5628) 
		replace c_a = .o if item == 27 & inlist(hhid, 5628) 
		
* 28) Krut (dried)

	local i = 28
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
	
* 29) Dogh

	local i = 29
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1  if item == 29 & inlist(hhid, 1235) 
		replace c_a = .o if item == 29 & inlist(hhid, 1235)
		
* 30) Ghee

	local i = 30
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3  if item == 30 & inlist(hhid, 1978, 1788) // Sajeda Shultan Aziz
		replace c_a = .o if item == 30 & inlist(hhid, 1978, 1788)
	
* 31) Butter

	local i = 31
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 32) Cheese

	local i = 32
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.

* 33) Eggs

	local i = 33
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 34) Other dairy products

	local i = 34
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 36) Vegetable oil

	local i = 36
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1  if item == 36 & inlist(hhid, 5100, 6096, 2121)
		replace c_a = .o if item == 36 & inlist(hhid, 5100, 6096, 2121)
	
* 37) Cotton oil or sesame oil

	local i = 37
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No observations
	
* 38) Animal fat

	local i = 38
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 39) Other oils and fat

	local i = 39
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1  if item == 39 & inlist(hhid, 6049, 6262, 1879)
		replace c_a = .o if item == 39 & inlist(hhid, 6049, 6262, 1879)
	
* 41) Potato

	local i = 41
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 41 & inlist(hhid, 5339)
		replace c_a = .o if item == 41 & inlist(hhid, 5339)
		replace flag_outlier = 3  if item == 41 & inlist(hhid, 1722, 2119)
		replace c_a = .o if item == 41 & inlist(hhid, 1722, 2119)
	
* 42) Sweet potato

	local i = 42
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.
	
* 43) Onion

	local i = 43
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3  if item == 43 & inlist(hhid, 1460, 1361, 1722)
		replace c_a = .o if item == 43 & inlist(hhid, 1460, 1361, 1722)

* 44) Tomato

	local i = 44
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 44 & inlist(hhid, 1036)
		replace c_a = .o if item == 44 & inlist(hhid, 1036)
		
* 45) Okra

	local i = 45
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

* 46) Spinach

	local i = 46
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 46 & inlist(hhid, 1244, 1251, 1460)
		replace c_a = .o if item == 46 & inlist(hhid, 1244, 1251, 1460)
		
* 47) Cauliflower

	local i = 47
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.	
	
* 48) Eggplant

	local i = 48
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.		

* 49) Carrots

	local i = 49
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 49 & inlist(hhid, 6179, 6221, 1361, 1251, 1290, 1684, 1788, 1460)
		replace c_a = .o if item == 49 & inlist(hhid, 6179, 6221, 1361, 1251, 1290, 1684, 1788, 1460)
		
* 50) Pumpkin, squash

	local i = 50
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 50 & inlist(hhid, 1068, 1220)
		replace c_a = .o if item == 50 & inlist(hhid, 1068, 1220)
			
* 51) Cucumber

	local i = 51
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.
	
* 52) Radish

	local i = 52
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 53) Turnip

	local i = 53
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 53 & inlist(hhid, 5097)
		replace c_a = .o if item == 53 & inlist(hhid, 5097)
		replace flag_outlier = 3  if item == 53 & inlist(hhid, 1220, 2119)
		replace c_a = .o if item == 53 & inlist(hhid, 1220, 2119)
			
* 54) Cabbage

	local i = 54
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 54 & inlist(hhid, 1068, 1227)
		replace c_a = .o if item == 54 & inlist(hhid, 1068, 1227)
	
* 55) Leek

	local i = 55
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 55 & inlist(hhid, 1361, 1457, 1913, 1220, 2092, 2201, 1696)
		replace c_a = .o if item == 55 & inlist(hhid, 1361, 1457, 1913, 1220, 2092, 2201, 1696)
		
* 56) Hot pepper

	local i = 56
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 56 & inlist(hhid, 1582, 5897, 6629, 6176)
		replace c_a = .o if item == 56 & inlist(hhid, 1582, 5897, 6629, 6176)
		
* 57) Wild leafy vegetables

	local i = 57
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 58) Coriander

	local i = 58
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 58 & c_a >= 100 & !mi(c_a) & inlist(a2, 10, 24, 13)
		replace c_a = .o if item == 58 & c_a >= 100 & !mi(c_a) & inlist(a2, 10, 24, 13)	
		replace flag_outlier = 1  if item == 58 & inlist(hhid, 6361, 6629)
		replace c_a = .o if item == 58 & inlist(hhid, 6361, 6629)
		
* 59) Mint

	local i = 59
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 59 & c_a >= 100 & !mi(c_a) & inlist(a2, 10, 24, 13)
		replace c_a = .o if item == 59 & c_a >= 100 & !mi(c_a) & inlist(a2, 10, 24, 13)	
		replace flag_outlier = 1  if item == 59 & inlist(hhid, 6629)
		replace c_a = .o if item == 59 & inlist(hhid, 6629)
		
* 60) Dried tomatoes

	local i = 60
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 60 & inlist(hhid, 2195, 2157, 2085)
		replace c_a = .o if item == 60 & inlist(hhid, 2195, 2157, 2085)
		
* 61) Dried vegetables

	local i = 61
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
* 62) Pickled vegetables

	local i = 62
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 62 & inlist(hhid, 5097)
		replace c_a = .o if item == 62 & inlist(hhid, 5097)
		replace flag_outlier = 3  if item == 62 & c_a >= 100 & !mi(c_a) & inlist(a2, 13)
		replace c_a = .o if item == 62 & c_a >= 100 & !mi(c_a) & inlist(a2, 13)
		
* 63) Green beans

	local i = 63
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 64) Other vegetables

	local i = 64
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 64 & c_a >= 200 & !mi(c_a) & inlist(a2, 4)
		replace c_a = .o if item == 64 & c_a >= 200 & !mi(c_a) & inlist(a2, 4)

* 66) Apple

	local i = 66
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 66 & inlist(hhid, 5431, 5339)
		replace c_a = .o if item == 66 & inlist(hhid, 5431, 5339)
		
* 67) Grapes

	local i = 67
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers

* 68) Melon/watermelon

	local i = 68
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No one consumed

* 69) Peach

	local i = 69
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No one consumed	
	
* 70) Fresh apricots

	local i = 70
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No one consumed			
	
* 71) Dried apricots

	local i = 71
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 72) Orange/citrus

	local i = 72
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 3  if item == 72 & c_a >= 200 & !mi(c_a) & inlist(a2, 13)
		replace c_a = .o if item == 72 & c_a >= 200 & !mi(c_a) & inlist(a2, 13)
		
* 73) Plum

	local i = 73
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 74) Pomegranate

	local i = 74
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 75) Pear

	local i = 75
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 76) Banana

	local i = 76
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 76 & inlist(hhid, 6033)
		replace c_a = .o if item == 76 & inlist(hhid, 6033)
		
* 77) Raisins

	local i = 77
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 77 & inlist(hhid, 1099)
		replace c_a = .o if item == 77 & inlist(hhid, 1099)
		
* 78) Fresh mulberries

	local i = 78
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers 
	
* 79) Dried mulberries

	local i = 79
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 80) Mangoes

	local i = 80
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 81) Walnuts

	local i = 81
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 81 & inlist(hhid, 6283)
		replace c_a = .o if item == 81 & inlist(hhid, 6283)
		
* 82) Pistachio

	local i = 82
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 83) Almonds

	local i = 83
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 84) Other fruit and/or nuts

	local i = 84
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1  if item == 84 & inlist(hhid, 5628)
		replace c_a = .o if item == 84 & inlist(hhid, 5628)
		
* 86) White sugar

	local i = 86
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		tab a2 if c_a>=50 & !mi(c_a) & item == 86  // 29 HHs. they look like issues with the units, we send them to missing. Except the enumerator with issues
		replace flag_outlier = 3 if c_a>=50 & !mi(c_a) & item == 86 & a2 == 13
		replace flag_outlier = 2 if mi(flag_outlier) & c_a>=50 & !mi(c_a) & item == 86  
		replace c_a = .o if c_a>=50 & !mi(c_a) & item == 86 

* 87) Brown sugar

	local i = 87
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 88) Honey

	local i = 88
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 89) Chocolates, Candy, sherinigack

	local i = 89
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		tab a2 if c_a>=20 & !mi(c_a) & item == 89 
		replace flag_outlier = 3   if item == 89 & c_a >= 20 & !mi(c_a) & inlist(a2, 13, 8, 24)
		replace  c_a = .o if item == 89 & c_a >= 20 & !mi(c_a) & inlist(a2, 13, 8, 24)
		
		replace flag_outlier = 2   if item == 89 & c_a >= 20 & !mi(c_a) & mi(flag_outlier)
		replace  c_a = .o if item == 89 & c_a >= 20 & !mi(c_a) & flag_outlier == 1
	
* 90) Candy, sherinigack

	* asked together with chocolate in baseline
	
* 91) Sweetener

	* Not asked in baseline			
	
* 92) Other sweets, specify

	local i = 92
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 94) Black teas

	local i = 94
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing. 30 out of 140 obs
		*tab c_a if  item == 94 & c_a != 0
		*replace flag_outlier = 2 if item == 94 & c_a < 1 & c_a != 0 // it looks like they misinterpreted the unit
		*replace flag_outlier_why = "Enumerator or respondent misinterpreted the unit of measure" if item == 94 & c_a < 1 & c_a != 0
		*replace c_a = .o if item == 94 & c_a < 1 & c_a != 0
	
* 95) Green teas

	local i = 95
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing. 13% of the valid values
		*tab c_a if  item == 95 & c_a != 0
		*replace flag_outlier = 2 if item == 95 & c_a < 1 & c_a != 0 
		*replace flag_outlier_why = "Enumerator or respondent misinterpreted the unit of measure" if item == 95 & c_a < 1 & c_a != 0
		*replace c_a = .o if item == 95 & c_a < 1 & c_a != 0	
	
* 96) Bottled/canned beverages, Mineral waters

	local i = 96
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
		
	* No clear outliers
		
* 97) Other beverages

	local i = 97
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
			
* 99) Salt

	local i = 99
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		tab c_a if  item == 99 & c_a != 0
		replace flag_outlier = 1 if  item == 99 & hhid == 6125
		replace c_a = .o if item == 99 & hhid == 6125 // clear outlier of 10,000 grams for a 9-member household		
	
	* Clear outliers: We send to missing. 22% of the valid values
		tab c_a if  item == 99 & c_a != 0
		replace flag_outlier = 2 if item == 99 & c_a < 1 & c_a != 0 
		replace flag_outlier_why = "Values too small to be grams" if item == 99 & c_a < 1 & c_a != 0
		replace c_a = .o if item == 99 & c_a < 1 & c_a != 0		
	
* 100) Black pepper

	local i = 100
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 34% of valid values
		tab c_a if  item == 100 & c_a != 0
		replace flag_outlier = 2 if item == 100 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 100 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 100 & c_a < 1 & c_a > 0 
		
* 101) Ginger and garlic

	local i = 101
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 34% of valid values
		tab c_a if  item == 101 & c_a != 0
		replace flag_outlier = 2 if item == 101 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 101 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 101 & c_a < 1 & c_a > 0
	
* 102) Tomato sauce

	local i = 102
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing: 65% of valid values
		tab c_a if  item == 102 & c_a != 0
		replace flag_outlier = 2 if item == 102 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 102 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 102 & c_a < 1 & c_a > 0
	
* 103) Mixed spices

	local i = 103
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 12% of valid values
		tab c_a if  item == 103 & c_a != 0
		replace flag_outlier = 2 if item == 103 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 103 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 103 & c_a < 1 & c_a > 0	
	
* 104) Other spices

	local i = 104
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 2% of valid values
		tab c_a if  item == 104 & c_a != 0
		replace flag_outlier = 2 if item == 104 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 104 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 104 & c_a < 1 & c_a > 0		
	
* Graph with cleaned variables
	/*
		local value_label_item: value label item
		levelsof item, local(item_num)
		foreach item of local item_num {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0
			if `r(N)' != 0 {
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1
			if `r(N)' != 0 {
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1, percent name("up_`item'", replace)title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		   } 
		}
	*/
	
* Deleting irrelevant variables
	drop ultra_poor a2 b3	
		