/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	Feb 10, 2020

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Looks at outliers in the finance roster using consistency checks, replacing as .o all potential outliers in the baseline


CONTENT:		Part 1 - Identify potential outliers


						
OUTPUTS:     	
				

Note: 			This do file does not call or save any dataset, it is exclusively used within the "preparing_and_cleaning_rosters" do files. 

*******************************************************************************/
	
********************************************************************************
** Part 1: Identify potential outliers
********************************************************************************
preserve 

use "$current_roster_bl", clear
duplicates drop hhid, force

tempfile family_size
save    `family_size'
restore

**********Look at the total number of loans - and control it with the size of the household

*Adding family size
merge m:1 hhid  using `family_size' , assert(2 3) keep(1 3) keepus(b3) nogen

*Generating the number of loans per capita
gen loan_number_pc   = m1_a/b3 
*hist loan_number_pc , percent

*Maximum is around 20 loans per capita which is high, and due to the facti that 165 hhs declared having 99 loans, which is most likely a mistake 
*for "don't know, which is -99. We will put them to missing. 
replace m1_a = .d if m1_a == 99

replace loan_number_pc   = m1_a/b3 
*hist loan_number_pc , percent
*Now maximum is around 4, which is high but possible


*********Look at outliers among loans. 
/*We have two variables for total loans, m5 is eliciting directly the total sum and we also have the detail
of each loan. By comparing the total outstanding amount of money owned versus the sum of each individual loan
we have a mean of checking for outliers / typing mistakes. 
*/

**********Compare the total sum of individual loans with the total they reported
		merge m:1 hhid using "${all_HH_interm_nopii_bl}", assert(2 3) keepus(m5 ultra_poor) keep(1 3) nogen //Keeping only the matched observations, ie hhs which have at least one loan as here we are looking at outliers among loans 
		replace m5 = .d if m5 == 99 
		
		bys hhid: egen sum_loan = sum(m4)
		label var sum_loan "Sum of outstanding loans per hhh"
		
		*Replace with missing when the outstanding value of one of the loans is missing
		bys hhid: egen missing_loan = max((m4==.d|m4==.))
		replace sum_loan = .d if missing_loan == 1
		
		gen flag_diff = 1 if sum_loan != m5 & !mi(sum_loan) & !mi(m5) //there are a few missings which cannot be seen as outliers
		lab var flag_diff "Sum of loans different from total loans for the hhh"
		tab ultra_poor if flag_diff == 1 & loan_number == 1 // 82 HH with this issue all of them UP
		br  hhid loan_number m4 m5 sum_loan if flag_diff==1
		gen diff =  m5-sum_loan

		sort m5 hhid loan_number

		*Let's look at the ratio of the diff to one of the totals to look at outliers 
		gen 	ratio_m5 		= abs(diff)/m5*100
		gen 	ratio_sum_loan  = abs(diff)/sum_loan*100
		
		*Create a new variable identyfying outliers when both ratios are more than 50% 
		gen 	flag_outlier = flag_diff
		replace flag_outlier = . if ratio_m5 <= 100 & ratio_sum_loan <= 100 // 16 HH with this issue (16 UP)
		lab var flag_outlier "Sum of loans or total loans is a gross outlier/mistake"
				
		*Replacing these observations by .o as these are now seen as outliers 
		*We cannot know which one of the two is the true one, if there is any, so both sums will be put to 0
		replace sum_loan = .o if flag_outlier == 1
		
		*Only keeping the variables of interest in the roster
		drop m5 missing_loan diff ratio_m5 ratio_sum_loan ultra_poor
		graph drop _all
*********************************************end of do file***********************************
