/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 21, 2019
Last udpate on: Mar 21, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the baseline database for Market survey. 


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Raw data PII - Stata format
		gl market_raw_bl "${TUP_DB}/Baseline/DataSets/Raw/Market_questionnaire_TUP_IE.dta"
		
	* Codebook
		gl codebook "${TUP_DB}/Baseline/Documentation/market_codebook_bl.xlsx"

* Outputs
	
	*if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
		gl market_clean_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/market_clean_bl.dta"
	 /*}
		if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub
			*gl market_clean_fl1 	"${fl1_dt}/Intermediate/market_clean_fl1.dta"
		}
	*/

********************************************************************************
	** Part 1: Cleaning
********************************************************************************

use "${market_raw_bl}", clear

* GPS coordinates
	gen latitude  = a1latitude 
		lab var latitude "Latitude"
	gen longitude  = a1longitude
		lab var longitude "Longitude"
	order latitude longitude, after(time)

* iecodebook
	*iecodebook template using "${codebook}"
	iecodebook apply using "${codebook}", drop
	
* Drop SCTO varaibles that are not needed
	drop key a1_v latitude longitude // here GPS is not really PII, but drop it since we also want to mask District
	
* Order and label varaibles 
	order ms4_a, before(ms4_b)
	order ms9_a ms9_b ms9_c, after(ms8_e)
	order ms3_j, after(ms3_i)
	
	label var vc1 "Enumerator"
	label var vc2 "Supervisor"
	label var vc3 "District"
	label var mkt_day "Is today a market day?"
	label var ms3_j	"What is the price of one dozen eggs in this market?"

* Save

	if	`c(stata_version)'>=14	{
		saveold "${market_clean_bl}", replace v(13)
	}
	else {
		save "${market_clean_bl}", replace
	}	