/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Feb 4, 2020
Last udpate on: Feb 4, 2020

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)
Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans non-consumption from gross outliers

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 1: Non-food items
********************************************************************************	
	
* Get ultra-poor variable 
	merge m:1 hhid using "${all_HH_interm_nopii_bl}", assert(3) nogen keepus(ultra_poor a2)
	
* Get number of HH members
	preserve
		use "${current_roster_bl}", clear
		keep hhid b3
		duplicates drop hhid, force
		tempfile b3
		save	`b3'
	restore
	merge m:1 hhid using `b3', assert(3) nogen	
	
* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""	
	
* Create one variable for c12 and c13: we're analyzing by item so it doesn't matter c12 is monthly and c13 yearly
	br hhid hhid item c12 c13
	gen 	non_food = c12
	replace non_food = c13 if item >= 21

*------------------------------------*
* Get variables we need for analysis *
*------------------------------------*	
	
*Most important is to check for all the UP first. Let's check their loans, whether they say they have a house, value of food consumption and savings, as well as the bl values for these. 
*It's about 15 HHs but with very high values. Check all above AFG 100K. The median for UP is AFG 7K

	preserve
	
		* HH-level baseline
			use "${all_HH_interm_nopii_bl}", clear
			keep hhid e1 m19 m20 m1_a m5
			rename * bl_*
			rename bl_hhid hhid
			tempfile hh_level_bars_bl
			save	`hh_level_bars_bl'
		
		* Assets
			use "${other_assets_bl}", clear
			keep if inlist(asset,5,6,7) 
			drop  l2 l3 l4
			gen 	asset_l = "_house_land" if asset == 5
			replace asset_l = "_other_land" if asset == 6
			replace asset_l = "_other_house" if asset == 7
			drop asset
			reshape wide l1 l5, i(hhid) j(asset_l) s
			egen owns_anything = rowtotal(l1_house_land l1_other_house l1_other_land)
			drop l5_*
			tempfile asset_bl
			save	`asset_bl'
			
	restore
	
* Merge
	merge m:1 hhid using `hh_level_bars_bl', assert(3) nogen
	merge m:1 hhid using `asset_bl', assert(3) nogen

*----------------------------*
* Graph and do summary stats *
*----------------------------*
	/*
		local value_label_item: value label item
		foreach item of numlist 1(1)38 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			
			count if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 0
			if `r(N)' != 0 {
			hist non_food if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			count if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 1
			if `r(N)' != 0 {
			hist non_food if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 1, percent name("up_`item'", replace)title("`l_`item'' - Ultra-poor") note(N=`r(N)')
			}
		}
	*/

*------------------------------------------------------------------------*
* Check big values to identify if they're gross outliers / typing errors *
*------------------------------------------------------------------------*		
		
* 1) Food consumed at home 
	
	* Seems to have some issues, specially in non-poor
	local i = 1
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 20k for ultra-poor
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=20000 & !mi(non_food) & ultra_poor == 1
		// all of them own at least the house they live in, and have savings or loans. no way to be sure. should be fixed with winsorization
	
* 2) Food consumed outside the home

	* Looks smooth, no big issues
	local i = 2
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
* 3) Cigarettes

	* Some values seem high, but there is no clear outlier. No way to know.
	* It should be fixed with winsorization
	local i = 3
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 4) Tobacco/snuff

	* Some issues
	* It should be fixed with winsorization
	local i = 4
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	

* 5) Matches

	* Some issues. Values above 100 seem high
	* It should be fixed with winsorization
	local i = 5
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 6) Laundry powder/detergents, cleaning supplies

	* Some issues, specially in non-poor. Values above 1000 seem high
	* It should be fixed with winsorization
	local i = 6
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 7) Soap (hand, toiletry)

	* Some issues in NUP. Values above 300 seem high
	* It should be fixed with winsorization
	local i = 7
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 8) Shampoo

	* Some issues in non-poor. Values above 1000 seem high
	* It should be fixed with winsorization
	local i = 8
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 9) Toothpaste

	* Some issues in non-poor. Should be fix with winsorization.
	local i = 9
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
* 10) Personal grooming (haircuts, etc.) for males

	* Some issues.
	* It should be fixed with winsorization
	local i = 10
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 11) Fee for public bath
	
	* Ask Lupe first
	local i = 11
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
* 12) Laundry charges

	* N = 8 for non-poor and N = 3 for poor.
	* Winsorization does not do anything but there are some big values. Not so important.
	local i = 12
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 13) Fee for baking bread

	* N = 88 for non-poor and N = 52 for poor.
	* Winsorization does not do anything but there are some big values
	local i = 13
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 10k 
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=10000 & !mi(non_food) 
		// most likely an error: no house, no loans, no savings
		replace flag_outlier = 4 if item == 13 & hhid == 6440
		replace c12 	 = .o if item == 13 & hhid == 6440
		replace non_food = .o if item == 13 & hhid == 6440
				
* 14) Fixed phone line and use (including PCO booths)

	* N = 8 for non-poor and N = 3 for poor.
	* Winsorization does not do anything. No big issues
	local i = 14
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
* 15) Mobile phone charges (minutes and prepaid)

	* Winsorization should fix it
	local i = 15
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 16) Internet service/Internet café, fax, mail

	* N = 40 for non-poor and N = 7 for poor.
	* Winsorization does not do anything. No big issues	
	local i = 16
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 17) Transportation fare - bus and taxis

	local i = 17
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* Check values above 10k 
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=10000 & !mi(non_food) 
		// values could be plausible. they have debt or they own a house. Only one not plausible
		replace flag_outlier = 4 if item == 17 & hhid == 5127 // 60k, no debt, no house, no land
		replace c12 	 = .o if item == 17 & hhid == 5127
		replace non_food = .o if item == 17 & hhid == 5127

* 18) Fuel for car/motor bike (do not include business vehicles)

	* Some issues with Non-poor that should be fix with winsorization
	local i = 18
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 19) Taxes (formal and informal)

	* No obs for ultra-poor
	local i = 19
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 20) Other miscellaneous expenses in last month

	local i = 20
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
		
	* Check values above 6.5k, where there's a discontinuity
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=6500 & !mi(non_food) 
		//they have loans so values could be plausible. big issues will be solved with winsorization
	
* 21) House construction and repair (materials and labor)

	local i = 21
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 100k for ultra-poor
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=100000 & !mi(non_food) & ultra_poor == 1	
	
	* Flag the ones who don't own the house and any land
	gen flag_house = 1 if !inlist(bl_e1, 1, 2, 5) & owns_anything == 0
	br item ultra_poor non_food bl_m5 bl_m19 bl_m20 if item == 21 & non_food>=100000 & !mi(non_food) & ultra_poor == 1 & flag_house == 1  
	drop flag_house
		// this household had loans. Values could be plausible
	
* 22) Education fees (tuition for school, college, university)

	local i = 22
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* Check values above 6k for ultra-poor
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=6000 & !mi(non_food) & ultra_poor == 1	
		// loans could explain it. Values could be plausible
	
	* One clear outlier in non-poor
		replace flag_outlier = 1 if item == 22 & hhid == 6155 // over 1million
		replace c13 	 = .o if item == 22 & hhid == 6155 
		replace non_food = .o if item == 22 & hhid == 6155 
		
* 23) School uniforms

	local i = 23
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* One big value of 20k in UP
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=10000 & !mi(non_food)
		// the non-poor household have loans that could explain
		
	* One ultra-poor household with no enough loans
	replace flag_outlier = 4 if item == 23 & inlist(hhid, 1625)
	replace c13 = .o if item == 23 & inlist(hhid, 1625)
	replace non_food = .o if item == 23 & inlist(hhid, 1625)
	
* 24) Textbooks

	local i = 24
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* One big value of 30k in UP
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=30000 & !mi(non_food)
		// the non-poor household have loans that could explain
		
* 25) Pens, pencils and notebooks (school supplies)

	local i = 25
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealt with the winsorization.

* 26) Other stationery

	local i = 26
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealt with the winsorization.

* 27) Repair, maintenance and tires for motor vehicles

	local i = 27
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 40k for ultra-poor
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=40000 & !mi(non_food) & ultra_poor == 1	
		// consumption of 60k, but loans of 53k, which can explain the amount

* 28) Airfares

	local i = 28
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>0 & !mi(non_food)
		// we cannot asses if values are plausible

* 29) Men's clothing (excluding shoes)

	local i = 29
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealt with the winsorization.

* 30) Women's clothing (excluding shoes)

	local i = 30
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* One weird value of 150k
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=150000 & !mi(non_food)	
		// could be explained by loans of 200k
		
* 31) Children's clothing (excluding shoes and school uniforms)

	local i = 31
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealt with the winsorization.

* 32) Men's shoes

	local i = 32
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealt with the winsorization.

* 33) Women's shoes

	local i = 33
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealt with the winsorization.
	
* 34) Children's shoes

	local i = 34
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* One weird value of 25k
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=25000 & !mi(non_food)	
		// could be explained by loans of 15k
		
* 35) Fines

	local i = 35
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* No way to asses
	
* 36) Weddings and funerals, haj

	local i = 36
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* weird value of 1 million and 4 million
	replace flag_outlier = 1 if item == 36 & inlist(hhid, 6370, 5158)
	replace c13 = .o if item == 36 & inlist(hhid, 6370, 5158)
	replace non_food = .o if item == 36 & inlist(hhid,  6370, 5158)
	
* 37) Annual celebrations and charitable donations (khair-o-khairat)

	local i = 37
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 100k
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=100000 & !mi(non_food)
	
	* Two households without loans or savings and big values
	replace flag_outlier = 4 if item == 37 & inlist(hhid, 5125, 6079)
	replace c13 = .o if item == 37 & inlist(hhid, 5125, 6079)
	replace non_food = .o if item == 37 & inlist(hhid, 5125, 6079)
	
* 38) Health services

	local i = 38
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 300k 
	br item ultra_poor non_food owns_anything bl_e1 bl_m5 bl_m19 bl_m20 if item == `i' & non_food>=300000 & !mi(non_food)
		// almost all of them have loans.
		
	* One household without loans or savings and a value 
	replace flag_outlier = 4 if item == 38 & inlist(hhid, 5222)
	replace c13 = .o if item == 38 & inlist(hhid, 5222)
	replace non_food = .o if item == 38 & inlist(hhid, 5222)
		
* Drop variables
	drop ultra_poor a2 b3 non_food bl_e1 bl_m1_a bl_m5 bl_m19 bl_m20 l1_house_land l1_other_house l1_other_land owns_anything 
	
