/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 15, 2018
Last udpate on: Nov 17, 2018

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Prepares and cleans the different rosters in the baseline dataset. Creating the long datasets for each module.

CONTENT:		

INPUTS:     	*

OUTPUTS:		*    	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Follow-up 1 survey data appended and merged
		*gl bl_compiled 		"${TUP_DB}/Baseline/DataSets/Intermediate/bl_compiled.dta"
		gl profile_info 			"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
		gl all_HH_interm_nopii_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_interm_nopii_bl.dta"
		*gl raw_roster_bl 			"${TUP_DB}/Baseline/DataSets/Raw/bl_ModuleB_Roster_Long_pii.dta"
		*gl roster_bl 				"${TUP_DB}/Baseline/DataSets/Raw/bl_ModuleB_Roster_Long.dta"


* Outputs

	*if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
		gl other_assets_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/l_hhassets_bl.dta"
		gl loans_bl 				"${TUP_DB}/Baseline/DataSets/Intermediate/m_b_loans_bl.dta"
		gl consumption_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/c_a_foodconsumption_bl.dta"
		gl current_roster_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/b_hhmemcurrent_bl.dta"
		gl nonfood_consumption_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/c_c_nonfoodconsumption_bl.dta"
		gl crops_bl		 			"${TUP_DB}/Baseline/DataSets/Intermediate/k_c_crops_bl.dta"
		gl businesses_bl	 		"${TUP_DB}/Baseline/DataSets/Intermediate/k_d_nonagbiz_bl.dta"
		gl livestock_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/k_a_livestock_bl.dta"
		gl animal_products_bl		"${TUP_DB}/Baseline/DataSets/Intermediate/k_b_animalproduct_bl.dta"
		gl productive_act_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/k_e_timeuse_bl.dta"
		gl productive_act_pm_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/k_e_timeuse_pm_bl.dta"
		gl given_transfers_bl		"${TUP_DB}/Baseline/DataSets/Intermediate/d_a_transfergiven_bl.dta"
		gl received_transfers_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/d_b_transferrecd_bl.dta"
		gl shocks_bl 				"${TUP_DB}/Baseline/DataSets/Intermediate/g_shocks_bl.dta"

		/*
		if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub
		gl other_assets_bl 			"${Baseline_dt}/Intermediate/other_assets_bl.dta"
		gl loans_bl 				"${Baseline_dt}/Intermediate/loans_bl.dta"
		gl consumption_bl 			"${Baseline_dt}/Intermediate/consumption_bl.dta"
		gl current_roster_bl 		"${Baseline_dt}/Intermediate/current_roster_bl.dta"
		gl nonfood_consumption_bl 	"${Baseline_dt}/Intermediate/nonfood_consumption_bl.dta"
		gl crops_bl		 			"${Baseline_dt}/Intermediate/crops_bl.dta"
		gl businesses_bl	 		"${Baseline_dt}/Intermediate/businesses_bl.dta"
		gl livestock_bl				"${Baseline_dt}/Intermediate/livestock_bl.dta"
		gl animal_products_bl		"${Baseline_dt}/Intermediate/animal_products_bl.dta"
	}
	*/
		
		
********************************************************************************
	** Module B: Household Roster (B)
********************************************************************************
		
*-------------------------------------*
* Roster of current household members *
*-------------------------------------*
	
	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid b3 b5_* /*b5_o*/ b6_*  b8_* b9_* b11_* ///
			b12_* b16_* b13_* b15_* b15_b* /*b15_o*/ b14_* b14_a* b14_a_month* b14_b*
			
		rename b15_b* b15_b_*
		rename b14_a*  b14_a_*
		rename b14_a__month* b14_a_month_*
		rename b14_b* b14_b_*
		rename b14_b__month* b14_b_month_*
		rename b11_y* b11_y_*
		rename b11_m* b11_m_*
			 
	* Drop variables that interfere with reshape
		drop  b8_year* b8_month*
    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long  	b5_ b6_ b8_ b9_ b11_ b11_y_ b11_m_ ///
						b12_ b16_ b13_ b15_ b15_b_ b14_ b14_a_ b14_a_month_ b14_b_ b14_b_month_, ///
						i(hhid) j(member)
						
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Drop non-existent member
			* We do it this way because some households have more members than the reported in b3 (not sure why). For example, hhids = 2167, 1592, 5302, 6205, 6364, 6044, 1086, 5233, 5596, 5120, 6272, 5723, 5246, 5934
			egen keep = rownonmiss(b5 b6 b8 b9 b11 b11_y b11_m b12 b16 b13 b15 b15_b b14_a b14_a_month b14_b b14_b_month)
			drop if keep==0 & hhid != 6364 // for some reason this HH doesn't have roster. We keep if so the merge is clean

		* Gen hh_mem
			bys hhid: egen 	hh_mem = max(member)
			replace hh_mem = 1 if hhid == 6364 // There has to be at least one member (the one who answers the survey)
			
		* Rename to match the survey
			drop b3 keep
			rename hh_mem b3 
			
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in b5 b8 b11_y b11_m b12 b16 b13 b15 b15_b b14_a b14_a_month b14_b b14_b_month {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}

		* Labels
			lab var hhid "Household ID"
			lab var member "Order of household member in baseline"
			lab var b3 "Number of household members"
			lab var b8 "How old is ${namefromearlier} in years?"
	
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${current_roster_bl}", replace v(13)
		}
		else {
			save "${current_roster_bl}", replace
		}	

********************************************************************************
	** Module L: Other asset ownership
********************************************************************************

use "${all_HH_interm_nopii_bl}", clear
						
	* Keep relevant variables
		keep hhid l1* l2* l3* l4* l5*
		rename (l1__98 l1__99) (l1_98 l1_99)
			
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
			
	* Reshape
		reshape long l1_ l2_ l3_ l4_ l5_ , i(hhid) j(asset)
		
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
			
	* Cleaning
		* Recode
			recode asset (98=-98) (99=-99)
			
		* Labels
			lab var asset "Assets"
			lab var hhid "Household ID"
			lab var l1 "Please tell me whether you or any member of your household owns any of the following assets:"
			lab var l2 "How many [asset] does your HH own?"
			lab var l3 "What is the total size of [asset]?"
			lab var l4 "Owner of [asset]?" 
			lab var l5 "Value if [asset] were sold today"
	
		* Label define
			lab def asset_l 1 "Radios/CDs/Cassettes" 2 "Televisions" 3 "Dish Antenna" ///
							4 "VCRs/DVD players" 5 "Land on which your home is built" ///
							6 "Other land(s) (excluding land on which your home is built)" ///
							7 "Other houses/buildings" 8 "Refrigerators " ///
							9 "Generators" 10 "Mattresses" 11 "Cell (mobile) phones" ///
							12 "Non-mobile phones" 13 "Clothes irons" 14 "Bed frames" ///
							15 "Pieces of jewelry (gold, silver, etc.)" ///
							16 "Mosquito nets" 17 "Mosquito-repellant candles" ///
							18 "Fans" 19 "Cameras" 20 "Other (please specify)" ///
							0 "None" -98 "Don't answer" -99 "Don't know", replace
			lab val asset asset_l
			order l1, after(asset)
		
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in l2 l3 l4 l5 {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}
	
	* Replace to extended missing when they reply "Don't know"
		loc item asset
		loc yesno l1
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da
	
	* Save
		if	`c(stata_version)'>=14	{
			saveold "${other_assets_bl}", replace v(13)
		}
		else {
			save "${other_assets_bl}", replace
		}	

		
********************************************************************************
	** Module M: Loans
********************************************************************************

use "${all_HH_interm_nopii_bl}", clear

	* Keep relevant variables
		keep hhid m1 m1_a m2_* m3_* m4_*
		drop *_f *_m
	
	* Keep only households who have loans
		keep if m1==1
	
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}

	* Fix m3
	* Rename so we can create the new variables
		forval varnum=1/11 {
			forval loan=1/15 {
				*display "m3_`varnum'_`loan'"
				rename m3_`varnum'_`loan' m3_`varnum'_`loan'_old
			}
		}
		
	* Create variables
		forval loan=1/15 {
			forval purpose=1/9 {
				gen m3_`purpose'_`loan' =  .
					forval varnum=1/11 {
						display "m3_`purpose'_`loan'"
						tab m3_`varnum'_`loan'_old if m3_`varnum'_`loan'_old == `purpose' | mi(m3_`varnum'_`loan'_old), m
						replace m3_`purpose'_`loan' = 1 if m3_`varnum'_`loan'_old == `purpose'
						replace m3_`purpose'_`loan' = 0 if m3_`varnum'_`loan'_old != `purpose' & !mi(m3_`varnum'_`loan'_old) & mi(m3_`purpose'_`loan')
						replace m3_`purpose'_`loan' = .r if m3_`varnum'_`loan'_old==.r
						replace m3_`purpose'_`loan' = .d if m3_`varnum'_`loan'_old==.d
						tab m3_`purpose'_`loan', m
					}
			}	
		}
		
	* Global for select_multiple variables
		drop *_old
		local m3_ "m3_1_ m3_2_ m3_3_ m3_4_ m3_5_ m3_6_ m3_7_ m3_8_ m3_9_"
	    
	* Reshape
		reshape long m2_ `m3_' m4_, i(hhid) j(loan_number) 
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning

		* Drop empty observations (no loan)
			keep if loan_number <= m1_a
			label drop  loan
	
		* Labels
			lab var hhid "Household ID"
			lab var m1_a "How many outstanding loans does your household have?"
			lab var loan_number "Loan number"
			lab var m3_1 "Loan's intended purpose includes: For health emergency"
			lab var m3_2 "Loan's intended purpose includes: To purchase food or other essential items for the household"
			lab var m3_3 "Loan's intended purpose includes: To purchase durable good"
			lab var m3_4 "Loan's intended purpose includes: To buy seeds/fertilizer or other farm inputs"
			lab var m3_5 "Loan's intended purpose includes: To start a business"
			lab var m3_6 "Loan's intended purpose includes: To invest in current business"
			lab var m3_7 "Loan's intended purpose includes: To provide working capital for current business"
			lab var m3_8 "Loan's intended purpose includes: To pay for wedding/religious celebration"
			lab var m3_9 "Loan's intended purpose includes: To pay dowry"	
	
		*Looking at outliers in the loan_outliers_bl do file
		qui do "${Baseline_do}/Cleaning/loan_outliers_bl.do"
		
		* Drop outlier flag
			drop loan_number_pc sum_loan m1
		
		* Save
			if	`c(stata_version)'>=14	{
				saveold "${loans_bl}", replace v(13)
			}
			else {
				save "${loans_bl}", replace
			}
			
********************************************************************************
	** Module K: Productive Activities and Assets (K)
********************************************************************************

*----------*
* 1. Crops *
*----------*

	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid k15* k16* k17* k19* k20* k21* 
		rename (k15__99 k15__98) (k15_99 k15_0) // in this questions -98 means "None"
			 	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	k15_ k16_ k17_ k19_ k20_ k21_, ///
						i(hhid) j(crop)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Drop empty vars (28-29 crop)
			drop if inlist(crop, 28, 29)
			
		* Recode -98 and -99
			recode crop (99=-99)			
		
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in k16 k17 k19 k20 k21 {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}
					
		* Labels
			lab var hhid "Household ID"
			lab var crop "Crop"
			lab var k15  "Has your household cultivated any of the following crops in the past twelve months:"
			lab var k16  "Harvesting periods in the past twelve months: [crop]"
			lab var k17  "Production in most recent harvesting period (KGs): [crop]"
			lab var k19  "Sold in most recent harvesting period (KGs): [crop]"
			lab var k20  "Earned from selling in the most recent harvesting period: [crop]"
			lab var k21  "Spent on inputs in last full crop season (excl. land): [crop]"

		* Label define
			lab def crop_l 	1 "Wheat" 2 "Vetch" 3 "Maize" 4 "Barley" 5 "Rice" ///
							6 "Weed" 7 "Sesame" 8 "Clover" 9 "Millet" 10 "Sharsham" ///
							11 "Sugarcane" 12 "Cotton" 13 "Caraway-seed" 14 "Potato" ///
							15 "Cereal" 16 "Eggplant" 17 "Tomato" 18 "Onion" 19 "Okra" ///
							20 "Fruits from a tree" 21 "Grape" 22 "Mellon" 23 "Opium" ///
							24 "Zaghar" 25 "Saffron" 26 "Other 1 ( please specify)" ///
							27 "Other 2 (please specify)" 0 "None" -99 "Don’t know"
			lab val crop crop_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item crop
		loc yesno k15
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk			
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${crops_bl}", replace v(13)
		}
		else {
			save "${crops_bl}", replace
		}		

*---------------*
* 2. Businesses *
*---------------*

	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid k23_a* k24* k26_m* k26_y* k27* k28* k29* k31* k32* k33* k34* k35* k25*
		
	* Drop variables that interfere with reshape
		rename (k23_a__99 k23_a__98) (k23_a_99 k23_a_0) // in this questions -98 means "None"
		
	* Fix k24: select multiple
	loc varname k24
		forval x=1/15 { //business
			forval varnum=1/4 {
				rename `varname'_`varnum'_`x' `varname'_`varnum'_`x'_old
			}
		}
		
	* Create variables for each business. x = business
		forval role=0/3 {
			forval x=1/15 {
				gen `varname'_`role'_`x' =  .
					forval varnum=1/4 {
						display "`varname'_`varnum'_`x'"
						replace `varname'_`role'_`x' = 1 if `varname'_`varnum'_`x'_old == `role'
						replace `varname'_`role'_`x' = 0 if `varname'_`varnum'_`x'_old != `role' & !mi(`varname'_`varnum'_`x'_old) & mi(`varname'_`role'_`x')
						replace `varname'_`role'_`x' = .r if `varname'_`varnum'_`x'_old == .r
						replace `varname'_`role'_`x' = .d if `varname'_`varnum'_`x'_old == .d
					}	
			}
		}
		drop *_old		
		
	* Global for select_multiple variables				   
		loc k24_mult "k24_3_ k24_2_ k24_1_ k24_0_"	   
				   
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		rename (k26_m* k26_y*) (k26_m_* k26_y_*)
		reshape long 	k23_a_ k24_ `k24_mult' k26_y_ k26_m_ k27_ k28_ k29_ k31_ ///
						k32_ k33_ k34_ k35_ k25_, ///
						i(hhid) j(business)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Order
			order k23_a, after(business)
			drop k24
		
		* Recode -98 and -99
			recode business (99=-99)
					
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in k26_y k27 k28 k29 k31 k32 k33 k34 k35 {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}
			
		* Labels
			lab var hhid "Household ID"
			lab var business "Business"
			lab var k23_a "Does anyone in your household fully, or partly, own and operate any of these businesses?"
			lab var k24_3 "Role in business includes: Owner"
			lab var k24_2 "Role in business includes: Manager"
			lab var k24_1 "Role in business includes: Worker"
			lab var k24_0 "Role in business includes: Do not participate"
			lab var k26_y "When did the [business] first start? (Years)"
			lab var k26_m "When did the [business] business first start? (Months)"
			lab var k27	"Was any startup capital needed to start [business #]?"
			lab var k28	"Value of the start-up capital needed for [business #]"
			lab var k29	"How many employees work in [business #]?"
			lab var k31	"How many employees in [business #] are not household members?"
			lab var k32	"What are the revenues of [business #] in the last 4 weeks?"
			lab var k33	"Spent on machinery or durable goods [business #] (past 12 months)"
			lab var k34	"Spent on operating costs/inputs for [business #] (past 4 weeks)"
			lab var k35	"Earn a profit, make a loss, or break even [business #] (past 4 weeks)"
			lab var k25	"How many months operated [business #] (past 12 months)"

			
		* Label define
			lab def business_l 	1 "Selling crafts (baskets, pots, etc.)" 2 "Repairing bicycles" ///
								3 "Selling prepared foods/run restaurant" ///
								4 "Selling raw produce (that is NOT cultivated by respondent but purchased elsewhere)" ///
								5 "Providing transportation" 6 "Making bricks" ///
								7 "Butchering" 8 "Doing carpentry" 9 "Selling clothes and sheets" ///
								10 "Building thatch or iron sheet roofs"  ///
								11 "Constructing houses/buildings" ///
								12 "Drilling boreholes/building latrines" ///
								13 "Collecting and selling firewood" ///
								14 "Other 1 (please specify)"  15 "Other 2 (please specify)" ///
								0 "None" -99 "Don’t know "
			lab val business business_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item business
		loc yesno k23_a
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		drop temp dk
		tab `yesno' if `item' == 1, m
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${businesses_bl}", replace v(13)
		}
		else {
			save "${businesses_bl}", replace
		}	

*--------------*
* 5. Livestock *
*--------------*

	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid k6* k7* k8* k14
		
	* Drop variables that interfere with reshape
		rename (k6__99 k6__98) (k6_99 k6_0) // in this question -98 means "None"
			
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	k6_ k7_ k8_, ///
						i(hhid) j(livestock)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning			
		* Order
			order k6, after(livestock)

		* Recode -98 and -99
			recode livestock (99=-99)			
		
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in k7 k8 {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}
		
		* Very likely that the k8 == 99 are actually don't knows (6 values) 
		replace k8 = .d if k8 == 99
			
		* Labels
			lab var hhid "Household ID"
			lab var livestock "Livestock"
			lab var k6 "Does your household own any of the following livestock?"
			lab var k14	"Spent on inputs for owned livestock and produce animal products (past 4 weeks)"
			lab var k7	"How many [animal] does your household own?"
			lab var k8	"Current market value of [animal]"
			
		* Label define
			lab def livestock_l 1 "Cows" 2 "Bulls" 3 "Horses" 4 "Donkeys" 5 "Goats" ///
								6 "Sheep" 7 "Chickens" 8 "Ducks" 9 "Turkeys" ///
								10 "Gooses" 11 "Rabbits" 12 "Guinea fowl" 13 "Bee hives" ///
								14 "Other animal 1 (please specify)" ///
								15 "Other animal 2 (please specify)" 0 "None" ///
								-99 "Don’t Know"
			lab val livestock livestock_l

	* Replace to extended missing when they reply "Don't know"
		loc item livestock
		loc yesno k6
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		drop temp dk
		tab `yesno' if `item' == 1, m
		
	* Looking at outliers
		 do "${Baseline_do}/Cleaning/livestock_outliers_bl.do"			
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${livestock_bl}", replace v(13)
		}
		else {
			save "${livestock_bl}", replace
		}	
	
*--------------------*
* 6. Animal products *
*--------------------*

	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid k9* k10* k12* k13*
			 
	* Drop variables that interfere with reshape
		rename (k9__99 k9__98) (k9_99 k9_0) // in this question -98 means "None"
				 	   
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	k9_ k10_ k12_ k13_, ///
						i(hhid) j(product)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning			
		* Recode -98 and -99
			recode product (99=-99)
	
		* Order
			order k9, after(product)
		
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in k10 k12 k13 {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}
			
		* Labels
			lab var hhid "Household ID"
			lab var product "Animal product"
			lab var k9 "In the past four weeks has your household produced any of these animal products?"
			lab var k10	"Amount [animal product] produced in the past four weeks (pieces of KG)"
			lab var k12	"Amount [animal product] sold in the past four weeks (pieces of KG)"
			lab var k13	"Earnings from sales [animal product] in the past four weeks"

		* Label define
			lab def product_l 	1 "Milk" 2 "Egg" 3 "Honey" 4 "Butter" 5 "Yogurt" ///
								6 "Meat" 7 "Other 1 (please specify)" ///
								8 "Other 2 (please specify)" 0 "None" ///
								-99 "Don’t know "
			lab val product product_l

	* Replace to extended missing when they reply "Don't know"
		loc item product
		loc yesno k9
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		drop temp dk
		tab `yesno' if `item' == 1, m		
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${animal_products_bl}", replace v(13)
		}
		else {
			save "${animal_products_bl}", replace
		}		
		
*-------------------------------------------------*
* 3. Productive activities module - All questions *
*-------------------------------------------------*

	use "${all_HH_interm_nopii_bl}", clear
	
* A. K30

	* Structure: question_activity_member
	* Reshape para activities: repeat activities_2_repeat
	
			keep hhid b3 k30_?_1 k30_?_2  k30_?_3  k30_?_4  k30_?_5  k30_?_6  k30_?_7  k30_?_8  k30_?_9  k30_?_10  k30_?_11  k30_?_12  k30_?_13  k30_?_14  k30_?_15  k30_?_16  k30_?_17  k30_?_18  k30_?_19 /*k30_o*/ ///
				 k30_1_?_1 k30_1_?_2 k30_1_?_3 k30_1_?_4 k30_1_?_5 k30_1_?_6 k30_1_?_7 k30_1_?_8 k30_1_?_9 k30_1_?_10 k30_1_?_11 k30_1_?_12 k30_1_?_13 k30_1_?_14 k30_1_?_15 k30_1_?_16 k30_1_?_17 k30_1_?_18 k30_1_?_19 ///
				 k30_2_?_1 k30_2_?_2 k30_2_?_3 k30_2_?_4 k30_2_?_5 k30_2_?_6 k30_2_?_7 k30_2_?_8 k30_2_?_9 k30_2_?_10 k30_2_?_11 k30_2_?_12 k30_2_?_13 k30_2_?_14 k30_2_?_15 k30_2_?_16 k30_2_?_17 k30_2_?_18 k30_2_?_19 k5_1* ///

			* Save labels
				foreach var of varlist * {
					local l_`var' : variable label `var'
					local val_`var': value label `var'
				}
					  
			* Reshape member	  
				reshape long k30_1_ k30_2_ k30_3_ k30_4_ k30_5_ k30_6_ k30_7_ k30_8_ k30_9_ k30_10_ k30_11_ k30_12_ ///
							 k30_1_1_ k30_1_2_ k30_1_3_ k30_1_4_ k30_1_5_ k30_1_6_ k30_1_7_ k30_1_8_ k30_1_9_ ///
							 k30_2_1_ k30_2_2_ k30_2_3_ k30_2_4_ k30_2_5_ k30_2_6_ k30_2_7_ k30_2_8_ k30_2_9_ ///
							 k5_1_, i(hhid) j(member)
				rename *_ *
				
			* Fix variable	k30
				rename k30_? k30_temp_?
				rename k30_1? k30_temp_1?
				forval	act_num=1/12	{
					egen	k30_`act_num'	=	anymatch(k30_temp_? k30_temp_1?), value(`act_num')
					replace	k30_`act_num'	=.  if k30_temp_1 == .
				}
				egen	k30_0		=	anymatch(k30_temp_? k30_temp_1?), value(0)
				egen	k30_98	=	anymatch(k30_temp_? k30_temp_1?), value(-98)
				egen	k30_99	=	anymatch(k30_temp_? k30_temp_1?), value(-99)
				
				replace	k30_0		=.	if	k30_temp_1 == .
				replace	k30_98	=.	if	k30_temp_1 == .
				replace	k30_99	=.	if	k30_temp_1 == .
				drop k30_10 k30_11 k30_12
				*rename k30_temp_o k30o 
				drop k30_temp_*
				order k30_? k30_98 k30_99, after(member)
				
			* Reshape activity
				reshape long k30_ k30_1_ k30_2_, i(hhid member) j(activity)
			
			* Additional cleaning
				rename *_ *
				
				recode activity (98 = -98) (99= -99)
				lab def activity_l 1 "1: Tend any animals owned or leased by the household" ///
									2 "2: Farm land owned or sharecropped by the household" ///
									3 "3: Work on business owned by household other than farm/animals (e.g. shop, crafts)" ///
									4 "4: Work as an agricultural laborer outside household" ///
									5 "5: Do housework in someone else's home" ///
									6 "6: Work as a non-agricultural laborer outside the household (other than housework)" ///
									7 "7: Work in salaried/formal employment" ///
									8 "8: Do any other work for pay  (money or in-kind)" ///
									9 "9: Work on household chores (e.g. collecting water, cooking, cleaning) in your household" ///
									0 "0: None" ///
									-98 "-98: Don't answer" ///
									-99 "-99: Don't know"
				lab val activity activity_l				
				
		* Drop non-existent member
			order b3, after(member)
			
			drop if member>b3 & hhid != 6364 // for some reason this HH doesn't have roster. We keep if so the merge is clean
		
			* Labels
				lab var hhid "Household ID"
				lab var member "Order of household member in follow-up"
				lab var activity "Productive activity"
				lab var k30 "Did [HH member #] do any of these activities in the last 4 weeks?"
				lab var k30_1 "How much did [HH member #] earn to [activity #] in the last 4 weeks?"
				lab var k30_2 "Approximately how much do you think is the value in Afghanis of what they received in-kind."
				lab var k5_1  "Did [HH member #] try to find work outside the home in the past 2 weeks?"
				drop b3		
						
			* Replace to extended missing when they reply "Don't know"
				loc item activity
				loc yesno k30
				tab `item' if `yesno' == 1, m
				gen temp = 1 if `item' == -99 & `yesno' == 1
				bys hhid member: egen dk = max(temp)
				replace `yesno' = .d if dk == 1	& `item' != -99
				tab `yesno' if `item' == 1, m
				drop temp dk
				
			* Replace to extended missing when they reply "Don't answer"
				tab `item' if `yesno' == 1, m
				gen temp = 1 if `item' == -98 & `yesno' == 1
				bys hhid member: egen da = max(temp)
				replace `yesno' = .r if da == 1	& `item' != -98
				tab `yesno' if `item' == 1, m
				drop temp da	
				
	* Looking at outliers in the time_activities_outliers_bl do file
		qui do "${Baseline_do}/Cleaning/time_activities_outliers_bl.do"
		
	*Quick cleaning
		*Putting in value in earning
		replace k30_1 = k30_2 if (mi(k30_1) & !mi(k30_2)) | inlist(k30_1,-97,.n)		
		drop k30_2
		
	* Weird label I get
		label drop asset_l
	
			if	`c(stata_version)'>=14	{
				saveold "${productive_act_bl}", replace v(13)
			}
			else {
				save "${productive_act_bl}", replace
			}		
	
		
********************************************************************************
	** Module C: Consumption 
********************************************************************************

*-------------------------*
* Food consumption module *
*-------------------------*

use "${all_HH_interm_nopii_bl}", clear

* Locals for names
	local c3_type "Bread"
	local c4_type "Meat"
	local c5_type "Dairy"
	local c6_type "Oils"
	local c7_type "Vegetables"
	local c8_type "Fruits"
	local c9_type "Sweets"
	local c10_type "Beverages"
	local c11_type "Spices"
	

	* Rename variables
		* Create variables
		foreach item_type in c3 c4 c5 c6 c7 c8 c9 c10 c11 {
			rename (`item_type'_i* `item_type'_a* `item_type'_s*) (`item_type'_i_* `item_type'_a_* `item_type'_s_*)
		}
		
	* Do manual renames to match folow-up names
		* Oils
			rename c6_3 c6_4
			rename c6_2 c6_3
			rename c6_*_3 c6_*_4
			rename c6_*_2 c6_*_3
		
* Reshape
	* Since each group is a different roster, we do the reshape separately 
		foreach item_type in c3 c4 c5 c6 c7 c8 c9 c10 c11 {
			preserve
			keep hhid `item_type'*
			
			reshape long `item_type'_ `item_type'_i_ `item_type'_a_ `item_type'_s_, i(hhid) j(item)
			rename  (`item_type'_ `item_type'_i_ `item_type'_a_ `item_type'_s_ ) ///
					(c c_i c_a c_s) // consumed consumed_days c_a consumed_source
			gen item_type = "``item_type'_type'"

		* We have to recode the items in order to get only one data for all
			if "``item_type'_type'" == "Bread" {
				recode item (100 = 13)
				}

			if "``item_type'_type'" == "Meat" {
				recode item (1=14) (2=15) (3=16) (4=17) (5=18) (6=19) (7=20) (8=21) (9=22) (100=23)
				}
				
			if "``item_type'_type'" == "Dairy" {
				recode item (1=24) (2=25) (3=26) (4=27) (5=28) (6=29) (7=30) (8=31) (9=32) (10=33) (11=34) (100=35)
				}
			
			if "``item_type'_type'" == "Oils" {
				recode item (1=36) (2=37) (3=38) (4=39) (100=40)
				}
				
			if "``item_type'_type'" == "Vegetables" {
				recode item (1=41) (2=42) (3=43) (4=44) (5=45) (6=46) (7=47) (8=48) (9=49) (10=50) ///
							(11=51) (12=52) (13=53) (14=54) (15=55) (16=56) (17=57) (18=58) (19=59) (20=60) ///
							(21=61) (22=62) (23=63) (24=64) (100=65)
				}
			
			if "``item_type'_type'" == "Fruits" {
				recode item (1=66) (2=67) (3=68) (4=69) (5=70) (6=71) (7=72) (8=73) (9=74) (10=75) ///
							(11=76) (12=77) (13=78) (14=79) (15=80) (16=81) (17=82) (18=83) (19=84) (100=85)
				}
				
			if "``item_type'_type'" == "Sweets" {
				recode item (1=86) (2=87) (3=88) (4=89) (5=90) (6=91) (7=92) (100=93)
				}
			
			if "``item_type'_type'" == "Beverages" {
				recode item (1=94) (2=95) (3=96) (4=97) (100=98)
				}

			if "``item_type'_type'" == "Spices" {
				recode item (1=99) (2=100) (3=101) (4=102) (5=103) (6=104) (100=105)
				}
	
		tempfile ``item_type'_type'
		save	```item_type'_type''
		restore
	}
	
	* Append all datasets
		use `Bread', clear
		append using `Meat'
		append using `Dairy'
		append using `Oils'
		append using `Vegetables'
		append using `Fruits'
		append using `Sweets'
		append using `Beverages'
		append using `Spices'
		
	* Labels
	lab def item_l 	1 "Rice (high quality)" 2 "Rice (low quality)" 3 "Wheat flour" ///
					4 "Naan not made at home" 5 "Barley" 6 "Maize" 7 "Beans" 8 "Mung" ///
					9 "Chickpeas" 10 "Lentils" 11 "Pasta" 12 "Other bread and/or cereal" ///
					13 "None" 14 "Beef" 15 "Veal" 16 "Mutton" 17 "Goat" 18 "Chicken" 19 "Liver" ///
					20 "Dried Meat" 21 "Fish" 22 "Other meat and/or fish" 23 "None" 24 "Milk (fresh)" ///
					25 "Milk (powdered)" 26 "Yogurt" 27 "Curd (chaka)" 28 "Krut (dried)" ///
					29 "Dogh" 30 "Ghee" 31 "Butter" 32 "Cheese" 33 "Eggs" 34 "Other dairy products" ///
					35 "None" 36 "Vegetable cotton oil or sesame oil" 38 "Animal fat" ///
					39 "Other oils and fat" 40 "None" 41 "Potato" 42 "Sweet potato" 43 "Onion" ///
					44 "Tomato" 45 "Okra" 46 "Spinach" 47 "Cauliflower" 48 "Eggplant" 49 "Carrots" ///
					50 "Pumpkin, squash" 51 "Cucumber" 52 "Radish" 53 "Turnip" 54 "Cabbage" ///
					55 "Leek" 56 "Hot pepper" 57 "Wild leafy vegetables" 58 "Coriander" 59 "Mint" ///
					60 "Dried tomatoes" 61 "Dried vegetables" 62 "Pickled vegetables" ///
					63 "Green beans" 64 "Other vegetables" 65 "None" 66 "Apple" 67 "Grapes" ///
					68 "Melon/watermelon" 69 "Peach" 70 "Fresh apricots" 71 "Dried apricots" ///
					72 "Orange/citrus" 73 "Plum" 74 "Pomegranate" 75 "Pear" 76 "Banana" ///
					77 "Raisins" 78 "Fresh mulberries" 79 "Dried mulberries" 80 "Mangoes" ///
					81 "Walnuts" 82 "Pistachio" 83 "Almonds" 84 "Other fruit and/or nuts" ///
					85 "None" 86 "White sugar" 87 "Brown sugar" 88 "Honey" 89 "Chocolates, candy, sherinigack" ///
					91 "Sweetener" 92 "Other sweets, specify" 93 "None" ///
					94 "Black teas" 95 "Green teas" 96 "Bottled/canned beverages, Mineral waters" ///
					97 "Other beverages" 98 "None" 99 "Salt" 100 "Black pepper" 101 "Ginger and garlic" ///
					102 "Tomato sauce" 103 "Mixed spices" 104 "Other spices" 105 "None"
	lab val item item_l
	
	* Order variables
		sort hhid item
		br hhid item_type item * 
		order hhid item_type item c c_i c_a c_s
		
	* Label main source
		lab def source_l 1 "Purchase" 2 "Own production" 3 "Bartered/payment in kind" ///
						4 "Borrowed/taken on credit" 5 "Received as gift from friends or family" ///
						6 "Food aid from organization" -97 "Other"
		lab val c_s source_l
	
	* Label 
		lab var c "Item was consumed in the last 7 days"
		lab var c_i "Days item was consumed in the last 7 days"
		lab var c_a "Quantity consumed"
		lab var c_s "Main source of item"
		lab var item "Item"
		lab var item_type "Item type"	
		
	* Replace -99 and 98
		foreach var of varlist c_s c_a {
			replace `var' = .d if `var' == -99
			replace `var' = .d if `var' == 99
			replace `var' = .r if `var' == -98
			replace `var' = .r if `var' == 98
			replace `var' = .o if `var' == -97 // other
		}
		
	* For an error in translation, we change ghee to the oils group
	* Mohammad: "On ghee consumption, I looked at the Dari instrument and followed 
	*			up with a surveyor in Afghanistan. Ghee is translated as "cooking oil".
	* 			On NRVA's classification, it seems to me that NRVA has translated ghee 
	*			into  a word the equivalent of which is "butter". In that case, it can 
	*			be categorized as a diary product. We used the word "butter" for that 
	*			in our instrument. 
		replace item_type = "Oils" if item==30
	
	/* Rename to keep original variable
		rename c_a c_a_original
		clonevar c_a = c_a_original*/
	
	* Looking at outliers in food items
		qui do "${Baseline_do}/Cleaning/food_consumption_outliers_bl.do"
	
	/* Rename to keep original variable
		rename c_a c_a_clean
		rename c_a_original c_a */
	
	* Clean outliers
		tab flag_outlier
		tab c_a if flag_outlier == 3
		replace c_a = .o if flag_outlier == 3
		replace c_a = .o if flag_outlier == 1
		replace c_a = .o if flag_outlier == 2 
	
	* Drop outlier flag
		drop flag*
	
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${consumption_bl}", replace v(13)
		}
		else {
			save "${consumption_bl}", replace
		}	

*-----------------------------------*
* Non-food consumption - last month *
*-----------------------------------*
		
	use "${all_HH_interm_nopii_bl}", clear	
	
	* Keep relevant variables
		keep hhid c12_*
			
	* Reshape
		reshape long c12_, i(hhid) j(item)
		rename c12_ c12
		
	* Lab var
		lab var c12 "What did your household spend in the last month on the following (value in Afghanis):"
		lab var item "Item"
		
	* Missings
		replace c12 = .d if c12 == -99
		replace c12 = .d if c12 == 99
		replace c12 = .r if c12 == -98
		replace c12 = .r if c12 == 98
		
	* Save
		tempfile nonfood_month
		save	`nonfood_month'
		
*----------------------------------*
* Non-food consumption - last year *
*----------------------------------*
		
	use "${all_HH_interm_nopii_bl}", clear	
	
	* Keep relevant variables
		keep hhid c13_*
			
	* Reshape
		reshape long c13_, i(hhid) j(item)
		rename c13_ c13
		
	* Lab var
		lab var c13 "What did your household spend in the last 12 months on the following (value in Afghanis):"
		lab var item "Item"
		replace item = item+20
		
	* Missings
		replace c13 = .d if c13 == -99
		replace c13 = .d if c13 == 99
		replace c13 = .r if c13 == -98
		replace c13 = .r if c13 == 98
		
	* Append monthly
		append using `nonfood_month'
			
	* Lab def
		lab def item_l 	1 "Food consumed at home" 2 "Food consumed outside the home" ///
						3 "Cigarettes" 4 "Tobacco/snuff" 5 "Matches" ///
						6 "Laundry powder/detergents, cleaning supplies" ///
						7 "Soap (hand, toiletry)" 8 "Shampoo" 9 "Toothpaste" ///
						10 "Personal grooming (haircuts, etc.) for males" ///
						11 "Fee for public bath" 12 "Laundry charges"  ///
						13 "Fee for baking bread" 14 "Fixed phone line and use (including PCO booths)"  ///
						15 "Mobile phone charges (minutes and prepaid)" ///
						16 "Internet service/Internet café, fax, mail"  ///
						17 "Transportation fare - bus and taxis" ///
						18 "Fuel for car/motor bike (do not include business vehicles)" ///
						19 "Taxes (formal and informal)"  ///
						20 "Other miscellaneous expenses in last month" ///
						21 "House construction and repair (materials and labor)" ///
						22 "Education fees (tuition for school, college, university)" ///
						23 "School uniforms" 24 "Textbooks" 25 "Pens, pencils and notebooks (school supplies)" ///
						26 "Other stationery" 27 "Repair, maintenance and tires for motor vehicles" ///
						28 "Airfares" 29 "Men's clothing (excluding shoes)"  ///
						30 "Women's clothing (excluding shoes)" ///
						31 "Children's clothing (excluding shoes and school uniforms)" ///
						32 "Men's shoes" 33 "Women's shoes" 34 "Children's shoes" ///
						35 "Fines" 36 "Weddings and funerals, haj"  ///
						37 "Annual celebrations and charitable donations (khair-o-khairat)" ///
						38 "Health services"
		lab val item item_l
				
	order hhid item c12 c13
	sort hhid item
		
	/* Rename c12 and c13 so do file below keeps original variables
		rename (c12 c13) (c12_original c13_original)
		clonevar c12 = c12_original
		clonevar c13 = c13_original */
		
	* Looking at outliers in non-food items
		qui do "${Baseline_do}/Cleaning/nonfood_consumption_outliers_bl.do"		
		
	/* Rename back c12 and c13 
		rename (c12 c13) (c12_clean c13_clean)
		rename (c12_original c13_original) (c12 c13) */
		
	* Clean outliers that are typing errors
		tab flag_outlier
		replace c12 = .o if flag_outlier == 1 & !mi(c12)
		replace c13 = .o if flag_outlier == 1 & !mi(c13)

	* Drop outlier flag
		drop flag*
		
	* Save
		if	`c(stata_version)'>=14	{
			saveold "${nonfood_consumption_bl}", replace v(13)
		}
		else {
			save "${nonfood_consumption_bl}", replace
		}				

********************************************************************************
	** Module 12: Transfers and Safety Nets (D)
********************************************************************************
	
*--------------------*
* 1. Transfers given *
*--------------------*
	
	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid d1* d2* d3*
			 
	* Drop variables that interfere with reshape
		drop d10* d13* d3_22* d3_23* d3_24* // d3_22* d3_23* d3_24* are not in the choice list
		rename (d1__99 d1__98) (d1_99 d1_98)
			 
	* Global for select_multiple variables
		loc d3_mult "d3_1_ d3_2_ d3_3_ d3_4_ d3_5_ d3_6_ d3_7_ d3_8_ d3_9_ d3_10_ d3_11_ d3_12_ d3_13_ d3_14_ d3_15_ d3_16_ d3_17_ d3_18_ d3_19_ d3_20_ d3_21_ d3__97_ d3__98_ d3__99_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	d1_ d2_1_ d2_ `d3_mult' , ///
						i(hhid) j(item)
	
	* Paste labels
		rename *_ *
		
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning	
		* Clean up d3 so it is a set of dummies 
			recode d3* (-97=97) (-98=98) (-99=99) 
			rename (d3__97 d3__98 d3__99) (d3_97 d3_98 d3_99)
			
			foreach i of numlist 1/21 97/99 {
				gen d3_`i'_ = .
				replace d3_`i'_ = 1 if (d3_1 == `i' | d3_2 == `i' | d3_3 == `i' | d3_4 == `i' | d3_5 == `i' | d3_6 == `i' | d3_7 == `i' | d3_8 == `i' | d3_9 == `i' | d3_10 == `i' | d3_11 == `i' | d3_12 == `i' | d3_13 == `i' | d3_14 == `i' | d3_15 == `i' | d3_16 == `i' | d3_17 == `i' | d3_18 == `i' | d3_19 == `i' | d3_20 == `i' | d3_21 == `i' | d3_97 == `i' | d3_98 == `i' | d3_99 == `i')
			}
			
			foreach i of numlist 1/21 97/99 {
				drop d3_`i'
			}
			
			rename *_ *
				
		* Recode -98 and -99
			recode item (97=-97) (98=-98) (99=-99)
			recode d3* (97=-97) (98=-98) (99=-99)
			
			rename (d3_97 d3_98 d3_99) (d3__97 d3__98 d3__99)
	
		* Labels
			lab var hhid "Household ID"
			lab var item "Item given"
			lab var d1 "Which of these items has your HH given to non-HH members in the last 12 months?"
			lab var d2_1 "How many times over the past 12 months did you give [item] to a non-HH member?"
			lab var d3_1 "Gift was given to: Spouse"
			lab var d3_2 "Gift was given to: Son/daughter"
			lab var d3_3 "Gift was given to: Stepson/stepdaughter/adopted/foster"
			lab var d3_4 "Gift was given to: Son-in-law/daughter-in-law"
			lab var d3_5 "Gift was given to: Grandchild"
			lab var d3_6 "Gift was given to: Brother/sister"
			lab var d3_7 "Gift was given to: Brother-in-law/sister-in-law"
			lab var d3_8 "Gift was given to: Father/mother"
			lab var d3_9 "Gift was given to: Father-in-law/mother-in-law"
			lab var d3_10 "Gift was given to: Grandparent"
			lab var d3_11 "Gift was given to: Great-grandchild"
			lab var d3_12 "Gift was given to: Cousin"
			lab var d3_13 "Gift was given to: Nephew/niece"
			lab var d3_14 "Gift was given to: Co-wife"
			lab var d3_15 "Gift was given to: Aunt/uncle"
			lab var d3_16 "Gift was given to: Other relative"
			lab var d3_17 "Gift was given to: Worker/household help"
			lab var d3_18 "Gift was given to: Co-worker"
			lab var d3_19 "Gift was given to: Friend"
			lab var d3_20 "Gift was given to: Lodger"
			lab var d3_21 "Gift was given to: Neighbor"
			lab var d3__97 "Gift was given to: Other unrelated (please specify)"
			lab var d3__98 "Gift was given to: Don't answer"
			lab var d3__99 "Gift was given to: Don't know"

		* Label define
			lab def item_l 	1 "Money" 2 "Clothes, pots, pans, pails, etc." ///
							3 "Uncooked produce" 4 "Meals" 5 "Work materials" ///
							6 "Dowry/bride price" 7 "Wedding gift" 8 "Livestock" ///
							9 "Land" 10 "Other (please specify)" -99 "Don’t know" ///
							-98 "Don't answer" 0 "None"
			lab val item item_l
		
	* Replace to extended missing when they reply "Don't know"
		loc item item
		loc yesno d1
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da
		
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${given_transfers_bl}", replace v(13)
		}
		else {
			save "${given_transfers_bl}", replace
		}		

*-----------------------*
* 2. Transfers received *
*-----------------------*
	
	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid d8* d9* d10*
		rename (d8__99 d8__98) (d8_99 d8_98)
			 			 
	* Global for select_multiple variables
		loc d10_mult "d10_1_ d10_2_ d10_3_ d10_4_ d10_5_ d10_6_ d10_7_ d10_8_ d10_9_ d10_10_ d10_11_ d10_12_ d10__97_ d10__98_ d10__99_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	d8_ d9_1_ d9_ `d10_mult' , ///
						i(hhid) j(item)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "[mem 1]" "[HH member #]", all 
			local l_`var'_1 : subinstr local l_`var'_1 "[activity 1]" "[activity #]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Clean up d10 so it is a set of dummies 
			recode d10* (-97=97) (-98=98) (-99=99) 
			rename (d10__97 d10__98 d10__99) (d10_97 d10_98 d10_99)
			
			foreach i of numlist 1/12 97/99 {
				gen d10_`i'_ = .
				replace d10_`i'_ = 1 if (d10_1 == `i' | d10_2 == `i' | d10_3 == `i' | d10_4 == `i' | d10_5 == `i' | d10_6 == `i' | d10_7 == `i' | d10_8 == `i' | d10_9 == `i' | d10_10 == `i' | d10_11 == `i' | d10_12 == `i' | d10_97 == `i' | d10_98 == `i' | d10_99 == `i')
			}
			
			foreach i of numlist 1/12 97/99 {
				drop d10_`i'
			}
			
			rename *_ *
				
		* Recode -98 and -99
			recode item (97=-97) (98=-98) (99=-99)
			recode d10* (97=-97) (98=-98) (99=-99)
			
			rename (d10_97 d10_98 d10_99) (d10__97 d10__98 d10__99)
		
		* Labels
			lab var hhid "Household ID"
			lab var item "Item given"
			lab var d8 "Which of these items has your HH received from non-HH members in the last 12 months?"
			lab var d9_1 "How many times over the past 12 months did you receive [item] from a non-HH member?"
			lab var d10_1 "Gift was recieved from: Government"
			lab var d10_2 "Gift was recieved from: World Food Program"
			lab var d10_3 "Gift was recieved from: Other Development Agency (e.g. UN, World Bank, USAID)"
			lab var d10_4 "Gift was recieved from: NGO"
			lab var d10_5 "Gift was recieved from: Religious institution (i.e., church, mosque)"
			lab var d10_6 "Gift was recieved from: Community"
			lab var d10_7 "Gift was recieved from: Relatives in the village"
			lab var d10_8 "Gift was recieved from: Relatives in another village within Afghanistan"
			lab var d10_9 "Gift was recieved from: Relatives abroad"
			lab var d10_10 "Gift was recieved from: Friends or neighbors in the village"
			lab var d10_11 "Gift was recieved from: Friends in another village within Afghanistan"
			lab var d10_12 "Gift was recieved from: Friends abroad"
			lab var d10__97 "Gift was recieved from: Other (please specify)"
			lab var d10__98 "Gift was recieved from: Don't answer"
			lab var d10__99 "Gift was recieved from: Don't know"
			lab var d9_1 "How many times over the past 12 months did you receive [gift] from a non-HH member?"

		* Label define
			lab def item_l 	1 "Money" 2 "Clothes, pots, pans, pails, etc." ///
							3 "Uncooked produce" 4 "Meals" 5 "Work materials" ///
							6 "Dowry/bride price" 7 "Wedding gift" 8 "Livestock" ///
							9 "Land" 10 "Construction/building material"  ///
							11 "Water and/or sanitation"  ///
							12 "Agricultural input assistance (tools, seeds, fertilizer, etc.)"  ///
							13 "Training and technical assistance in improved agricultural/livestock practices" ///
							14 "Fish ponds" 15 "Veterinary services" 16 "For education (e.g. school materials)" /// 
							17 "Medical services" 18 "Pension payment" 19 "Other (please specify)" ///
							-99 "Don’t know" -98 "Don't answer" 0 "None"
			lab val item item_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item item
		loc yesno d8
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da			
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${received_transfers_bl}", replace v(13)
		}
		else {
			save "${received_transfers_bl}", replace
		}
		

*-----------*
* 3. Shocks *
*-----------*
	
	use "${all_HH_interm_nopii_bl}", clear
	
	* Keep relevant variables
		keep hhid g1* g2* 
		rename (g1__99 g1__98) (g1_99 g1_98)
				
	* Global for select_multiple variables
		loc g2_mult "g2_0_ g2_1_ g2_2_ g2_3_ g2_4_ g2_5_ g2_6_ g2_7_ g2_8_ g2_9_ g2_10_ g2_11_ g2_12_ g2_13_ g2_14_ g2_15_ g2_16_ g2_17_ g2_18_ g2_19_ g2__97_ g2__99_ g2__98_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	g1_ `g2_mult', ///
						i(hhid) j(shock)
	
	* Paste labels
		rename *_ *
		drop g2_19
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Recode -98 and -99
			recode shock (98=-98) (99=-99)

		* Labels
			lab var hhid "Household ID"
			lab var shock "Shock"
			lab var g1 "Please tell me if any of these happened to your household in the past 12 months."
			lab var g2_0 "What did the household do to cope: Nothing"
			lab var g2_1 "What did the household do to cope: Did not need to do anything to compensate"
			lab var g2_2 "What did the household do to cope: Reduced quantity or quality of diet"
			lab var g2_3 "What did the household do to cope: Decreased expenditures"
			lab var g2_4 "What did the household do to cope: Purchased food on credit from traders"
			lab var g2_5 "What did the household do to cope: Took out any other loans"
			lab var g2_6 "What did the household do to cope: Received help from others in the community"
			lab var g2_7 "What did the household do to cope: Rented out or mortgaged land"
			lab var g2_8 "What did the household do to cope: Sold house, land or female reproductive livestock"
			lab var g2_9 "What did the household do to cope: Sold any other assets"
			lab var g2_10 "What did the household do to cope: Worked on relief programmes"
			lab var g2_11 "What did the household do to cope: Joined military"
			lab var g2_12 "What did the household do to cope: Dropped children from school"
			lab var g2_13 "What did the household do to cope: Increased child labor"
			lab var g2_14 "What did the household do to cope: Used daughter's dowry as bride"
			lab var g2_15 "What did the household do to cope: Started begging"
			lab var g2_16 "What did the household do to cope: Used savings"
			lab var g2_17 "What did the household do to cope: Sent children to other household"
			lab var g2_18 "What did the household do to cope: Sent non-working adult member to work"
			lab var g2__97 "What did the household do to cope: Other (please specify)"
			lab var g2__99 "What did the household do to cope: Don't know"
			lab var g2__98 "What did the household do to cope: Don't answer"

		* Label values
			lab def shock_l 1 "Reduced drinking water quantity" 2 "Reduced drinking water quality" ///
							3 "Reduced agricultural water quality or quantity" ///
							4 "Unusually high level of crop pests or diseases" ///
							5 "Opium eradication" 6 "Unusually high livestock diseases" ///
							7 "Reduced availability of grazing areas" ///
							8 "Reduced availability of Kuchi migration routes" ///
							9 "Earthquakes" 10 "Landslides and avalanches" ///
							11 "Flooding" 12 "Late damaging frosts" 13 "Heavy rains preventing work" ///
							14 "Severe winter conditions" 15 "Hailstorms" ///
							16 "Unusually high level of human disease" ///
							17 "Large influx of returnee households" ///
							18 "Unusually high increases in food prices" ///
							19 "Unusual decrease in farm gate prices" ///
							20 "Loss of employment by a household member" ///
							21 "Reduced salary of a household member" ///
							22 "Bankruptcy of family business" ///
							23 "Serious illness or accident of working household member" ///
							24 "Death of a working household member" ///
							25 "Death or serious illness of other household member" ///
							26 "Theft" 27 "Involuntary loss of house or land" ///
							28 "Loss of livestock" 29 "Droughts" 0 "None" ///
							-99 "Don't know" -98 "Don't answer"
			lab val shock shock_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item shock
		loc yesno g1
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da			
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${shocks_bl}", replace v(13)
		}
		else {
			save "${shocks_bl}", replace
		}	
		

********************************************************************************
	** Module K: Productive Activities and Assets (K) - Respondent 
********************************************************************************
	use "${all_HH_interm_nopii_bl}", clear 

	keep hhid k1_1_1 - k4_1_9 position_pm position_pf
		rename (k2_1_hr* ) (k2_1_hr_* )
		drop k3_1o*
		rename (k1_1__98 k1_1__99) (k1_1_98 k1_1_99)
						
		reshape long k1_1_ k2_1_ k2_1_hr_ k3_1_ k4_1_, i(hhid) j(activity)
		
		* Additional cleaning
		drop if mi(k1_1_)
		rename *_ *
		
		gen member = position_pm
			replace member = position_pf if mi(member)
			drop position_pm position_pf
		
		recode activity (98 = -98) (99= -99)
		lab def activity_l 1 "1: Tend any animals owned or leased by the household" ///
							2 "2: Farm land owned or sharecropped by the household" ///
							3 "3: Work on business owned by household other than farm/animals (e.g. shop, crafts)" ///
							4 "4: Work as an agricultural laborer outside household" ///
							5 "5: Do housework in someone else's home" ///
							6 "6: Work as a non-agricultural laborer outside the household (other than housework)" ///
							7 "7: Work in salaried/formal employment" ///
							8 "8: Do any other work for pay  (money or in-kind)" ///
							9 "9: Work on household chores (e.g. collecting water, cooking, cleaning) in your household" ///
							0 "0: None" ///
							-98 "-98: Don't answer" ///
							-99 "-99: Don't know"
		lab val activity activity_l		
	
		label drop asset_l
		
		label var member "Household member position in roster"
		label var k1_1 "Did HH head do any of these activities in the last 4 weeks?"
		label var k2_1 "On how many different days did HH head work on the activity?"
		label var k2_1_hr "For how many hours did HH head work on that activity the last time?"
		label var k3_1 "How much did HH head earn to work on that activity in the last 4 weeks?"
		label var k4_1 "Approx. how much is the value in Afghanis of what HH head received in-kind?"
		
		* Merge with LHH k30 data 
		merge 1:1 hhid activity member using "${productive_act_bl}", assert(2 3) nogen
			
		* Order variables 
		order member k5_1 k30 k30_1, after(activity)
		
		* Save the combined dataset 
			save "${productive_act_bl}", replace
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
	
		