/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Oct 18, 2016
Last udpate on: Nov 4, 2019

Written by:  	Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com) and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the Targeting baseline survey.


CONTENT:		
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/	

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Targeting Household Survey
		global Targ_allsvys_raw_bl_nopii "${TUP_DB}/Baseline/DataSets/Raw/Targ_allsvys_raw_bl_nopii.dta"			
		
* Outputs

	* Wide format
		* Cleaned Targeting, not including PII
			global Targ_interm_bl_nopii "${TUP_DB}/Baseline/DataSets/Intermediate/Targ_interm_bl_nopii.dta"			

		* Cleaned LHH, to compare with Targeting	
			global LHH_interm_bl_nopii "${TUP_DB}/Baseline/DataSets/Intermediate/LHH_interm_bl_nopii.dta"	

********************************************************************************
	** Part 1: Data Cleaning
********************************************************************************


use	"${Targ_allsvys_raw_bl_nopii}", clear
	
*----------------*
* Basic cleaning *
*----------------*

	* Survey
		gen survey = 3
			lab define survey 1 "LHH" 2 "MHHH" 3 "Targeting" 
			lab val survey survey
			lab var survey "Type of survey administered"
	
	* Enumerator ID, name, and gender
		lab var a2 "Interviewer ID"

	* Supervisor ID and name
		lab var a3 "Supervisor ID"
			
	* Date
		gen		temp=date(date_f,"DMY")												//,after(date_f)
		order	temp,after(date_f)
		drop	date_f
		rename	temp	date_f
		format	date_f	%td
		drop if	date_f < 20512
			
		drop		date
		clonevar	date	=	date_f
		replace		date	=	date_a	if	date_v==0
		lab	var		date	"Survey Date"
	
	* Consent vars
		lab var a12 "Survey was consented"
	
	* Survey complete
		gen complete = (a12==1)
			lab var complete "Survey was completed"
			lab val complete yesno
			
	* Respondent gender
		gen respondent_gender = . 
			lab var respondent_gender "Respondent gender (calculated)"
			lab def gender 1 "Male" 2 "Female"
			lab val respondent_gender gender
			replace respondent_gender = 2 if (a8==1 | a9==1) // if LHH is available or not at home
			replace respondent_gender = 1 if (a8_m==1 | a9_m==1) // if MHHH is available or not at home
 
	* Time vars
	
		* Survey time
		gen	double	time_final	=	clock(time,"hms")
		replace		time_final	=	time_a	if	time_v==0
		format		time_final %tcHH:MM:SS
		replace		time_final	=	time_final	+	(date*24*60*60*1000)
		drop		time
		rename		time_final	time
		lab	var		time	"Survey Time"
		
		* Time after consent	&	time after the last question
		gen double	time_start	=	clock(time_startinteraction,"YMD hms")
		gen	double	time_end	=	clock(qtime_end_q,"YMD hms")
		
		format		time_start	time_end %tcHH:MM:SS
		lab	var		time_start	"Time after consent"
		lab	var		time_end	"Time after the last question"	
				
	* Household Head gender
		loc	var		hh_head_gender
		gen	byte	`var'=bhh_head_gender										
		lab	var		`var'	"HH head gender (from LHH roster, SurveyCTO-captured)"
		lab val hh_head_gender gender
		drop bhh_head_gender
		
*--------------------*
* Cleaning by module *
*--------------------*		
	
	* Labels
		lab	var	a10	"What is your primary language?"
		lab	var	a11	"Please select the language that is used to conduct this interview."
	
	* Roster 	
		rename	age_all*			*
		rename	length_of_stay*		*
		rename	madrassa_duration*	*
		rename	mosque_duration*	*	
		rename  bb3					b3
	
	* Consumption *
		rename	cc*		c*
		rename	c14*	*
		rename	c12*	*
		rename	c13*	*	
		rename ctime_begin_c time_begin_c
	
			* Locals for names
				local c3_type "Bread"
				local c4_type "Meat"
				local c5_type "Dairy"
				local c6_type "Oils"
				local c7_type "Vegetables"
				local c8_type "Fruits"
				local c9_type "Sweets"
				local c10_type "Beverages"
				local c11_type "Spices"
				
			* Locals for counter	
				local c3_counter 13
				local c4_counter 10
				local c5_counter 12
				local c6_counter 4
				local c7_counter 25
				local c8_counter 20
				local c9_counter 5
				local c10_counter 5
				local c11_counter 7
				
			* Create correct variables
				* Rename variables
					foreach var in c3 c4 c5 c6 c7 c8 c9 c10 c11 {
						* Renames
						forval productnum=1/``var'_counter' {
							rename  `var'_`productnum' `var'_`productnum'_old
							}
						* Create var
						forval productnum=1/``var'_counter' {
							egen 	`var'_`productnum' = anymatch(`var'_1_old-`var'_``var'_counter'_old), value(`productnum')			
						}
						drop `var'_``var'_counter' 
						egen 	`var'_100 = anymatch(`var'_1_old-`var'_``var'_counter'_old), value(-100)
						order `var'_1-`var'_100, before(`var'_1_old)
					}
					drop *_old	
				
				
			* Labels
			lab	var	c3_1	"Bread consumed includes: Rice (high quality)"
			lab	var	c3_2	"Bread consumed includes: Rice (low quality)"
			lab	var	c3_3	"Bread consumed includes: Wheat flour"
			lab	var	c3_4	"Bread consumed includes: Naan not made at home"
			lab	var	c3_5	"Bread consumed includes: Barley"
			lab	var	c3_6	"Bread consumed includes: Maize"
			lab	var	c3_7	"Bread consumed includes: Beans"
			lab	var	c3_8	"Bread consumed includes: Mung"
			lab	var	c3_9	"Bread consumed includes: Chickpeas"
			lab	var	c3_10	"Bread consumed includes: Lentils"
			lab	var	c3_11	"Bread consumed includes: Pasta"
			lab	var	c3_12	"Bread consumed includes: Other bread and/or cereal"
			lab	var	c3_100	"Bread consumed includes: None"
					
			lab	var	c4_1	"Meat consumed includes: Beef"
			lab	var	c4_2	"Meat consumed includes: Veal"
			lab	var	c4_3	"Meat consumed includes: Mutton"
			lab	var	c4_4	"Meat consumed includes: Goat"
			lab	var	c4_5	"Meat consumed includes: Chicken"
			lab	var	c4_6	"Meat consumed includes: Liver"
			lab	var	c4_7	"Meat consumed includes: Dried Meat"
			lab	var	c4_8	"Meat consumed includes: Fish"
			lab	var	c4_9	"Meat consumed includes: Other meat and/or fish"
			lab	var	c4_100	"Meat consumed includes: None"				
		
			lab	var	c5_1	"Dairy consumed includes: Milk (fresh)"
			lab	var	c5_2	"Dairy consumed includes: Milk (powdered)"
			lab	var	c5_3	"Dairy consumed includes: Yogurt"
			lab	var	c5_4	"Dairy consumed includes: Curd (chaka)"
			lab	var	c5_5	"Dairy consumed includes: Krut (dried)"
			lab	var	c5_6	"Dairy consumed includes: Dogh"
			lab	var	c5_7	"Dairy consumed includes: Ghee"
			lab	var	c5_8	"Dairy consumed includes: Butter"
			lab	var	c5_9	"Dairy consumed includes: Cheese"
			lab	var	c5_10	"Dairy consumed includes: Eggs"
			lab	var	c5_11	"Dairy consumed includes: Other dairy products"
			lab	var	c5_100	"Dairy consumed includes: None"
					
			lab	var	c6_1	"Oil consumed includes: Vegetable oil, cotton oil or sesame oil"
			lab	var	c6_2	"Oil consumed includes: Animal fat"
			lab	var	c6_3	"Oil consumed includes: Other oils and fat"
			lab	var	c6_100	"Oil consumed includes: None"	
			
			lab	var	c7_1	"Vegetables consumed includes: Potato"
			lab	var	c7_2	"Vegetables consumed includes: Sweet potato"
			lab	var	c7_3	"Vegetables consumed includes: Onion"
			lab	var	c7_4	"Vegetables consumed includes: Tomato"
			lab	var	c7_5	"Vegetables consumed includes: Okra"
			lab	var	c7_6	"Vegetables consumed includes: Spinach"
			lab	var	c7_7	"Vegetables consumed includes: Cauliflower"
			lab	var	c7_8	"Vegetables consumed includes: Eggplant"
			lab	var	c7_9	"Vegetables consumed includes: Carrots"
			lab	var	c7_10	"Vegetables consumed includes: Pumpkin, squash"
			lab	var	c7_11	"Vegetables consumed includes: Cucumber"
			lab	var	c7_12	"Vegetables consumed includes: Radish"
			lab	var	c7_13	"Vegetables consumed includes: Turnip"
			lab	var	c7_14	"Vegetables consumed includes: Cabbage"
			lab	var	c7_15	"Vegetables consumed includes: Leek"
			lab	var	c7_16	"Vegetables consumed includes: Hot pepper"
			lab	var	c7_17	"Vegetables consumed includes: Wild leafy vegetables"
			lab	var	c7_18	"Vegetables consumed includes: Coriander"
			lab	var	c7_19	"Vegetables consumed includes: Mint"
			lab	var	c7_20	"Vegetables consumed includes: Dried tomatoes"
			lab	var	c7_21	"Vegetables consumed includes: Dried vegetables"
			lab	var	c7_22	"Vegetables consumed includes: Pickled vegetables"
			lab	var	c7_23	"Vegetables consumed includes: Green beans"
			lab	var	c7_24	"Vegetables consumed includes: Other vegetables"
			lab	var	c7_100	"Vegetables consumed includes: None"		

			lab	var	c8_1	"Fruits consumed includes: Apple"
			lab	var	c8_2	"Fruits consumed includes: Grapes"
			lab	var	c8_3	"Fruits consumed includes: Melon/watermelon"
			lab	var	c8_4	"Fruits consumed includes: Peach"
			lab	var	c8_5	"Fruits consumed includes: Fresh apricots"
			lab	var	c8_6	"Fruits consumed includes: Dried apricots"
			lab	var	c8_7	"Fruits consumed includes: Orange/citrus"
			lab	var	c8_8	"Fruits consumed includes: Plum"
			lab	var	c8_9	"Fruits consumed includes: Pomegranate"
			lab	var	c8_10	"Fruits consumed includes: Pear"
			lab	var	c8_11	"Fruits consumed includes: Banana"
			lab	var	c8_12	"Fruits consumed includes: Raisins"
			lab	var	c8_13	"Fruits consumed includes: Fresh mulberries"
			lab	var	c8_14	"Fruits consumed includes: Dried mulberries"
			lab	var	c8_15	"Fruits consumed includes: Mangoes"
			lab	var	c8_16	"Fruits consumed includes: Walnuts"
			lab	var	c8_17	"Fruits consumed includes: Pistachio"
			lab	var	c8_18	"Fruits consumed includes: Almonds"
			lab	var	c8_19	"Fruits consumed includes: Other fruit and/or nuts"
			lab	var	c8_100	"Fruits consumed includes: None"
				
			lab	var	c9_1	"Sweets consumed includes: White sugar"
			lab	var	c9_2	"Sweets consumed includes: Brown sugar"
			lab	var	c9_3	"Sweets consumed includes: Honey"
			lab	var	c9_4	"Sweets consumed includes: Chocolates, candy, sherinigack"
			lab	var	c9_100	"Sweets consumed includes: None"	
		
			lab	var	c10_1	"Beverages consumed includes: Black teas"
			lab	var	c10_2	"Beverages consumed includes: Green teas"
			lab	var	c10_3	"Beverages consumed includes: Bottled/canned beverages, Mineral waters"
			lab	var	c10_4	"Beverages consumed includes: Other beverages"
			lab	var	c10_100	"Beverages consumed includes: None"
		
			lab	var	c11_1	"Spices consumed includes: Salt"
			lab	var	c11_2	"Spices consumed includes: Black pepper"
			lab	var	c11_3	"Spices consumed includes: Ginger and garlic"
			lab	var	c11_4	"Spices consumed includes: Tomato sauce"
			lab	var	c11_5	"Spices consumed includes: Mixed spices"
			lab	var	c11_6	"Spices consumed includes: Other spices"
			lab	var	c11_100	"Spices consumed includes: None"
	
	* Transfers and safety nets 	
		rename	dd*	d*
		
		* D1
				
			forval	gift_num=1/10	{
				egen	d1_temp_`gift_num'	=	anymatch(d1_1-d1_13), value(`gift_num')
				replace	d1_temp_`gift_num'	=.	if	a12!=1
			}
			egen	d1_temp__98	=	anymatch(d1_1-d1_13), value(-98)
			egen	d1_temp__99	=	anymatch(d1_1-d1_13), value(-99)
			egen	d1_temp_0	=	anymatch(d1_1-d1_13), value(0)
			
			replace	d1_temp__98	=.	if	a12!=1
			replace	d1_temp__99	=.	if	a12!=1
			replace	d1_temp_0	=.	if	a12!=1
			
			drop	d1_1-d1_13
			rename	d1_temp_*	d1_*
			
			lab	var	d1_1	"Gift item includes: Money"
			lab	var	d1_2	"Gift item includes: Clothes, pots, pans, pails, etc."
			lab	var	d1_3	"Gift item includes: Uncooked produce"
			lab	var	d1_4	"Gift item includes: Meals"
			lab	var	d1_5	"Gift item includes: Work materials"
			lab	var	d1_6	"Gift item includes: Dowry/bride price"
			lab	var	d1_7	"Gift item includes: Wedding gift"
			lab	var	d1_8	"Gift item includes: Livestock"
			lab	var	d1_9	"Gift item includes: Land"
			lab	var	d1_10	"Gift item includes: Other (please specify)"
			lab	var	d1__98	"Gift item includes: Don't Answer"
			lab	var	d1__99	"Gift item includes: Don’t know"
			lab	var	d1_0	"Gift item includes: None"

			lab	val	d1_1-d1_0	yesno
			order	d1_1-d1_0, before(d1_o)
			
	* d8
		
		rename d8_* d8_temp_*
		forval	gifttaken_num=1/19	{
			egen	d8_`gifttaken_num'	=	anymatch(d8_temp_1-d8_temp_22), value(`gifttaken_num')
			replace	d8_`gifttaken_num'	=.	if	a12!=1
		}
		egen	d8__98	=	anymatch(d8_temp_1-d8_temp_22), value(-98)
		egen	d8__99	=	anymatch(d8_temp_1-d8_temp_22), value(-99)
		egen	d8_0	=	anymatch(d8_temp_1-d8_temp_22), value(0)
		
		replace	d8__98	=.	if	a12!=1
		replace	d8__99	=.	if	a12!=1
		replace	d8_0	=.	if	a12!=1
			
		rename d8_temp_o d8_o	
		drop	d8_temp_1-d8_temp_22
		order	d8_1-d8_0, before(d8_o)
		lab	val	d8_1-d8_0	yesno
		
		lab	var	d8_1		"Gift received includes: Money"
		lab	var	d8_2		"Gift received includes: Clothes, pots, pans, pails, etc."
		lab	var	d8_3		"Gift received includes: Uncooked produce"
		lab	var	d8_4		"Gift received includes: Meals"
		lab	var	d8_5		"Gift received includes: Work materials"
		lab	var	d8_6		"Gift received includes: Dowry/bride price"
		lab	var	d8_7		"Gift received includes: Wedding gift"
		lab	var	d8_8		"Gift received includes: Livestock"
		lab	var	d8_9		"Gift received includes: Land"
		lab	var	d8_10		"Gift received includes: Construction/building material"
		lab	var	d8_11		"Gift received includes: Water and/or sanitation"
		lab	var	d8_12		"Gift received includes: Agricultural input assistance (tools, seeds, fertilizer, etc.)"
		lab	var	d8_13		"Gift received includes: Training and technical assistance in improved agricultural/livestock practices"
		lab	var	d8_14		"Gift received includes: Fish ponds"
		lab	var	d8_15		"Gift received includes: Veterinary services"
		lab	var	d8_16		"Gift received includes: For education (e.g. school materials)"
		lab	var	d8_17		"Gift received includes: Medical services"
		lab	var	d8_18		"Gift received includes: Pension payment"
		lab	var	d8_19		"Gift received includes: Other (please specify)"
		lab	var	d8__99		"Gift received includes: Don’t know"
		lab	var	d8__98		"Gift received includes: Don't Answer"
		lab	var	d8_0		"Gift received includes: None"		
	
	* Housing characteristics 
		rename	ee*	e*
		
	* Other Asset Ownership 
		rename	ll*	l*
		
		* L1
		
			forval	asset_num=1/20	{
				egen	l1_temp_`asset_num'	=	anymatch(l1_1-l1_23), value(`asset_num')
				replace	l1_temp_`asset_num'	=.	if	a12!=1
			}
			egen	l1_temp_0	=	anymatch(l1_1-l1_23), value(0)
			egen	l1_temp__98	=	anymatch(l1_1-l1_23), value(-98)
			egen	l1_temp__99	=	anymatch(l1_1-l1_23), value(-99)
			
			replace	l1_temp_0	=.	if	a12!=1
			replace	l1_temp__98	=.	if	a12!=1
			replace	l1_temp__99	=.	if	a12!=1
			
			order	l1_temp_1-l1_temp__99, before(l1_o)
			drop	l1_1-l1_23
			rename	l1_temp_*	l1_*
			
			lab	val	l1_1-l1__99	yesno			
			
			lab	var	l1_1	"Asset includes: Radios/CDs/Cassettes"
			lab	var	l1_2	"Asset includes: Televisions"
			lab	var	l1_3	"Asset includes: Dish TVs"
			lab	var	l1_4	"Asset includes: VCRs/DVD players"
			lab	var	l1_5	"Asset includes: Land on which your home is built"
			lab	var	l1_6	"Asset includes: Other land(s) (excluding land on which your home is built)"
			lab	var	l1_7	"Asset includes: Other houses/buildings"
			lab	var	l1_8	"Asset includes: Refrigerators"
			lab	var	l1_9	"Asset includes: Generators"
			lab	var	l1_10	"Asset includes: Mattresses"
			lab	var	l1_11	"Asset includes: Cell (mobile) phones"
			lab	var	l1_12	"Asset includes: Non-mobile phones"
			lab	var	l1_13	"Asset includes: Clothes irons"
			lab	var	l1_14	"Asset includes: Bed frames"
			lab	var	l1_15	"Asset includes: Pieces of jewelry (gold, silver, etc.)"
			lab	var	l1_16	"Asset includes: Mosquito nets"
			lab	var	l1_17	"Asset includes: Mosquito-repellant candles"
			lab	var	l1_18	"Asset includes: Fans"
			lab	var	l1_19	"Asset includes: Cameras"
			lab	var	l1_20	"Asset includes: Other (please specify)"
			lab	var	l1_0	"Asset includes: None"
			lab	var	l1__98	"Asset includes: Don't Answer"
			lab	var	l1__99	"Asset includes: Don't know"		
		
	* Aspirations & Psychological Well-being 
		rename	ii*	i*
		
		*	Life satisfaction
		rename	ipsychwellai*	i*
		rename	ipsychwellci*	i*		
		
		
	* Credit and savings	
		*	m21_m
			forval	acc_num=1/6	{
				egen	m21_`acc_num'	=	anymatch(m_mm21_m1-m_mm21_m8), value(`acc_num')
				replace	m21_`acc_num'	=.	if	a12!=1
			}
			egen	m21__97	=	anymatch(m_mm21_m1-m_mm21_m8), value(-97)
			egen	m21__99	=	anymatch(m_mm21_m1-m_mm21_m8), value(-99)
			
			replace	m21__97	=.	if	a12!=1
			replace	m21__99	=.	if	a12!=1
			
			order	m21_1-m21__99, before(m_mm21_m1)
			drop	m_mm21_m1-m_mm21_m8
			rename	m_mm21_o_m m21_o
			
			lab	val	m21_1-m21__99	yesno
			
			lab	var	m21_1	"Saving places includes: In formal bank"
			lab	var	m21_2	"Saving places includes: At home"
			lab	var	m21_3	"Saving places includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m21_4	"Saving places includes: With Microfinance institution"
			lab	var	m21_5	"Saving places includes: At post office"
			lab	var	m21_6	"Saving places includes: With another individual (not a formal bank)"
			lab	var	m21__97	"Saving places includes: Other (specify)"
			lab	var	m21__99	"Saving places includes: Don't know"		
		
		rename m_mm23_m m23
		
		*	m24
			egen	m24_1	=	anymatch(m_mm24_1 m_mm24_2 m_mm24_3), value(1)
			egen	m24_2	=	anymatch(m_mm24_1 m_mm24_2 m_mm24_3), value(2)	
			egen	m24__97	=	anymatch(m_mm24_1 m_mm24_2 m_mm24_3), value(-97)	
			
			replace	m24_1	=.	if	m23!=1
			replace	m24_2	=.	if	m23!=1
			replace	m24__97	=.	if	m23!=1
			
			order	m24_1-m24__97, before(m_mm24_1)
			drop	m_mm24_1 m_mm24_2 m_mm24_3
			rename	m_mm24_o	m24_o
			
			lab	val	m24_1-m24__97	yesno
			
			lab	var	m24_1	"Account having includes: Formal bank"
			lab	var	m24_2	"Account having includes: Microfinance institution"
			lab	var	m24__97	"Account having includes: Other (please specify)"
		
		*	m22_m
			forval	loan_num=0/9	{
				egen	m22_`loan_num'	=	anymatch(m_mm22_m1-m_mm22_m13), value(`loan_num')
				replace	m22_`loan_num'	=.	if	a12!=1
			}
			egen	m22__97	=	anymatch(m_mm22_m1-m_mm22_m13), value(-97)
			egen	m22__98	=	anymatch(m_mm22_m1-m_mm22_m13), value(-98)
			egen	m22__99	=	anymatch(m_mm22_m1-m_mm22_m13), value(-99)
			
			replace	m22__97	=.	if	a12!=1
			replace	m22__98	=.	if	a12!=1
			replace	m22__99	=.	if	a12!=1
			
			order	m22_0-m22__99, before(m_mm22_m1)
			drop	m_mm22_m1-m_mm22_m13
			rename	m_mm22_m_o m22_o
			
			lab	val	m22_0-m22__99	yesno
			
			lab	var	m22_0	"Available loan includes: I would not be able to get a loan"
			lab	var	m22_1	"Available loan includes: Formal banks"
			lab	var	m22_2	"Available loan includes: Microfinance institution"
			lab	var	m22_3	"Available loan includes: Landlord"
			lab	var	m22_4	"Available loan includes: Employer"
			lab	var	m22_5	"Available loan includes: Relative"
			lab	var	m22_6	"Available loan includes: Friend"
			lab	var	m22_7	"Available loan includes: Local money lender"
			lab	var	m22_8	"Available loan includes: ROSCA/chit fund/merry-go-round"
			lab	var	m22_9	"Available loan includes: I would not need a loan as I would draw on my savings/sell an asset"
			lab	var	m22__97	"Available loan includes: Other (please specify)"
			lab	var	m22__98	"Available loan includes: Don't Answer"
			lab	var	m22__99	"Available loan includes: Don’t know"		
	
		* Cash loan
			rename	(m_mm1_m m_mm1_a_m	m_mm5_m)	(m1	m1_a m5)
				*	Treat mis-entered answers
				replace	m1_a	=	1		if	bl_key	==	"uuid:b8c6dd5e-9b3d-4092-ae11-9328eda65c19"	//	HH entered values in the opposite order
				replace	m5		=	10000	if	bl_key	==	"uuid:b8c6dd5e-9b3d-4092-ae11-9328eda65c19"	//	HH entered values in the opposite order
				replace	m1_a	=	-99		if	inlist(bl_key, "uuid:4fff44d0-1947-4108-88de-39f4a9af9f25",	///
															"uuid:efa37b45-6902-4b4e-9e8e-aea6d420651e")	//	HH entered loan value instead of the number of loans. Replace with "don't know"
		
		* m18_m, m19_m
			rename	m_mm16_m	m16
			
			forval	save_num=1/6	{
				egen	m17_`save_num'	=	anymatch(m_mm17_m1-m_mm17_m8), value(`save_num')
				replace	m17_`save_num'	=.	if	m16!=1
			}
			egen	m17__97	=	anymatch(m_mm17_m1-m_mm17_m8), value(-97)
			egen	m17__99	=	anymatch(m_mm17_m1-m_mm17_m8), value(-99)
			
			replace	m17__97	=.	if	m16!=1
			replace	m17__99	=.	if	m16!=1

			order	m17_1-m17__99, before(m_mm17_m1)
			drop	m_mm17_m1-m_mm17_m8
			rename	m_mm17_o_m	m17_o
			
			lab	val	m17_1-m17__99	yesno
			
			lab	var	m17_1		"Saving money includes: In formal bank"
			lab	var	m17_2		"Saving money includes: At home"
			lab	var	m17_3		"Saving money includes: In ROSCA, merry-go-round or chit fund"
			lab	var	m17_4		"Saving money includes: With Microfinance institution"
			lab	var	m17_5		"Saving money includes: At post office"
			lab	var	m17_6		"Saving money includes: With another individual (not a formal bank)"
			lab	var	m17__97		"Saving money includes: Other (specify)"
			lab	var	m17__99		"Saving money includes: Don't know"
			
		* m21_m, m22_m
			rename	(m_mm20_a_m m_mm20_m)	(m20_a	m20)
		
		* Formal account
			rename	m_*	*
			drop	mhaveacct
			rename	(mexperienceBankm25_y mexperienceBankm25_m mexperienceMFIm26_y mexperienceMFIm26_m)	///
					(m25_y	m25_m	m26_y	m26_m)
			lab	var	m25_y	"For how long have you been in a relationship with the formal bank? (years)"
			lab	var	m25_m	"For how long have you been in a relationship with the formal bank? (months)"
			lab	var	m26_y	"For how long have you been in a relationship with MFI? (years)"
			lab	var	m26_m	"For how long have you been in a relationship with MFI? (months)"
			
		* m27
			forval	acc_num=0/5	{
				egen	m27_`acc_num'	=	anymatch(mexperiencem27_1-mexperiencem27_7), value(`acc_num')
				replace	m27_`acc_num'	=.	if	(mi(m25_y) & mi(m26_y))
			}
			egen	m27__97	=	anymatch(mexperiencem27_1-mexperiencem27_7), value(-97)
			
			replace	m27__97	=.	if	(mi(m25_y) & mi(m26_y))

			order	m27_0-m27__97, before(mexperiencem27_1)
			drop	mexperiencem27_1-mexperiencem27_7
			rename	mexperiencem27_o	m27_o
			
			lab	val	m27_0-m27__97	yesno
			
			lab	var	m27_0	"Saving benefit includes: No benefits"
			lab	var	m27_1	"Saving benefit includes: Encouraged to save"
			lab	var	m27_2	"Saving benefit includes: Received better management of savings"
			lab	var	m27_3	"Saving benefit includes: Aided in sending remittances"
			lab	var	m27_4	"Saving benefit includes: Aided in receiving remittances"
			lab	var	m27_5	"Saving benefit includes: Aided in obtaining a loan"
			lab	var	m27__97	"Saving benefit includes: Other (please specify)"		
		
		* m28
			forval	imp_num=0/5	{
				egen	m28_`imp_num'	=	anymatch(mexperiencem28_1-mexperiencem28_7), value(`imp_num')
				replace	m28_`imp_num'	=.	if	(mi(m25_y) & mi(m26_y))
			}
			egen	m28__97	=	anymatch(mexperiencem28_1-mexperiencem28_7), value(-97)
			
			replace	m28__97	=.	if	(mi(m25_y) & mi(m26_y))

			order	m28_0-m28__97, before(mexperiencem28_1)
			drop	mexperiencem28_1-mexperiencem28_7
			rename	mexperiencem28_o	m28_o
			
			lab	val	m28_0-m28__97	yesno
			
			lab	var	m28_0	"Things to be improved includes: No improvement"
			lab	var	m28_1	"Things to be improved includes: Simpler application procedure (for deposit and loans)"
			lab	var	m28_2	"Things to be improved includes: Reduced application processing time (for deposit and loans)"
			lab	var	m28_3	"Things to be improved includes: Easier access to bank branch"
			lab	var	m28_4	"Things to be improved includes: Easier access to ATM"
			lab	var	m28_5	"Things to be improved includes: Reduced fees for transactions"
			lab	var	m28__97	"Things to be improved includes: Other (please specify)"		
			
		* m29, m30
			rename	(mexperiencem29 mexperiencem30 mexperiencem30_a) (m29 m30 m30_a)
		
		* Business Opportunity
			rename	(mm31 mm31_a mm31_a_a)	(m31 m31_a m31_a_a)
			
			*	m31
			forval	reason_num=1/9	{
				egen	m32_`reason_num'	=	anymatch(mm32_1-mm32_11), value(`reason_num')
				replace	m32_`reason_num'	=.	if	mi(mm32_1)
			}
			egen	m32__97	=	anymatch(mm32_1-mm32_11), value(-97)
			egen	m32__99	=	anymatch(mm32_1-mm32_11), value(-99)
			
			replace	m32__97	=.	if	mi(mm32_1)
			replace	m32__99	=.	if	mi(mm32_1)

			order	m32_1-m32__99, before(mm32_1)
			drop	mm32_1-mm32_11
			rename	mm32_o	m32_o
			
			lab	val	m32_1-m32__99	yesno
			
			lab	var	m32_1	"Reason for not having account includes: financial institutions are too far away"
			lab	var	m32_2	"Reason for not having account includes: financial services are too expensive"
			lab	var	m32_3	"Reason for not having account includes: don't have the necessary documentation (id card, wage slip, etc.)"
			lab	var	m32_4	"Reason for not having account includes: don't trust financial institutions"
			lab	var	m32_5	"Reason for not having account includes: religious reasons"
			lab	var	m32_6	"Reason for not having account includes: don't have enough money to use financial institutions"
			lab	var	m32_7	"Reason for not having account includes: someone else in the family already has an account"
			lab	var	m32_8	"Reason for not having account includes: cannot get an account"
			lab	var	m32_9	"Reason for not having account includes: no need for financial services at a formal institution"
			lab	var	m32__97	"Reason for not having account includes: other (please specify)"
			lab	var	m32__99	"Reason for not having account includes: don't answer"		
		
	* Direct observation questions
		rename doec consent_direct_obs
		rename do* *
		
	* Interview summary
		rename	qq*	q*
	
		*	q5
		forval	relat_num=1/30	{
			egen	q5_`relat_num'_temp	=	anymatch(q5_1-q5_30), value(`relat_num')
			replace	q5_`relat_num'_temp	=.	if	q4!=1
		}

		order	q5_1_temp-q5_30_temp, before(q5_1)
		drop	q5_1-q5_30
		rename	q5_*_temp	q5_*
		
		lab	val	q5_1-q5_30	yesno
		
		lab	var	q5_1	"Relative observing interview includes: Grandson"
		lab	var	q5_2	"Relative observing interview includes: Granddaughter"
		lab	var	q5_3	"Relative observing interview includes: Son"
		lab	var	q5_4	"Relative observing interview includes: Son-in-law"
		lab	var	q5_5	"Relative observing interview includes: Daughter"
		lab	var	q5_6	"Relative observing interview includes: Daughter-in-law"
		lab	var	q5_7	"Relative observing interview includes: Brother"
		lab	var	q5_8	"Relative observing interview includes: Brother-in-law"
		lab	var	q5_9	"Relative observing interview includes: Sister"
		lab	var	q5_10	"Relative observing interview includes: Sister-in-law"
		lab	var	q5_11	"Relative observing interview includes: Father"
		lab	var	q5_12	"Relative observing interview includes: Father-in-law"
		lab	var	q5_13	"Relative observing interview includes: Mother"
		lab	var	q5_14	"Relative observing interview includes: Mother-in-law"
		lab	var	q5_15	"Relative observing interview includes: Grandfather"
		lab	var	q5_16	"Relative observing interview includes: Grandmother"
		lab	var	q5_17	"Relative observing interview includes: Uncle"
		lab	var	q5_18	"Relative observing interview includes: Aunt"
		lab	var	q5_19	"Relative observing interview includes: Husband"
		lab	var	q5_20	"Relative observing interview includes: Wife"
		lab	var	q5_21	"Relative observing interview includes: Nephew"
		lab	var	q5_22	"Relative observing interview includes: Niece"
		lab	var	q5_23	"Relative observing interview includes: First cousin (male)"
		lab	var	q5_24	"Relative observing interview includes: First cousin (female)"
		lab	var	q5_25	"Relative observing interview includes: Other male relative"
		lab	var	q5_26	"Relative observing interview includes: Other female relative"
		lab	var	q5_27	"Relative observing interview includes: Other male relatives"
		lab	var	q5_28	"Relative observing interview includes: Other female relatives"
		lab	var	q5_29	"Relative observing interview includes: Female non-relative(s)"
		lab	var	q5_30	"Relative observing interview includes: Male non-relative(s)"
		
	* Rename vars to match survey
		rename village a6
	* Save intermediate dataset
		order 	hhid bl_hhid date a2 a3 hh_head_gender respondent_gender ///
				a12 complete a6, first		

	* Recode extended missing
		
		* Variables that are integers or decimals (according to surveyCTO)
		ds b3 b8_year* b8_month* b8_month_to_year* b8_* b11_y* b11_m* b14_a* b14_b*  ///
		   c*_a* c1 c2 c12_* d2_* ///
		   d9_* e3 e11 l3_* l5_* m1_a m5 m20 m25_* m26_* e13 
		loc	integer_list `r(varlist)' 
		
		* Variables that are select_one, but not the ones that are rosters
		ds a10 d13 e1 e2 e4 e5 e6 e7 e9 e8 e10 i7 i10 i11 i12 i16 i23 i25 i34 i35  /// 
			i37 i38 i39 i43 m23 m1 m16 m20_a m29 m30 m31 m31_a m23 m1 m16 m20_a ///
			e12 e14 e15 e16 q2 q4
		loc	selectone_list `r(varlist)' 

		foreach var in `integer_list'  `selectone_list' {
			di "`var'"
			replace `var' = .d if inlist(`var', -99) //, 99)
			replace `var' = .r if inlist(`var', -98) // , 98)
		}
		
		
*** New MDC code starts here

	* Destring all numeric variables 
		qui: destring *, replace
		
	* Tostring variables
		tostring a7_o a9_o_m a11_o c9_s_o* e12_o , replace 
	
	* Drop GPS 
		drop a1Accuracy q8Accuracy

	* Drop SCTO-generated variables not used: _cal_, index, repeat, count, timebegin, etc.
		** Keep: hh_mem_left_* - used to reshape data long for rosters 
		drop *roster* *_cal* *repeat* *count* *_id* *time_begin* *time_end* *time_start* device* SubmissionDate subscriberid starttime endtime ///
			simid namenumber* metainstance* *position* formdef_version *_less5_* *_less5* *age* ///
			b8_month_to_year* b8_final* time_f date_f _merge
		
		unab  name : *_name*
		local name_keep "confirm_name confirm_name_2"
		local name_drop : list local name - local name_keep
		drop `name_drop'
	
	* Drop "Other, specify values" in Dari (drop *_o strings)
		drop a11_o b5_o* d1_o b15_o* c*_o c*_s_o* d1_o d3_o_r* d6_o d8_o d10_o_r* d3_o_u* d13_o e1_o e4_o e5_o e6_o ///
			e7_o e9_o e8_o l1_o m21_o m24_o m22_o ///
			m17_o m27_o m28_o m32_o e12_o e14_o e15_o e16_o a9_o a9_o_m  
	
	label drop enum supname district  	
	
	* Apply codebook templates
		** LHH first
		*cap noi iecodebook apply using "${codebook}\lhh_template.xlsx" ///
		*	, drop miss(.d "Don't Know" .r "Refused")
		
		
			
	* Save intermediate dataset
	/* Order variables to match paper survey order 
		order hhid, first 
		order date_a, after(date_v)
		order a6, after(a5)
		order a8_m_av_date a8_m_av_time, after(a8_m_av)
		order a18_v, after(a18)
		order date date_v date_a time time_v time_a a2, before(a3)
		order r40_1 r40_2 r40_3, before(r41_1_1)
		order r48_1 r48_2 r48_3, after(r47c) 
		order a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17, after(a19_6) 
		order r36_1_1 r36_1_2 r36_1_3, after(r36_3) 
		order r53, after(r52__97)
		order ultra_poor, after(hhid)
		order hh_head_gender respondent_gender time_collection time_endinteraction, last // constructed / SCTO vars we need */
	
	* Save
		keep if complete == 1
			drop complete
			
		if	`c(stata_version)'>=14	{
			saveold "${Targ_interm_bl_nopii}", replace v(13)
		}
		else {
			save "${Targ_interm_bl_nopii}", replace
		}
	

* Targeting survey is a subset of the LHH survey, so we compare the variables between
* the two datasets to confirm that the variables are correctly named
	cfvars "${LHH_interm_bl_nopii}" "${Targ_interm_bl_nopii}"
* The differences come from variables in the roster module, which is explain by the fact
* that in the targeting survey, respondent could include more HH members.	
	
