/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Oct 18, 2016
Last udpate on: Nov 4, 2019

Written by:  	Seungmin Lee (slee31@worldbank.org, eatorange@gmail.com) and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Prepares the Targeting baseline survey for cleaning. This includes doing modification and corrections based on field reports.


CONTENT:		
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/	

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Targeting Household Survey ("odkmeta" applied, wide format)
		global	Targeting_raw	"${TUP_DB_PII}/Baseline/DataSets/Raw/Targeting/Targeting_TUP_IE.dta"

	* Duplicates
		global duplicates_bl "${TUP_DB_PII}/Baseline/DataSets/Intermediate/Duplicates"
		
	* District and village anonymized
		global village_anonymized "${TUP_DB_PII}/Profile_and_merging/DataSets/Intermediate/village_anonymized.dta"
		
	* Profile info
		global profile_info_PII "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/fl1_profile_info.dta"
		
* Outputs

	* Wide format
		* Cleaned Targeting, including PII
			global Targ_allsvys_raw_bl_nopii "${TUP_DB}/Baseline/DataSets/Raw/Targ_allsvys_raw_bl_nopii.dta"			

********************************************************************************
	** Part 1: Data Cleaning
********************************************************************************

use	"${Targeting_raw}", clear

	* HH ID
		assert	hh_id	==	hh_id_2
		replace hh_id = upper(trim(itrim(hh_id)))
		replace	hh_id	=	subinstr(hh_id," ","",.)
		clonevar bl_hhid = hh_id //  HH id
			lab var bl_hhid "Household ID (Baseline)"
			assert !mi(bl_hhid)
			*drop hh_id hh_id_2	
		
	* Additional corrections made before by SML, Garima or RdG: 
		replace	father_spouse_name_file="Baba Jora"	if	(bl_hhid=="Ta4001410")
		replace	hhhead_name_file="Widow of Mohammad Nasim"	if	(bl_hhid=="Nta400242")
		replace	hhhead_name_file="Widow of Abdulghani"	if	(bl_hhid=="Nta400245")

	* Rename variables
		rename	hhhead_name_file		hhhead_name
		rename	father_spouse_name_file	father_spouse_name
		rename	srpsrc*					*
		rename	srp*					*
			
	* Modify village label
		* For unknown reason "village" label in SurveyCTO format has missing label for "1" and "31"
		* From another source ("${data_analysis}/Randomization/Data/Raw/TUP Eligibility/Village_sample_TUP.dta") we could find "1" means "Qezel abad". We will add this village to "village" label
		* RdG (Rebecca) found that "31" indicates "Amin Husain".  a6==31
		lab define village 	1	"Qezel abad" ///
							31	"Amin Husain", add

	* Correction of duplicates in hhid: Done by SML, explanation in the file
		rename (bl_hhid KEY) (HHID_survey key) //temporaly rename so we can use SML's file
		ieduplicates HHID_survey, folder("${duplicates_bl}") uniquevars(key) keepvars(SubmissionDate starttime endtime a1Latitude a1Longitude hhhead_name b4_1 father_spouse_name a2 a7 a8) suffix(Targeting) nodaily
		rename (HHID_survey key) (bl_hhid KEY)
		isid bl_hhid
			
	* GPS coordinates
		gen	double	latitude	=	a1Latitude
		replace		latitude	=	qq8Latitude	if	mi(a1Latitude)
		
		gen	double	longitude	=	a1Longitude
		replace	longitude	=	qq8Longitude	if	mi(a1Longitude)
			
		lab	var	latitude	"Latitude"
		lab	var	longitude	"Longitude"
		 
		
	* Village
		* Change qezel Abad so it matches village_anonymized dataset
		replace a6 = 89 if a6 == 1
		merge m:1 a6 using "${village_anonymized}", assert(1 3)
		codebook a6 if _merge == 1 // three villages that we don't have in baseline.
		drop _merge
		label drop village
		
	* Drop unnecessary variables
		drop	*gnn*		
				
	* Merge final HHID using survey key
		isid KEY
		preserve
			use "${profile_info_PII}", clear
			drop if mi(bl_key)
			rename (bl_hhid father_spouse_name hhhead_name) (bl_hhid_prof father_spouse_name_prof hhhead_name_prof)
			isid bl_key
			tempfile profile
			save	`profile'
		restore
		
		rename KEY bl_key
		merge 1:1 bl_key using `profile', keepus(hhid bl_hhid_prof bl_key ultra_poor father_spouse_name_prof hhhead_name_prof)
		tab ultra_poor _merge, m
		drop if _merge == 2
		drop ultra_poor father_spouse_name hhhead_name bl_hhid
		rename (bl_hhid_prof father_spouse_name_prof hhhead_name_prof) (bl_hhid father_spouse_name hhhead_name)
		
		lab var hhhead_name	"Household head name (pre-loaded)"
		lab	var	father_spouse_name	"Father/spouse name (pre-loaded)"
		
		
			/*
				Result                           # of obs.
				-----------------------------------------
				not matched                         1,340
					from master                       158  (_merge==1)
					from using                      1,182  (_merge==2)

				matched                             1,679  (_merge==3)
				-----------------------------------------


					 HH is |              _merge
				ultra-poor | master on  using onl  matched ( |     Total
				-----------+---------------------------------+----------
						 0 |         0          1      1,679 |     1,680 
						 1 |         0      1,181          0 |     1,181 
						 . |       158          0          0 |       158 
				-----------+---------------------------------+----------
					 Total |       158      1,182      1,679 |     3,019 

			*/

	*----------------*
	* Anonymize data * 
	*----------------*

	drop a1Altitude qq8Altitude a6 bhhhead_name b4_* namefromearlier* father_spouse_name hhhead_name latitude longitude a1Latitude qq8Latitude a1Longitude qq8Longitude

	* Save
		if	`c(stata_version)'>=14	{
			saveold "${Targ_allsvys_raw_bl_nopii}", replace v(13)
		}
		else {
			save "${Targ_allsvys_raw_bl_nopii}", replace
		}
