/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	March 19, 2019
Last udpate on: March 19, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct the asset index for the baseline


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 -


				INPUTS:     	* other_assets_fl1 on household assets

						
OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge 
				
				* Github files: 

Note: 			

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off
set maxvar 20000

	* Input files
		global assets_data 	"${TUP_DB}/Baseline/DataSets/Intermediate/l_hhassets_bl.dta"
		global profile  	"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
		global inputdata 	"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"

		* Output files: 
	 *if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
	 
		global asset_index_ses "${TUP_DB}/Baseline/DataSets/Intermediate/asset_index_ses_bl.dta"
		global asset_index_up "${TUP_DB}/Baseline/DataSets/Intermediate/asset_index_up_bl.dta"
	 /*}

		if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub

		global asset_index_ses "${bl_dt}/Intermediate/asset_index_ses_bl.dta"
		global asset_index_up "${bl_dt}/Intermediate/asset_index_up_bl.dta"		
		}
		*/

********************************************************************************
	** Part 1: Basic cleaning
********************************************************************************
	
use "${inputdata}", clear

keep e1 ultra_poor	bl_hhid hhid

*Merging to have the treatment variable and cortisol
merge 1:1 hhid using "${profile}", keepusing(treatment PRA_lottery) 	
count if _merge == 2
assert r(N) == 47
drop if _merge == 2 /*47 observations from the profile datasets do not have any data for wellbeing, probably due to attrition*/
drop _merge

merge 1:m hhid using "${assets_data}", nogen 
drop if inlist(asset, -98,-99)

* Rename suffix for each item
	rename l1 l1_ 
	rename l2 l2_ 
	rename l3 l3_ 
	rename l5 l5_ 

	drop l4

	reshape wide l1_ l2_ l3_ l5_, i(hhid) j(asset)




gen 	control = 0 if treatment == 1
replace control = 1 if treatment == 0 

	loc	asset1	radio_CD
	loc	asset2	TV
	loc	asset3	DishTV
	loc	asset4	VCR_DVD
	loc	asset5	house_Land
	loc	asset6	nonHouse_Land
	loc	asset7	othHouse
	loc	asset8	fridge
	loc	asset9	generator
	loc	asset10	matress
	loc	asset11	mobile_phone
	loc	asset12	non_mobilephone
	loc	asset13	iron
	loc	asset14	bedframe
	loc	asset15	jewelry
	loc	asset16	mosquitonet
	loc	asset17	mosq_repel_candle
	loc	asset18	fan
	loc	asset19	camera
	loc	asset20	other

	forval	assetnum=1/20	{
		gen	own_`asset`assetnum''		= 0 if !mi(l1_`assetnum')
		replace own_`asset`assetnum'' 	= 1 if l1_`assetnum' == 1 
		lab	var	own_`asset`assetnum''	"Household owns any `asset`assetnum''"

		gen num_`asset`assetnum'' 		= 0 if !mi(l1_`assetnum') 
		replace num_`asset`assetnum''   = l1_`assetnum' * l2_`assetnum' if l1_`assetnum' == 1  
		lab	var	num_`asset`assetnum''	"Number of `asset`assetnum'' owned by the household"
}

*Checking whether there can be issues when multiplying l1*l2 with one missing and not the other. Only issues are lands for which we don't ask
	forval	assetnum=1/20	{
di "`asset`assetnum''"
count if mi(l1_`assetnum') & !mi(l2_`assetnum')
count if !mi(l1_`assetnum') & mi(l2_`assetnum')
		}

replace num_house_Land 		= l1_5 * l3_5
replace num_nonHouse_Land 	= l1_6 * l3_6 
lab	var	num_house_Land		"Size of land on which the dwelling is"
lab	var	num_nonHouse_Land	"Size of land owned by household, excluding land on which the house is"

*Not Including any value for now as not used in later analysis, too much variation
*Haven't included the "other" either as question on whether they others have them or not 


*Household ownership e1 
gen own_dwelling = 0 
replace own_dwelling = 1 	if e1 == 1 | e1 == 2 
replace own_dwelling = .d 	if e1 == .d
label var own_dwelling "HH owns the dwelling in which they live"
*For others, not treated yet, to add later but probably unlikely to change much

loc	assets	num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  num_mobile_phone  num_non_mobilephone ///
 			num_iron  num_bedframe  num_jewelry  num_mosquitonet  num_mosq_repel_candle  num_fan  num_camera ///
 			/*num_other: Exclude for now, as they are extra assets but not sure that the ones who did not mention them actually don't have them or just did
 			not mention them */
loc property own_dwelling own_house_Land own_nonHouse_Land own_othHouse 

foreach var in `assets' {
	sum `var'
}

		pca `assets', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict wealth_score, score 
			lab var wealth_score "Asset-based wealth index (PCA) (hh assets excluding land/property) - Whole sample" 

		pca `property', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict property_score, score 
			lab var property_score "Property-based index (PCA), owning dwelling and land  - Whole sample" 

**********************Saving the bigger sample
				if	`c(stata_version)'>=14	{
				saveold "${asset_index_ses}", replace v(13)
			}
			else {
				save "${asset_index_ses}", replace
			}	


drop wealth_score property_score

keep if ultra_poor == 1

		pca `assets', mineigen(1) means 
		* Generates the wealth distribution "wealthscore"
			predict wealth_score, score 
			lab var wealth_score "Asset-based wealth index from PCA (hh assets excluding land/property)" 

		pca `property', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict property_score, score 
			lab var property_score "Property-based index (PCA), owning dwelling and land" 

*Saving
				if	`c(stata_version)'>=14	{
				saveold "${asset_index_up}", replace v(13)
			}
			else {
				save "${asset_index_up}", replace
			}	


