/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 22, 2019
Last udpate on: Mar 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Merges the constructed variables to the household dataset and creates the dataset for data analysis.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off
* Inputs
	gl all_HH_nopii_bl	 			"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl profile_info 				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl total_expenditure_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/total_expenditure_bl.dta"
	gl f_empowerment_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta"
	gl polinvolvement_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/political_involvement_index_bl.dta"
	gl foodsecurity_bl 				"${TUP_DB}/Baseline/DataSets/Intermediate/food_security_index_bl.dta"
	gl asset_index_up_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/asset_index_up_bl.dta"
	gl asset_index_ses_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/asset_index_ses_bl.dta"
	gl finance_index_up_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/finance_index_up_bl.dta"
	gl finance_index_ses_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/finance_index_ses_bl.dta"
	gl labor_bl 					"${TUP_DB}/Baseline/DataSets/Intermediate/labor_bl.dta"
	gl psy_bl 						"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta"
	gl livestock_assets_index_bl	"${TUP_DB}/Baseline/DataSets/Intermediate/livestock_assets_index_bl.dta"
	gl livestock_revenue_index_bl	"${TUP_DB}/Baseline/DataSets/Intermediate/livestock_revenue_index_bl.dta"
	gl crop_production_index_bl		"${TUP_DB}/Baseline/DataSets/Intermediate/crop_production_index_bl.dta"
	gl business_revenue_earnings_bl	"${TUP_DB}/Baseline/DataSets/Intermediate/business_revenue_earnings_bl.dta"
	gl codebook_data_bl				"${TUP_DB}/Baseline/Dofiles/Construct/codebook_data_for_analysis_bl.xlsx"
	gl schooling_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"
	gl current_roster_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/b_hhmemcurrent_bl.dta"
	gl health_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/health_bl.dta"
	
	set maxvar 30000

* Outputs

	* Data for analysis: Baseline (all vars)
		gl data_for_analysis_bl	"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"

	* Data for analysis: Baseline (IE Main paper)
		gl data_for_analysis_bl_IEpaper	"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl_IEpaper.dta"
	
	
	
********************************************************************************
	** Part 1: Merge dataset with indices
********************************************************************************

* Prepare labor
	use "${labor_bl}", clear
	keep if pf == 1
	isid hhid
	keep hhid did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork did_casual did_mkt_outhh
	tempfile labor_bl
	save	`labor_bl'

use "${all_HH_nopii_bl}", clear
drop treatment pweight

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) keep(1 3) nogen

* Get number of HH members
	preserve
		use "${current_roster_bl}", clear
		keep hhid b3
		duplicates drop hhid, force
		tempfile b3
		save	`b3'
	restore
	merge m:1 hhid using `b3', assert(3) nogen		

* Consumption
	loc consumption_vars "exp_tot_m_pc exp_tot_m_pc_ALCS exp_f_tot_m_pc exp_nf_tot_m_pc_w below_pov_af below_pov_af_ALCS exp_nf_tot_m_pc_ALCS exp_durable_m_pc exp_rent_m_pc"
	merge 1:1 hhid using "${total_expenditure_bl}", keepus(`consumption_vars') assert(3) nogen
	 
* Food Security
	loc foodsec_vars "c14_7 c14_3_ac c14_5_ac c14_1_ac index_sdC_food_sec index_sdC_food_sec2 index_sdUP_food_sec index_sdUP_food_sec2"
	merge 1:1 hhid using "${foodsecurity_bl}", keepus(`foodsec_vars') assert(2 3) keep(3) nogen
	
* Finance
	loc finance_vars "fin_index_sdC_bl"
	loc finance_vars_UP "fin_knowledge saving_account access_credit save_4wdummy saving saving_win fin_index_sdUP_bl loan_dummy loan"
	merge 1:1 hhid using "${finance_index_up_bl}", keepus(`finance_vars') assert(1 3) nogen
	merge 1:1 hhid using "${finance_index_ses_bl}", keepus(`finance_vars_UP') assert(2 3) keep(3) nogen
	
* HH assets
	loc hhasset_vars "wealth_score property_score"
	loc hhasset_vars_UP "num_radio_CD num_TV num_DishTV num_VCR_DVD  num_fridge num_generator num_matress num_mobile_phone num_non_mobilephone num_iron num_bedframe num_jewelry num_mosquitonet num_mosq_repel_candle num_fan num_camera own_dwelling own_house_Land own_nonHouse_Land own_othHouse own_house_Land own_nonHouse_Land own_mobile_phone"
	merge 1:1 hhid using "${asset_index_up_bl}", keepus(`hhasset_vars') assert(1 3) nogen
	merge 1:1 hhid using "${asset_index_ses_bl}", keepus(`hhasset_vars_UP') assert(3) nogen

* Labor
	merge 1:1 hhid using `labor_bl', assert(1 3)  nogen // 103 hhs for which we don't know who is the primary female

* Psy well being
	loc psy_vars "satisf_score_f satisf_score_m cesd_f_md cesd_m_md psy_5index_z_f psy_5index_z_m satisf_score_z_f satisf_score_z_m cesd_score_z_f cesd_score_z_m rses_score_z_f rses_score_z_m hap_score_z_f hap_score_z_m cohen_score_z_f cohen_score_z_m i27_f i27_m cesd_f_md cesd_m_md happy_i27_f happy_i27_m"
	merge 1:1 hhid using "${psy_bl}", keepus(`psy_vars') assert(3) nogen 

* Female empowerment
	loc empowerment_vars "index_sdC_all_decisions* index_sdC_foodexp* index_sdC_homeexp* index_sdC_homefin* index_sdC_chischool* index_sdC_chihealth* index_sdC_chimarr* index_sdC_homesale* index_sdC_otherexp* index_sdC_fert* h1_ac h2_ac h3_ac h4_ac h5_ac h6_ac h7_ac h8_ac h9_ac h10_ac h11_ac h12_ac h13_ac h14_ac h28_ac h31_ac h24_ac h30 index_sdC_role_prod_act* owner_manager_pf did_labor_pf index_sdC_social_norms* ed_level_d ed_help_d age_marriage_d index_sdC_social_capital* n1 n2 index_sdC_f_empowerment* index_sdC_f_empowerment_3c* index_sdC_work* index_sdC_inputs* index_sdC_educ* index_sdC_marriage* occupation_d*"

	merge 1:1 hhid using "${f_empowerment_bl}", keepus(`empowerment_vars') assert(1 3) nogen	
	
* Political involvement
	loc polinvolvement_vars "n1 n2 index_sdC_pol_involv_village index_sdUP_pol_involv_village"
	merge 1:1 hhid using "${polinvolvement_bl}", keepus(`polinvolvement_vars') assert(2 3) keep(3) nogen	

* Value of assets
	loc assets_vars "tot_lstock_value tot_lstock_value_med lstock_value_cow lstock_value_bull lstock_value_goat lstock_value_sheep tot_lstock_value_goat tot_lstock_value_med_goat lstock_value_goat_cow lstock_value_goat_bull lstock_value_goat_goat lstock_value_goat_sheep tot_lstock_w_value lstock_value_w_cow lstock_value_w_bull lstock_value_w_goat lstock_value_w_sheep"
	merge 1:1 hhid using "${livestock_assets_index_bl}", keepus(`assets_vars') assert(1 3) nogen	

* Health	
	loc health_vars "diarrhea_yes fever_yes birth_yes diarrhea_advice fever_advice birth_advice vaccinecard_yes girl_diarrhea_yes girl_fever_yes girl_vaccinecard_yes boy_diarrhea_yes boy_fever_yes boy_vaccinecard_yes"
	merge 1:1 hhid using "${health_bl}", assert(3) nogen keepus(`health_vars')	
	
* Revenues
	merge 1:1 hhid using "${livestock_revenue_index_bl}", assert(1 3) nogen
	merge 1:1 hhid using "${crop_production_index_bl}", assert(1 3) nogen
	merge 1:1 hhid using "${business_revenue_earnings_bl}", assert(1 3) nogen
	
* Construct other variables
	
	*loc hh_vars "HHsize age_pm age_pf schoolyear_pf literacy_pf schoolyear_pm literacy_pm hhhead_gender diarrhea_yes son_schooling_rate daughter_schooling_rate child_in_schooling_age own_House_Land_yes own_NonHouse_Land_yes own_Mobile_phone_yes sanitasanitation_improved water_improved"
	*merge 1:1 HHID_survey using "${bl_analysis_prep}", keepus(`hh_vars')  assert(2 3) keep(3) 
	
* Generating additional variables
	* HH head is female
		gen hhhead_female = (hh_head_gender==2)
	
	* Illiteracy
		foreach var in age literacy schoolyear {
			lab var `var'_pf "Primary Woman"
			lab var `var'_pm "Primary Man"
		}
		gen		illiteracy_pf = 1 if literacy_pf == 0
		replace illiteracy_pf = 0 if literacy_pf == 1
		gen		illiteracy_pm = 1 if literacy_pm == 0
		replace illiteracy_pm = 0 if literacy_pm == 1
		lab var illiteracy_pm "Primary Man Is Illiterate"
		lab var illiteracy_pf "Primary Woman Is Illiterate"	
		
	foreach var in age literacy schoolyear {
		lab var `var'_pm "Primary Man"
		lab var `var'_pf "Primary Woman"
	}

	
	* Household head characteristics
		local hhhead_vars "age schoolyear literacy"
		
		foreach var of local hhhead_vars {
			gen 	`var'_hhh = .
			replace `var'_hhh = `var'_pm if hh_head_gender == 1
			replace `var'_hhh = `var'_pf if hh_head_gender == 2
		}

	* Total income
		*egen tot_hh_income = rowtotal(earnings_labor_all_pf tot_lstock_revenue tot_crop_revenue tot_biz_revenue), missing
	
	* PPP values

		foreach var in exp_tot_m_pc exp_tot_m_pc_ALCS tot_lstock_value tot_lstock_value_med exp_f_tot_m_pc exp_nf_tot_m_pc_w tot_lstock_revenue tot_crop_revenue tot_biz_revenue exp_nf_tot_m_pc_ALCS exp_durable_m_pc exp_rent_m_pc saving saving_win loan { // tot_hh_income saving_4w  loan saving exp_tot_m_pc_c_ALCS
			local l_`var' : variable label `var'
			gen `var'_ppp = `var'*${ppp_factor}
			lab var `var'_ppp "`l_`var''"
		}	
	
	* Consumption in dollars
		gen exp_tot_m_pc_USD = exp_tot_m_pc/${exchange_rate_2016}
		gen exp_tot_m_pc_ALCS_USD = exp_tot_m_pc_ALCS/${exchange_rate_2016}

	* Savings
		gen 	savings_dummy = 1 if saving > 0 & !mi(saving)
		replace savings_dummy = 0 if saving == 0 & !mi(saving)

	* Own land
		gen 	own_Land_yes = 1 if own_house_Land ==1 | own_nonHouse_Land ==1
		replace own_Land_yes = 0 if own_house_Land==0 & own_nonHouse_Land ==0
		
	* Add 99% winsorization to livestock value to deal with potential outliers 	
		winsor2 tot_lstock_value, cut(0 99) by(ultra_poor) suffix(_w99)
		sum tot_lstock_value tot_lstock_value_w99

*------------*
* iecodebook *
*------------*
	
	*iecodebook template using "${codebook_data_bl}"
	*iecodebook apply using "${codebook_data_fl1}", drop	
		
		
	lab var b3 "Household Size"
	lab var diarrhea_yes "Oldest U-5 Child Diarrhea Rate"
	lab var hhhead_female "Primary Woman Is Household Head"
	lab var exp_tot_m_pc 	"Consumption AFN (US\textdollar) pc/Month"
	lab var exp_tot_m_pc_ALCS  "Consumption Consistent With Poverty Line Estimate AFN (US\textdollar) pc/Month"
	lab var below_pov_af "Household Is Below the Poverty Line"
	lab var savings_dummy "Household Saves"
	lab var loan_dummy "Households Has Any Outstanding Loans"
	lab var own_Land_yes "Household Owns Land"
	lab var own_mobile_phone "Household Owns a Mobile Phone"
	lab var satisf_score_f "Primary Woman Life Satisfaction Rating (1-10)"
	lab var cesd_f_md "Primary Woman Is Depressed (7-CESD $\geq$ 8)"
	*lab var index_sdC_f_empowerment "Women's Empowerment Index (4 dimensions)"
	lab var index_sdC_f_empowerment_3c "Women's Empowerment Index (3 dimensions)"
	lab var index_sdC_all_decisions "Women's Decisionmaking Index"
	lab var index_sdC_foodexp "Major Say in Food Expenditures and What to Cook"
	lab var index_sdC_homeexp "Major Say in Home Improvements/Repairs"
	lab var index_sdC_homefin "Major Say in Managing Household Finances"
	lab var index_sdC_chischool "Major Say in Children's School Attendance"
	lab var index_sdC_chihealth "Major Say in Children's Health Seeking"
	lab var index_sdC_chimarr "Major Say in Children's Marriage"
	lab var index_sdC_homesale "Major Say in Buying or Selling Land or Property"
	lab var index_sdC_otherexp "Major Say in Clothing and Other Non-food Expenditures"
	lab var index_sdC_fert "Major Say in Her Fertility"
	lab var index_sdC_role_prod_act "Economic Opportunities Index"
	lab var index_sdC_social_norms "Aspirations for Daughters Index"
	lab var index_sdC_social_capital "Political Involvement and Social Capital Index"
	
	*lab var tot_hh_income_ppp "Total Household Income (US\textdollar)"
	*lab var saving_4w "HH Savings (AFN), Past 4 Weeks"
	*lab var saving_4w_ppp "HH Savings (US\textdollar), Past 4 Weeks"
	lab var loan "HH Total Outstanding Cash Loans (AFN)"
	lab var loan_ppp "HH Total Outstanding Cash Loans (US\textdollar)"
	*lab var loan_win "HH Total Outstanding Cash Loans (AFN)- Winsorized"
	*lab var loan_win_ppp "HH Total Outstanding Cash Loans (US\textdollar)"
	lab var saving "HH Total Savings (AFN)"
	lab var saving_ppp "HH Total Savings (US\textdollar) - Winsorized"
	lab var saving_win "HH Total Savings (AFN) - Winsorized"
	lab var saving_win_ppp "HH Total Savings (US\textdollar)"
	lab var exp_tot_m_pc "Consumption per Capita (AFN), Month"
	lab var exp_tot_m_pc_ppp "Consumption per Capita (US\textdollar), Month"
	lab var exp_tot_m_pc_ALCS  "Consumption per Capita Poverty-Line Consistent (AFN), Month"
	lab var exp_tot_m_pc_ALCS_ppp  "Consumption per Capita Poverty-Line Consistent (US\textdollar), Month"
	lab var index_sdC_food_sec "Food Security Index"
	label var wealth_score "HH Asset Ownership Index (PCA)"
	label var property_score "Land and Dwelling Ownership Index (PCA)" 
	label var tot_lstock_value "Value of Livestock (AFN), Past 4 Weeks"
	label var tot_lstock_value_med "Value of Livestock (AFN), Past 4 Weeks - median based"
	label var tot_lstock_value_ppp "Value of Livestock (US\textdollar)" 
	label var tot_lstock_value_med_ppp "Value of Livestock (US\textdollar) - median based" 
	label var did_livestock     "PW Worked in Own Livestock"
    label var did_ownFarming     "PW Worked in Own Agriculture"
    label var did_ownBiz     "PW Worked in Own Non-Agricultural Business"
    label var did_oFarm     "Casual Labor: Agricultural"
    label var did_maid     "Casual Labor: Maid Services"
    label var did_outWork     "Casual Labor: Non-Agricultural"
	label var did_casual	"Casual Labor (Agricultural, Non-Agricultural, Maid)" 	
    label var did_salEmp     "Salaried or Formal Employment"
    *label var k30_9     "Household Chores in the Household"
    label var did_oPaidWork      "Other Paid Work"  
	*label var tot_hh_income "Total Household Income"
	lab var happy_i27_m "Primary Man Is Very Happy or Quite Happy"
	lab var cesd_m_md "Primary Man Is Depressed (7-CESD $\geq$ 8)"
	lab var h30 "PW has financial assets in her name (separate from other HH members)"
	lab var n2 "Did you ever approach the village leader in the past 12 months?"
	lab var vaccinecard_yes "Oldest U-5 Child Has Vaccination Card" 
	lab var fin_index_sdC_bl "Financial Inclusion Index"
	lab var index_sdC_food_sec "Food Security Index"
	lab var below_pov_af_ALCS "Household Is Below National Poverty Line"
	lab var did_mkt_outhh "PW Does Any Paid Work Outside of HH"
	lab var did_labor_pf  "PW Does Market Work"
	
	lab var happy_i27_f "Primary Woman Is Very Happy or Quite Happy"
	lab var satisf_score_f "Primary Woman Life Satisfaction Rating (1-10)"
	lab var cesd_f_md "Primary Woman Is Depressed (7-CESD $\geq$ 8)"
	lab var exp_tot_m_pc_ppp "Consumption per Capita (US\textdollar), Month"
	lab var loan_dummy "Household Has Any Outstanding Loans"
	
* Save dataset will all the vars
	if	`c(stata_version)'>=14	{
		saveold "${data_for_analysis_bl}", replace v(13)
	}
	else {
		save "${data_for_analysis_bl}", replace
	}
	
* Save dataset with vars used for the IE Main paper
	* Drop unnecesary variables
		keep hhid treatment ultra_poor PRA_lottery b3 ///
		`consumption_vars' `foodsec_vars' `finance_vars' `finance_vars_UP' `hhasset_vars' ///
		`hhasset_vars_UP' `psy_vars' `empowerment_vars' `polinvolvement_vars' `assets_vars' ///
		`health_vars' tot_lstock_revenue tot_lstock_earn tot_crop_revenue ///
		tot_biz_revenue tot_biz_earn hhhead_female illiteracy_pf illiteracy_pm ///
		literacy_* schoolyear_* age_hhh schoolyear_hhh literacy_hhh *_ppp *_USD ///
		savings_dummy own_Land_yes did_livestock did_ownFarming did_ownBiz did_casual did_oFarm did_mkt_outhh ///
		did_maid did_outWork did_salEmp did_oPaidWork did_labor_pf a10 a10_o


	if	`c(stata_version)'>=14	{
		saveold "${data_for_analysis_bl_IEpaper}", replace v(13)
	}
	else {
		save "${data_for_analysis_bl_IEpaper}", replace
	}

