/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	May 9, 2019
Last udpate on: May 9, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct the Entrepeneurship index 


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 -




						
OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge 
				
				* Github files: 

Note: 			

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		global inputdata 	"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
		global profile 		"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"

	* Output files: 
	 *if "`c(username)'" == "escan" { // Outputs are saved in Dropbox
		global entrepreneur_index_up "${TUP_DB}/Baseline/DataSets/Intermediate/entrepreneur_index_up_bl.dta"
	 /*}


	if "`c(username)'" != "escan" { // Outputs are saved in local GitHub
		}
		*/


use "${inputdata}", clear

* Merging to have the treatment variable and cortisol
merge 1:1 hhid using "${profile}", keepusing(treatment PRA_lottery)	

gen 	control = 0 if treatment == 1
replace control = 1 if treatment == 0 


*Create Score per psychological traits, following "Who are the microentreprise Owners, 2008 McKenzie et al.
/*Entrepreneurial psychology survey questions Responses to all questions are on a scale of 1 to 5, with 5 
indicating “Agree Strongly” and 1 indicating “Disagree Strongly” 
Impulsiveness:  
I plan tasks carefully.  = j6
I make up my mind quickly.( Scale reversed) = j7


Passion for work :
I look forward to returning to my work when I am away from work ( Scale reversed) = j8

Tenacity :
I can think of many times when I persisted with work when others quit.( Scale reversed) = j9 
I continue to work on hard projects even when others oppose me ( Scale reversed)  = j10

Polychronicity: 
I like to juggle several activities at the same time ( Scale reversed) = j11
I would rather complete an entire project every day than complete parts of several projects  = j12
I believe it is best to complete one task before beginning another  = j13 

Locus of control: 
It is difficult to know who my real friends are. ( Scale reversed) = j14
I never try anything that I am not sure of. ( Scale reversed) = j15
A person can get rich by taking risks   = j16 

Achievement:  
It is important for me to do whatever I'm doing as well as I can even if it isn't  popular with people around me. ( Scale reversed) j17
Part of my enjoyment in doing things is improving my past performance. ( Scale reversed) = j18
When a group I belong to plans an activity, I would rather direct it myself than just help out and have someone else organize it.( Scale reversed) =j19
I try harder when I'm in competition with other people.( Scale reversed) = j20 
It is important to me to perform better than others on a task.( Scale reversed) = j21
 
Power motivation:  
I enjoy planning things and deciding what other people should do.( Scale reversed) = j22
I find satisfaction in having influence over others. ( Scale reversed)= j23
I like to have a lot of control over the events around me.( Scale reversed) = j24

Work centrality: 
The most important thing that happens in life involves work.( Scale reversed) = j25

Organized person: 
My family and friends would say I am a very organized person( Scale reversed) = j26

 */
 
keep if ultra_poor == 1 

*Inverse variables to create the index 
global inv_entrepreneur j7 j8 j9 j10 j11 j14 j15 j17 j18 j19 j20 j21 j22 j23 j24 j25 j26    
foreach var in $inv_entrepreneur {
		recode `var' (5 = 1) (4 = 2) (3 = 3) (2 = 4) (1 = 5), pre(inv_) test
}

*Impulsiveness: 
gen impuls_score = j6 + inv_j7
egen impuls_index_sdC_bl = weightave(impuls_score), normby(control)

*Passion for work :
gen passion_work_score = inv_j8
egen passion_work_index_sdC_bl = weightave(passion_work_score), normby(control)

*Tenacity
gen tenacity_score = inv_j9 + inv_j10
egen tenacity_index_sdC_bl = weightave(tenacity_score), normby(control)

*Polychronicity: 
gen polychronicity_score = inv_j11 + j12 + j13
egen polychronicity_index_sdC_bl = weightave(polychronicity_score), normby(control)

*Locus of control: 
gen locus_control_score = inv_j14 + inv_j15 + j16
egen locus_control_index_sdC_bl = weightave(locus_control_score), normby(control)

*Achievement: 
gen achievement_score = inv_j17 + inv_j18 + inv_j19 + inv_j20 + inv_j21
egen achievement_index_sdC_bl = weightave(achievement_score ), normby(control)

*Power motivation: 
gen power_motivation_score= inv_j22 + inv_j23 + inv_j24
egen power_motivation_index_sdC_bl = weightave(power_motivation_score), normby(control)

*Work Centrality
gen work_central_score = inv_j25
egen work_central_index_sdC_bl = weightave(work_central_score), normby(control) 

*Organized person: 
gen organized_score = inv_j26
egen organized_index_sdC_bl = weightave(organized_score), normby(control)



*Create the Index Entrepreneurship - Standardized
global psy_traits impuls_index_sdC_bl passion_work_index_sdC_bl tenacity_index_sdC_bl ///
							polychronicity_index_sdC_bl locus_control_index_sdC_bl achievement_index_sdC_bl /// 
							power_motivation_index_sdC_bl  work_central_index_sdC_bl organized_index_sdC_bl
							
egen entrep_index_sdC_bl = weightave($psy_traits), normby(control)
		
		
* Label variables
lab var impuls_index_sdC_bl    "Impulsiveness"
lab var passion_work_index_sdC_bl   "Passion for Work"
lab var tenacity_index_sdC_bl    "Tenacity" 
lab var polychronicity_index_sdC_bl  "Polychronicity" 
lab var locus_control_index_sdC_bl   "Locus of Control" 
lab var achievement_index_sdC_bl   "Achievement"
lab var power_motivation_index_sdC_bl  "Power Motivation"
lab var work_central_index_sdC_bl   "Work Centrality"
lab var organized_index_sdC_bl    "Organizational Ability"
		
* Create the index using PCA
	pca $psy_traits, mineigen(1) means 

* Generates the wealth distribution "wealthscore"
	predict entrep_index_pca_bl, score 
			
	if	`c(stata_version)'>=14	{
		lab var inv_j17 "RECODE of j17 It is important for me to do whatever I’m doing"
		saveold "${entrepreneur_index_up}", replace v(13)
	}
	else {
		save "${entrepreneur_index_up}", replace
	}	

