/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Apr 23, 2019
Last udpate on: Apr 23, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates female empowerment index based on discussion with Lupe and 
				in the following file: TUP_Afghanistan/Data Analysis/Others/Empowerment/female_empowerment_indicators_23Apr2019_adjusted2available.xlsx

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl profile_info				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl loans_bl 				"${TUP_DB}/Baseline/DataSets/Intermediate/loans_bl.dta"
	gl schooling_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"	
	gl businesses_bl	 		"${TUP_DB}/Baseline/DataSets/Intermediate/k_d_nonagbiz_bl.dta"
	gl time_activities_ses 		"${TUP_DB}/Baseline/DataSets/Intermediate/labor_bl.dta"
	gl data_for_analysis_fl1	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1_IEpaper.dta"
	
	*For households for which question on daughter was asked 
	gl all_HH_nopii_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
 
* Outputs
	gl f_empowerment_all_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_all_bl.dta"          // all indicators, intermediate 

	* pooled vars are control-ethnicity standardized [not just control] 
	gl f_empowerment_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta"          // full baseline sample 
	
	* pashto-standardized datasets do not have pooled versions of outcomes 
	gl f_empowerment_pashto_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_pashto_bl.dta"          // pashto-standardized
	
	* Select standartization 
	global normvar control // pashto 
	
********************************************************************************
	** Part 0: Prepare dataset
********************************************************************************

use "${all_HH_nopii_bl}", clear

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) keep(1 3) nogen
	
* Merge on baseline indicator for whether the HH had a young daughter at baseline	
preserve 	
	use "${all_HH_nopii_bl}", clear 
		keep bl_hhid hhid i2_d1
		gen dau_bl = 1 if !mi(i2_d1)
		replace dau_bl = 0 if mi(dau_bl)
		
		tempfile dau_bl
		save `dau_bl'
		
restore 	
	
	merge 1:1 bl_hhid hhid using "`dau_bl'", keep(1 3) nogen		
	
* Control dummy
	gen 	control = treatment==0
	replace control = . if mi(treatment)
	lab var control "HH is part of control group"

* Indicator for each ethnicity to standardize by	
	* Pashto dummy
		gen 	pashto = a10 == 2
		lab var pashto "HH is Pashto speaking"

	* Dari dummy
		gen 	dari = a10 == 1
		lab var dari "HH is Dari speaking"	
		
	* Uzbek dummy
		gen 	uzbek = a10 == 3
		lab var uzbek "HH is Uzbek speaking"	
		
	* Turkmen dummy
		gen 	turkmen = a10 == 4
		lab var turkmen "HH is Turkmen speaking"
		
	* Arabic dummy [N = 69]
		gen 	arabic = a10 == -97 & !inlist(a10_o,"هراره", "هزاره")
		lab var arabic "HH is Arabic speaking"
		
	* Hazar dummy [do not estimate the index since there are no UP hazars - all 10 are NUP]
		gen 	hazar = inlist(a10_o,"هراره", "هزاره")
		lab var hazar "HH is Hazar speaking"
		
	* Other than Pashto
		gen other = (pashto == 0)
		lab var other "HH is Other (not Pashto)"

* Create an indicator for the control HHs for each ethnicity 	
	foreach ethnicity in pashto dari uzbek turkmen arabic hazar other {
		gen `ethnicity'_control = (`ethnicity' == 1 & control == 1)
		lab var `ethnicity'_control "`ethnicity' control group"
	}	
		
	
********************************************************************************
	** Part 1: Household expenses
********************************************************************************
	
/* 1. Major Say in Food Expenditures and What to Cook (2):

	h1: What to cook on a daily basis
	h2: Buying groceries */
	
* Local for survey vars related 
	loc foodexp_survey_vars "h1 h2"
	loc foodexp_vars "h1_ac h2_ac"
	loc foodexp_vars_r "h1_ac_r h2_ac_r"
	tabm `foodexp_survey_vars', m
	
/* 2. Major Say in Home Improvements/Repairs (1):

	h8: Making home improvements/repair
*/
	loc homeexp_survey_vars "h8"
	loc homeexp_vars "h8_ac"
	loc homeexp_vars_r "h8_ac_r"
	tab `homeexp_survey_vars', m

/* 3. Major Say in Managing Household Finances (1):
		
	h7: Managing household finances
*/
	loc homefin_survey_vars "h7"
	loc homefin_vars "h7_ac"
	loc homefin_vars_r "h7_ac_r"
	tab `homefin_survey_vars', m

/* 4. Major Say in Children's School Attendance (2):

	h9: Whether your daughter should attend school
	h10: Whether your son should attend school
*/
	loc chischool_survey_vars "h9 h10"
	loc chischool_vars "h9_ac h10_ac"
	loc chischool_vars_r "h9_ac_r h10_ac_r"
	tabm `chischool_survey_vars', m

/* 5. Major Say in Children's Health Seeking (1):

	h13: Consulting a doctor when your child is ill
*/
	loc chihealth_survey_vars "h13"
	loc chihealth_vars "h13_ac"
	loc chihealth_vars_r "h13_ac_r"	
	tab `chihealth_survey_vars', m

/* 6. Major Say in Children's Marriage (2):

	h11: Marriage of daughters
	h12: Marriage of sons
*/
	loc chimarr_survey_vars "h11 h12"
	loc chimarr_vars "h11_ac h12_ac"
	loc chimarr_vars_r "h11_ac_r h12_ac_r"
	tabm `chimarr_survey_vars', m

/* 7. Major Say in Buying or Selling Land or Property (1):

	h6: Buying or selling land or property
*/
	loc homesale_survey_vars "h6"
	loc homesale_vars "h6_ac"
	loc homesale_vars_r "h6_ac_r"
	tab `homesale_survey_vars', m

/* 8. Major Say in Other Non-food Expenditures (3):

	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
*/
	loc otherexp_survey_vars "h3 h4 h5"
	loc otherexp_vars "h3_ac h4_ac h5_ac"
	loc otherexp_vars_r "h3_ac_r h4_ac_r h5_ac_r"
	tabm `otherexp_survey_vars', m

/* 9. Major Say in Her Fertility (1):

		h14: How many children to have
*/
	loc fert_survey_vars "h14"
	loc fert_vars "h14_ac"
	loc fert_vars_r "h14_ac_r"
	tab `fert_survey_vars', m

/* 10. Major Say in Her Taking a Loan, Opening a Business, and Working Outside of Home (3):

	h28: If you wanted to take out a loan
	h31: If you wanted to pursue a job outside the home
	h24: If you wanted to open a new business
*/	
	loc h24_survey_vars "h24"
	loc h24_vars "h24_ac"
	loc h24_vars_r "h24_ac_r"
	loc h28_survey_vars "h28"
	loc h28_vars "h28_ac"
	loc h28_vars_r "h28_ac_r"
	loc h31_survey_vars "h31"
	loc h31_vars "h31_ac"
	loc h31_vars_r "h31_ac_r"
	
	loc decide_survey_vars `foodexp_survey_vars' `homeexp_survey_vars' `homefin_survey_vars' `homesale_survey_vars' `chischool_survey_vars' `chihealth_survey_vars' `chimarr_survey_vars' `otherexp_survey_vars' `fert_survey_vars' 	`h24_survey_vars' `h28_survey_vars' `h31_survey_vars'
	
* Generate variables for index. = 1 if always consulted or always consulted and followed decision
	foreach var of local decide_survey_vars {
		local 	`var'_ac_l : variable label `var'
		gen 	`var'_ac = 1 if `var' == 3 | `var' == 4
		replace `var'_ac = 0 if `var'_ac != 1
		replace `var'_ac = . if mi(`var')
		lab var `var'_ac "``var'_ac_l'"
	}
	
* Generate variables for Robustness Checks. = 1 if always consulted AND followed decision
	foreach var of local decide_survey_vars {
		local 	`var'_ac_r_l : variable label `var'
		gen 	`var'_ac_r = 1 if `var' ==  4
		replace `var'_ac_r = 0 if `var'_ac_r != 1
		replace `var'_ac_r = . if mi(`var')
		lab var `var'_ac_r "``var'_ac_r_l'"
	}	

	* Labels
		lab var h28_ac "If you wanted to take out a loan"
		lab var h31_ac "If you wanted to pursue a job outside the home"
		lab var h24_ac "If you wanted to open a new business"
		lab var h30 "Have savings/loans/other financial assets in your own name and separate from other household members"	 		

********************************************************************************
	** Part 4: Taking advantage of economic opportunities
********************************************************************************

/* Includes:
	Engaged in productive activities
	Engaged in paid productive activities 
	k24: Primary female is owner or manager of a HH non-agricultural bussiness */
	
	*--------------------------------------------------------------------*
	* Engaged in productive activities and in paid productive activities *
	*--------------------------------------------------------------------*	
preserve 	

	* Open dataset for productive activities 	
		use "${time_activities_ses}", clear
	* Keep only primary female
		keep if pf == 1
		isid hhid
		keep hhid did_mkt
		rename did_mkt did_labor_pf
		lab var did_labor_pf "Primary Woman Participates in Market Work"
		tempfile engaged_prod_activities_pf
		save `engaged_prod_activities_pf'

	*----------------------------------------------------------------------------*
	* k24: Primary female is owner or manager of a HH non-agricultural bussiness * 
	*----------------------------------------------------------------------------*	

	* Open businesses roster
		use "${businesses_bl}", clear
		
	* Create variable if primary female is owner or manager in one of the bussiness
		gen 	owner_manager_pf = 1 if k24_3 == 1 | k24_2 == 1
		replace owner_manager_pf = 0 if k24_3 == 0 & k24_2 == 0
		replace owner_manager_pf = 0 if k23_a == 0

		
		* Get hhs with no business (none or don't know)
		*br hhid business k23_a owner_manager_pf
		gen no_biz = 1 if business == 0 & k23_a == 1
		gen dk_biz = 1 if business == -99 & k23_a == 1
		bys hhid: egen biz_no = max(no_biz)
		bys hhid: egen biz_dk = max(dk_biz)
		bys hhid: egen max_owner_manager_pf = max(owner_manager_pf)
		replace max_owner_manager_pf = 0 if biz_no == 1
		replace max_owner_manager_pf = .d if biz_dk == 1
		drop owner_manager_pf biz_no no_biz dk_biz biz_dk
		rename max_owner_manager_pf owner_manager_pf
		duplicates drop hhid, force
		lab var owner_manager_pf "PW Is Owner or Manager of a HH Non-Agricultural Business"
		tempfile owner_manager_pf
		save	`owner_manager_pf'
	
restore	

	merge 1:1 hhid using `engaged_prod_activities_pf', assert(1 3) nogen	
	merge 1:1 hhid using `owner_manager_pf', assert(3) nogen
	
	
	loc work_vars owner_manager_pf did_labor_pf
	loc inputs_vars h30
	
********************************************************************************
	** Part 5: Aspirations for daughters / Social norms
********************************************************************************
/* Includes:
	i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
	i2_d: How will this level of education help ${name_youngest_daughter}?
	i4_d: At what age would you like to see ${name_youngest_daughter} marry? 
	School-age girls are enrolled in school */
	
* i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
* Bachelor or above 
	foreach x in d s {
		gen 	ed_level_`x' = 1 if inlist(i1_`x',14,15) // 14 = BA, 15 = MA 
		replace ed_level_`x' = 0 if !inlist(i1_`x',14,15) & !mi(i1_`x')
		replace ed_level_`x' = .  if i1_`x' == -97 // other is missing
		replace ed_level_`x' = .  if i1_`x' == 17 // whatever is already completed
		replace ed_level_`x' = .d if i1_`x'==.d
		replace ed_level_`x' = .n if i1_`x'==.n
		replace ed_level_`x' = .r if i1_`x'==.r
	}
	
* In years
	foreach x in d s {
		gen 	ed_level_yr_`x' = i1_`x' 
		replace ed_level_yr_`x' = ed_level_yr_`x' -1 if i1_`x'>0 & i1_`x'<=13
		replace ed_level_yr_`x' = .  if i1_`x' == -97 // other is missing
		replace ed_level_yr_`x' = .  if i1_`x' == 17 // whatever is already completed
		replace ed_level_yr_`x' = 16 if i1_`x' == 14 // bachelor
		replace ed_level_yr_`x' = 18  if i1_`x' == 15 // masters
		replace ed_level_yr_`x' = 0  if i1_`x' == 18 // no education
		replace ed_level_yr_`x' = 12  if i1_`x' == 16 // technical	
	}	

* i2_d: How will this level of education help ${name_youngest_daughter}? -> 1 if get job/earn money, make him/her wiser
	foreach x in d s {
		gen 	ed_help_`x' = 0 if !mi(i2_`x'1)
		replace ed_help_`x' = 1 if i2_`x'1 == 1
		replace ed_help_`x' = 1 if i2_`x'2 == 1
		replace ed_help_`x' = .d if i2_`x'99 == 1
		replace ed_help_`x' = .r if i2_`x'98 == 1
	}
	
* i4_d: At what age would you like to see ${name_youngest_daughter} marry? */
	foreach x in d s {
		gen 	age_marriage_`x' = 1 if i4_`x'>18 & !mi(i4_`x')
		replace age_marriage_`x' = 0 if i4_`x'<=18 & !mi(i4_`x')
		replace age_marriage_`x' = .d if i4_`x'==.d
		replace age_marriage_`x' = .r if i4_`x'==.r
		replace age_marriage_`x' = .o if i4_`x'==100 // implausible value (outlier)
	}	
	
* i3_d: Desired Occupation: Doctor, Engineer, Anything She Wishes. */
	foreach x in d s {
		gen 	occupation_`x' = 1 if inlist(i3_`x',2,6,8) & !mi(i3_`x')
		replace occupation_`x' = 0 if !inlist(i3_`x',2,6,8)  & !mi(i3_`x')
		replace occupation_`x' = .d if i3_`x'==.d
		replace occupation_`x' = .n if i3_`x'==.n
		replace occupation_`x' = .r if i3_`x'==.r
	}	
	
	lab var ed_level_d 		"Highest Education Level Desired (Bachelor or Above)"
	lab var ed_help_d 		"Education Level Desired Will Help to Get a Better Job and Make Her Wiser"
	lab var age_marriage_d 	"Desired Age of Marriage is Adulthood ($\geq$ 18)" 	
	lab var occupation_d 	"Desired Occupation: Doctor, Engineer, Anything She Wishes"
	lab var ed_level_yr_d 	"Highest Education Level Desired (Years)"
	
	loc educ_vars ed_level_yr_d ed_help_d
	//loc occup_vars occupation_d 
	loc marriage_vars age_marriage_d

* Create additional variables needed for analysis 	
	*Highest Education Desired Is Class 9-12
	gen class_9_12_f = 0 if !mi(ed_level_d) 
		replace class_9_12_f = 1 if inrange(ed_level_d,9,12) 
	
	gen class_9_12_m = 0 if !mi(ed_level_s) 
		replace class_9_12_m = 1 if inrange(ed_level_s,9,12)
		
	lab var class_9_12_m "Highest Education Desired Is Class 9-12 (Boys)"
	lab var class_9_12_f "Highest Education Desired Is Class 9-12 (Girls)"

	*Highest Education Desired Is Bachelor's Degree or Higher
	gen class_ba_f = 0 if !mi(i1_d) 
		replace class_ba_f = 1 if inrange(i1_d,14,16)
		
	gen class_ba_m = 0 if !mi(i1_s) 
		replace class_ba_m = 1 if inrange(i1_s,14,16) 
	
	lab var class_ba_m "Highest Education Desired Is $\geq$ Bachelor's Degree (Boys)"
	lab var class_ba_f "Highest Education Desired Is $\geq$ Bachelor's Degree (Girls)"

	*Teacher Is the Occupation Desired
	gen occ_teacher_f = 0 if !mi(i3_d)
		replace occ_teacher_f = 1 if (i3_d == 3)
		
	gen occ_teacher_m = 0 if !mi(i3_s)
		replace occ_teacher_m = 1 if (i3_s == 3) 
	
 	lab var occ_teacher_m "Teacher Is the Occupation Desired (Boys)"
	lab var occ_teacher_f "Teacher Is the Occupation Desired (Girls)"

	*Doctor/Engineer Is the Occupation Desired
	gen occ_doctor_f = 0 if !mi(i3_d)
		replace occ_doctor_f = 1 if inlist(i3_d,2,6)
		
	gen occ_doctor_m = 0 if !mi(i3_s)	
		replace occ_doctor_m = 1 if inlist(i3_s,2,6)
	
	lab var occ_doctor_m "Doctor/Engineer Is the Occupation Desired (Boys)"
	lab var occ_doctor_f "Doctor/Engineer Is the Occupation Desired (Girls)"

	*Anything She/He Wishes Is the Occupation Desired
	gen occ_desire_f = 0 if !mi(i3_d)
		replace occ_desire_f = 1 if (i3_d == 8)
		
	gen occ_desire_m = 0 if !mi(i3_s)
		replace occ_desire_m = 1 if (i3_s == 8)
	
	lab var occ_desire_m "Anything She/He Wishes Is the Occupation Desired (Boys)"
	lab var occ_desire_f "Anything She/He Wishes Is the Occupation Desired (Girls)"
		 
	
	
	
********************************************************************************
	** Part 6: Social Capital/Voice outside of the HH = Political involvement Index
********************************************************************************

/* Includes:
	s21: Not in Baseline 
	s10: Not in Baseline
	s12: Not in Baseline 
	s13: Not in Baseline
	n1: Attended village meetings 
	n2: Approached village leaders about village issue */

* Labels
	lab var n1 "PW Attended Village Meetings"
	lab var n2 "PW Approached Village Leaders About Village Issue"

* Local for survey vars related to political involment
	loc community_vars "n1 n2" 
	
* Create averges from variables to have 10 "major say" variables 
	egen foodexp = rowmean(h1_ac h2_ac)	
	egen otherexp = rowmean(h3_ac h4_ac h5_ac)
	egen chischool = rowmean(h9_ac h10_ac)
	egen chimarr = rowmean(h11_ac h12_ac)	

	save "${f_empowerment_all_bl}", replace 
	
********************************************************************************
	** Construction for: Men-headed households
********************************************************************************

preserve
	
	* Decisionmaking
	loc foodexp_l		"Food Expenditures and What to Cook"
	loc homeexp_l 		"Home Improvements/Repairs"
	loc homefin_l 		"Managing Household Finances"
	loc chischool_l 	"Children's School Attendance"
	loc chihealth_l 	"Children's Health Seeking"
	loc chimarr_l 		"Children's Marriage"
	loc homesale_l		"Buying or Selling Land or Property"
	loc otherexp_l 		"Other Non-food Expenditures"
	loc fert_l 			"Her Fertility"
	loc h28_l 			"Her Taking a Loan"
	loc h31_l 			"Her Working Outside of Home"
	loc h24_l 			"Her Opening a Business"	
	
	* Econ opp 
	loc work_l "Participation in Market Work and Running a Business"
	loc inputs_l "Access to Resources and Inputs"
	
	* Political and Social Capital
	loc community_l "Community Participation"
	
	* Aspirations 
	loc educ_l "Daughters' Education"
	loc marriage_l "Daughter's Marriage in Adulthood"

	
	gl all "foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31 work inputs community educ marriage"
	
	keep if ultra_poor == 1
	* Drop if there is no LHH in the household
	drop if  respondent_gender == 1
	* Keep male-headed HHs only 
	keep if hh_head_gender == 2
	
	foreach index in $all {
		display "`index'"
		des ``index'_vars'
		egen index_sdC_`index'_m = weightave(``index'_vars'), normby(${normvar})
		lab var index_sdC_`index'_m "``index'_l' Index sd(${normvar}) - Men-headed HH"	
	}	
		
* Decisionmaking index
	loc decide_index_m "index_sdC_foodexp_m index_sdC_homeexp_m index_sdC_homefin_m index_sdC_chischool_m index_sdC_chihealth_m index_sdC_chimarr_m index_sdC_homesale_m index_sdC_otherexp_m index_sdC_fert_m index_sdC_h24_m index_sdC_h28_m index_sdC_h31_m"
	egen index_sdC_all_decisions_m = weightave(`decide_index_m'), normby(${normvar})
	lab var index_sdC_all_decisions_m "Women's Decisionmaking Index sd(${normvar}) - Men-headed HH"			
	
* Econ Opp Index
	loc econ_opp_index_m "index_sdC_work_m index_sdC_inputs_m"
	egen index_sdC_role_prod_act_m = weightave(`econ_opp_index_m'), normby(${normvar})
	lab var index_sdC_role_prod_act_m "Economic Opportunities Index sd(${normvar}) - Men-headed HH"
	
* Social Capital Index
	loc soc_cap_index_m "index_sdC_community_m"
	egen index_sdC_social_capital_m = weightave(`soc_cap_index_m'), normby(${normvar})
	lab var index_sdC_social_capital_m "Social Involvement Index sd(${normvar}) - Men-headed HH"	

* Social Norms Index
	loc soc_norms_index_m "index_sdC_educ_m index_sdC_marriage_m"
	egen index_sdC_social_norms_m = weightave(`soc_norms_index_m'), normby(${normvar})
	lab var index_sdC_social_norms_m "Aspirations for Daughters Index sd(${normvar}) - Men-headed HH"	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) //Social Norm only to be added for a subsample
	loc all_index3_m "index_sdC_all_decisions_m index_sdC_role_prod_act_m index_sdC_social_capital_m"
	egen index_sdC_f_empowerment_3c_m = weightave(`all_index3_m'), normby(${normvar})
	lab var index_sdC_f_empowerment_3c_m "Women's Empowerment Index sd(${normvar}) (3 dimensions) - Men-headed HH"		
		
		tempfile malehead
		save	`malehead'
restore
	
	merge 1:1 hhid using `malehead', assert(1 3) nogen

preserve 		
********************************************************************************
	** Part 7: Construction of indices - full sample
********************************************************************************

* Decisionmaking
	loc foodexp_l		"Food Expenditures and What to Cook"
	loc homeexp_l 		"Home Improvements/Repairs"
	loc homefin_l 		"Managing Household Finances"
	loc chischool_l 	"Children's School Attendance"
	loc chihealth_l 	"Children's Health Seeking"
	loc chimarr_l 		"Children's Marriage"
	loc homesale_l		"Buying or Selling Land or Property"
	loc fert_l 			"Her Fertility"
	loc fert_l 			"Her Fertility"
	loc h28_l 		"Her Taking a Loan"
	loc h31_l 		"Her Working Outside of Home"
	loc h24_l 		"Her Opening a Business"
	
	* Econ opp 
	loc work_l "Participation in Market Work and Running a Business"
	loc inputs_l "Access to Resources and Inputs"
	
	* Political and Social Capital
	loc community_l "Community Participation"
	
	* Aspirations 
	loc educ_l 		"Daughters' Education"
	loc marriage_l 	"Daughter's Marriage in Adulthood"
	gl all "foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31 work inputs community educ marriage"
	
	keep if ultra_poor == 1

	* Drop if there is no LHH in the household
	drop if  respondent_gender == 1
	
	* Generate indices for the overall control group 
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index' "``index'_l' Index sd(${normvar})"	
		}	
		
	* Decisionmaking index
		loc decide_index "index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert index_sdC_h24 index_sdC_h28 index_sdC_h31"
		egen index_sdC_all_decisions = weightave(`decide_index'), normby(${normvar})
		lab var index_sdC_all_decisions "Decision-making Index sd(${normvar})"
		
	* Econ Opp Index
		loc econ_opp_index "index_sdC_work index_sdC_inputs"
		egen index_sdC_role_prod_act = weightave(`econ_opp_index'), normby(${normvar})
		lab var index_sdC_role_prod_act "Economic Opportunities Index sd(${normvar})"
		
	* Social Capital Index
		loc soc_cap_index "index_sdC_community"
		gen index_sdC_social_capital = index_sdC_community
		lab var index_sdC_social_capital "Social Involvement Index sd(${normvar})"
	
	* Social Norms Index
		loc soc_norms_index "index_sdC_educ index_sdC_marriage"
		egen index_sdC_social_norms = weightave(`soc_norms_index'), normby(${normvar})
		lab var index_sdC_social_norms "Aspirations for Daughters Index sd(${normvar})"	
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) //Social Norm only to be added for a subsample
		loc all_index_3 "index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital"
		egen index_sdC_f_empowerment_3c = weightave(`all_index_3'), normby(${normvar})
		lab var index_sdC_f_empowerment_3c "Women's Empowerment Index sd(${normvar}) (3 dimensions)"

	* Merging treatment and PRA
		merge m:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) assert(2 3) keep(1 3) nogen	
		
		lab var foodexp "Food Expenditures and What to Cook"
		lab var h8_ac "Home Improvements/Repairs"
		lab var h7_ac "Managing Household Finances"
		lab var h6_ac "Buying or Selling Land or Property"
		lab var otherexp "Other Non-food Expenditures"
		lab var chischool "Children's School Attendance"
		lab var h13_ac "Children's Health Seeking"
		lab var chimarr "Children's Marriage"
		lab var h14_ac "Her Fertility"
		lab var h28_ac "Her Taking a Loan"
		lab var h24_ac"Her Opening a Business"
		lab var h31_ac "Her Working Outside of Home"
		lab var n2 "PW Approached Village Leaders About Issues"
		lab var did_labor_pf "PW Does Market Work"
		lab var h30 "PW Has Financial Assets in Her Own Name"
		lab var index_sdC_all_decisions "Decision-Making Index"
		lab var index_sdC_role_prod_act "Economic Opportunities Index"
		lab var index_sdC_social_norms "Aspirations for Daughters Index"
		lab var index_sdC_social_capital "Social Involvement Index"
		lab var index_sdC_f_empowerment_3c "Women's Empowerment Index (3 dimensions)"

		
* Save data	
if "$normvar" == "pashto" {
	if	`c(stata_version)'>=14	{
			saveold "${f_empowerment_pashto_bl}", replace v(13) 
		}
		else {
			save "${f_empowerment_pashto_bl}", replace
		}
} 	
	
if "$normvar" == "control" {
		if	`c(stata_version)'>=14	{
			saveold "${f_empowerment_bl}", replace v(13) 
		}
		else {
			save "${f_empowerment_bl}", replace
		}		
}				

	* Generate indices for each individual ethnicity standardizing by the control group for that ethnicity
	
	local i = 1

	foreach ethnicity in pashto dari uzbek turkmen arabic other {
		foreach index in $all {
			
			if "$normvar" == "pashto" {
				use "${f_empowerment_pashto_bl}", clear 
			}					
			
			if "$normvar" != "pashto" {
				use "${f_empowerment_bl}", clear 
			}	
			* Keep the ethnicity for which we are estimating the index
				keep if `ethnicity' == 1 				
			
			* Define the variable by which we normalize
			global normvar_ethnic `ethnicity'_control
			
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_`i' = weightave(``index'_vars'), normby(${normvar_ethnic})
			lab var index_sdC_`index'_`i' "``index'_l' Index sd(${normvar_ethnic})"
			
			keep hhid index_sdC_`index'_`i' 
			tempfile index_sdC_`index'_`i'
			save	`index_sdC_`index'_`i''
		}
			local i = `i' + 1 
	}	

			if "$normvar" == "pashto" {
				use "${f_empowerment_pashto_bl}", clear 
			}					
				
			if "$normvar" != "pashto" {
				use "${f_empowerment_bl}", clear 
			}	
				foreach index in $all {
					forval i = 1/6 {
					merge 1:1 hhid using "`index_sdC_`index'_`i''", assert(1 3) nogen
					}
				}
				
		local i = 1
		
		foreach ethnicity in pashto dari uzbek turkmen arabic other {

			* Define the variable by which we normalize
			global normvar_ethnic `ethnicity'_control
				
		* Decisionmaking index
			loc decide_index "index_sdC_foodexp_`i' index_sdC_homeexp_`i' index_sdC_homefin_`i' index_sdC_chischool_`i' index_sdC_chihealth_`i' index_sdC_chimarr_`i' index_sdC_homesale_`i' index_sdC_otherexp_`i' index_sdC_fert_`i' index_sdC_h24_`i' index_sdC_h28_`i' index_sdC_h31_`i'"
			egen index_sdC_all_decisions_`i' = weightave(`decide_index'), normby(${normvar_ethnic})
			lab var index_sdC_all_decisions_`i' "Decision-making Index sd(${normvar_ethnic})"
			
		* Econ Opp Index -- all ethnicities 
		if "`ethnicity'" != "arabic" {
			loc econ_opp_index "index_sdC_work_`i' index_sdC_inputs_`i'"
			egen index_sdC_role_prod_act_`i' = weightave(`econ_opp_index'), normby(${normvar_ethnic})
			lab var index_sdC_role_prod_act_`i' "Economic Opportunities Index sd(${normvar_ethnic})"
		}
		
		* Econ Opp Index -- Arabic ONLY	
		if "`ethnicity'" == "arabic" {
			gen index_sdC_role_prod_act_`i' = index_sdC_work_`i'
			lab var index_sdC_role_prod_act_`i' "Economic Opportunities Index sd(${normvar_ethnic})"
		}
			
		* Social Capital Index
			loc soc_cap_index "index_sdC_community_`i'"
			gen index_sdC_social_capital_`i' = index_sdC_community_`i'
			lab var index_sdC_social_capital_`i' "Social Involvement Index sd(${normvar_ethnic})"
			
		* Social Norms Index
			loc soc_norms_index "index_sdC_educ_`i' index_sdC_marriage_`i'"
			egen index_sdC_social_norms_`i' = weightave(`soc_norms_index'), normby(${normvar_ethnic})
			lab var index_sdC_social_norms_`i' "Aspirations for Daughters Index sd(${normvar_ethnic})"				
			
		* Total index (3 dimensions: decisionmaking, econ opp, social capital)
			loc all_index_3c "index_sdC_all_decisions_`i' index_sdC_role_prod_act_`i' index_sdC_social_capital_`i'"
			egen index_sdC_f_empowerment_3c_`i' = weightave(`all_index_3c'), normby(${normvar_ethnic})
			lab var index_sdC_f_empowerment_3c_`i' "Women's Empowerment Index sd(${normvar_ethnic}) (3 dimensions)"
				
			local i = `i' + 1 
		}
		
		* Create pooled versions (i.e., all ethnicities in one variable) of the index to gain power (as in Banerjee et al.)
		* Create indices
			foreach index in $all all_decisions role_prod_act social_norms social_capital f_empowerment_3c {
				local index_sdC_`index'_lab : var lab index_sdC_`index'_1
				local index_sdC_`index'_lab : subinstr local index_sdC_`index'_lab " sd(pashto_control)" "", all
				
				* Use ", m" egen option so that the index goes to missing if all components are missing 
				egen index_sdC_`index'_p = rowtotal(index_sdC_`index'_1 index_sdC_`index'_2 index_sdC_`index'_3 index_sdC_`index'_4 index_sdC_`index'_5), m	
				lab var index_sdC_`index'_p "`index_sdC_`index'_lab' - pooled"	
			}	
	
		* Save data	
	if "$normvar" == "control" {
			if	`c(stata_version)'>=14	{
				saveold "${f_empowerment_bl}", replace v(13) 
			}
			else {
				save "${f_empowerment_bl}", replace
			}
	}
	if "$normvar" == "pashto" {
		if	`c(stata_version)'>=14	{
				saveold "${f_empowerment_pashto_bl}", replace v(13) 
			}
			else {
				save "${f_empowerment_pashto_bl}", replace
			}
	}
restore

********************************************************************************
	** Construction of indices for those that had a daughter at baseline
********************************************************************************
preserve 
	use "${f_empowerment_all_bl}", clear 

	keep if ultra_poor == 1 & dau_bl == 1

	* Drop if there is no LHH in the household
	drop if respondent_gender == 1
	
	*Adding only for daughters components 
	gl all "foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31 work inputs community educ marriage"	
	
	* Generate indices for the overall control group 
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_dau = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_dau "``index'_l' Index sd(${normvar}) - HH with daughters"	
		}	
		
	* Decisionmaking index
		loc decide_index_dau "index_sdC_foodexp_dau index_sdC_homeexp_dau index_sdC_homefin_dau index_sdC_chischool_dau index_sdC_chihealth_dau index_sdC_chimarr_dau index_sdC_homesale_dau index_sdC_otherexp_dau index_sdC_fert_dau index_sdC_h24_dau index_sdC_h28_dau index_sdC_h31_dau"
		egen index_sdC_all_decisions_dau = weightave(`decide_index_dau'), normby(${normvar})
		lab var index_sdC_all_decisions_dau "Decision-making Index sd(${normvar})"
		
	* Econ Opp Index
		loc econ_opp_index_dau "index_sdC_work_dau index_sdC_inputs_dau"
		egen index_sdC_role_prod_act_dau = weightave(`econ_opp_index_dau'), normby(${normvar})
		lab var index_sdC_role_prod_act_dau "Economic Opportunities Index sd(${normvar})"
		
	* Social Capital Index
		loc soc_cap_index_dau "index_sdC_community_dau"
		gen index_sdC_social_capital_dau = index_sdC_community_dau
		lab var index_sdC_social_capital_dau "Social Involvement Index sd(${normvar})"
		
	* Social Norms Index
		loc soc_norms_index_dau "index_sdC_educ_dau index_sdC_marriage_dau"
		egen index_sdC_social_norms_dau = weightave(`soc_norms_index_dau'), normby(${normvar})
		lab var index_sdC_social_norms_dau "Aspirations for Daughters Index sd(${normvar})"		
				
	* Total index (3 dimensions: decisionmaking, econ opp, social capital)
		loc all_index_3_dau "index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_capital_dau"
		egen index_sdC_f_emp_dau_3c = weightave(`all_index_3_dau'), normby(${normvar})
		lab var index_sdC_f_emp_dau_3c "Women's Empowerment Index sd(${normvar}) (3 dimensions)"

	* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
		loc all_index_dau "index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_capital_dau index_sdC_social_norms_dau"
		egen index_sdC_f_emp_dau = weightave(`all_index_dau'), normby(${normvar})
		lab var index_sdC_f_emp_dau "Women's Empowerment Index sd(${normvar}) (4 dimensions)"			
		
	* Merging treatment and PRA
		merge m:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) assert(2 3) keep(1 3) nogen	
		
		lab var index_sdC_all_decisions_dau "Decision-Making Index"
		lab var index_sdC_role_prod_act_dau "Economic Opportunities Index"
		lab var index_sdC_social_norms_dau "Aspirations for Daughters Index"
		lab var index_sdC_social_capital_dau "Social Involvement Index"
		lab var index_sdC_f_emp_dau_3c "Women's Empowerment Index (3 dimensions)"
		lab var index_sdC_f_emp_dau "Women's Empowerment Index (4 dimensions)"
		
		keep hhid 	*dau* 
	
	tempfile we_aspiration_daughter
	save `we_aspiration_daughter'
restore		

	if "$normvar" == "pashto" {
		use "${f_empowerment_pashto_bl}", clear 
	}

	if "$normvar" == "control" {
		use  "${f_empowerment_bl}", clear 
	}
		
* Save data	
if "$normvar" == "pashto" {
	if	`c(stata_version)'>=14	{
			merge 1:1 hhid using `we_aspiration_daughter', assert(1 3) nogen 
			
			saveold "${f_empowerment_pashto_bl}", replace v(13) 
		}
		else {
			merge 1:1 hhid using `we_aspiration_daughter', assert(1 3) nogen 

			save "${f_empowerment_pashto_bl}", replace
		}
} 	
	
if "$normvar" == "control" {
		if	`c(stata_version)'>=14	{			
			merge 1:1 hhid using `we_aspiration_daughter', assert(1 3) nogen 

			saveold "${f_empowerment_bl}", replace v(13) 
		}
		else {
			merge 1:1 hhid using `we_aspiration_daughter', assert(1 3) nogen 

			save "${f_empowerment_bl}", replace
		}		
}				