/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Dec 22, 2019
Last udpate on: Dec 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates health variables for baseline. Including: diahrrea rate in older under-5 child, and if any under-5 child has vaccination card.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl profile_info				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl roster_bl_balance 		"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"

* Outputs
	gl health_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/health_bl.dta"

********************************************************************************
	** Part 1: Under 5 Diarrhea
********************************************************************************

use "${all_HH_nopii_bl}", clear

* Being sick
	clonevar diarrhea_yes = f6
	clonevar fever_yes = f10
	clonevar birth_yes = f17
	clonevar vaccinecard_yes = f14
	lab var diarrhea_yes "Diahrrea in oldest under-5 child (last 2 weeks)"
	lab var fever_yes "Fever in oldest under-5 child (last 2 weeks)"
	lab var birth_yes "Primary woman has given birth in the last 2 years"
	lab var vaccinecard_yes "Oldest under-5 child has a vaccination card (physically checked)"
	
* Sought advice
	clonevar diarrhea_advice = f7
	clonevar fever_advice = f11
	clonevar birth_advice = f18
	lab var diarrhea_advice "Sought advice for diarrhea treatment"
	lab var fever_advice "Sought advice for fever treatment"
	lab var birth_advice "Saw someone for prenatal care (most recent pregnancy)"

	keep hhid *_yes *_advice  vaccinecard_yes
	
* Identify gender of the oldest under-5 child 
preserve 	
use "${roster_bl_balance}", clear
	
	keep if b8_bl <= 5
	bys hhid: egen maxage = max(b8_bl)
	bys hhid: gen oldest_under5 = (b8_bl == maxage)
	keep if oldest_under5 == 1 
	* In cases where there is > 1 child of the same age in the HH (~50 HHs), the questionnaire takes max() of under 5 position, 
		*so it will be the last member under 5 in the roster 
	duplicates tag hhid, gen(tag)
	bys hhid: gen n = _n if tag > 0
	bys hhid: egen maxn = max(n)
	drop if maxn!=n
	isid hhid 

	keep hhid b8_bl b6 ultra_poor
	
	tempfile oldest_under5
	save `oldest_under5'
restore 		
	
	merge 1:1 hhid using "`oldest_under5'"
	
	gen oldest_under5 = (_merge == 3)
	drop _merge 
					
	* Identify oldest child gender 
	foreach var in diarrhea_yes fever_yes vaccinecard_yes {
		gen boy_`var' = `var' if b6 == 1 & oldest_under5 == 1 
		gen girl_`var'= `var' if b6 == 2 & oldest_under5 == 1 
	}
		
	lab var boy_diarrhea_yes "Diarrhea Rate in Oldest Under-5 Child, Past 2 Weeks (Boys)"
	lab var boy_fever_yes "Fever in Oldest Under-5 Child, Past 2 Weeks (Boys)"
	lab var boy_vaccinecard_yes "Under-5 Child Has Vaccination Card, At Least One (Physically Checked) (Boys)"
	
	lab var girl_diarrhea_yes "Diarrhea Rate in Oldest Under-5 Child, Past 2 Weeks (Girls)"
	lab var girl_fever_yes "Fever in Oldest Under-5 Child, Past 2 Weeks (Girls)"
	lab var girl_vaccinecard_yes "Under-5 Child Has Vaccination Card, At Least One (Physically Checked) (Girls)"
	
* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) keep(1 3) nogen	
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${health_bl}", replace v(13)
	}
	else {
		save "${health_bl}", replace
	}

