/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Feb 19, 2017
Last udpate on: March 23, 2019

Written by:  	Lupe Bedoya (gbedoya@worldbank.org, guadalupe.bedoya@gmail.com)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Construct labor variables


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

****************************************************************************
*** Part 0: Create directories and paths
****************************************************************************

* Inputs
	gl all_HH_nopii_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl profile_info			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl productive_act_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/k_e_timeuse_bl.dta"
	gl roster_bl_balance 	"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"

	
* Outputs
	gl labor_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/labor_bl.dta"
	
	
use "${productive_act_bl}", clear	

*Replace household head values with what they mentionned for themselves
	replace k30 	= k1_1 if !mi(k1_1)
	replace k30_1 	= k3_1 if !mi(k1_1)

	keep hhid activity member k30 k30_1

*Replacing some of the missings 	
	replace k30_1 = .d if k30_1 == -97

* add treatment variable
	merge m:1 hhid using "${all_HH_nopii_bl}", keepus(treatment) assert(3) nogen

	
	*No lady of the household chose don't answer or don't know
		drop if activity == -98 | activity == -99
	
	*Reshaping to have one variable per activity
		rename k30 		k30_0_ 		/*Did activity*/
		rename k30_1 	k30_1_ 		/*Earned in last 4 weeks*/
		
		reshape wide k30_0_ k30_1_  , i(hhid member treatment) j(activity)		
		
********************************************************************************
** Part 2: Creating and cleaning variables per activity
********************************************************************************

	*Creating locals for each activity
		loc	act0	none
		loc	act1	livestock
		loc	act2	ownFarming
		loc	act3	ownBiz
		loc	act4	oFarm
		loc	act5	maid
		loc	act6	outWork
		loc	act7	salEmp
		loc act8  	oPaidWork
		loc act9 	HHChores	
	
*There is no missing in all the "did" variables
		*Total earnings in any activity
		gen tot_earnings_act_4w 	= 0
		label var tot_earnings_act_4w "Total earnings in last 4 weeks from activities"	
	
	forval	actnum=1/9	{
		gen	did_`act`actnum''				= 0
			replace did_`act`actnum'' 		= 1 if k30_0_`actnum' == 1 
			lab	var	did_`act`actnum''		"Did `act`actnum'' in last 4 week"
	
	*Earnings
	gen earnings_`act`actnum''_4w = 0
		
		if `actnum' == 4 | `actnum' == 5 | `actnum' == 6 | `actnum' == 7 | `actnum' == 8 {	
			replace earnings_`act`actnum''_4w  = k30_1_`actnum' if k30_0_`actnum' == 1 
			lab	var earnings_`act`actnum''_4w "Average earnings doing `act`actnum'' over last 4 weeks"
			replace tot_earnings_act_4w = tot_earnings_act_4w + earnings_`act`actnum''_4w 
		}
}	
	
	
********************************************************************************
** Part 3: Creating for wider categories
********************************************************************************
	* Market work inside the household : livestock, ownFarming, OwnBiz
	gen 	did_mkt_inhh = 0
	replace did_mkt_inhh = 1 if (did_livestock == 1 | did_ownFarming == 1 | did_ownBiz == 1 )
	
	*Market work outside the household: oFarm maid OutWork SalEmp oPaidWork
	gen 	did_mkt_outhh = 0
	replace did_mkt_outhh = 1 if (did_oFarm == 1 | did_maid == 1 | did_outWork == 1 | did_salEmp == 1 | did_oPaidWork == 1 )	

	* Market work inside the household (livestock, ownFarming, OwnBiz) or outside the household (oFarm maid OutWork SalEmp oPaidWork)
	gen 	did_mkt = 0
	replace did_mkt = 1 if (did_mkt_outhh == 1 | did_mkt_inhh == 1) 
	
	*Non-Market Work: HHChores
	gen 	did_Nmkt_HHChores = did_HHChores
	
	*Casual labor 
	gen 	did_casual = 0
	replace did_casual = 1 if (did_oFarm == 1 | did_maid == 1 | did_outWork == 1 )
	
	
	*label
lab var did_mkt_inhh 		"\% Doing any market work inside HH"
lab var did_mkt_outhh 		"\% Doing any market work outside HH"
lab var did_mkt 			"\% Doing any market work"
lab var did_Nmkt_HHChores 	"\% Doing any household chores"
lab var did_casual			"\% Doing any casual labor"

keep did* hhid member treatment	earnings* tot_earnings_act_4w k30_*

************************************************************************************************************
** Part 4: Treating outliers at the individual level before we sum: winsorize and replace the .o with median
************************************************************************************************************
		*Replacing .o, only in the earnings. Impute with the median 
*No Outliers

		*Winsorizing total earning at 99
	winsor2 tot_earnings_act_4w, s(_win) c(0 99)
	
	foreach var in  tot_earnings_act_4w {
		local lab : variable label `var'
		label var `var'_win "Winsorized `lab'"
	}

************************************************************************************************************
** Part 5: Merge and save
************************************************************************************************************	
*Merge indicator of primary female in the roster (position_pf)
* For 103 households, we have missing in position_pf (20 control, 14 treatment)
merge 1:1 member hhid using "$roster_bl_balance", assert(2 3) keep(3) nogen	

* Create additional variables needed for analysis 	
	* Participation in Market Work
	gen did_mkt_adult_m = did_mkt if adult_m_bl == 1 
	gen did_mkt_adult_f = did_mkt if adult_f_bl == 1
	gen did_mkt_15_18_m = did_mkt if kidm_15_18_bl == 1 
	gen did_mkt_15_18_f = did_mkt if kidf_15_18_bl == 1
	lab var did_mkt_adult_m "Adults (Men)"
	lab var did_mkt_15_18_m "Ages 15-18 (Men)"
	lab var did_mkt_adult_f "Adults (Women)"
	lab var did_mkt_15_18_f "Ages 15-18 (Women)"

	* Participation in HH Chores
	gen did_HHChores_adult_m = did_HHChores if adult_m_bl == 1 
	gen did_HHChores_adult_f = did_HHChores if adult_f_bl == 1
	gen did_HHChores_15_18_m = did_HHChores if kidm_15_18_bl == 1 
	gen did_HHChores_15_18_f = did_HHChores if kidf_15_18_bl == 1
	lab var did_HHChores_adult_m "Adults (Men)"
	lab var did_HHChores_15_18_m "Ages 15-18 (Men)"
	lab var did_HHChores_adult_f "Adults (Women)"
	lab var did_HHChores_15_18_f "Ages 15-18 (Women)"
	
	if	`c(stata_version)'>=14	{
		saveold "${labor_bl}", replace v(13)
	}
	else {
		save "${labor_bl}", replace
	}		
