/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 11, 2019
Last udpate on: Mar 11, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Constructs the following variables: value of livestock, livestock revenue, agricultural revenue, and non-agricultural business revenue.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl livestock_bl			  	 	"${TUP_DB}/Baseline/DataSets/Intermediate/k_a_livestock_bl.dta"
	gl crops_bl		 		  	    "${TUP_DB}/Baseline/DataSets/Intermediate/k_c_crops_bl.dta"
	gl businesses_bl	 		    "${TUP_DB}/Baseline/DataSets/Intermediate/k_d_nonagbiz_bl.dta"
	gl profile_info_nopii  			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl animal_products_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/k_b_animalproduct_bl.dta"
	
	
* Outputs
	gl livestock_assets_index_bl	  "${TUP_DB}/Baseline/DataSets/Intermediate/livestock_assets_index_bl.dta"
	gl livestock_revenue_index_bl	  "${TUP_DB}/Baseline/DataSets/Intermediate/livestock_revenue_index_bl.dta"
	gl crop_production_index_bl		  "${TUP_DB}/Baseline/DataSets/Intermediate/crop_production_index_bl.dta"
	gl business_revenue_earnings_bl	  "${TUP_DB}/Baseline/DataSets/Intermediate/business_revenue_earnings_bl.dta"

********************************************************************************
	** Part 1: Livestock
********************************************************************************

*-----------------*
* Livestock value *
*-----------------*

use "${livestock_bl}", clear

	merge m:1 hhid using "${profile_info_nopii}", assert(2 3) keepusing(ultra_poor) keep(3) nogen

* Drop if "none" or "don't know"
	tab livestock if k6 == 1, m
	tab livestock if k6 == 1, m nol
	drop if inlist(livestock, -99, 0, 14, 15)

* Drop household without this information (no MHHH survey -- or targeting households, and 3 with "Don't know")
	tab k6 if livestock == 1, m
	tab k6, m
	drop if mi(k6)
	
* Does the household own?
	gen lstock_yes = k6
	
* Quantity owned
	gen 	lstock_num = k7 
	replace lstock_num = 0 if k6==0

* Value of livestock
	* Taking the self reported value of the asset and replacing with the mean when missing. 
	gen unit_value = k8

* Replacing outliers and don't know / don't answer in k8. We will follow what we do elsewhere, replacing with the mean (not including by treatment as too few observations otherwise)
	bys livestock ultra_poor: egen mean_unit_value = mean(k8) if k8 > 0 
	replace unit_value = mean_unit_value if k8 == .o  | k8 == .d | k8 == .r
	drop  mean_unit_value  ultra_poor  	
  
	* Find median unit value
		bys livestock: egen unit_value_median = median(unit_value) if unit_value>0
		bys livestock: egen unit_value_med = max(unit_value_median)
		drop unit_value_median
	
	* Use winsorization in k8 to get another measure
		winsor2 unit_value if unit_value>0, c(1 99) by(livestock)
    
	* Find unit value in terms of goats
		* Median 
		gen value_goat_med = unit_value_med if livestock== 5
		egen value_goat_med_max = max(value_goat_med) 
		gen unit_value_med_goat = unit_value_med/(value_goat_med_max)
		drop value_goat_med value_goat_med_max
		* Actual
		gen value_goat = unit_value if livestock== 5
		egen value_goat_max = max(value_goat) 
		gen unit_value_goat = unit_value/(value_goat_max)
		drop value_goat value_goat_max
		
	* Find livestock value
		* Median
		gen lstock_value_med = unit_value_med*lstock_num
		gen lstock_value_med_goat = unit_value_med_goat*lstock_num
		* Actual 
		gen lstock_value = unit_value*lstock_num
		gen lstock_value_goat = unit_value_goat*lstock_num	
		
		replace lstock_value 			= 0 if lstock_yes==0
		replace lstock_value_med 		= 0 if lstock_yes==0	
		replace lstock_value_goat 		= 0 if lstock_yes==0
		replace lstock_value_med_goat 	= 0 if lstock_yes==0
	
	* Find livestock value winsorized
		gen 	lstock_value_w = unit_value_w*lstock_num
		replace lstock_value_w = 0 if lstock_yes==0
		
* Replace with .d and .r for the corresponding missing values for the number of livestock 
		replace lstock_value_w 		= .d if k7 == .d & k6==1
		replace lstock_value   		= .d if k7 == .d & k6==1		
		replace lstock_value_goat 	= .d if k7 == .d & k6==1
		replace lstock_value_med   		= .d if k7 == .d & k6==1		
		replace lstock_value_med_goat 	= .d if k7 == .d & k6==1		
		
	* Generate variables of value conditional on having livestock
		gen lstock_value_yes = lstock_value if k6==1
		gen lstock_value_w_yes = lstock_value_w if k6==1
		
	* Generate total values of livestock by household 
		bys hhid:	egen tot_lstock_value = sum(lstock_value) 
		bys hhid:	egen tot_lstock_value_goat = sum(lstock_value_goat) 
		bys hhid:	egen tot_lstock_w_value = sum(lstock_value_w) 
		
	lab var tot_lstock_value 		"Total livestock value (Afghanis)"
	lab var tot_lstock_w_value 		"Total livestock value - Winsorized (Afghanis)"
	lab var tot_lstock_value_goat 	"Total livestock value (Goats)"		
	
* Reshape
	drop k6 k7 k8
	rename * *_
	rename (hhid_ livestock_) (hhid livestock)
	reshape wide lstock_yes_ lstock_num_ unit_value_ unit_value_med_ unit_value_w_ unit_value_goat_ unit_value_med_goat_ lstock_value_ lstock_value_med_   lstock_value_yes_ lstock_value_w_ lstock_value_w_yes_ lstock_value_goat_ lstock_value_med_goat_, i(hhid) j(livestock)
	
* Generate total value of livestock
* Median
	egen tot_lstock_value_med 		= rowtotal(lstock_value_med_1 lstock_value_med_2 lstock_value_med_3 lstock_value_med_4 lstock_value_med_5 		lstock_value_med_6 lstock_value_med_7 lstock_value_med_8 lstock_value_med_9 lstock_value_med_10 lstock_value_med_11 lstock_value_med_12 lstock_value_med_13)
	* Actual
	egen tot_lstock_value 		= rowtotal(lstock_value_1 		lstock_value_2 		lstock_value_3 		lstock_value_4 		lstock_value_5 		lstock_value_6 		lstock_value_7 		lstock_value_8 		lstock_value_9 		lstock_value_10 	 lstock_value_11 		lstock_value_12 		lstock_value_13)
	* Median
	egen tot_lstock_value_med_goat 	= rowtotal(lstock_value_med_goat_1 	lstock_value_med_goat_2 lstock_value_med_goat_3 lstock_value_med_goat_4 lstock_value_med_goat_5 lstock_value_med_goat_6 lstock_value_med_goat_7 lstock_value_med_goat_8 lstock_value_med_goat_9 lstock_value_med_goat_10 lstock_value_med_goat_11 lstock_value_med_goat_12 	lstock_value_med_goat_13)
	* Actual
	egen tot_lstock_value_goat 	= rowtotal(lstock_value_goat_1 	lstock_value_goat_2 lstock_value_goat_3 lstock_value_goat_4 lstock_value_goat_5 lstock_value_goat_6 lstock_value_goat_7 lstock_value_goat_8 lstock_value_goat_9 lstock_value_goat_10 lstock_value_goat_11 	lstock_value_goat_12 	lstock_value_goat_13)

	egen tot_lstock_w_value 	= rowtotal(lstock_value_w_1 	lstock_value_w_2 	lstock_value_w_3 	lstock_value_w_4 	lstock_value_w_5 	lstock_value_w_6 	lstock_value_w_7 	lstock_value_w_8 	lstock_value_w_9 	lstock_value_w_10 	 lstock_value_w_11 		lstock_value_w_12 		lstock_value_w_13)
	lab var tot_lstock_value 			"Total livestock value (Afghanis)"
	lab var tot_lstock_value_med 		"Total livestock value (Afghanis) - median based"
	lab var tot_lstock_w_value 			"Total livestock value - Winsorized (Afghanis)"
	lab var tot_lstock_value_goat 		"Total livestock value (Goats)"
	lab var tot_lstock_value_med_goat 	"Total livestock value (Goats) - median based"
	
* Labeling and renaming
	loc	lstock1		cow 
	loc	lstock2		bull
	loc	lstock3		horse
	loc	lstock4		donkey
	loc	lstock5		goat
	loc	lstock6		sheep
	loc	lstock7		chicken
	loc	lstock8		duck
	loc	lstock9		turkey
	loc lstock10	goose
	loc lstock11	rabbit
	loc lstock12	guineafowl
	loc lstock13	beehive
	
	loc lstock_yes_l 			"HH owns any"
	loc lstock_num_l 			"Number of owned"
	loc unit_value_l 			"Unit value of"
	loc unit_value_med_l 		"Median Unit value of"
	loc unit_value_w_l 			"Unit value (winsorized) of"
	loc unit_value_med_goat_l 	"Median Unit value in goats of"
	loc unit_value_goat_l 		"Unit value in goats of"
	loc lstock_value_l 			"(Afghanis)"
	loc lstock_value_med_l 		"(Afghanis) - median based"
	loc lstock_value_yes_l 		"(Afghanis)"
	loc lstock_value_w_yes_l 	"- Winsorized (Afghanis)"
	loc lstock_value_goat_l 	"(Goats)"
	loc lstock_value_med_goat_l "(Goats) - median based"
	
	loc vars "lstock_yes lstock_num unit_value unit_value_med unit_value_w unit_value_goat unit_value_med_goat lstock_value lstock_value_med lstock_value_yes lstock_value_w lstock_value_w_yes lstock_value_goat lstock_value_med_goat"
	
	foreach var of local vars {
		forval lstocknum=1/13 {
			rename `var'_`lstocknum' `var'_`lstock`lstocknum''
			lab var `var'_`lstock`lstocknum'' "``var'_l' `lstock`lstocknum''"
	if inlist("`var'", "lstock_value", "lstock_value_med", "lstock_value_w", "lstock_value_yes", "lstock_value_w_yes", "lstock_value_goat", "lstock_value_med_goat") {
		lab var `var'_`lstock`lstocknum'' "Total value of `lstock`lstocknum'' ``var'_l'"
				*histogram `var'_`lstock`lstocknum'' if lstock_yes_`lstock`lstocknum''==1, percent name(graph_`var'_`lstocknum', replace)
			}
		}
	}
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_assets_index_bl}", replace v(13)
	}
	else {
		save "${livestock_assets_index_bl}", replace
	}		

*-------------------*
* Livestock revenue *
*-------------------*
	
* 1. Revenues from sales in livestock and costs
*----------------------------------------------
	use "${livestock_bl}", clear
		
	* Generate variable for costs
		gen 	lstock_cost = k14
		keep hhid lstock_cost
		duplicates drop
		replace	lstock_cost = 0 if lstock_cost==.

		tempfile rev_sales
		save	`rev_sales'
	

* 2. Revenues from production
*----------------------------
	use "${animal_products_bl}", clear
	
	* Drop if "none" or "don't know"
		tab product if k9 == 1
		tab product if k9 == 1, nol
		drop if inlist(product, -99, 0, 7, 8)
		
	* households without information (no MHHH survey -- or targeting survey -- or no livestock)
		tab k9 if product == 1, m
		merge m:1 hhid using "${livestock_assets_index_bl}", assert (1 3) keepus(hhid)  // to check if they have livestock
		drop if mi(k9) & _merge ==1
		drop _merge
		
	* Produced product
		replace k9 = 0 if mi(k9)
		gen prod_yes = k9
		
	* Quantity sold and produced
		gen 	prod_qty_prod = k10
		replace prod_qty_prod = 0 if prod_yes == 0
		
		gen prod_qty_sold = k12
		
	* Calculate price
		gen 	price_unit = k13/prod_qty_sold
		replace price_unit = . if price_unit == 0
		
	* Get median price to impute to HHs who didn't sell
		bys product: egen median_price = median(price_unit)
		replace price_unit = median_price if mi(price_unit) 
	
	* Revenue of production in the past month = prod_qty_prod x price_unit x 4.3/4
		gen 	prod_revenue = (prod_qty_prod*price_unit)
		replace prod_revenue = 0 if k9==0

		keep hhid product prod_revenue
		rename * *_
		rename (hhid_ product_) (hhid product)
		reshape wide prod_revenue_, i(hhid) j(product)
		
* Merge revenue from sales
	merge 1:1 hhid using `rev_sales', assert(2 3) nogen keep(3)

* Gen total revenue
	egen 	tot_lstock_revenue = rowtotal(prod_revenue_*)
	lab var tot_lstock_revenue "Total livestock revenue (past 4 weeks, Afghanis)"
	
* Gen total earning
	gen		tot_lstock_earn = tot_lstock_revenue-lstock_cost
	lab var tot_lstock_earn "Total livestock earnings (past 4 weeks, Afghanis)"
			
* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_revenue_index_bl}", replace v(13)
	}
	else {
		save "${livestock_revenue_index_bl}", replace
	}			

********************************************************************************
	** Part 2: Crops
********************************************************************************

use "${crops_bl}", clear

* Drop if "none" or "don't know"
	tab crop if k15==1
	tab crop if k15==1, nol
	drop if inlist(crop, -99, 0)

* Drop household without this information (no MHHH survey -- or targeting households or don't know)
	tab k15 if crop == 1, m
	drop if mi(k15)
	
* Cultivated the crop
	gen crop_yes = k15

* Quantity sold and produced and earnings from sold
	gen 	crop_prod_qty = k17
	replace crop_prod_qty = 0 if crop_yes==0
	replace crop_prod_qty = . if k17==0 // we're doing this for now, but to be checked later (see asana's task for more info)
	
	gen crop_prod_sold = k19
	
* Calculate price
	gen 	price_kg = k20/crop_prod_sold
	replace price_kg = . if price_kg==0

* Get median price to impute to HHs who didn't sell
	bys crop: egen median_price = median(price_kg) if price_kg>0
	replace price_kg = median_price if mi(price_kg) | price_kg==0

		/*
				. tab crop if mi(median_price) & k15==1
							 Crop |      Freq.     Percent        Cum.
		--------------------------+-----------------------------------
							Grape |          2      100.00      100.00
		--------------------------+-----------------------------------
							Total |          2      100.00

		*/

* Value of production in the last 12 months = crop_prod_qty x price_kg x k16
	gen 	crop_revenue = (crop_prod_qty*price_kg*k16)
	replace crop_revenue = 0 if k15==0
	replace crop_prod_qty = crop_prod_qty*k16 if crop_prod_qty!=0
			
	keep hhid crop crop_yes crop_revenue  // crop_prod_qty //agric_income
	rename * *_
	rename (hhid_ crop_) (hhid crop)
	reshape wide crop_yes_ crop_revenue_ , i(hhid) j(crop) // crop_prod_qty_ agric_income_
	
* Totals
	egen 	tot_crop_revenue = rowtotal(crop_revenue_1 crop_revenue_2 crop_revenue_3 crop_revenue_4 crop_revenue_5 crop_revenue_6 crop_revenue_7 crop_revenue_8 crop_revenue_9 crop_revenue_10 crop_revenue_11 crop_revenue_12 crop_revenue_13 crop_revenue_14 crop_revenue_15 crop_revenue_16 crop_revenue_17 crop_revenue_18 crop_revenue_19 crop_revenue_20 crop_revenue_21 crop_revenue_22 crop_revenue_23 crop_revenue_24 crop_revenue_25)
	replace tot_crop_revenue = tot_crop_revenue/13 // 52 weeks in a year. divided by 13 to get 4 weeks
	lab var tot_crop_revenue "Total crop revenue (Afghanis, 4 weeks)"
	
* Labeling and renaming
	loc	crop1	wheat
	loc	crop2	vetch
	loc	crop3	maize
	loc	crop4	barley
	loc	crop5	rice
	loc	crop6	weed
	loc	crop7	sesame
	loc	crop8	clover
	loc	crop9	millet
	loc	crop10	sharsham
	loc	crop11	sugarcane
	loc	crop12	cotton
	loc	crop13	caraway
	loc	crop14	potato
	loc	crop15	cereal
	loc	crop16	eggplant
	loc	crop17	tomato
	loc	crop18	onion
	loc	crop19	okra
	loc	crop20	treefruit	
	loc	crop21	grape
	loc	crop22	melon
	loc	crop23	opium
	loc	crop24	zaghar
	loc	crop25	saffron
	loc crop26	othercrop1
	loc	crop27	othercrop2
	
	loc crop_yes_l "HH cultivated"
	loc crop_value_l "Total value of"
	loc agric_income_l "Agricultural income from"
	loc crop_prod_qty_l "Total production of"
	
	loc vars "crop_yes crop_revenue" //agric_income crop_prod_qty
	
	foreach var of local vars {
		forval cropnum=1/27 {
			rename `var'_`cropnum' `var'_`crop`cropnum''
			if inlist("`var'", "crop_prod_qty") {
				lab var `var'_`crop`cropnum'' "``var'_l' `crop`cropnum'' (Kgs, last 12 months)"
			}
			else {
				lab var `var'_`crop`cropnum'' "``var'_l' `crop`cropnum'' (Afghanis, last 12 months)"
			}
		}
	}	
			

	tempfile crop_revenue
	save	`crop_revenue'
			
		
* Save
	if	`c(stata_version)'>=14	{
		saveold "${crop_production_index_bl}", replace v(13)
	}
	else {
		save "${crop_production_index_bl}", replace
	}	
	
********************************************************************************
	** Part 3: Business
********************************************************************************

use "${businesses_bl}", clear

* Drop if "none" or "don't know". We keep other as it is important
	tab business if k23_a==1
	tab business if k23_a==1, nol
	drop if inlist(business, -99, 0)

* Drop household without this information (no MHHH survey -- 47 households)
	tab k23_a if business==1, m
	drop if mi(k23_a)
	
* Operate business
	gen biz_yes = k23_a
	
* Revenues in last 4 weeks
	gen 	biz_revenue = k32 
	replace biz_revenue = 0 if biz_yes==0
	
* Operational costs in the last 4 weeks
	gen biz_cost = k34
	
* Earnings
	gen 	biz_earn = biz_revenue-biz_cost
	replace biz_earn = 0 if biz_yes ==0
	
* Reshape
	keep hhid business biz_revenue biz_earn
	rename * *_
	rename (hhid_ business_) (hhid business)
	reshape wide biz_revenue_ biz_earn_, i(hhid) j(business)
	
* Totals
	egen 	tot_biz_revenue = rowtotal(biz_revenue_1 	biz_revenue_2 	biz_revenue_3 	biz_revenue_4 	biz_revenue_5 	biz_revenue_6 	biz_revenue_7 	biz_revenue_8 	biz_revenue_9 	biz_revenue_10 	biz_revenue_11 	biz_revenue_12 	biz_revenue_13	biz_revenue_14	biz_revenue_15)
	egen	tot_biz_earn  	= rowtotal(biz_earn_1 		biz_earn_2 		biz_earn_3 		biz_earn_4		biz_earn_5 		biz_earn_6 		biz_earn_7 		biz_earn_8 		biz_earn_9 		biz_earn_10 	biz_earn_11 	biz_earn_12 	biz_earn_13		biz_earn_14		biz_earn_15)
	lab var tot_biz_revenue "Total business revenue (Afghanis, 4 weeks)"
	lab var tot_biz_earn 	"Total business earnings (Afghanis, 4 weeks)"
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${business_revenue_earnings_bl}", replace v(13)
	}
	else {
		save "${business_revenue_earnings_bl}", replace
	}	
	