/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Apr 27, 2019
Last udpate on: Apr 27, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates psych well-being variables

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	global all_HH_nopii_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"	
	global profile_info				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	global roster_bl_balance 	    "${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"

	global date 		= word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3)

* Outputs
	global psy_bl 			    "${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta"
	global psy_bl_ses 		  	"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl_ses.dta"
	global psy_bl_gender 	  	"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_gender_bl.dta"	
	global psy_bl_gender2 	  	"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_gender_all_bl.dta"		
	
********************************************************************************
	** Part 1: Prepare dataset
********************************************************************************
clear all
use "${all_HH_nopii_bl}", clear
 
* Control dummy
	gen 	control = treatment==0
	replace control = . if mi(treatment)
	lab var control "HH is part of control group"
	
		global id  hhid treatment ultra_poor control

		
	
		global psy_f i5 i7 i10 i11 i12 i16 i23 i25 i26 i27 i28_a i28_b i28_c i28_d i28_e i28_f ///
						i28_g i28_h i28_i i28_j i34 i35 i37 i38 i39 i43 i44 i45 i46 i47 
		
		* Temporary rename so the code can be run
		foreach var of global psy_f {
			rename `var' `var'_f
		}
		
		global psy_f i5_f i7_f i10_f i11_f i12_f i16_f i23_f i25_f i26_f i27_f i28_a_f i28_b_f i28_c_f i28_d_f i28_e_f i28_f_f ///
						i28_g_f i28_h_f i28_i_f i28_j_f i34_f i35_f i37_f i38_f i39_f i43_f i44_f i45_f i46_f i47_f 
						
						
		global psy_m i5_m i7_m i10_m i11_m i12_m i16_m i23_m i25_m i26_m i27_m i28_a_m i28_b_m i28_c_m i28_d_m i28_e_m i28_f_m ///
						i28_g_m i28_h_m i28_i_m i28_j_m i34_m i35_m i37_m  i38_m i39_m i43_m i44_m i45_m i46_m i47_m
	
	
	* Keep only psy well-being section and id-related information
	
		keep $psy_f $psy_m $id merge_mhhh
		
	* Recode missing when "don't answer" (-98)--> very few ranging between 0 and 13 most cases (out of 3030 or 1200 depending the sample)
	* Only one of the questions with 23 missing  "In the last month, how often you felt that you were lucky" when asked to women
	
	
		foreach x in psy_f psy_m  {
			foreach y of global `x' {
			recode `y' (-98 = .r)
			recode `y' (-99 = .d)
			}
		}
		
	
	* Change scale of options to map GD scales (and later apply the same inversion numbers)
	* Notes: RSES has a neutral for us (5-point scale vs. 4-point scale in the GD instruments)
				
    * globals per measure
	
		global satisf i5
		global cesd i7 i10 i11 i12 i16 i23 i25
		global trust i26
		global hap i27
		global lotr i28_a i28_b i28_c i28_d i28_e i28_f i28_g i28_h i28_i i28_j
		global rses i34 i35 i37 i38 i39 i43
		global cohen i44 i45 i46 i47
	
		lab define lotr  5 "Strongly agree" 4  "Agree" 3  "Neither agree nor disagree" 2  "Disagree" 1  "Strongly disagree"
		*lab define cohen 1 "Never" 2  "Almost never" 3  "Sometimes" 4  "Fairly often" 5  "Very often"

		
	* When different, change scale to GD scale
	
		foreach x in lotr   {
			foreach y of global `x' {			
				recode `y'_* (1 = 5) (2 = 4) (3 = 3) (4 = 2) (5 = 1), pre(new) test
				rename `y'_* old`y'_*
				rename new`y'_* `y'_*
				lab values `y'_* lotr 
							
		}
		}
			
		foreach x in cohen   {
			foreach y of global `x' {			
				recode `y'_* (0 = 1) (1 = 2) (2 = 3) (3 = 4) (4 = 5), pre(new) test
				rename `y'_* old`y'_*
				rename new`y'_* `y'_*
				lab values `y'_* cohen
							
		}
		}				  
		
	******
	* Invert so that "positive" outcomes go with higher values for all variables (this requires to look into individual questions for each measure)
	******
	
	
	* CESD - DEPRESSION 
	
	
	* First unmodified score for international comparison
	
	/* 
	
	0 point: Rarely or none of the time (< 1 day)
	1 point: Some or a little of the time (1-2 days)
	2 points: Occasionally or a moderate amount of the time (3-4 days)
	3 points: Most or all of the time (5-7 days).
	
	
	                       900         1  Rarely or none of the time (< 1
                                          day)
                           989         2  Some or a little of the time
                                          (1-2 days)
                           698         3  Occasionally or a moderate
                                          amount of time (3-4 days)
                           440         4  All of the time (5-7 days)
                             1         .  
                             2        .r  



	*/

	


	foreach x in cesd  {
				foreach y of global `x' {	
					foreach z in _f _m {		
						gen `y'`z'_s=0 if `y'`z'==1
						replace `y'`z'_s = 1 if `y'`z'==2
						replace `y'`z'_s = 2 if `y'`z'==3
						replace `y'`z'_s = 3 if `y'`z'==4
						lab var `y'`z'_s "cesd item with instrument score point"
					}
					}
					}

				
		foreach x in _f _m {	
			egen cesd`x'_ts=rowtotal(i7`x'_s i10`x'_s i11`x'_s i12`x'_s i16`x'_s i23`x'_s i25`x'_s), missing
			replace cesd`x'_ts=. if (i7`x'_s==. | i10`x'_s==. | i11`x'_s==. | i12`x'_s==. | i16`x'_s==. | i23`x'_s==. | i25`x'_s==.)
			
			gen cesd`x'_md=1 if (cesd`x'_ts>=8 & !mi(cesd`x'_ts))
			replace cesd`x'_md=0 if cesd`x'_md!=1
			replace cesd`x'_md=. if cesd`x'_ts==.
			
			lab var cesd`x'_ts "CESD total score (0-21)"
			lab var cesd`x'_md "CESD Major depression 1/0 (=1 if score>=8)"	
			
		}	
		
		
		fsum cesd_f_ts cesd_m_ts cesd_f_md cesd_m_md, uselabel 
		
		fsum cesd_f_ts cesd_m_ts cesd_f_md cesd_m_md if ultra_poor==1, uselabel 
		fsum cesd_f_ts cesd_m_ts cesd_f_md cesd_m_md if ultra_poor==0, uselabel 

		
		* Percentage with major depression >=8
		
		
	

	
	** Now for the standardized tests
	
		*lab define cesd_inv 4 "Rarely or none of the time (<1 day)" 3 "Some or a little of the time (1-2 days)" 2 "Occasionally or a moderate (amount of time (3-4 days))" 	1 "All of the time (5-7 days)"
		
			foreach x in cesd  {
				foreach y of global `x' {	
					foreach z in _f _m {		
						replace `y'`z' = 5-`y'`z'
						lab values `y'`z' cesd_inv
					}
					}
					}
					
				

	* TRUST
			*lab define trust_inv 0 "Need to be very careful in dealing with people" 1 "Most people can be trusted"
	

			foreach x in trust  {
				foreach y of global `x' {		
					replace `y'_m = 0 if `y'_m == 2
					replace `y'_f = 0 if `y'_f == 2
					lab values `y'_f trust_inv
					lab values `y'_m trust_inv	
				}
				}
	
	
	
	

		
	* HAPPINESS 
	
	* Unmodified scores and also very and quite happy new variable for international comparison
	
	foreach x in i27_f i27_m {
		gen happy_`x'=1 if `x'<=2
		replace happy_`x'=0 if happy_`x'!=1 & `x'!=.
		lab var happy_`x' "Very happy or quite happy (1/0)"
	
	}
	
	 sum happy_i27_f happy_i27_m if ultra_poor==1
	 sum happy_i27_f happy_i27_m if ultra_poor==0
	 
	
	
	
		*lab define hap_inv 4 "Very happy" 3	"Quite happy" 2	"Not very happy" 1	"Not at all happy"
	
		foreach x in hap  {
				foreach y of global `x' {	
					foreach z in _f _m {		
						replace `y'`z' = 5-`y'`z'
						lab values `y'`z' hap_inv
					}
					}
					}
					
	
	
	
		
	* LOTR /  Scheier (OPTIMISM)
	* Need to invert questions _c _g and _i
	
	**** Note that questions _b _e and _f are excluded from the score *****
	
	
		*lab define lotr_inv  1 "Strongly agree" 2  "Agree" 3  "Neither agree nor disagree" 4  "Disagree" 5  "Strongly disagree"
	
		foreach x in i28  {
			foreach j in _c _g _i {
			replace `x'`j'_f=6-`x'`j'_f
			replace `x'`j'_m=6-`x'`j'_m
			lab values `x'`j'_f lotr_inv
			lab values `x'`j'_m lotr_inv	
				}							
			}
				

				
	* Rosenberg 
	* Need to invert i34 i35 i37 i39
	
	*lab define rses_inv 5 "Strongly agree" 4 "Agree" 3	"Neither agree nor disagree" 2	"Disagree"  1	"Strongly disagree"
	
	
		foreach x in i34 i35 i37 i39 {
			replace `x'_f = 6-`x'_f
			replace `x'_m = 6-`x'_m
			lab values `x'_f rses_inv
			lab values `x'_m rses_inv
			}
	

	
	* Cohen
	* Need to invert i44 and i47
	
	*lab define cohen_inv 5  "Never" 4  "Almost never" 3  "Sometimes" 2  "Fairly often" 1  "Very often"


		foreach x in i44 i47 {
			replace `x'_f=6-`x'`j'_f
			replace `x'_m=6-`x'`j'_m	
			lab values `x'_f cohen_inv
			lab values `x'_m cohen_inv
			}

	
************
* Part 2: Indices Construction, Figures and Tables by SES
* group for standardization --> ultra-poor
* only comparing the ones for which there is data in both samples (Actually now adding all of them, but with missing for NUP)
* 1) Self-reported life satisfaction (WVS), 2) Self-reported happiness (WVS), 3) CES-D-SF, and 4) Rosenberg Self-esteem Scale (RSES) 
************
	
	
	
	* Creating the scores (adding up by groups) // Rowtotals when needed 

	* Scores that don't require grouping (one indicator per measure)
		foreach j in _f _m {
					gen satisf_score`j' = i5`j' 
					gen hap_score`j' 	= i27`j'
					gen trust_score`j' 	= i26`j'
				}
			
	* Scores that require grouping (more than one indicator per measure)
	* LOTR / Scheier *** Note that questions _b _e and _f are excluded from the scores by construction
	* Adding all the variables, so that if any of the var is missing, the whole sums goes to missing
	
		foreach j in _f _m {
			gen cesd_score`j'  = i7`j'  + i10`j' + i11`j' + i12`j' + i16`j' + i23`j' + i25`j'
			gen rses_score`j'  = i34`j' + i35`j' + i37`j' + i38`j' + i39`j' + i43`j'
			gen cohen_score`j' = i44`j' + i45`j' + i46`j' + i47`j'
			gen lotr_score`j'  = i28_a`j' + i28_c`j' + i28_d`j' + i28_g`j' + i28_i`j' + i28_j`j'
		}

		label var satisf_score_f 		"PW Life Satisfaction (WVS) Score (1 - 10)"
		label var trust_score_f 		"PW Trust (WVS) Score (0 - 1)"
		label var hap_score_f 			"PW Happiness (WVS) Score (1 - 4)"
		label var cesd_score_f			"PW Depression (CESD) Score (Negatively Coded) (7 - 28)"
		label var lotr_score_f			"PW Life Orientation Test (LOT-R) Score (6 - 30)"
		label var rses_score_f 			"PW Self-Esteem (Rosenberg) Score (6 - 30)"
		label var cohen_score_f 		"PW Stress (Cohen) Score (Negatively Coded) (4 - 20)"
		label var cesd_f_md 			"PW Major Depression (0 - 1)"
		label var cesd_f_ts 			"PW Depression (CESD) Score (0 - 21)"
		
		label var satisf_score_m 		"PM Life Satisfaction (WVS) Score (1 - 10)"
		label var trust_score_m 		"PM Trust (WVS) Score (0 - 1)"
		label var hap_score_m 			"PM Happiness (WVS) Score (1 - 4)"
		label var cesd_score_m			"PM Depression (CESD) Score (Negatively Coded) (7 - 28)"
		label var lotr_score_m			"PM Life Orientation Test (LOT-R) Score (6 - 30)"
		label var rses_score_m 			"PM Self-Esteem (Rosenberg) Score (6 - 30)"
		label var cohen_score_m 		"PM Stress (Cohen) Score (Negatively Coded) (4 - 20)"
		label var cesd_m_md 			"PM Major Depression (0 - 1)"
		label var cesd_m_ts 			"PM Depression (CESD) Score (0 - 21)"		
		
	* Standardization based on control SD 
	tempfile psyc_index_all
	save	`psyc_index_all'
	
	preserve
	keep if treatment != .
	
	
	cou if mi(satisf_score_m) & mi(hap_score_m) & mi(trust_score_m) & mi(cesd_score_m) & mi(rses_score_m) & mi(cohen_score_m) & mi(lotr_score_m)
	* 282 
	
	
	foreach x in satisf_score hap_score cesd_score  rses_score cohen_score  {
			foreach j in _f _m {
				egen `x'_z`j' = weightave(`x'`j'), normby(control)
				lab var `x'_z`j' "Standardized score (control)"
		}
		}

	* Overall Index
			global all5_f satisf_score_z_f cesd_score_z_f rses_score_z_f hap_score_z_f cohen_score_z_f
			global all5_m satisf_score_z_m cesd_score_z_m rses_score_z_m hap_score_z_m cohen_score_z_m
			
			foreach j in _f _m {
				egen psy_index_z`j' = weightave(${all5`j'}), normby(control)
			}
			
			keep hhid satisf_score_z_? cesd_score_z_? rses_score_z_? hap_score_z_? cohen_score_z_? psy_index_z_?
			tempfile psyc_index
			save	`psyc_index'
	restore
			
	merge 1:1 hhid using `psyc_index', assert(1 3) nogen
			
		lab var psy_index_z_f "PW Psychological Well-being Index"
		lab var psy_index_z_m "PM Psychological Well-being Index"
	
	global psy_balance treatment hhid ultra_poor satisf_score_z_f cesd_score_z_f rses_score_z_f hap_score_z_f cohen_score_z_f ///
		satisf_score_z_m cesd_score_z_m rses_score_z_m hap_score_z_m cohen_score_z_m psy_index_z_f psy_index_z_m
	global index_raw satisf_score_f satisf_score_m  hap_score_f hap_score_m trust_score_f trust_score_m cesd_score_f cesd_score_m rses_score_f rses_score_m cohen_score_f cohen_score_m  lotr_score_f lotr_score_m cesd_f_md cesd_m_md cesd_f_ts cesd_m_ts
	keep $psy_balance  $index_raw cesd_m_md cesd_score_m happy_i27_f happy_i27_m i27_f i27_m
	
	rename (psy_index_z_f psy_index_z_m) (psy_5index_z_f psy_5index_z_m)
	
	*Save dataset for ultra poors
	if	`c(stata_version)'>=14	{
		saveold "${psy_bl}", replace v(13)
	}
	else {
		save "${psy_bl}", replace
	}
	
******************************************   Standardization based on Ultra Poor   **********************************************	
	* Standardization based on Ultra Poor
	use `psyc_index_all', clear
	
	drop cohen*

		foreach x in satisf hap cesd rses   {
			foreach j in _f {
				egen `x'_zscore_ses_f = weightave(`x'_score`j'), normby(ultra_poor)
		}
		}



	* Overall Index
			global all4 satisf_zscore_ses_f cesd_zscore_ses_f rses_zscore_ses_f hap_zscore_ses_f 

			
			egen psy_index_ses_f = weightave($all4), normby(ultra_poor)
			
	*Labelling all variables
		label var satisf_zscore_ses_f 	"Life Satisfaction (WVS) Score [UP SD, women]"
		label var hap_zscore_ses_f  	"Happiness (WVS) Score [UP SD, women]"
		label var cesd_zscore_ses_f 	"(Inverted) Depression (CESD) Score [UP SD, women]"
		label var rses_zscore_ses_f  	"Self-Esteem (RSES) Score [UP SD, women]"
		label var psy_index_ses_f 		"Psychological Well-being Index [UP SD, women]"


			global all satisf_zscore_ses_f cesd_zscore_ses_f rses_zscore_ses_f hap_zscore_ses_f  psy_index_ses_f
			
			keep hhid satisf_zscore_ses_f cesd_zscore_ses_f rses_zscore_ses_f  hap_zscore_ses_f   psy_index_ses_f ultra_poor
		


	if	`c(stata_version)'>=14	{
		saveold "${psy_bl_ses}", replace v(13)
	}
	else {
		save "${psy_bl_ses}", replace
	}

******************************************   Standardization based on female    **********************************************	
* Standardization based on Ultra Poor
	use `psyc_index_all', clear
	keep if ultra_poor == 1
	keep *satisf* *hap* *cesd* *rses* *cohen* *trust* *lotr* control hhid
	drop happy_i*
	
	
		foreach groupvar in satisf hap cesd rses cohen lotr trust  {
			rename `groupvar'_score_f  	`groupvar'_score1
			rename `groupvar'_score_m 	`groupvar'_score2
		}


		rename cesd_f_md 		cesd_md1
		rename cesd_m_md 		cesd_md2
		rename cesd_f_ts 		cesd_ts1
		rename cesd_m_ts 		cesd_ts2
		
	*Reshape to have one variable for male and one variable for female
		reshape long satisf_score trust_score hap_score cesd_score lotr_score rses_score cohen_score  cesd_md cesd_ts, i(hhid control) j(female)
		replace female = 0 if female == 2
		replace female = . if mi(satisf_score) & mi(trust_score) & mi(hap_score) & mi(cesd_score) & mi(lotr_score) & mi(rses_score) & mi(cohen_score) & female == 0 //When male was not surveyed or we have no information
		label define  hh 1 "LHH" 0 "MHH"
		label values female hh
		
		label var satisf_score 		"Life Satisfaction (WVS) Score (1 - 10)"
		label var trust_score 		"Trust (WVS) Score (0 - 1)"
		label var hap_score 		"Happiness (WVS) Score (1 - 4)"
		label var cesd_score		"Depression (CESD) Score (Negatively Coded) (7 - 28)"
		label var lotr_score		"Life Orientation Test (LOT-R) Score (6 - 30)"
		label var rses_score 		"Self-Esteem (Rosenberg) Score (6 - 30)"
		label var cohen_score 		"Stress (Cohen) Score (Negatively Coded) (4 - 20)"
		label var cesd_md 			"Major Depression (0 - 1)"
		label var cesd_ts 			"Depression (CESD) Score (0 - 21)"
		
	
	
		foreach x in satisf hap cesd rses cohen lotr trust {
				egen `x'_zscore_ses_fC_bl = weightave(`x'_score), normby(female)
		}



	* Overall Index
			global all5 satisf_zscore_ses_fC_bl hap_zscore_ses_fC_bl cesd_zscore_ses_fC_bl rses_zscore_ses_fC_bl cohen_zscore_ses_fC_bl 
			
			egen psy_index_ses_fC_bl = weightave($all5), normby(female)
			
	*Labelling all variables
		label var satisf_zscore_ses_fC_bl 	"Life Satisfaction (WVS) Index [SD Women]"
		label var hap_zscore_ses_fC_bl  	"Happiness (WVS) Index [SD Women]"
		label var cesd_zscore_ses_fC_bl 	"(Inverted) Depression (CESD) Index [SD Women]"
		label var rses_zscore_ses_fC_bl  	"Self-Esteem (RSES) Index [SD Women]"
		label var cohen_zscore_ses_fC_bl  	"(Inverted) Stress (Cohen) Index [SD Women]"
		label var psy_index_ses_fC_bl 		"Standardized Index"

	
		tempfile psychological_gender
			save `psychological_gender'

		*Merging with roster to have the different indicators
			use "$roster_bl_balance", clear
			keep if ultra_poor == 1 			
			keep hhid treatment hh_only_pf ultra_poor
			duplicates drop hhid, force
			
			merge 1:m hhid using `psychological_gender', assert(1 3) keep(3) nogen //We are matching with non UP, only keep UP

		*Need to differentiate between when male is missing because no male in the household or male is missing because he did not answer
			replace female = 0 if hh_only_pf != 1 & mi(female)
			drop if mi(female) //No information, just missing observations anyway
			gen pf_pm = 1 - female
			gen t_pf_pm = pf_pm * treatment
			label var pf_pm 	"Man"
			label var t_pf_pm 	"Treatment x Man"	
			
			gen male = 1 - female 
				label define hh2 1 "Male" 0 "Female", modify
				label values male hh2
			
	if	`c(stata_version)'>=14	{
		saveold "${psy_bl_gender}", replace v(13)
	}
	else {
		save "${psy_bl_gender}", replace
	}

	
******************************************   Standardization based on female UP   **********************************************	
* Standardization based on Ultra Poor
	use `psyc_index_all', clear

	keep *satisf* *hap* *cesd* *rses* *cohen* *trust* *lotr* control hhid ultra_poor
	drop happy_i*
	
	
		foreach groupvar in satisf hap cesd rses cohen lotr trust  {
			rename `groupvar'_score_f  	`groupvar'_score1
			rename `groupvar'_score_m 	`groupvar'_score2
		}


		rename cesd_f_md 		cesd_md1
		rename cesd_m_md 		cesd_md2
		rename cesd_f_ts 		cesd_ts1
		rename cesd_m_ts 		cesd_ts2
		
	*Reshape to have one variable for male and one variable for female
		reshape long satisf_score trust_score hap_score cesd_score lotr_score rses_score cohen_score  cesd_md cesd_ts, i(hhid control) j(female)
		
		gen female_std = female 
		replace female_std = 0 if female == 2 | (female == 1 & ultra_poor == 0) //standardization by ultra-poor female
		drop if mi(satisf_score) & mi(trust_score) & mi(hap_score) & mi(cesd_score) & mi(lotr_score) & mi(rses_score) & mi(cohen_score) //When male was not surveyed or we have no information
		label define  hh 1 "LHH" 2 "MHH"
		label values female hh
		
		label var satisf_score 		"Life Satisfaction (WVS) Score (1 - 10)"
		label var trust_score 		"Trust (WVS) Score (0 - 1)"
		label var hap_score 		"Happiness (WVS) Score (1 - 4)"
		label var cesd_score		"Depression (CESD) Score (Negatively Coded) (7 - 28)"
		label var lotr_score		"Life Orientation Test (LOT-R) Score (6 - 30)"
		label var rses_score 		"Self-Esteem (Rosenberg) Score (6 - 30)"
		label var cohen_score 		"Stress (Cohen) Score (Negatively Coded) (4 - 20)"
		label var cesd_md 			"Major Depression (0 - 1)"
		label var cesd_ts 			"Depression (CESD) Score (0 - 21)"
		
	
	
		foreach x in satisf hap cesd rses cohen lotr trust {
				egen `x'_zscore_ses_fC_bl = weightave(`x'_score), normby(female_std)
		}


	* Overall Index
			global all5 satisf_zscore_ses_fC_bl hap_zscore_ses_fC_bl cesd_zscore_ses_fC_bl rses_zscore_ses_fC_bl cohen_zscore_ses_fC_bl 
			
			egen psy_index_ses_fC_bl = weightave($all5), normby(female_std)
			
	*Labelling all variables
		label var satisf_zscore_ses_fC_bl 	"Life Satisfaction (WVS) Index [SD Women]"
		label var hap_zscore_ses_fC_bl  	"Happiness (WVS) Index [SD Women]"
		label var cesd_zscore_ses_fC_bl 	"(Inverted) Depression (CESD) Index [SD Women]"
		label var rses_zscore_ses_fC_bl  	"Self-Esteem (RSES) Index [SD Women]"
		label var cohen_zscore_ses_fC_bl  	"(Inverted) Stress (Cohen) Index [SD Women]"
		label var psy_index_ses_fC_bl 		"Standardized Index"

	
		tempfile psychological_gender
			save `psychological_gender'

		*Merging with roster to have the different indicators
			use "$roster_bl_balance", clear
			
			keep hhid treatment hh_only_pf 
			duplicates drop hhid, force
			
			merge 1:m hhid using `psychological_gender', assert(1 3)  nogen //We are matching with non UP, only keep UP
			
			drop female_std
			
			reshape wide cesd_ts cesd_md satisf_score hap_score trust_score cesd_score rses_score cohen_score lotr_score satisf_zscore_ses_fC_bl hap_zscore_ses_fC_bl cesd_zscore_ses_fC_bl rses_zscore_ses_fC_bl cohen_zscore_ses_fC_bl lotr_zscore_ses_fC_bl trust_zscore_ses_fC_bl psy_index_ses_fC_bl, i(hhid treatment hh_only_pf control ultra_poor) j(female)
						
	if	`c(stata_version)'>=14	{
		saveold "${psy_bl_gender2}", replace v(13)
	}
	else {
		save "${psy_bl_gender2}", replace
	}