/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	
Last udpate on: 

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Balance tables at baseline for the roster, ie whether households are similar in treatment and control

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

*setting global 
*Input	
	gl current_roster_bl 	      "${TUP_DB}/Baseline/DataSets/Intermediate/b_hhmemcurrent_bl.dta"
	gl all_HH_nopii_bl 			   "${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl profile_info_nopii		  "${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"

*Output
	gl roster_bl_balance 		"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"
	
	use "$current_roster_bl", clear
	
* Gen HHsize - per adult equivaleng
	gen 	weight = 1 if b8>=10 & !mi(b8)
	replace weight = 0.5 if b8<10 & !mi(b8)
	replace weight = 1 if mi(b8)
	bys hhid: egen HHsize = sum(weight)
	order HHsize, after(b3)
	drop weight
	lab var HHsize "HH size per adult equivalent (>=10 years)"

	*Computing age at follow up. Baseline done from end of feb 2016 to end of april 2016 / endline from mid july 2018 to mid october 2018 => 2.5 years 
	gen b8_fl1 = b8 + 2.5 
	replace b8_fl1 = .o if b8 >= 104 & !mi(b8)
	rename b8 b8_bl
	
* Merging treatment and PRA
	merge m:1 hhid using "${profile_info_nopii}", keepus(ultra_poor treatment PRA_lottery) assert(2 3) keep(3) nogen
		
*Create variables necessary to the analysis
	*First merge with data analysis bl to get the position of primary male / female in the roster
	
	merge m:1 hhid using "$all_HH_nopii_bl", assert(3) nogen keepusing(position_pm position_pf)
	
	gen pf = (position_pf == member) //They are all female, checked
	gen pm = (position_pm == member) //They are all male, checked	
	
*Dummy variable for whether member is primary man (pm) or primary female (pf) (0==woman) (1==man)
	gen     pf_pm = 0 if  pf == 1 //Is primary female
	replace pf_pm = 1 if  pm == 1 //Is primary man
	lab var pf_pm "Male"
	
	egen pf_in_hh = total(pf), by(hhid)
	egen pm_in_hh = total(pm), by(hhid)
	gen hh_only_pf = (pf_in_hh==1 & pm_in_hh == 0)
	gen hh_only_pm = (pf_in_hh==0 & pm_in_hh == 1)
	gen pm_pf_hh = (pf_in_hh==1 & pm_in_hh == 1)
	
	lab var hh_only_pf 			"Household has only Primary Woman (No PM)"
	lab var hh_only_pm 			"Household has only Primary Man (No PW)"
	lab var pm_pf_hh 			"Household has Primary Woman & Primary Man"	
	
* Conditions to be considered children [from follow-up]: we use the relationship to the head of the household
* Discuss whether we should include this in Baseline 
	//loc cond_kid = "!inlist(b5, 1, 8, 9, 10, 14, 17, 18, 19, 20, 21)"	
	
foreach round in _bl _fl1 {	
	gen adult_f`round'	   = (b6 == 2 & b8`round' > 18 & !mi(b8`round'))
	gen adult_m`round'	   = (b6 == 1 & b8`round' > 18 & !mi(b8`round'))
	gen oth_f_adult`round' = (b6 == 2 & b8`round' > 18 & !mi(b8`round') & position_pf != member & position_pm != member)
	gen oth_m_adult`round' = (b6 == 1 & b8`round' > 18 & !mi(b8`round') & position_pm != member & position_pf != member)
	gen kidf_6_14`round' 	= (b6 == 2 & b8`round' > 5 & b8`round' <15)	
	gen kidm_6_14`round' 	= (b6 == 1 & b8`round' > 5 & b8`round' <15)
	gen kidf_15_17`round' 	= (b6 == 2 & b8`round' >= 15 & b8`round' <=17)	
	gen kidm_15_17`round' 	= (b6 == 1 & b8`round' >= 15 & b8`round' <=17)
	gen kidf_15_18`round' 	= (b6 == 2 & b8`round' >= 15 & b8`round' <=18)	
	gen kidm_15_18`round' 	= (b6 == 1 & b8`round' >= 15 & b8`round' <=18)
	
	gen 	kid_15_18`round'_m = 0 if kidf_15_18`round' == 1
	replace kid_15_18`round'_m = 1 if kidm_15_18`round'  == 1
	lab var kid_15_18`round'_m "Children aged 15 - 18 (Boy=1, Girl=0)"
	
	label var adult_f`round'	 "Adult Women (19 and over)"
	label var adult_m`round'	 "Adult Men (19 and over)"
	label var oth_f_adult`round' "Adult Women >=19 yo (except PW)"
	label var oth_m_adult`round' "Adult Men >=19 yo (except PM)"
	lab var kidf_6_14`round' 		"Girl Children (6-14)"
	lab var kidm_6_14`round' 		"Boy Children (6-14)"
	lab var kidf_15_17`round' 		"Girl Children (15-17)"
	lab var kidm_15_17`round' 		"Boy Children (15-17)"	
	lab var kidf_15_18`round' 		"Girl Children (15-18)"
	lab var kidm_15_18`round' 		"Boy Children (15-18)"
	
	foreach var in adult_f`round' adult_m`round' oth_f_adult`round' oth_m_adult`round' kidf_6_14`round' kidm_6_14`round' kidf_15_17`round' kidm_15_17`round' kidf_15_18`round' kidm_15_18`round' {
	egen tot_`var' =  total(`var'), by(hhid)
	}
	
	gen 	adult`round'_m = 0 if adult_f`round' == 1
	replace adult`round'_m = 1 if adult_m`round' == 1
	lab var adult`round'_m "All adults >= 19 (Man=1, Woman=0)"
	
	gen 	kid_6_14`round'_m = 0 if kidf_6_14`round' == 1
	replace kid_6_14`round'_m = 1 if kidm_6_14`round' == 1
	lab var kid_6_14`round'_m "Children aged 6 - 14 (Boy=1, Girl=0)"
	
	gen 	kid_15_17`round'_m = 0 if kidf_15_17`round' == 1
	replace kid_15_17`round'_m = 1 if kidm_15_17`round' == 1
	lab var kid_15_17`round'_m "Children aged 15 - 17 (Boy=1, Girl=0)"

	lab var tot_adult_f`round' 			"Total Adult Women >=19 yo"
	lab var tot_adult_m`round' 			"Total Adult Men >=19 yo"
	lab var tot_oth_f_adult`round' 		"Total Adult Women >=19 yo (except PW)"
	lab var tot_oth_m_adult`round' 		"Total Adult Men >=19 yo (except PM)"
	lab var tot_kidf_6_14`round' 		"Total Girl Children (6-14)"
	lab var tot_kidm_6_14`round' 		"Total Boy Children (6-14)"
	lab var tot_kidf_15_17`round' 		"Total Girl Children (15-17)"
	lab var tot_kidm_15_17`round' 		"Total Boy Children (15-17)"
	lab var tot_kidf_15_18`round' 		"Total Girl Children (15-18)"
	lab var tot_kidm_15_18`round' 		"Total Boy Children (15-18)"
}

	* Create treatment interactions for relevant variables 
	gen 	t_adult_bl_m 		= treatment * adult_bl_m
	gen 	t_kid_6_14_bl_m 	= treatment * kid_6_14_bl_m
	gen 	t_kid_15_18_bl_m 	= treatment * kid_15_18_bl_m

	*Literacy variable
	gen 	literacy = 0
	replace literacy = 1   if b13 == 3
	replace literacy = b13 if b13 == .d | b13 == .r | b13 == .
	label var literacy "Literacy Rate"
	
		
	gen illiteracy_f = (1 - literacy) if adult_f_bl == 1
	gen illiteracy_m = (1 - literacy) if adult_m_bl == 1
	
	lab var illiteracy_m "Adults Are Illiterate (Men)"
	lab var illiteracy_f "Adults Are Illiterate (Women)"

	gen schoolyears_f = b16 if adult_f_bl == 1
	gen schoolyears_m = b16 if adult_m_bl == 1
		* College degree typically takes 4 years in Afghanistan, 12 + 4 = 16 
		replace schoolyears_f = 16 if schoolyears_f == 13
		replace schoolyears_m = 16 if schoolyears_m == 13
		
		lab var schoolyears_m "Adults' Number of Years of Education (Men)"
		lab var schoolyears_f "Adults' Number of Years of Education (Women)"
	
	*Number of girls and boys under 12 for balance check
preserve 
	gen u12_girl = (b6 == 2 & b8_bl < 13) & !mi(b8_bl) &!mi(b6)
	gen u12_boy = (b6 == 1 & b8_bl < 13) & !mi(b8_bl) &!mi(b6)

	collapse (sum) u12_girl u12_boy, by(hhid)	
	
	lab var u12_girl "Number of girls under 12 yo"
	lab var u12_boy "Number of boys under 12 yo"
	
	tempfile u12_kids
	save `u12_kids'
restore 

	merge m:1 hhid using "`u12_kids'", assert(3) nogen
	
	*Saving the dataset
	
		if	`c(stata_version)'>=14	{
				saveold "${roster_bl_balance}", replace v(13)
			}
			else {
				save "${roster_bl_balance}", replace
			}	
