/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Dec 10, 2019
Last udpate on: Dec 10, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Constructs school enrollment ans absenteeism variables.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl profile_info			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl roster_bl_balance 	"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"

* Outputs
	gl schooling_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"

********************************************************************************
	** Part 1: Schooling variables
********************************************************************************

use "${roster_bl_balance}", clear

* Conditions to be considered children: we use the relationship to the head of the household
	loc cond_hh = "!inlist(b5, 1, 8, 9, 10, 14, 17, 18, 19, 20, 21, -97)"
	
* Create variables

	foreach group in hh {
	
		* School age children: between 6 and 18 inclusive
			gen child_in_schooling_age_`group' 	= 1 if inrange(b8_bl,6,18) & `cond_`group''
			gen boy_in_schooling_age_`group' 	= 1 if child_in_schooling_age_`group'==1 & b6==1
			gen girl_in_schooling_age_`group' 	= 1 if child_in_schooling_age_`group'==1 & b6==2

		* Children in school last year (b15 == 1) among those in schooling age
			gen 	child_inschool_`group' 	= 1 if child_in_schooling_age_`group' == 1 & b15 == 1
			gen 	boy_inschool_`group'	= 1 if boy_in_schooling_age_`group'   == 1 & b15 == 1
			gen 	girl_inschool_`group'	= 1 if girl_in_schooling_age_`group'  == 1 & b15 == 1
			*6-14
			gen 	boy_inschool_`group'_6_14	= 1 if boy_in_schooling_age_`group'  == 1 & b15 == 1 & inrange(b8_bl,6,14)
			gen 	girl_inschool_`group'_6_14	= 1 if girl_in_schooling_age_`group' == 1 & b15 == 1 & inrange(b8_bl,6,14)
			*15-18
			gen 	boy_inschool_`group'_15_18	= 1 if boy_in_schooling_age_`group'  == 1 & b15 == 1 & inrange(b8_bl,15,18)
			gen 	girl_inschool_`group'_15_18	= 1 if girl_in_schooling_age_`group' == 1 & b15 == 1 & inrange(b8_bl,15,18)
			*6-15
			gen 	boy_inschool_`group'_6_15	= 1 if boy_in_schooling_age_`group'  == 1 & b15 == 1 & inrange(b8_bl,6,15)
			gen 	girl_inschool_`group'_6_15	= 1 if girl_in_schooling_age_`group' == 1 & b15 == 1 & inrange(b8_bl,6,15)
		
		* Children not in school  last year (b15 == 0) among those in schooling age
			replace 	child_inschool_`group' 	= 0 if child_in_schooling_age_`group' == 1 & b15 == 0
			replace 	boy_inschool_`group'	= 0 if boy_in_schooling_age_`group'   == 1 & b15 == 0
			replace 	girl_inschool_`group'	= 0 if girl_in_schooling_age_`group'  == 1 & b15 == 0
			*6-14
			replace 	boy_inschool_`group'_6_14	= 0 if boy_in_schooling_age_`group'  == 1 & b15 == 0 & inrange(b8_bl,6,14)
			replace 	girl_inschool_`group'_6_14	= 0 if girl_in_schooling_age_`group' == 1 & b15 == 0 & inrange(b8_bl,6,14)
			*15-18
			replace 	boy_inschool_`group'_15_18	= 0 if boy_in_schooling_age_`group'  == 1 & b15 == 0 & inrange(b8_bl,15,18)
			replace 	girl_inschool_`group'_15_18	= 0 if girl_in_schooling_age_`group' == 1 & b15 == 0 & inrange(b8_bl,15,18)			
			*6-15
			replace 	boy_inschool_`group'_6_15	= 0 if boy_in_schooling_age_`group'  == 1 & b15 == 0 & inrange(b8_bl,6,15)
			replace 	girl_inschool_`group'_6_15	= 0 if girl_in_schooling_age_`group' == 1 & b15 == 0 & inrange(b8_bl,6,15)	
	}

* Labels
	foreach group in hh {
		lab var child_in_schooling_age_`group' "School-Age Children"
		lab var boy_in_schooling_age_`group' "Boy in schooling age"
		lab var girl_in_schooling_age_`group' "Girl in schooling age"
		lab var child_inschool_`group' "School-Age Children Enrolled in School"
		lab var boy_inschool_`group' "School-Age Boys Are Enrolled at School"
		lab var girl_inschool_`group' "School-Age Girls Are Enrolled at School"
		lab var boy_inschool_`group'_6_14 "School-Age Boys Are Enrolled at School (6-14)"
		lab var girl_inschool_`group'_6_14 "School-Age Girls Are Enrolled at School (6-14)"
		lab var boy_inschool_`group'_15_18 "School-Age Boys Are Enrolled at School (15-18)"
		lab var girl_inschool_`group'_15_18 "School-Age Girls Are Enrolled at School (15-18)"
		lab var boy_inschool_`group'_6_15 "School-Age Boys Are Enrolled at School (6-15)"
		lab var girl_inschool_`group'_6_15 "School-Age Girls Are Enrolled at School (6-15)"
	}
	
	
* HHs with children in schooling age:
	bys hhid: gen count= _n
	bys hhid: egen child = max(child_in_schooling_age_hh)
	tab child if count == 1, m
	drop count child
	/*
		  child |      Freq.     Percent        Cum.
	------------+-----------------------------------
			  1 |      2,220       77.84       77.84
			  . |        632       22.16      100.00
	------------+-----------------------------------
		  Total |      2,852      100.00

	*/

* Child years of schooling completed (those not enrolled)	
	gen boy_schoolyears_6_18 = b16 if (kidm_6_14_bl == 1 | kidm_15_18_bl == 1) & child_inschool_hh == 0
	gen girl_schoolyears_6_18 = b16 if (kidf_6_14_bl == 1 | kidf_15_18_bl == 1) & child_inschool_hh == 0
		* College degree typically takes 4 years in Afghanistan, 12 + 4 = 16 
		replace boy_schoolyears_6_18 = 16 if boy_schoolyears_6_18 == 13
		replace girl_schoolyears_6_18 = 16 if girl_schoolyears_6_18 == 13
	lab var boy_schoolyears_6_18 "Last Grade Completed (Ages 6-18, Not In School) (Boys)"
	lab var girl_schoolyears_6_18 "Last Grade Completed (Ages 6-18, Not In School) (Girls)"

	lab var boy_inschool_hh_6_14  "Ages 6-14 (Boys)"
	lab var boy_inschool_hh_15_18 "Ages 15-18 (Boys)"
	lab var girl_inschool_hh_6_14  "Ages 6-14 (Girls)"
	lab var girl_inschool_hh_15_18 "Ages 15-18 (Girls)"
	
	keep if child_in_schooling_age_hh == 1
		
* Save
	if	`c(stata_version)'>=14	{
		saveold "${schooling_bl}", replace v(13)
	}
	else {
		save "${schooling_bl}", replace
	}
