/****************************************************************
		Village construction
****************************************************************/	

* Inputs
	gl village_clean_bl	  		"${TUP_DB}/Baseline/DataSets/Intermediate/village_clean_bl.dta"

*Outputs
	gl village_interm_bl	  "${TUP_DB}/Baseline/DataSets/Intermediate/village_interm_bl.dta"


	use "${village_clean_bl}", clear 

		/* Various through tab
			tab v22_b, gen(conflict_cat_)
			tab v11_a, gen(road_condit_cat_)*/
			
		* Type of school/health facility
			local type_vars "v8_c v8_c_g v9_c v9_c_g v10_b_p"
				
			foreach type_var of varlist `type_vars' {
			gen `type_var'_pub  = 1 if `type_var'==1
			replace `type_var'_pub = 0 if `type_var'==2
			}
			*

			lab var v8_c_pub "Boy primary – Nearest school is public"
			lab var v8_c_g_pub "Girl primary – Nearest school is public"
			lab var v9_c_pub "Boy secondary – Nearest school is public"
			lab var v9_c_g_pub "Girl secondary – Nearest school is public"
			lab var v10_b_p_pub "Nearest health facility is public"
		
	* Aggregate banks and MFIs in and near village for services offered:
		destring, replace
		
		local fin_insts 		v14 v15
		local servs 			1 2 3 4
		
		foreach fin_inst of local  fin_insts {
			foreach serv of local servs {
				gen `fin_inst'_tot`serv' = `fin_inst'_b2_`serv'
				replace `fin_inst'_tot`serv' = `fin_inst'_a_`serv' if `fin_inst'_b2_`serv'==.
			}		
		}
		
	***** Villages with at least one...

		* Primary school
		egen	prim_no = rowtotal(v8 v8_g)	
		gen		prim_any = 1 if prim_no>=1
		replace prim_any = 0 if prim_no==0
		drop 	prim_no
		lab var prim_any "There is a primary school in village"

		* Secondary school	
		egen	secon_no = rowtotal(v9 v9_g)	
		gen		secon_any = 1 if secon_no>=1
		replace secon_any = 0 if secon_no==0
		drop	secon_no
		lab var secon_any "There is a secondary school in village"

		* Health facility	
		gen		health_any = 1 if  v10>=1
		replace	health_any = 0 if  v10==0
		lab var health_any "There is a health facility in village"

		* Microfinance bank	
		gen		microfin_any = 1 if  v15>=1
		replace microfin_any = 0 if  v15==0
		lab var microfin_any "There is a microfinance institution in village"

		* Commercial bank			
		gen		bank_any = 1 if  v14>=1
		replace bank_any = 0 if  v14==0
		lab var bank_any "There is a commercial bank in village"
		
		clonevar	vet_present			 	=	v13		
		clonevar	prim_boys_near_dur		=	v8_b		
		clonevar	prim_girls_near_dur		=	v8_b_g	
		clonevar	secon_boys_near_dur		=	v9_b		
		clonevar	secon_girls_near_dur	=	v9_b_g	
		clonevar	health_near_dur			=	v10_b	
		clonevar	vet_near_dur			=	v13_b	
		clonevar	bank_near_dur			=	v14_a2	
		clonevar	microfin_near_dur		=	v15_a2	
		clonevar	elect_grid_days  		= 	v6
		clonevar 	conflict_yes			= 	v22
		
		* Irrigation access (& phone access)
		loc lperc1 "10%"
		loc lperc2 "10-25%"
		loc lperc3  "25-50%"
		loc lperc4  "50-75%"
		loc lperc5  "75-100%" 

		forval val=1/5 {
			gen irrig_perc`val'=1 if v4_a_`val'== 1 
			replace irrig_perc`val'=0 if v4_a_`val'!= 1 
			lab var irrig_perc`val' "`lperc`val'' of households has access to irrigation"
		}
		
		lab var prim_any "Primary School"
		lab var secon_any "Secondary School"
		lab var health_any "Health Facility"
		lab var vet_present "Veterinary"
		lab var bank_any "Commercial Bank"
		lab var microfin_any "Microfinance Institution"
		lab var prim_boys_near_dur "Primary School for Boys"
		lab var prim_girls_near_dur "Primary School for Girls"
		lab var secon_boys_near_dur "Secondary School for Boys"
		lab var secon_girls_near_dur "Secondary School for Girls"
		lab var health_near_dur "Health Facility"
		lab var vet_near_dur "Veterinary"
		lab var bank_near_dur "Commercial Bank"
		lab var microfin_near_dur "Microfinance Institution"
		lab var irrig_perc1 "Less than 10\%"
		lab var irrig_perc2 "10-25\%"
		lab var irrig_perc3 "25-50\%"
		lab var irrig_perc4 "50-75\%"
		lab var irrig_perc5 "75-100\%"
		lab var elect_grid_days "Days with Electricity from the Grid, Past Week"
		lab var conflict_yes "Experienced Conflict, Instability, or Violence Event"

		egen prim_near_dur = rowmean(prim_boys_near_dur prim_girls_near_dur)
		egen secon_near_dur = rowmean(secon_boys_near_dur secon_girls_near_dur)
		lab var prim_near_dur "Primary School"
		lab var secon_near_dur "Secondary School"
		
		* Save data 
		save "${village_interm_bl}", replace 
