/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Feb 3, 2021


Written by:  	Thomas Escande

Revision: 		

********************************************************************************			

THIS DO FILE: 	Construct wage variables - only for head of the household


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

****************************************************************************
*** Part 0: Create directories and paths
****************************************************************************

* Inputs
	gl all_HH_nopii_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl profile_info			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl productive_act_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/k_e_timeuse_bl.dta"
	gl roster_bl_balance 	"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"

	
* Outputs
	gl wage_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/wage_bl.dta"
	
	
use "${productive_act_bl}", clear	

keep hhid activity member k1_1 k2_1 k2_1_hr k3_1 /*k4_1*/


* add treatment variable
	merge m:1 hhid member using "${roster_bl_balance}", keepus( b5 b6 b8_bl position_pm position_pf hh_only_pf treatment ultra_poor) assert(2 3) keep(3) nogen
	keep if ultra_poor == 1

	*keeping head of the household, which is the primary man or primary women if there is no primary man
	keep if  position_pm == member | (position_pf == member & hh_only_pf == 1)
	
	*Dropping female head of the household if there is already a male head of the household
	bysort hhid b6 activity : gen order =_n
	
	*Dropping don't answer or don't know
	drop if activity == -98 | activity == -99

********************************************************************************
** Part 2: Creating and cleaning variables per activity
********************************************************************************

* Per activities, creating one variable for whether the activity was done, for how long did the person do the activity and how much they earned,
* over the last 4 weeks. Variables are generated in absolute and conditional on having done the activity (If did not do the activity becomes 0 in first case and missing in second case)
	
	gen 	did_bl = 1 if k1_1 == 1
	replace did_bl = 0 if k1_1 == 0
	lab var did_bl "Did activity in last 4 week"
	
	gen 	days_bl = k2_1
	replace days_bl = 0 if did_bl == 0
	lab var days_bl "Number of days did activity in the past 7 days"
	
	gen 	hr_bl = k2_1_hr
	replace hr_bl = 0 if did_bl == 0
	lab var hr_bl "Number of hours did activity last time they did it"
	
	gen 	hr_4w_bl = hr_bl*days_bl*4
	replace hr_4w_bl = .d if hr_bl == .d | days_bl == .d
	replace hr_4w_bl = .r if hr_bl == .r | days_bl == .r
	lab var hr_4w_bl "Number of hours doing activity in the last 4 weeks"
	
* Only for activities for which people receive a wage : other farming, maid, outside work, salaried employment and other paid work
	replace k3_1 = . if k3_1 == 99 /*Most likely meant -99 which is don't know*/
	
	gen 	earnings_4w_bl = k3_1 if did_bl == 1 & inlist(activity,4,5,6,7,8)
	tab earnings_4w_bl if mi(earnings_4w_bl) & did_bl == 1 & inlist(activity,4,5,6,7,8), m // misisng values
	lab	var earnings_4w_bl "Earnings doing activity over last 4 weeks"

	gen 	wage_bl = earnings_4w_bl/hr_4w_bl
	replace wage_bl = .d if wage == 0 // 0 earnings cannot count for the computation of the wage 
	replace wage_bl = .o if earnings_4w == .o
	replace wage_bl = .d if earnings_4w == .d
	replace wage_bl = .r if earnings_4w == .r
	replace wage_bl = . if b8_bl < 18 
	lab	var	wage_bl  "Hourly wage (adults) conditional on doing the activity"
	
	*Winsorizing, in aggregate for all activities and then by activity 
	winsor2 wage_bl , cuts(5 95) by(ultra_poor b6) suffix(_win_aggregate) 
	winsor2 wage_bl , cuts(5 95) by(ultra_poor b6 activity) suffix(_win_activity) 	
	
	label var wage_bl_win_activity  "winsorized (5 95) by activites"	
	label var wage_bl_win_aggregate "winsorized (5 95) in aggregate"	
	
	
	
	if	`c(stata_version)'>=14	{
		saveold "${wage_bl}", replace v(13)
	}
	else {
		save "${wage_bl}", replace
	}		
