/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Apr 2, 2019
Last udpate on: Apr 2, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates CDFs by treatment status for some outcomes

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl data_for_analysis	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

* Outputs

	
	use "${data_for_analysis}", clear	
	keep if ultra_poor==1
* Earning conditional in having livestock	
	lab var tot_lstock_earn "Profit from Livestock"
	lab var tot_lstock_earn_w "Profit from Livestock - Winsorized"
	egen have_livestock = rowmax(lstock_yes_turkey lstock_yes_sheep lstock_yes_rabbit lstock_yes_otherlstock2 lstock_yes_otherlstock1 lstock_yes_horse lstock_yes_guineafowl lstock_yes_goose lstock_yes_goat lstock_yes_duck lstock_yes_donkey lstock_yes_cow lstock_yes_chicken lstock_yes_bull lstock_yes_beehive)
	clonevar tot_lstock_earn_yes = tot_lstock_earn
	replace tot_lstock_earn_yes= . if have_livestock==0
	
	rename (index_sdC_pol_involv_village index_sdC_pol_involv) (pol_involv_village pol_involv	)
	lab var pol_involv_village "Political Involvement Index - Village Level"
	lab var pol_involv "Political Involvement Index - Higher Levels of Goverment"
	
	global consumption_sum		exp_tot_m_pc_c exp_tot_m_pc_c_w index_sdC_food_sec
	global fin_sum 				loan loan_w fin_index_sdC_fl1  fin_index_sdC_fl1_w
	global asset_sum 			tot_lstock_value tot_lstock_value_w wealth_score property_score
	global revenues_sum			tot_lstock_revenue tot_lstock_revenue_w tot_crop_revenue tot_biz_revenue tot_lstock_earn tot_lstock_earn_yes tot_lstock_earn_w 
	global psy_sum 				psy_indexC_sdC_fl1 psy_indexC_sdC_m_fl1
	global empower				index_sdC_empower
	global polinvolvement_sum	pol_involv_village pol_involv
	

	global all  $consumption_sum $fin_sum $asset_sum $revenues_sum $psy_sum $empower $polinvolvement_sum
	
	/*
	foreach var of global all {
		local `var'_lab : variable label `var'

		local op_title title("``var'_lab'")
		
		if inlist(`var', exp_tot_m_pc_c,  exp_tot_m_pc_c_w, loan, loan_w, tot_lstock_value, tot_lstock_value_w, tot_lstock_revenue, tot_lstock_revenue_w, tot_crop_revenue, tot_biz_revenue, tot_lstock_earn, tot_lstock_earn_w ) {
			local op_xtitle "xtitle(Afghanis)"
		}
		else if inlist(`var', wealth_score) {
			local op_title title("Asset-based wealth index from PCA" "(HH assets excluding land/property), normalized")
			local op_xtitle xtitle("Asset-based wealth index from PCA")
		}
		else if inlist(`var', property_score) {
			local op_title title("Property-based index (PCA)" "(Owning dwelling and land), normalized")
			local op_xtitle xtitle("Property-based index (PCA)")
		}		
		else if inlist(`var', tot_lstock_earn_yes) {
			local op_title title("Earnings from Livestock - Conditional on having livestock")
			local op_xtitle xtitle("Afghanis")
		}
		else if inlist(`var', psy_indexC_sdC_fl1) {
			local op_title title("Psycohological Well-being Index" "Primary Female")
			local op_subtitle subtitle("Index(5+cortisol)")
			local op_xtitle xtitle("Psycohological Well-being Index")
		}		
		else if inlist(`var', psy_indexC_sdC_m_fl1) {
			local op_title title("Psycohological Well-being Index" "Primary Male")
			local op_subtitle subtitle("Index(5+cortisol)")
			local op_xtitle xtitle("Psycohological Well-being Index")
		}			
		else {
			local op_xtitle xtitle("``var'_lab'")
			local op_subtitle 
		}
		
		twoway 	(kdensity `var' if treatment == 0, color(gs10)) ///
			(kdensity `var' if treatment == 1, color(emerald)), ///
			legend(order(1 "Control" 2 "Treatment")) ///
			`op_title' `op_xtitle' `op_subtitle' ///
			ytitle(Density) ///
			bgcolor (white) graphregion(color(white)) name(`var', replace)
	}
	
* Logs	
preserve	
	foreach var of global all {
		replace `var' = log(`var')
		local `var'_lab : variable label `var'

		local op_title title("``var'_lab'")
		
		if inlist(`var', exp_tot_m_pc_c,  exp_tot_m_pc_c_w, loan, loan_w, tot_lstock_value, tot_lstock_value_w, tot_lstock_revenue, tot_lstock_revenue_w, tot_crop_revenue, tot_biz_revenue, tot_lstock_earn, tot_lstock_earn_w ) {
			local op_xtitle "xtitle(Afghanis)"
		}
		else if inlist(`var', wealth_score) {
			local op_title title("Asset-based wealth index from PCA" "(HH assets excluding land/property), normalized")
			local op_xtitle xtitle("Asset-based wealth index from PCA")
		}
		else if inlist(`var', property_score) {
			local op_title title("Property-based index (PCA)" "(Owning dwelling and land), normalized")
			local op_xtitle xtitle("Property-based index (PCA)")
		}		
		else if inlist(`var', tot_lstock_earn_yes) {
			local op_title title("Earnings from Livestock - Conditional on having livestock")
			local op_xtitle xtitle("Afghanis")
		}
		else if inlist(`var', psy_indexC_sdC_fl1) {
			local op_title title("Psycohological Well-being Index" "Primary Female")
			local op_subtitle subtitle("Index(5+cortisol)")
			local op_xtitle xtitle("Psycohological Well-being Index")
		}		
		else if inlist(`var', psy_indexC_sdC_m_fl1) {
			local op_title title("Psycohological Well-being Index" "Primary Male")
			local op_subtitle subtitle("Index(5+cortisol)")
			local op_xtitle xtitle("Psycohological Well-being Index")
		}			
		else {
			local op_xtitle xtitle("``var'_lab'")
			local op_subtitle 
		}
		
		twoway 	(kdensity `var' if treatment == 0, color(gs10)) ///
			(kdensity `var' if treatment == 1, color(emerald)), ///
			legend(order(1 "Control" 2 "Treatment")) ///
			`op_title' `op_xtitle' `op_subtitle' ///
			ytitle(Density) ///
			bgcolor (white) graphregion(color(white)) name(`var', replace)
	}	
restore
	*/
* Removing 20% left and right for profit
-
	foreach var of varlist tot_lstock_earn tot_lstock_earn_yes {
		local `var'_lab : variable label `var'

		local op_title title("``var'_lab'")
		
		if inlist(`var', exp_tot_m_pc_c,  exp_tot_m_pc_c_w, loan, loan_w, tot_lstock_value, tot_lstock_value_w, tot_lstock_revenue, tot_lstock_revenue_w, tot_crop_revenue, tot_biz_revenue, tot_lstock_earn, tot_lstock_earn_w ) {
			local op_xtitle "xtitle(Afghanis)"
		}
		else if inlist(`var', wealth_score) {
			local op_title title("Asset-based wealth index from PCA" "(HH assets excluding land/property), normalized")
			local op_xtitle xtitle("Asset-based wealth index from PCA")
		}
		else if inlist(`var', property_score) {
			local op_title title("Property-based index (PCA)" "(Owning dwelling and land), normalized")
			local op_xtitle xtitle("Property-based index (PCA)")
		}		
		else if inlist(`var', tot_lstock_earn_yes) {
			local op_title title("Earnings from Livestock - Conditional on having livestock")
			local op_xtitle xtitle("Afghanis")
		}
		else if inlist(`var', psy_indexC_sdC_fl1) {
			local op_title title("Psycohological Well-being Index" "Primary Female")
			local op_subtitle subtitle("Index(5+cortisol)")
			local op_xtitle xtitle("Psycohological Well-being Index")
		}		
		else if inlist(`var', psy_indexC_sdC_m_fl1) {
			local op_title title("Psycohological Well-being Index" "Primary Male")
			local op_subtitle subtitle("Index(5+cortisol)")
			local op_xtitle xtitle("Psycohological Well-being Index")
		}			
		else {
			local op_xtitle xtitle("``var'_lab'")
			local op_subtitle 
		}
		
		twoway 	(kdensity `var' if treatment == 0, color(gs10)) ///
			(kdensity `var' if treatment == 1, color(emerald)), ///
			legend(order(1 "Control" 2 "Treatment")) ///
			`op_title' `op_xtitle' `op_subtitle' ///
			ytitle(Density) ///
			bgcolor (white) graphregion(color(white)) name(`var', replace)
	}
		
	
	
	-
