/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Jan 23, 2019
Last udpate on: Jan 23, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Descriptive stats for raw and clean follow-up data

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl food_consumption_all	"${TUP_DB}/Followup_1/DataSets/Intermediate/food_consumption_all_fl1.dta"
	gl nonfood_consumption_all	"${TUP_DB}/Followup_1/DataSets/Intermediate/nonfood_consumption_all_fl1.dta"
		
* Outputs
	gl consump_desc_stats_fl1			"${TUP_DB}/Followup_1/Output/Final/consump_desc_stats_fl1.xlsx"

	
********************************************************************************
	** Part 1: Descriptive stats
********************************************************************************

	* Locals for dataset
		local dataset_food 			food_consumption_all
		local dataset_nonfood 		nonfood_consumption_all

	* Locals for variables of select_one
		local mult_food			consumed_source
		local mult_nonfood 		ultra_poor 

	* Locals for variables to do stats
		local vars_food			consumed consumed_days consumed_source consumed_source__* consumed_qty consumed_qty_pc consumed_qty_pc_c price exp_f_m_pc_item_c
		local vars_nonfood 		c12 c13 exp_nf_m exp_nf_m_pc exp_nf_m_pc_c 

	* Local of variable identify item/product/crop/etc
		local item_food 		item
		local item_nonfood 		item

		
	* Local for label value of item
		local label_v_food		item_l
		local label_v_nonfood 	item_l
		
	* Sheet name
		local sheet_food 		"Food consumption"
		local sheet_nonfood 	"Non-food consumption"

*---------------*
* Prepare table *
*---------------*
		
	tempfile stats_food
	tempfile stats_nonfood
	scalar rank = 0
	
	foreach module in food nonfood { //  
		* Open dataset and create dummies for select_one variables
			use "${`dataset_`module''}", clear
			
			loc mult `mult_`module''
				
			foreach var of local mult {
				tab `var', gen(`var'__)
			}
			
		* Fix labels
			if "`module'" == "nonfood" {
				foreach var of varlist exp_nf_m_pc_c exp_nf_tot_m_pc_c exp_nf_tot_m_pc_c_NRVA exp_nf_m_pae_c exp_nf_tot_m_pae_c exp_nf_tot_m_pae_c_NRVA {
					local lab_`var' : var lab `var'
					lab var `var' "`var' (capped)"
				}
			}
		
		* Local for variables to do stats		
			ds `vars_`module''
			loc module_roster `r(varlist)'
		
			tempfile `dataset_`module''
			save	``dataset_`module'''
		
		* Create table
			levelsof `item_`module'', local(item_type_`module')
			
			di "`item_type'"
		
			foreach item of local item_type_`module' {
				use ``dataset_`module''', clear
				local lab_item : label `label_v_`module'' `item'	
				keep if `item_`module'' == `item'
			
				foreach var of local module_roster {
					preserve
					loc	`var'_l: var lab `var' 
					di "`lab_item': ``var'_l'"
					gen count = !mi(`var')
					collapse (sum) N = count (mean) mean = `var' (min) min = `var' (max) max = `var' (median) median = `var' (p90) p90 = `var' (p95) p95 = `var'
					scalar rank = rank + 1
					qui gen rank  = rank
					qui gen var  = "`var'"
					qui gen label = "`lab_item': ``var'_l'"
					if ("`var'" != "consumed" & "`module'" == "food") | ("`var'" != "c12" & "`module'" == "nonfood") {
						qui append using `stats_`item'_`module''
					}
					tempfile stats_`item'_`module'
					qui save `stats_`item'_`module'', replace
					restore
				}
				 
			}
		}
			
*------------------*
* Food consumption *
*------------------*
	use `stats_1_food', clear
	foreach item of local item_type_food {
		di  "`item'"
		if "`item'" != "1" {
			qui append using `stats_`item'_food'
			}	
		}
	qui save `stats_food', replace
	
			
				
	* Export table 
		use `stats_food', clear
		sort rank
		order var label 
		drop rank
		
		* Labels
			lab var var "Variable"
			lab var label "Question"
			lab var N "N"
			lab var mean "Mean"
			lab var min "Min"
			lab var max "Max"
			lab var median "Median"
			lab var p90 "p90"
			lab var p95 "p95"
		
		export excel using "${consump_desc_stats_fl1}",  sheetreplace  firstrow(varlabels) 	sheet("Food consumption")
	
*----------------------*
* Non-food consumption *
*----------------------*

	use `stats_1_nonfood', clear
	foreach item of local item_type_nonfood {
		if "`item'" != "1" {
			qui append using `stats_`item'_nonfood'
			}	
		}
	qui save `stats_nonfood', replace
			
				
	* Export table 
		use `stats_nonfood', clear
		sort rank
		order var label 
		drop rank
		
		* Labels
			lab var var "Variable"
			lab var label "Question"
			lab var N "N"
			lab var mean "Mean"
			lab var min "Min"
			lab var max "Max"
			lab var median "Median"
			lab var p90 "p90"
			lab var p95 "p95"
		
		export excel using "${consump_desc_stats_fl1}",  sheetreplace  firstrow(varlabels) 	sheet("Non-food consumption")
	
