/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Jan 23, 2019
Last udpate on: Jan 23, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Descriptive stats for raw and clean follow-up data

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
		gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		gl members_who_left_fl1 	"${TUP_DB}/Followup_1/DataSets/Intermediate/members_who_left_fl1.dta"
		gl current_roster_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1.dta"
		gl crops_fl1		 		"${TUP_DB}/Followup_1/DataSets/Intermediate/crops_fl1.dta"
		gl businesses_fl1	 		"${TUP_DB}/Followup_1/DataSets/Intermediate/businesses_fl1.dta"
		gl productive_act_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/productive_act_fl1.dta"
		gl k5_1_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/k5_1_fl1.dta"
		gl livestock_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_fl1.dta"
		gl animal_products_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/animal_products_fl1.dta"
		gl TUP_livestock_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_livestock_fl1.dta"
		gl TUP_sick_livestock_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_sick_livestock_fl1.dta"
		gl TUP_sold_livestock_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_sold_livestock_fl1.dta"
		gl TUP_dead_livestock_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_dead_livestock_fl1.dta"
		gl TUP_animal_products_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_animal_products_fl1.dta"
		gl consumption_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/consumption_fl1.dta"
		gl nonfood_consumption_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/nonfood_consumption_fl1.dta"
		gl other_assets_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/other_assets_fl1.dta"
		gl loans_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/loans_fl1.dta"
		gl given_transfers_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/given_transfers_fl1.dta"
		gl received_transfers_fl1 	"${TUP_DB}/Followup_1/DataSets/Intermediate/received_transfers_fl1.dta"
		gl shocks_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/shocks_fl1.dta"
		gl mobile_phone_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/mobile_phone_fl1.dta"
		gl productive_act_m_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/productive_act_m_fl1.dta"
		
* Outputs
	gl desc_stats_fl1			"${TUP_DB}/Followup_1/Output/Final/desc_stats_fl1.xlsx"

	
********************************************************************************
	** Part 1: Prepare dataset
********************************************************************************


*-------------*
* MAIN SURVEY *
*-------------*

	use "${all_HH_nopii_fl1}", clear

	* Intro
		loc intro_mult a9 a9_m a10 a10_m
		
		foreach var of local intro_mult {
			tab `var', gen(`var'_)
		}

		ds a8 a9 a9_1 a8_m a9_m a10 a10_1 a10_2 a10_3 a10_4 a10_5 a10_m a10_m_1 a10_m_2 a10_m_3 a10_m_4 a10_m_5 ///
			consent_svy consent_svy_m consent_phone a13 b3 // including b3 here
			 
		loc intro `r(varlist)'

	* Module K

		ds k22 k36 k37 k38 k41 k14 
		loc module_k `r(varlist)'
		
	* Module R
		ds r80 r81 r13
		loc module_r `r(varlist)'
		
	* Module C
		loc c_mult c14_2 c14_4 c14_6
		
		foreach var of local c_mult {
			tab `var', gen(`var'_)
		}
		
		ds c1 c2 c14_1 c14_2 c14_2_* c14_3 c14_4 c14_4_* c14_5 c14_6 c14_6_* c14_7 c12_* c13_*
		loc module_c `r(varlist)'
		
	* Module E	
		
		loc e_mult e1 e4 e5 e6 e7 e9 e20 e8 
		
		foreach var of local e_mult {
			tab `var', gen(`var'__)
		}
		
		ds e1 e1__* e2 e3 e4 e4__* e5 e5__* e6 e6__* e7 e7__* e9 e9__* e20__* e8 e8__* e10 e11 
		loc module_e `r(varlist)'
		
	* Module F

		loc f_mult f1 f2 f3  f20 f21 f22 
		
		foreach var of local f_mult {
			tab `var', gen(`var'__)
		}
		
		ds f1 f1__* f2 f2__* f3 f3__* f3_a_* f6 f7 f8_1-f8__99 f9_1-f9__99 f10 f11 f12_1-f12__99 ///
			f13_1-f13__99 f4_1-f4__99 f14 f14_b f15_a f15_* f16_* f17 f18 f19_1-f19__98 ///
			f20 f20__* f21 f21__* f22 f22__*
		loc module_f `r(varlist)'
		
	* Module H
		
		loc h_mult h1 h2 h3 h4 h5 h6 h7 h8 h9 h10 h11 h12 h13 h14 h28 h31 h24
		
		foreach var of local h_mult {
			tab `var', gen(`var'_)
		}

		ds h1 h1_* h2 h2_* h3 h3_* h4 h4_* h5 h5_* h6 h6_* h7 h7_* h8 h8_* h9 h9_* h10 h10_* h11 h11_* h12 h12_* h13 h13_* h14 h14_* h28 h28_* h31 h31_* h24 h24_* h30
		loc module_h `r(varlist)'	
		
	* Module I
		loc i_mult i7 i10 i11 i12 i16 i23 i25 i26 i27 i28_a i28_b i28_c i28_d i28_e i28_f i28_g i28_h i28_i i28_j i34 i35 i37 i38 i39 i43 i44 i45 i46 i47
		
		foreach var of local i_mult {
			tab `var', gen(`var'__)
			tab `var'_m, gen(`var'_m__)
		}	
		
		ds 	i5 i48 i49 i7 i7__* i10 i10__* i11 i11__* i12 i12__* i16 i16__* i23 i23__* i25 i25__* ///
			i26 i26__* i27 i27__* i28_a i28_a__* i28_b i28_b__* i28_c i28_c__* i28_d i28_d__* ///
			i28_e i28_e__* i28_f i28_f__* i28_g i28_g__* i28_h i28_h__* i28_i i28_i__* i28_j i28_j__* ///
			i34 i34__* i35 i35__* i37 i37__* i38 i38__* i39 i39__* i43 i43__* i44__* i45 i45__* i46 i46__* i47 i47__* ///	
			i5_m i48_m i49_m i7_m i7_m__* i10_m i10_m__* i11_m i11_m__* i12_m i12_m__* i16_m i16_m__* i23_m i23_m__* i25_m i25_m__* ///
			i26_m i26_m__* i27_m i27_m__* i28_a_m i28_a_m__* i28_b_m i28_b_m__* i28_c_m i28_c_m__* i28_d_m i28_d_m__* ///
			i28_e_m i28_e_m__* i28_f_m i28_f_m__* i28_g_m i28_g_m__* i28_h_m i28_h_m__* i28_i_m i28_i_m__* i28_j_m i28_j_m__* ///
			i34_m i34_m__* i35_m i35_m__* i37_m i37_m__* i38_m i38_m__* i39_m i39_m__* i43_m i43_m__* i44_m__* i45_m i45_m__* i46_m i46_m__* i47_m i47_m__*
		loc module_i `r(varlist)'	
		
	* Module U
		loc u_mult u1 u2 u3 u4 u5 u14 u15 u6 u7 u8 u9a u9b u10a u11a u12a u13a u10b u11b u12b u13b
		
		foreach var of local u_mult {
			tab `var', gen(`var'__)
			tab `var'_m, gen(`var'_m__)
		}	
		
		ds u1 u1__* u2 u2__* u3 u3__* u4 u4__* u5 u5__* u14 u14__* u15 u15__* u6 u6__* u7 u7__* ///
			u8 u8__* u9a u9a__* u9b u9b__* u10a u10a__* u11a u11a__* u12a u12a__* u13a u13a__* ///
			u10b u10b__* u11b u11b__* u12b u12b__* u13b u13b__* ///
			u1_m u1_m__* u2_m u2_m__* u3_m u3_m__* u4_m u4_m__* u5_m u5_m__* u14_m u14_m__* u15_m u15_m__* u6_m u6_m__* u7_m u7_m__* ///
			u8_m u8_m__* u9a_m u9a_m__* u9b_m u9b_m__* u10a_m u10a_m__* u11a_m u11a_m__* u12a_m u12a_m__* u13a_m u13a_m__* ///
			u10b_m u10b_m__* u11b_m u11b_m__* u12b_m u12b_m__* u13b_m u13b_m__* 
		loc module_u `r(varlist)'	
		
	* Module N

		ds n1 n2	
		loc module_n `r(varlist)'	
		
	* Module S
		loc s_mult s9 s24
		
		foreach var of local s_mult {
			tab `var', gen(`var'__)
		}
	 
		ds s1 s4 s5 s6 s7 s8_1-s8__98 s9 s9__* s10 s11 s21 s12 s13 s22 s23 s24 s24__* s14 s15
		loc module_s `r(varlist)'	
		
	* Module T
		loc t_mult t3 t4 t5a t5b t5c t5d t5e t5f t6 t11

		foreach var of local t_mult {
			tab `var', gen(`var'__)
			tab `var'_m, gen(`var'_m__)
		}	
		
		ds t1 t2_1 t2_2 t2__99 t3 t3__* t4 t4__* t5a t5a__* t5b t5b__* t5c t5c__* t5d t5d__* ///
			t5e t5e__* t5f t5f__* t6 t6__* t7 t8 t9 t10 t11 t11__* ///
			t1_m t2_1_m t2_2_m t2__99_m t3_m t3_m__* t4_m t4_m__* t5a_m t5a_m__* t5b_m t5b_m__* t5c_m t5c_m__* t5d_m t5d_m__* ///
			t5e_m t5e_m__* t5f_m t5f_m__* t6_m t6_m__* t7_m t8_m t9_m t10_m t11_m t11_m__*
		loc module_t `r(varlist)'	
		
	* Module J
		loc j_mult j6 j7 j8 j9 j10 j11 j12 j13 j14 j15 j16 j17 j18 j19 j20 j21 j22 j23 j24 j25 j26 j1 j2
		
		foreach var of local j_mult {
			tab `var', gen(`var'__)
			tab `var'_m, gen(`var'_m__)
		}
		
		ds j6 j6__* j7 j7__* j8 j8__* j9 j9__* j10 j10__* j11 j11__* j12 j12__* j13 j13__* ///
			j14 j14__* j15 j15__* j16 j16__* j17 j17__* j18 j18__* j19 j19__* j20 j20__* ///
			j21 j21__* j22 j22__* j23 j23__* j24 j24__* j25 j25__* j26 j26__* j1 j1__* ///
			j2 j2__* j3 j5 ///
			j6_m j6_m__* j7_m j7_m__* j8_m j8_m__* j9_m j9_m__* j10_m j10_m__* j11_m j11_m__* j12_m j12_m__* j13_m j13_m__* ///
			j14_m j14_m__* j15_m j15_m__* j16_m j16_m__* j17_m j17_m__* j18_m j18_m__* j19_m j19_m__* j20_m j20_m__* ///
			j21_m j21_m__* j22_m j22_m__* j23_m j23_m__* j24_m j24_m__* j25_m j25_m__* j26_m j26_m__* j1_m j1_m__* ///
			j2_m j2_m__* j3_m j5_m
		loc module_j `r(varlist)'	
		
	* Module M 
		loc m_mult m29 m30 m31_a
		
		foreach var of local m_mult {
			tab `var', gen(`var'__)
		}
		
		ds m37 m21_1-m21__99 m23 m24_1-m24__97 m22_0-m22__99 m1 m1_a m5 m6_1-m6__99 ///
			m6_a_1-m6_a__99 m10 m11_1-m11__99 m12_1-m12__98 m12_h_1-m12_h__98 ///
			m12_other_1-m12_other__98 m13_1-m13__99 m16 m17_1-m17__99 m19 m20 m25_y m26_y ///
			m27_0-m27__97 m28_0-m28__97 m29 m29__* m30 m30__* m33 m34_y m35 m36 m31 ///
			m31_a m31_a__* m31_a_a_1-m31_a_a__98 m32_0-m32__98
		loc module_m `r(varlist)'		

	* Module D
		loc d_mult d6 d13
		
		foreach var of local d_mult {
			tab `var', gen(`var'__)
		}
		
		ds d6 d6__* d13 d13__*
		loc module_d `r(varlist)'		
			
	* Module G		
		loc g_mult o1_b
		
		foreach var of local g_mult {
			tab `var', gen(`var'__)
		}
		
		ds o1 o1_a o1_b o1_b__* o2 o3_0-o3__99
		loc module_g `r(varlist)'	
		
	* Module v
		ds v1
		loc module_v `r(varlist)'		
		
	* Module saliva 
		ds consent_saliva a13_saliva_1-a13_saliva__99 a18 a19_1-a19_6 ///
			consent_saliva_m a13_saliva_1_m-a13_saliva__99_m a18_m a19_1_m-a19_6_m
		loc module_saliva `r(varlist)'		
		
	* Module do
		loc do_mult e12 e14 e15 e16 r68 r71 r72 r79
		
		foreach var of local do_mult {
			tab `var', gen(`var'__)
		}
		
		ds ec e12 e12__* e13 e14 e14__* e15 e15__* e16 e16__* r68 r68__* r69 r70 r71 r71__* ///
			r72 r72__* r77 r78 r79 r79__*
		loc module_do `r(varlist)'		
			
	* Module q
		loc q_mult a11 q1 q6
		
		foreach var of local q_mult {
			tab `var', gen(`var'__)
			tab `var'_m, gen(`var'_m__)
		}
		
		ds a11 a11__* q1 q1__* q4 q5_1-q5_30 q6 q6__* ///
			a11_m a11_m__* q1_m q1_m__* q4_m q5_1_m-q5_30_m q6_m q6_m__*
		loc module_q `r(varlist)'		
				
*------------------------------*
* EXPORT TABLE FOR MAIN SURVEY *
*------------------------------*
	
	local desc_vars `intro' `module_k'  `module_r'  `module_c' `module_e' `module_f' `module_h' `module_i' `module_u'  `module_n' `module_s' `module_t' `module_j'  `module_m' `module_d' `module_g' `module_v' `module_saliva'  `module_do' `module_q' 

	tempfile stats
	scalar rank = 0
	
	foreach var of local desc_vars { 
		di "`var'" 
		preserve
			loc	`var'_l: var lab `var' 
			gen count = !mi(`var')
			collapse (sum) N = count (mean) mean = `var' (min) min = `var' (max) max = `var' (median) median = `var' (p90) p90 = `var' (p95) p95 = `var'
			scalar rank = rank + 1
			qui gen rank  = rank
			qui gen var  = "`var'"
			qui gen label = "``var'_l'"
			if "`var'" != "a8" {
				qui append using `stats'
			}
			qui save `stats', replace
		restore
	}
	
	use `stats', clear
	sort rank
	order var label 
	drop rank
	
	* Labels
		lab var var "Variable"
		lab var label "Question"
		lab var N "N"
		lab var mean "Mean"
		lab var min "Min"
		lab var max "Max"
		lab var median "Median"
		lab var p90 "p90"
		lab var p95 "p95"
	
	export excel using "${desc_stats_fl1}",  sheetreplace  firstrow(varlabels) sheet("Main data")
	
*-------------*
* ROSTER DATA *
*-------------*
	
	*-------------------------------------------*
	* Rosters where type of item doesn't matter *
	*-------------------------------------------*
	
	
	* Locals for dataset
		local dataset_b		current_roster_fl1
		local dataset_loans	loans_fl1
		local dataset_phone	mobile_phone_fl1
		
	* Locals for variables of select_one
		local mult_b 		b5 b5_ladyhh b6 b28 b12 b16 b13 b15_b	
		local mult_loans	m2
		local mult_phone	v4 v5
		
	* Locals for variables to do stats
		local vars_b		b5 b5__* b5_ladyhh b5_ladyhh__* b6 b6__* b8 b26 b27_1-b27__97 b28 b28__* b12 b12__* b16 b16__* b13 b13__* b15a b18 b19 b15_b b15_b__*		
		local vars_loans	m1_a m2 m2__* m3_1-m3__97
		local vars_phone	v4 v4__* v5 v5__*
				
			
		tempfile stats
		scalar rank = 0			
			
		foreach module in b loans phone { // 
		
		* Open dataset
			use "${`dataset_`module''}", clear
		
			loc roster_mult `mult_`module''
			
			foreach var of local roster_mult {
				tab `var', gen(`var'__)
			}
				
		* Local for variables to do stats		
			ds `vars_`module''
			loc module_roster `r(varlist)'
	
		* Create table
			foreach var of local module_roster  { 
				di "`var'" 
				preserve
					loc	`var'_l: var lab `var' 
					gen count = !mi(`var')
					collapse (sum) N = count (mean) mean = `var' (min) min = `var' (max) max = `var' (median) median = `var' (p90) p90 = `var' (p95) p95 = `var'
					scalar rank = rank + 1
					qui gen rank  = rank
					qui gen var  = "`var'"
					qui gen label = "``var'_l'"
					if "`var'" != "b5" {
						qui append using `stats'
					}
					qui save `stats', replace
				restore
			}
		}
		
	*----------------------------------------------*
	* Remaining rosters where type of item matters *
	*----------------------------------------------*
	
	* i.e. consumption of rice, different from consumption of oil
	* 		qty of cow, different from chicken, etc
	
	* Locals for dataset
		local dataset_c 			consumption_fl1
		local dataset_crops 		crops_fl1
		local dataset_biz   		businesses_fl1
		local dataset_lstock 	  	livestock_fl1
		local dataset_prod			animal_products_fl1
		local dataset_act			productive_act_fl1
		local dataset_asset			other_assets_fl1
		local dataset_given_t		given_transfers_fl1
		local dataset_received_t	received_transfers_fl1
		local dataset_shocks		shocks_fl1
		
	* Locals for variables of select_one
		local mult_c 			consumed_source
		local mult_crops 		k15 
		local mult_biz	 		k29 k31 k35
		local mult_lstock		k6
		local mult_prod			k9
		local mult_act			k30_3
		local mult_asset		l4
		local mult_given_t		d1
		local mult_received_t	d8
		local mult_shocks		g1
		
	* Locals for variables to do stats
		local vars_c 			consumed consumed_days consumed_qty consumed_source consumed_source__*
		local vars_crops 		k16 k17 k19 k20 k21 k40
		local vars_biz 			k23_a k24_3-k24_0 k26_y k27 k28 k29 k29__* k31__* k32 k33 k43 k34 k35 k35__* k25
		local vars_lstock		k6 k7 k8	
		local vars_prod			k9 k10 k12 k13
		local vars_act			k30 k30_3 k30_3_hr k30_1 k30_2
		local vars_asset		l1 l2 l3 l4 l4__* l5
		local vars_given_t 		d1 d2_1 d2 d3_1-d3__99
		local vars_received_t	d8 d9 d10_1-d10__99
		local vars_shocks		g1 g2a g2_0-g2__98 
		
	* Local of variable identify item/product/crop/etc
		local item_c 			item
		local item_crops 		crop
		local item_biz	 		business
		local item_lstock		livestock
		local item_prod			product
		local item_act			activity
		local item_asset		asset
		local item_given_t		item
		local item_received_t	item
		local item_shocks		shock
		
	* Local for label value of item
		local label_v_c 			item_l
		local label_v_crops 		crop_l
		local label_v_biz			business_l
		local label_v_lstock		livestock_l
		local label_v_prod			product_l
		local label_v_act			activity_l
		local label_v_asset			asset_l
		local label_v_given_t		item_l
		local label_v_received_t	item_l
		local label_v_shocks		shock_l
	
	foreach module in c crops biz lstock prod act asset given_t received_t shocks { //  
		* Open dataset and create dummies for select_one variables
			use "${`dataset_`module''}", clear
			
			loc mult `mult_`module''
				
			foreach var of local mult {
				tab `var', gen(`var'__)
			}
			
		* Local for variables to do stats		
			ds `vars_`module''
			loc module_roster `r(varlist)'
		
			tempfile `dataset_`module''
			save	``dataset_`module'''
		
		* Create table
			levelsof `item_`module'', local(item_type)
		
			foreach item of local item_type {
				use ``dataset_`module''', clear
				local lab_item : label `label_v_`module'' `item'	
				keep if `item_`module'' == `item'
			
				foreach var of local module_roster {
					preserve
					loc	`var'_l: var lab `var' 
					di "`lab_item': ``var'_l'"
					gen count = !mi(`var')
					collapse (sum) N = count (mean) mean = `var' (min) min = `var' (max) max = `var' (median) median = `var' (p90) p90 = `var' (p95) p95 = `var'
					scalar rank = rank + 1
					qui gen rank  = rank
					qui gen var  = "`var'"
					qui gen label = "`lab_item': ``var'_l'"
					qui append using `stats'
					qui save `stats', replace
					restore
				}
			}
		}
		
	* Export table 
		use `stats', clear
		sort rank
		order var label 
		drop rank
		
		* Labels
			lab var var "Variable"
			lab var label "Question"
			lab var N "N"
			lab var mean "Mean"
			lab var min "Min"
			lab var max "Max"
			lab var median "Median"
			lab var p90 "p90"
			lab var p95 "p95"
		
		export excel using "${desc_stats_fl1}",  sheetreplace  firstrow(varlabels) 	sheet(Rosters)
	
