/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	July 31, 2019
Last udpate on: July 31, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	*Data for analysis dataset "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	global 		data_for_analysis	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	gl profile_info 					"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	
	/*global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"
*/
		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	use "${data_for_analysis}", clear
	keep if ultra_poor == 1

*--------------------*
* Economic inclusion *
*--------------------*
	
	loc econ_inclusion_svy "i48 i49"

	foreach var of local econ_inclusion_svy {
		local `var'_ac_l : variable label `var'
		gen 	`var'_ac=`var'
		recode 	`var'_ac (1=10) (2=9) (3=8) (4=7) (5=6) (6=5) (7=4) (8=3) (9=2) (10=1)
		lab var `var'_ac "``var'_ac_l'' (negatively coded)"
	}

	
	loc econ_inclusion_vars "i48_ac i49_ac"	
	
*----------------*
* Human Security *
*----------------*	
	
	
	* Number of preventive measures
		egen 	num_preventive = rowtotal(s8_1 s8_2 s8_3 s8_4 s8_5 s8_6 s8_7 s8_8 s8_9 s8__97)
		replace num_preventive = . if s8__98 == 1

	*loc human_security_vars "s4 s5 s6 s7 num_preventive s9 s14 s15"
	loc human_security_vars "s4 s5 s6 s7 num_preventive s9"
	*loc human_security_vars "s14 s15"
	
*-----------------*
* Social cohesion *
*-----------------*	

	loc social_coh_svy "s10 s11 s21"
	
	foreach var of local social_coh_svy {
		local `var'_ac_l : variable label `var'
		gen 	`var'_ac=`var'
		recode 	`var'_ac (1=0) (0=1)
		lab var `var'_ac "``var'_ac_l'' (negatively coded)"
	}
	
	loc social_coh_vars "s10_ac s11_ac s21_ac"
	
	
*----------------*
* Create indexes *
*----------------*	

	* Control dummy
	gen 	control = treatment==0
	replace control = . if mi(treatment)
	lab var control "HH is part of control group"


	loc econ_inclusion_l	"Economic Inclusion"
	loc human_security_l	"Human Security"
	loc social_coh_l		"Social Cohesion"

	
	gl all "econ_inclusion human_security social_coh"

	foreach index in $all {
		display "`index'"
		des ``index'_vars'
		egen index_sdC_`index' = weightave(``index'_vars'), normby(control)
		lab var index_sdC_`index' "``index'_l' Index sd(Control)"	
	}	

*---------*
* Density *
*---------*

	foreach var in $all {
		reg index_sdC_`var' treatment i.PRA_lottery, r
	}
	
	foreach var in $all {	
		twoway 	(kdensity index_sdC_`var' if treatment == 0, color(gs10)) ///
			(kdensity index_sdC_`var' if treatment == 1, color(emerald)), ///
			legend(order(1 "Control" 2 "Treatment")) ///
			xtitle(Index) ///
			ytitle(Density) title(``var'_l') ///
			bgcolor (white) graphregion(color(white)) name(`var', replace)
			
	}
