/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	February 20, 2020

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Analysis of various variables on time used and loan at different levels of the household . 


CONTENT:		Part 0 - Create globals for directories and files 

INPUTS: 		"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_hh_fl1.dta"
				
OUTPUTS: 

Note:
				
				
*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

	clear all
	set more off
	set maxvar 20000
	global date = word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3)

	* Input files
	global weights_village 					"${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights_CWR_villagelevel.dta"
	global weights_CWR 						"${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights_CWR.dta"
	global data_for_analysis				"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	global data_for_analysis_bl				"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	global time_activities_ses 				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
	global roster_bl_balance 				"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"
	global schooling_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"	
	global mobile_phone_ownership_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/mobile_phone_ownership_fl1.dta"
	global wellbeing_index_gender 			"${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_gender_fl1.dta"	
	global psy_bl_gender 					"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_gender_bl.dta"	
	global schooling_bl						"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"
	global labor_bl 						"${TUP_DB}/Baseline/DataSets/Intermediate/labor_bl.dta"	
	global psy_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta"
	
	global	output						"${fl1_out}/Raw"	
	
	global controls						i.PRA_lottery
	
	*List of variable to analyse
		*table 1 
	global hh_general_desc		hhhead_female illiteracy_pf illiteracy_pm girl_inschool_hh boy_inschool_hh
	global consump_assets		exp_tot_m_pc_c_ppp
	global consump_assets3 		below_pov_af savings_dummy loan_dummy own_Land_yes own_mobile_phone
	global psych_bl	 			i27_f cesd_f_md i27_m  cesd_m_md
	global panelb				employment_pf employment_pm lstock_yes_cow lstock_yes_goat lstock_yes_chicken crop_yes biz_yes	

		*table 2
	global  var_table1	lit_rate Time Psy School
	global lit_rate 	literacy
	global Time  		did_mkt did_Nmkt_HHChores
	global Psy  		psy_index_ses_fC_bl satisf_score hap_score cesd_ts  rses_score cohen_score
	global School 		child_inschool_hh
	
		*Composition of Household
	global hh_comp	   		hh_only_pf hh_only_pm pm_pf_hh tot_oth_f_adult_fl1 tot_oth_m_adult_fl1 tot_kidf_6_14_fl1 tot_kidm_6_14_fl1 tot_kidf_15_17_fl1 tot_kidm_15_17_fl1 	
		*Activities done by each member
	global activities   	labor_nohh  HHChores 
		*Children in school
	global school 			 child_inschool_hh days_missed_school_hh
		*Psychological Indices
	global psychological     psy_indexC_sdfC_fl1   
		*Psychological Scores
	global psychological2    lcortisol_clean_inv satisf_score  hap_score cesd_ts cesd_md  rses_score cohen_score 	
		
	
	*Globals for the table
	
*****Same for all tables
	global PanelA "Primary Members"
	global PanelB  "Other Adults"
	global PanelC  "Children 6-14"
	global PanelD  "Children 15-17"
	
	global title_1  "Treatment"
	global title_2 	"Treatment x Male"
	global title_3  "Male"	
	
	
*****Different for the different tables
*Baseline differences 
	global Time_title 		"Time Use"
	global Psy_title  		"Psychological Well-being"
	global School_title  	"Children School Enrollment"	
	global School_title_1  	"Children aged 6-14"
	global School_title_2  	"Children aged 15-18"

*time use	
	global Act_C_1 "All Market \\[-1.0ex]Work"
	global Act_C_2 "Household \\[-1.0ex]Chores"
	global Act_C_3 "All Market \\[-1.0ex]Work"
	global Act_C_4 "Household \\[-1.0ex]Chores"

	
*School
	global School_C_1 "School \\[-1.0ex]Enrollment"
	global School_C_2 "School \\[-1.0ex]Absenteeism"	
	
*Psy	
	global Psy_C_1 "Psychological \\[-1.0ex]Well-being \\[-1.0ex]Index"
	global Psy_C_2 "Log \\[-1.0ex]Cortisol \\[-1.0ex](with Controls) \\[-1.0ex](Inverted)"
	global Psy_C_3 "Life \\[-1.0ex]Satisfaction \\[-1.0ex]Index"
	global Psy_C_4 "Happiness \\[-1.0ex]Index"
	global Psy_C_5 "Depression \\[-1.0ex]Index \\[-1.0ex](Inverted)"
	global Psy_C_6 "Self-esteem \\[-1.0ex]Index"
	global Psy_C_7 "Stress \\[-1.0ex]Index \\[-1.0ex](Inverted)"
	
	global Psy2_C_1 "Log \\[-1.0ex]Cortisol\\[-1.0ex](with Controls) \\[-1.0ex](Inverted)"
	global Psy2_C_2 "Life \\[-1.0ex]Satisfaction \\[-1.0ex]Score \\[-1.0ex](Max 10)"
	global Psy2_C_3 "Happiness \\[-1.0ex]Score \\[-1.0ex](Max 4)"
	global Psy2_C_4 "Depression \\[-1.0ex]Score \\[-1.0ex](Max 21)"
	global Psy2_C_5 "Major \\[-1.0ex]Depression "
	global Psy2_C_6 "Self-esteem \\[-1.0ex]Score \\[-1.0ex](Max 30)"
	global Psy2_C_7 "Stress \\[-1.0ex]Score \\[-1.0ex](Max 20) \\[-1.0ex](Inverted)"
	
	*Notes
	#delimit ;
	global note_bl_check_compo "The age categories are based on the age household member would have at endline, which happened two years and a half after baseline.
								The number of adults in household is different in baseline and in endline. The reason is that a number of adults left the household between these two periods.
								199 adult women left the household, the majority of who got married (57\%). 143 adult men moved away from the household, with 48\% moving for work and 10\% following their wedding." ;
	#delimit cr
	
	*Program to save the coefficients
*Program for the do file
cap prog drop coeff_treat //clearing any program that might exist under that name. Always start with that line
	prog def coeff_treat

args name_coeff name_var 

local mean = `r(mean)'
if `mean' >= 0 {
	global meanpos = `mean'
}
if `mean' < 0 {
	global meanpos = -`mean'
}

local test = 2
local sd = `r(sd)'
	global `name_coeff'm0 :  di %10.3fc `r(mean)'
	global `name_coeff's0 :  di %10.3fc `r(sd)'
global `name_coeff't :  di %10.3fc _b[`name_var']
global `name_coeff'tse :  di %10.3fc _se[`name_var']

*Impact in percentage:
 	global `name_coeff'imp1 =   _b[`name_var'] /$meanpos * 100
if ${`name_coeff'imp1} >= 10 {
	global `name_coeff'imp1 :  di %2.0f ${`name_coeff'imp1}	
}
if ${`name_coeff'imp1} < 10 {
	global `name_coeff'imp1 :  di %1.0f ${`name_coeff'imp1}	
}

*Impact in standard deviation: 
global `name_coeff'imp2 = _b[`name_var']/`sd'	
global `name_coeff'imp2 : di %10.3fc ${`name_coeff'imp2}

*Other locals
global R_`name_coeff' :  di %10.3f e(r2)
global N_`name_coeff' = e(N)

*Pvalues
global `name_coeff'p :  di %10.3f (2 * ttail(e(df_r), abs(_b[`name_var']/_se[`name_var'])))
global `name_coeff't = "$" + "${`name_coeff't}" + "$"

*Adding the star
	*disp "`i'"
		if  ${`name_coeff'p} <= 0.1 {
		global `name_coeff't = "${`name_coeff't}" + "*"			
			if ${`name_coeff'p} <= 0.05 {
			global `name_coeff't = "${`name_coeff't}" + "*"
				if ${`name_coeff'p} <= 0.01 {
				global `name_coeff't = "${`name_coeff't}" + "*"				
			}				
		}
	}

*Putting all numbers in string to have them in math mode in Latex
global `name_coeff'm0 = "$" + "${`name_coeff'm0}" + "$"
global `name_coeff's0 = "$" + "${`name_coeff's0}" + "$"
global `name_coeff'tse = "$" + "${`name_coeff'tse}" + "$"
global `name_coeff'p = "$" + "${`name_coeff'p}" + "$"
global N_`name_coeff' = "$" + "${N_`name_coeff'}" + "$"
global R_`name_coeff' = "$" + "${R_`name_coeff'}" + "$"
global `name_coeff'imp1 = "$" + "${`name_coeff'imp1}" + "$"
global `name_coeff'imp2 = "$" + "${`name_coeff'imp2}" + "$"
	end //

	
****************Program 2****************************************
	cap prog drop stat_estim
	prog def stat_estim
	args name_var var N_dec

local dec = 3
if "`N_dec'" != "3" & "`N_dec'"!= "" {
local dec = 1
}
	* Coefficient
	global `name_var' :  di %4.`dec'f _b[`var']
							
	* Standard error
	global `name_var'sd :  di %4.`dec'f _se[`var']
							
	* P-value
	global `name_var'p: di %4.3f (2 * ttail(e(df_r), abs(_b[`var']/_se[`var'])))
	
	*Other locals
	global `name_var'_R :  di %10.3f e(r2)
	global `name_var'_N = e(N)

	global `name_var'_number = ${`name_var'}	
	global `name_var' = "$" + "${`name_var'}" + "$"
*Adding the star
	*disp "`i'"
		if  ${`name_var'p} <= 0.1 {
		global `name_var' = "${`name_var'}" + "*"			
			if ${`name_var'p} <= 0.05 {
			global `name_var' = "${`name_var'}" + "*"
				if ${`name_var'p} <= 0.01 {
				global `name_var' = "${`name_var'}" + "*"				
			}				
		}
	}	

		if  ${`name_var'p} > 0.1 {
		global `name_var' = "${`name_var'}" + "\hspace*{0.5cm}"			
			if ${`name_var'p} > 0.05 & ${`name_var'p} <=0.01 {
			global `name_var' = "${`name_var'}" + "\hspace*{0.34cm}"
				if ${`name_var'p} > 0.01 & ${`name_var'p} <=0.05 {
				global `name_var' = "${`name_var'}" + "\hspace*{0.167cm}"				
			}				
		}
	}

	if  ${`name_var'_number} >= 0 {
global `name_var' = "\hspace*{0.27cm}" + "${`name_var'}" 
		}
	
	global `name_var'p 	= "$" + "${`name_var'p}" + "$"
	global `name_var'sd = "$" + "${`name_var'sd}" + "$"
	global `name_var'_N = "$" + "${`name_var'_N}" + "$"
	global `name_var'_R = "$" + "${`name_var'_R}" + "$"
			end //
	
	
*****************Program 3 *Test of equality****************************************
	cap prog drop test_interaction //clearing any program that might exist under that name. Always start with that line

	prog def test_interaction
	args name_var  treatment indep_var_t
	
	*Test of equality
	test `treatment' + `indep_var_t'  = 0
	global `name_var'_test :  di %4.3f r(p)
	end //	
	

*****************Program 4 *Impact in SD and % when interaction ****************************************
	cap prog drop impact_interaction //clearing any program that might exist under that name. Always start with that line

	prog def impact_interaction
	args name_var  treatment indep_var_t indic //indic will be 1 if want to run the impact on treatment only, 2 if want to run on treatment + interaction term

	local mean = `r(mean)'
if `mean' >= 0 {
	global meanpos = `mean'
}
if `mean' < 0 {
	global meanpos = -`mean'
}

local sd = `r(sd)'
	
if `indic' == 1 {
	global `name_var'imp2_1 :  di %4.2f (_b[`treatment']) / `sd'
	global `name_var'imp1_1 =   (_b[`treatment']) /$meanpos * 100
			if ${`name_var'imp1_1} >= 10 {
				global `name_var'imp1_1 :  di %2.0f ${`name_var'imp1_1}
					}
			if ${`name_var'imp1_1} < 10 {
						global `name_var'imp1_1 :  di %1.0f ${`name_var'imp1_1}
					}
}	
if `indic' == 2 {					
	global `name_var'imp2_2 :  di %4.2f (_b[`treatment'] + _b[`indep_var_t']) / `sd'
	global `name_var'imp1_2 =   (_b[`treatment'] + _b[`indep_var_t']) /$meanpos * 100
			if ${`name_var'imp1_2} >= 10 {
				global `name_var'imp1_2 :  di %2.0f ${`name_var'imp1_2}
					}
			if ${`name_var'imp1_2} < 10 {
						global `name_var'imp1_2 :  di %1.0f ${`name_var'imp1_2}
					}
}
	end //	
	

	
	*Program to keep coefficient of means and diff / Make sure that indep is a dummy for the two groups
*Program for the do file
cap prog drop test_diff //clearing any program that might exist under that name. Always start with that line
	prog def test_diff

args name_coeff name_var  indep

	ttest `name_var'  , by(`indep') welch //Welch so that we don't assume equal variance
 
global `name_coeff'1   :  di %4.3f `r(mu_1)'
global `name_coeff'2   :  di %4.3f `r(mu_2)'


*Compute the diff
global `name_coeff'3   :  di %4.3f ${`name_coeff'1} - ${`name_coeff'2}
global `name_coeff'3_number = ${`name_coeff'3}

*Compute P value 
global `name_coeff'4 :  di %10.3f `r(p)'

*Adding the star to the difference
global `name_coeff'3 = "$" + "${`name_coeff'3}" + "$"
	*disp "`i'"
		if  ${`name_coeff'4} <= 0.1 {
		global `name_coeff'3 = "${`name_coeff'3}" + "*"			
			if ${`name_coeff'4} <= 0.05 {
			global `name_coeff'3 = "${`name_coeff'3}" + "*"
				if ${`name_coeff'4} <= 0.01 {
				global `name_coeff'3 = "${`name_coeff'3}" + "*"				
			}				
		}
	}

		if  ${`name_coeff'4} > 0.1 {
		global `name_coeff'3 = "${`name_coeff'3}" + "\hspace*{0.5cm}"			
			if ${`name_coeff'4} > 0.05 & ${`name_coeff'4} <=0.01 {
			global `name_coeff'3 = "${`name_coeff'3}" + "\hspace*{0.34cm}"
				if ${`name_coeff'4} > 0.01 & ${`name_coeff'4} <=0.05 {
				global `name_coeff'3 = "${`name_coeff'3}" + "\hspace*{0.167cm}"				
			}				
		}
	}

	if  ${`name_coeff'3_number} >= 0 {
global `name_coeff'3 = "\hspace*{0.27cm}" + "${`name_coeff'3}" 
		}
		
	end //	
	
	*Finally generating tables
	texdoc do		"${fl1_do}/Analysis/gender_withinHH_table_fl1.do", replace	// Creates a .tex document
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
