texdoc init "${output}/tables_additional_analysis_${date}.tex", replace hardcode nokeep

/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	February 24, 2019
Last udpate on: February 24, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Dynamic do file for the analysis of wellbeing Index



				INPUTS:     	* Final psychological well being dataset

						
OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge 
				
				* Github files: 


*******************************************************************************/


********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************


/***
\documentclass[10pt]{article}

\usepackage{amssymb,amsmath,amsfonts,eurosym,geometry,ulem,graphicx,caption,color,setspace,sectsty,footmisc,comment,caption,natbib,pdflscape,subfigure,array,hyperref}
\usepackage{textcomp}
\usepackage[utf8]{inputenc}
\usepackage{titlesec}
\usepackage[usenames,dvipsnames]{xcolor}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{longtable}
\usepackage{indentfirst}
\usepackage[justification=centering]{caption}
%For the tables
\setcounter{secnumdepth}{4}
\setcounter{tocdepth}{4}

\onehalfspacing
\newtheorem{theorem}{Theorem}
\newtheorem{corollary}[theorem]{Corollary}
\newtheorem{proposition}{Proposition}
\newenvironment{proof}[1][Proof]{\textbf{#1.} }{\ \rule{0.5em}{0.5em}}

\newtheorem{hyp}{Hypothesis}
\newtheorem{subhyp}{Hypothesis}[hyp]

\renewcommand{\thesubhyp}{\thehyp\alph{subhyp}}
\renewcommand{\thetable}{\Roman{table}}
\renewcommand{\thefigure}{\Roman{figure}}
\captionsetup{labelsep=newline}

\newcommand{\red}[1]{{\color{red} #1}}
\newcommand{\blue}[1]{{\color{blue} #1}}

\newcolumntype{L}[1]{>{\raggedright\let\newline\\arraybackslash\hspace{0pt}}m{#1}}
\newcolumntype{C}[1]{>{\centering\let\newline\\arraybackslash\hspace{0pt}}m{#1}}
\newcolumntype{R}[1]{>{\raggedleft\let\newline\\arraybackslash\hspace{0pt}}m{#1}}
\renewcommand{\thetable}{X\arabic{table}}
\geometry{left=1.0in,right=1.0in,top=1.0in,bottom=1.0in}

\begin{document}

\title{Extra analysis on Time Use}
\maketitle
\section{Main Tables}
***/


* Notes
	gl note_table1 "\footnotesize{\textit{Notes.} Panel A is constructed using baseline data and panel B using follow-up data for control ultra-poor households and non-UP households. School-age is 6 to 19 years old. Sampling weights based on the total population for each village is used to estimate the non-UP statistics. Our consumption estimate includes food (purchased, produced and received as a gift), personal and household items, education, health, household repairs, social expenses (weddings, funeral, religious expenses, and other ceremonies), and temptation goods and legal expenses. The Afghanistan national poverty line estimate excludes legal, health and social expenses, and household construction and repairs, and includes expenses in consumer durables and housing vs. our estimate. We report both for comparability with national poverty estimates. The poverty line threshold is AFN 2,064 (USD 30 and USD 112 PPP) per capita per month from the Afghanistan Living Conditions Survey (ALCS). The psychological well-being measures includes the Center for Epidemiologic Studies Depression (CES-D) 7-point scale (Radloff 1977) and the World Values Survey (WVS) questions on life satisfaction.  All monetary amounts are PPP-adjusted USD terms, set at 2018 prices using the Afghanistan CPI and PPP conversion factor from the IMF.}"


	
*---------------------------------------------*
* Table 1. Household Socioeconomic Conditions *
*---------------------------------------------*

	/***
	\begin{landscape}
	\begin{table}	
	\renewcommand{\arraystretch}{0.9}
	\captionof{table}{Household Socioeconomic Conditions by Wealth Group}
	\small
	\centering
	\begin{tabular}{@{\extracolsep{0pt}}p{8cm}ccp{0.2cm}cccccccc}
	 \hline \\[-1.8ex]
	 & \multicolumn{2}{c}{Ultra-poor} & & \multicolumn{2}{c}{Near UP} & & \multicolumn{2}{c}{Poor} & & \multicolumn{2}{c}{Better-off/Well-off}
	  \\ \\[-1.8ex]  \cline{2-3} \cline{5-6} \cline{8-9} \cline{11-12} \\[-1.8ex]
	 & \makecell{Mean} & SD & & \makecell{Mean} & SD & & \makecell{Mean} & SD & & \makecell{Mean} & SD\\    
	   & (1) & (2) & & (3)  & (4)  & & (5)  & (6)  & & (7)  & (8)  \\ \hline \\[-1.8ex]
	***/


	texdoc stlog, nolog

	* PANEL A
	use "${weights_village}", clear
	
	collapse (sum) total_CWR = total, by(WealthRankingCategory_v)
	egen total = sum(total_CWR)
	gen perc = total_CWR/total
	
	foreach category in 1 2 3 4 {
		sum perc if WealthRankingCategory_v == `category'
		global CWR_perc`category': di %10.3f `r(mean)'
	}
	
	tex  \textit{Share of Population in this Wealth Group} & \multicolumn{2}{c}{${CWR_perc1}} & & \multicolumn{2}{c}{${CWR_perc2}}  & & \multicolumn{2}{c}{${CWR_perc3}}  & & \multicolumn{2}{c}{${CWR_perc4}}  \\ \\[-1.8ex]	
	
	use "${data_for_analysis_bl}", clear
	merge 1:1 hhid using "${psy_bl}", keepus(i27_f i27_m cesd_f_md cesd_m_md) assert(3)
	lab var i27_m "Primary Man Happiness (1-4)"
	lab var i27_f "Primary Woman Happiness (1-4)"
	lab var cesd_m_md "Primary Man Is Depressed (7-CESD $\geq$ 8)"
	
	
	merge 1:1 hhid using "${weights_CWR}", assert(2 3) keep(3) nogen
		
	tex  \multicolumn{12}{@{} l}{\textbf{{Panel A: Household Characteristics, Assets and Psychological Well-being at Baseline}}}      \\ \hline \\[-1.8ex]

	tex  \textit{Household Characteristics}  & & & & &   & & & &  & &   \\

	foreach var in $hh_general_desc {
		global `var'_lab : variable label `var'
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 1 
		global `var'm1 :  di %10.3f `r(mean)'
		global `var's1 :  di %10.3f `r(sd)'
		global `var'N1 :  di %10.0fc 	`r(N)'

		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 2
		global `var'm2 :  di %10.3f `r(mean)'
		global `var's2 :  di %10.3f `r(sd)'
		global `var'N2 :  di %10.0fc 	`r(N)'
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 3 
		global `var'm3 :  di %10.3f `r(mean)'
		global `var's3 :  di %10.3f `r(sd)'
		global `var'N3 :  di %10.0fc 	`r(N)'	
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 4
		global `var'm4 :  di %10.3f `r(mean)'
		global `var's4 :  di %10.3f `r(sd)'
		global `var'N4 :  di %10.0fc 	`r(N)'

		tex \everypar{\hangindent=0.7cm\hangafter=0} ${`var'_lab} &  ${`var'm1} &  ${`var's1} & & ${`var'm2} &  ${`var's2} & & ${`var'm3} &  ${`var's3} & & ${`var'm4} &  ${`var's4} \\  \\[-1.8ex]
	}
	

	tex  \textit{Consumption and Assets}  & & & & &      \\
	
	foreach var in $consump_assets {

		global `var'_lab : variable label `var'
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 1 
		global `var'm1 :  di %10.3f `r(mean)'
		global `var's1 :  di %10.3f `r(sd)'
		global `var'N1 :  di %10.0fc 	`r(N)'

		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 2
		global `var'm2 :  di %10.3f `r(mean)'
		global `var's2 :  di %10.3f `r(sd)'
		global `var'N2 :  di %10.0fc 	`r(N)'
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 3 
		global `var'm3 :  di %10.3f `r(mean)'
		global `var's3 :  di %10.3f `r(sd)'
		global `var'N3 :  di %10.0fc 	`r(N)'	
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 4
		global `var'm4 :  di %10.3f `r(mean)'
		global `var's4 :  di %10.3f `r(sd)'
		global `var'N4 :  di %10.0fc 	`r(N)'

		tex \everypar{\hangindent=0.7cm\hangafter=0} ${`var'_lab} &  ${`var'm1} &  ${`var's1} & & ${`var'm2} &  ${`var's2} & & ${`var'm3} &  ${`var's3} & & ${`var'm4} &  ${`var's4} \\  \\[-1.8ex]
	}	
	
	foreach var in $consump_assets3 {
		global `var'_lab : variable label `var'
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 1 
		global `var'm1 :  di %10.3f `r(mean)'
		global `var's1 :  di %10.3f `r(sd)'
		global `var'N1 :  di %10.0fc 	`r(N)'

		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 2
		global `var'm2 :  di %10.3f `r(mean)'
		global `var's2 :  di %10.3f `r(sd)'
		global `var'N2 :  di %10.0fc 	`r(N)'
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 3 
		global `var'm3 :  di %10.3f `r(mean)'
		global `var's3 :  di %10.3f `r(sd)'
		global `var'N3 :  di %10.0fc 	`r(N)'	
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 4
		global `var'm4 :  di %10.3f `r(mean)'
		global `var's4 :  di %10.3f `r(sd)'
		global `var'N4 :  di %10.0fc 	`r(N)'

		tex \everypar{\hangindent=0.7cm\hangafter=0} ${`var'_lab} &  ${`var'm1} &  ${`var's1} & & ${`var'm2} &  ${`var's2} & & ${`var'm3} &  ${`var's3} & & ${`var'm4} &  ${`var's4} \\  \\[-1.8ex]
	}		
	

	tex  \textit{Psychological Well-being}   & & & &  &    \\

	
	foreach var in $psych_bl {
		global `var'_lab : variable label `var'
		global `var'_lab : variable label `var'
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 1 
		global `var'm1 :  di %10.3f `r(mean)'
		global `var's1 :  di %10.3f `r(sd)'
		global `var'N1 :  di %10.0fc 	`r(N)'

		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 2
		global `var'm2 :  di %10.3f `r(mean)'
		global `var's2 :  di %10.3f `r(sd)'
		global `var'N2 :  di %10.0fc 	`r(N)'
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 3 
		global `var'm3 :  di %10.3f `r(mean)'
		global `var's3 :  di %10.3f `r(sd)'
		global `var'N3 :  di %10.0fc 	`r(N)'	
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 4
		global `var'm4 :  di %10.3f `r(mean)'
		global `var's4 :  di %10.3f `r(sd)'
		global `var'N4 :  di %10.0fc 	`r(N)'
	
		if inlist("`var'", "cesd_m_md", "i27_m") {
		
				tex \everypar{\hangindent=0.7cm\hangafter=0} ${`var'_lab} &  ${`var'm1} &  ${`var's1} & & NA &  NA & & NA &  NA & & NA & NA \\  \\[-1.8ex]

		}
		else {
		tex \everypar{\hangindent=0.7cm\hangafter=0} ${`var'_lab} &  ${`var'm1} &  ${`var's1} & & ${`var'm2} &  ${`var's2} & & ${`var'm3} &  ${`var's3} & & ${`var'm4} &  ${`var's4} \\  \\[-1.8ex]
		}
	}	
	
	foreach category in 1 2 3 4 {
		count if WealthRankingCategory_v == `category'
		loc CWR_N`category' `r(N)'
	}
	

	tex Number of Sampled Households & \multicolumn{2}{c}{`CWR_N1'} & & \multicolumn{2}{c}{`CWR_N2'}  & & \multicolumn{2}{c}{`CWR_N3'}  & & \multicolumn{2}{c}{`CWR_N4'}  \\ \\[-1.8ex]

	
	* PANEL B
	
	tex  \multicolumn{12}{@{} l}{\textbf{Panel B: Economic Activities for UP Controls and Non-UP at Follow-up}}   \\ \hline \\[-1.8ex]

	
	use "${data_for_analysis}", clear
	drop if treatment == 1
	lab var employment_pm "Primary Men Participate in Market Work"

	merge 1:1 hhid using  "${weights_CWR}", assert(2 3) keep(3) nogen
	
	foreach var in $panelb {
		global `var'_lab : variable label `var'
		global `var'_lab : variable label `var'
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 1 
		global `var'm1 :  di %10.3f `r(mean)'
		global `var's1 :  di %10.3f `r(sd)'
		global `var'N1 :  di %10.0fc 	`r(N)'

		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 2
		global `var'm2 :  di %10.3f `r(mean)'
		global `var's2 :  di %10.3f `r(sd)'
		global `var'N2 :  di %10.0fc 	`r(N)'
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 3 
		global `var'm3 :  di %10.3f `r(mean)'
		global `var's3 :  di %10.3f `r(sd)'
		global `var'N3 :  di %10.0fc 	`r(N)'	
		
		sum `var' [aweight=pweight_CWR] if WealthRankingCategory_v  == 4
		global `var'm4 :  di %10.3f `r(mean)'
		global `var's4 :  di %10.3f `r(sd)'
		global `var'N4 :  di %10.0fc 	`r(N)'

		tex \everypar{\hangindent=0.7cm\hangafter=0} ${`var'_lab} &  ${`var'm1} &  ${`var's1} & & ${`var'm2} &  ${`var's2} & & ${`var'm3} &  ${`var's3} & & ${`var'm4} &  ${`var's4} \\  \\[-1.8ex]
	}	

	foreach category in 1 2 3 4 {
		count if WealthRankingCategory_v == `category'
		loc CWR_N`category' `r(N)'
	}
	
	
	tex Number of Sampled Households & \multicolumn{2}{c}{`CWR_N1'} & & \multicolumn{2}{c}{`CWR_N2'}  & & \multicolumn{2}{c}{`CWR_N3'}  & & \multicolumn{2}{c}{`CWR_N4'}  \\ \\[-1.8ex]

	tex \hline \\[-1.8ex]
	tex \multicolumn{12}{p{22cm}}{${note_table1}}\\
	
	texdoc stlog close

	/***
	\end{tabular}	
	\end{table}
	\end{landscape}
	***/
	

*------------------------------------------------------------------------------*
* Looking at differences at baseline across gender *
*------------------------------------------------------------------------------*

			
	/***
\newpage	
\renewcommand{\arraystretch}{0.9}
\small
\centering	
***/
	
foreach Panel in lit_rate Time Psy School {
		if "`Panel'" == "lit_rate" {
	use "$roster_bl_balance", clear
	keep if ultra_poor == 1
		}
		if "`Panel'" == "Time" {
	use "$labor_bl", clear
	keep if ultra_poor == 1
	keep if !mi(pf_pm) //Not necessary, just keeping the info we have for primary members
		}
		if "`Panel'" == "Psy" {
	use "$psy_bl_gender", clear
	keep if ultra_poor == 1
		}
		if "`Panel'" == "School" {
	use "$schooling_bl", clear
	keep if ultra_poor == 1
	 
		}
		
local j = 1
foreach var in ${`Panel'} {
		if "`Panel'" != "School" {
	global `Panel'_title_`j' : variable label `var'
	disp "`var'"
	test_diff L`j'_`Panel' `var' pf_pm	
	}
		if "`Panel'" == "School" {
	disp "`var'"
	test_diff L`j'_`Panel' `var' kid_6_14_bl_m	
local j = `j' + 1	
	disp "`var'"
	test_diff L`j'_`Panel' `var' kid_15_18_bl_m	
	}	
local j = `j' + 1	
	}
}		
		
		
	texdoc stlog, nolog

tex	\begin{longtable}{@{\extracolsep{1pt}}p{8cm}cccc}
tex	\caption{Select Mean Indicators by Gender at Baseline}
tex		\\[-1.8ex]\hline \\[-1.8ex]
tex	& \makecell{Female} & \makecell{Male}  & \makecell{(1) $-$ (2)} & \makecell{p-value}    \\     
tex & (1) & (2) & (3)  & (4)     \\ \hline \\  


foreach Panel in School {
tex ${`Panel'_title} &   &   &    &         \\
forvalues j = 1/2 {
tex \hspace*{0.2cm} ${`Panel'_title_`j'}
forvalues k = 1/4 {
tex  & ${L`j'_`Panel'`k'}   
		} 
tex \\
	}
}

tex \textit{Primary Members} &   &   &    &          \\
foreach Panel in lit_rate Time Psy  {
	if "`Panel'" != "lit_rate" {
tex ${`Panel'_title} &   &   &    &         \\
	}
local count: word count ${`Panel'}
forvalues j = 1/`count' {
	if `j' == 1 & ("`Panel'" == "Psy"|"`Panel'" == "lit_rate") {
tex ${`Panel'_title_`j'}
	}
	else {
tex \hspace*{0.2cm} ${`Panel'_title_`j'}
	}
forvalues k = 1/4 {
tex  & ${L`j'_`Panel'`k'}   
}  
tex \\
	}
}


tex  \hline \hline \\[-1.8ex]
tex %%% This is the note. If it does not have the correct margins, edit text below to fit to table size.
tex \multicolumn{5}{p{13cm}}
tex {\textit{Notes}:\footnotesize \hspace{0.1 cm}  }
	
	texdoc stlog close
	/***
	\end{longtable}
***/
	


*------------------------------------------------------------------------------*
* Table  Impact on  Activity (Full-time Days), Interaction ...*
*------------------------------------------------------------------------------*

	
	/***
\newpage	
\renewcommand{\arraystretch}{0.7}
\small
\centering	      
	***/				
		
foreach Panel in "A" "B" "C" "D"  { 

if "`Panel'" == "A" {
	local indep  pf_pm
	local indep_t t_pf_pm
}

if "`Panel'" == "B" {
	local indep  otheradult_m
	local indep_t t_otheradult_m
}
if "`Panel'" == "C" {
	local indep  kid_6_14_m
	local indep_t t_kid_6_14_m
}
if "`Panel'" == "D" {
	local indep  kid_15_17_m
	local indep_t t_kid_15_17_m
}

	local i = 1	
	
	foreach type in "did_" "hr_" {	
	if "`type'" == "did_" {
		local ending ""
		local title_end "Any Time" 
		local decimal =	3
		}
	if "`type'" == "hr_" {
		local ending "_4w"
		local title_end "Hours"
		local decimal =	1
		}

	use "$time_activities_ses", clear
	keep if ultra_poor == 1
	
	
	
	foreach var in $activities {
*Any time

	reg `type'`var'`ending' treatment `indep' `indep_t' ${controls}, r	
	gen sample_`Panel' = e(sample)
	*Saving all the coefficients 
	test_interaction L1_C`i'_`Panel' treatment `indep_t'
	stat_estim L1_C`i'_`Panel' treatment `decimal'
	stat_estim L2_C`i'_`Panel' `indep_t' `decimal'	
	stat_estim L3_C`i'_`Panel' `indep'	 `decimal'
	
	*control mean	
	sum `type'`var'`ending' if sample_`Panel' == 1 & treatment == 0 & `indep' == 1
	global L1_C`i'_`Panel'_m0 :  di %4.3f `r(mean)'
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 2
	sum `type'`var'`ending' if sample_`Panel' == 1 & treatment == 0 & `indep' == 0
	global L2_C`i'_`Panel'_m0 :  di %4.3f `r(mean)' 
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 1
		
	drop sample_*
		local i = `i' + 1	
		}	
	}
}	
	
	texdoc stlog, nolog
	
tex \begin{longtable}{@{\extracolsep{1pt}}p{4cm}cccc}
tex \caption{Impact on Time Use by Activity and Gender (`title_end')}
tex \\[-1.8ex]\hline \\[-1.8ex]
tex & \multicolumn{2}{c}{Participation} & \multicolumn{2}{c}{Hours}    
tex	  \\ \\[-1.8ex]  \cline{2-3} \cline{4-5} \\[-1.8ex] 
tex & \makecell{$Act_C_1} & \makecell{$Act_C_2}  & \makecell{$Act_C_3}  & \makecell{$Act_C_4}    \\ 
tex & (1) & (2) & (3)  & (4)     \\ \hline \\   
	foreach Panel in "A" "B" "C" "D"  { 
tex & \multicolumn{4}{c}{Panel `Panel': \textit{${Panel`Panel'}}}   \\ \\

	local N_line = 3

	forvalues k=1/`N_line' {
tex  ${title_`k'}
	forvalues j=1/4 {
tex  & \begin{tabular}[t]{@{}c@{}} ${L`k'_C`j'_`Panel'} \\ (${L`k'_C`j'_`Panel'sd}) \\ $[$${L`k'_C`j'_`Panel'p}$]$ \end{tabular}  
	}
tex  \\ \\[-1.8ex]
	}

tex  N 					  & ${L1_C1_`Panel'_N}    & ${L1_C2_`Panel'_N}     & ${L1_C3_`Panel'_N}    & ${L1_C4_`Panel'_N} 	 \\ 
tex  $ {R}^{2} $ 		  & ${L1_C1_`Panel'_R}    & ${L1_C2_`Panel'_R}     & ${L1_C3_`Panel'_R}    & ${L1_C4_`Panel'_R} 	 \\  
tex Control Mean Female   & ${L2_C1_`Panel'_m0}   & ${L2_C2_`Panel'_m0}    & ${L2_C3_`Panel'_m0}   & ${L2_C4_`Panel'_m0} 	 \\ 	
tex Control Mean Male     & ${L1_C1_`Panel'_m0}   & ${L1_C2_`Panel'_m0}    & ${L1_C3_`Panel'_m0}   & ${L1_C4_`Panel'_m0} 	 \\	
tex Impact Female (\%, SD) & \{${L1_C1_`Panel'imp1_1}\%;${L1_C1_`Panel'imp2_1}\} & \{${L1_C2_`Panel'imp1_1}\%;${L1_C2_`Panel'imp2_1}\} & \{${L1_C3_`Panel'imp1_1}\%;${L1_C3_`Panel'imp2_1}\} & 
tex 						 \{${L1_C4_`Panel'imp1_1}\%;${L1_C4_`Panel'imp2_1}\} \\
tex Impact Male (\%, SD)   & \{${L1_C1_`Panel'imp1_2}\%;${L1_C1_`Panel'imp2_2}\} & \{${L1_C2_`Panel'imp1_2}\%;${L1_C2_`Panel'imp2_2}\} & \{${L1_C3_`Panel'imp1_2}\%;${L1_C3_`Panel'imp2_2}\} & 
tex 						 \{${L1_C4_`Panel'imp1_2}\%;${L1_C4_`Panel'imp2_2}\}  \\
tex Test T + T x Male = 0 & ${L1_C1_`Panel'_test} & ${L1_C2_`Panel'_test}  & ${L1_C3_`Panel'_test} & ${L1_C4_`Panel'_test}   \\
tex \\ 
	 if "`Panel'" == "B" {	
tex \newpage
tex \\[-1.8ex]\hline \\[-1.8ex]
tex & \multicolumn{2}{c}{Participation} & \multicolumn{2}{c}{Hours}    
tex	  \\ \\[-1.8ex]  \cline{2-3} \cline{4-5} \\[-1.8ex] 
tex & \makecell{$Act_C_1} & \makecell{$Act_C_2}  & \makecell{$Act_C_3}  & \makecell{$Act_C_4}    \\ 
tex & (1) & (2) & (3)  & (4)     \\ \hline \\ 
	}
}

tex  \hline \hline \\[-1.8ex]
tex %%% This is the note. If it does not have the correct margins, edit text below to fit to table size.
tex \multicolumn{5}{p{12cm}}
tex {\textit{Notes}:\footnotesize \hspace{0.1 cm}  }
	
	texdoc stlog close
	/***
	\end{longtable}
***/



*------------------------------------------------------------------------------*
* Table  Impact onWell being Phone ownership School, Interaction ...*
*------------------------------------------------------------------------------*
		
	/***
\newpage	
\renewcommand{\arraystretch}{0.8}
\small
\centering	      
	***/	
	local Panel A_T1
	local i = 1	

*Psy Well Being
	use "$wellbeing_index_gender", clear
	local indep  pf_pm
	local indep_t t_pf_pm

	foreach var in $psychological {
*Any time

	reg `var' treatment `indep' `indep_t' ${controls}, r	
	gen sample_`Panel' = e(sample)
	*Saving all the coefficients 
	test_interaction L1_C`i'_`Panel' treatment `indep_t'
	stat_estim L1_C`i'_`Panel' treatment
	stat_estim L2_C`i'_`Panel' `indep_t'	
	stat_estim L3_C`i'_`Panel' `indep'	
	
	*control mean	
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 1
	global L1_C`i'_`Panel'_m0 :  di %4.3f `r(mean)'
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 2
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 0
	global L2_C`i'_`Panel'_m0 :  di %4.3f `r(mean)' 
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 1		
	drop sample_*
		local i = `i' + 1	
	}				

*Mobile Ownership
	use "$mobile_phone_ownership_fl1", clear
			keep if ultra_poor == 1		
		local indep    male_adult
		local indep_t  t_male_adult			
		local var      own_mobile
		
	reg `var' treatment `indep' `indep_t' ${controls}, r	
	gen sample_`Panel' = e(sample)
	*Saving all the coefficients 
	test_interaction L1_C`i'_`Panel' treatment `indep_t'
	stat_estim L1_C`i'_`Panel' treatment
	stat_estim L2_C`i'_`Panel' `indep_t'	
	stat_estim L3_C`i'_`Panel' `indep'	
	
	*control mean	
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 1
	global L1_C`i'_`Panel'_m0 :  di %4.3f `r(mean)'
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 2
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 0
	global L2_C`i'_`Panel'_m0 :  di %4.3f `r(mean)' 
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 1	
	drop sample_*	
		local i = `i' + 1

*School Enrollment
	use "$schooling_fl1", clear
	keep if ultra_poor == 1
	
		foreach age in "_6_14" "_15_17" {	
	foreach var in $school {
		local indep    kid`age'_m
		local indep_t  t_kid`age'_m

	reg `var' treatment `indep' `indep_t' ${controls}, r	
	gen sample_`Panel' = e(sample)
	*Saving all the coefficients 
	test_interaction L1_C`i'_`Panel' treatment `indep_t'
	stat_estim L1_C`i'_`Panel' treatment
	stat_estim L2_C`i'_`Panel' `indep_t'	
	stat_estim L3_C`i'_`Panel' `indep'	
	
	*control mean	
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 1
	global L1_C`i'_`Panel'_m0 :  di %4.3f `r(mean)'
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 2
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 0
	global L2_C`i'_`Panel'_m0 :  di %4.3f `r(mean)' 
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 1	
	drop sample_*
		local i = `i' + 1	
	}	
}
	
	
	texdoc stlog, nolog
	
tex \begin{landscape}		
tex \begin{longtable}{@{\extracolsep{1pt}}p{4cm}cccccc}
tex \caption{Impact on Psychological Well Being, Phone Ownership and Children's Education by Gender}
tex \\[-1.8ex]\hline \\[-1.8ex]
tex & \makecell{Primary \\[-1.0ex]Members} & \makecell{All \\[-1.0ex]Adults} & \multicolumn{2}{c}{Children 6 - 14} & \multicolumn{2}{c}{Children 15 - 17}    
tex	  \\ \\[-1.8ex]  \cline{2-2} \cline{3-3} \cline{4-5} \cline{6-7} \\[-1.8ex] 
tex & \makecell{${Psy_C_1}} & \makecell{Phone \\[-1.0ex]Ownership}  & \makecell{$School_C_1} & \makecell{$School_C_2}  & \makecell{$School_C_1} & \makecell{$School_C_2}    \\ 
tex & (1) & (2) & (3)  & (4) & (5) & (6)      \\ \hline \\   

	forvalues k=1/3 {
tex  ${title_`k'}
	forvalues j=1/6 {
tex  & \begin{tabular}[t]{@{}c@{}} ${L`k'_C`j'_`Panel'} \\ (${L`k'_C`j'_`Panel'sd}) \\ $[$${L`k'_C`j'_`Panel'p}$]$ \end{tabular}  
	}
tex  \\ \\[-1.8ex]
	}

tex  N 					  & ${L1_C1_`Panel'_N}    & ${L1_C2_`Panel'_N}     & ${L1_C3_`Panel'_N}    & ${L1_C4_`Panel'_N}  & ${L1_C5_`Panel'_N}    & ${L1_C6_`Panel'_N}	 \\  
tex Control Mean Female   & ${L2_C1_`Panel'_m0}   & ${L2_C2_`Panel'_m0}    & ${L2_C3_`Panel'_m0}   & ${L2_C4_`Panel'_m0} & ${L2_C5_`Panel'_m0}   & ${L2_C6_`Panel'_m0}	 \\ 	
tex Control Mean Male     & ${L1_C1_`Panel'_m0}   & ${L1_C2_`Panel'_m0}    & ${L1_C3_`Panel'_m0}   & ${L1_C4_`Panel'_m0} & ${L1_C5_`Panel'_m0}   & ${L1_C6_`Panel'_m0}	 \\	
tex Impact Female (\%, SD) & \{${L1_C1_`Panel'imp1_1}\%;${L1_C1_`Panel'imp2_1}\} & \{${L1_C2_`Panel'imp1_1}\%;${L1_C2_`Panel'imp2_1}\} & \{${L1_C3_`Panel'imp1_1}\%;${L1_C3_`Panel'imp2_1}\} & 
tex 						 \{${L1_C4_`Panel'imp1_1}\%;${L1_C4_`Panel'imp2_1}\} & \{${L1_C5_`Panel'imp1_1}\%;${L1_C5_`Panel'imp2_1}\} & \{${L1_C6_`Panel'imp1_1}\%;${L1_C6_`Panel'imp2_1}\}  \\
tex Impact Male (\%, SD)   & \{${L1_C1_`Panel'imp1_2}\%;${L1_C1_`Panel'imp2_2}\} & \{${L1_C2_`Panel'imp1_2}\%;${L1_C2_`Panel'imp2_2}\} & \{${L1_C3_`Panel'imp1_2}\%;${L1_C3_`Panel'imp2_2}\} & 
tex 						 \{${L1_C4_`Panel'imp1_2}\%;${L1_C4_`Panel'imp2_2}\} & \{${L1_C5_`Panel'imp1_2}\%;${L1_C5_`Panel'imp2_2}\} & \{${L1_C6_`Panel'imp1_2}\%;${L1_C6_`Panel'imp2_2}\}  \\
tex Test T + T x Male = 0 & ${L1_C1_`Panel'_test} & ${L1_C2_`Panel'_test}  & ${L1_C3_`Panel'_test} & ${L1_C4_`Panel'_test} & ${L1_C5_`Panel'_test} & ${L1_C6_`Panel'_test} \\
tex \\ 



tex  \hline \hline \\[-1.8ex]
tex %%% This is the note. If it does not have the correct margins, edit text below to fit to table size.
tex \multicolumn{7}{p{16cm}}
tex {\textit{Notes}:\footnotesize \hspace{0.1 cm}  }

	
	texdoc stlog close
	/***
	\end{longtable}
 \end{landscape}	
***/




	/***
\setcounter{table}{0}
\renewcommand{\thetable}{A\arabic{table}}	
\newpage
\section{Appendix}
***/

*------------------------------------------------------------------------------*
* Balance checks on Household composition at baseline *
*------------------------------------------------------------------------------*
	
	/***

\renewcommand{\arraystretch}{0.9}
\small
\centering	
	\begin{longtable}{@{\extracolsep{1pt}}p{8cm}ccc}
	\caption{Statistics on Household Composition at Baseline}
	\\[-1.8ex]\hline \\[-1.8ex]
	& \makecell{Control \\Mean} & \makecell{Treatment \\Effect}  & \makecell{N}   \\     
	& (1) & (2) & (3)     \\ \hline \\[-1.8ex]   		      
	***/	

	use "$roster_bl_balance", clear
	duplicates drop hhid, force
	keep if ultra_poor == 1
	
	texdoc stlog, nolog

	foreach var in tot_oth_m_adult_fl1 tot_kidm_6_14_fl1  tot_kidm_15_17_fl1 {
	label var `var' "Male"
	}
	foreach var in tot_oth_f_adult_fl1 tot_kidf_6_14_fl1  tot_kidf_15_17_fl1  {
	label var `var' "Female"
	}
	
	lab var hh_only_pf 			"Female Only"
	lab var hh_only_pm 			"Male Only"
	lab var pm_pf_hh 			"Female and Male"
	
	foreach var in $hh_comp {
		global `var'_l : variable label `var'
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment
	}	
	
tex \%HHs by Primary Member Composition & &  &      \\  
	foreach var in pm_pf_hh hh_only_pf hh_only_pm  {	
tex \hspace*{0.5cm} ${`var'_l} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}  & ${N_`var'} \\  \\[-1.8ex]
}			
tex Number of Other Adult Members & &  &      \\  
	foreach var in tot_oth_f_adult_fl1 tot_oth_m_adult_fl1 {	
tex \hspace*{0.5cm} ${`var'_l} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}  & ${N_`var'} \\  \\[-1.8ex]
}	
tex Number of Children (6-14) & &  &      \\  
	foreach var in tot_kidf_6_14_fl1 tot_kidm_6_14_fl1 {	
tex \hspace*{0.5cm} ${`var'_l} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}  & ${N_`var'} \\  \\[-1.8ex]
}	
tex Number of Children (15-17) & &  &      \\  
	foreach var in tot_kidf_15_17_fl1 tot_kidm_15_17_fl1  {	
tex \hspace*{0.5cm} ${`var'_l} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}  & ${N_`var'} \\  \\[-1.8ex]
}	

	tex \hline \\[-1.8ex]\multicolumn{4}{p{13cm}}{$note_bl_check_compo}\\
	
	texdoc stlog close
	/***
	\end{longtable}
***/

*------------------------------------------------------------------------------*
* Relation of adults to the head of the household *
*------------------------------------------------------------------------------*

*Run the code below and then directly copy paste in the latex table below
	*HHs with Primary Man only
	use "$roster_bl_balance", clear
	tab b5 if oth_f_adult_fl1 == 1 & ultra_poor == 1 & hh_only_pf !=1
	
/*	
    What is the relation of  to the |
            head of your household? |      Freq.     Percent        Cum.
------------------------------------+-----------------------------------
   other unrelated (please specify) |          9        1.38        1.38
                             spouse |          8        1.23        2.62
                       son/daughter |        333       51.23       53.85-------
stepson/stepdaughter/adopted/foster |          3        0.46       54.31
         son-in-law/daughter-in-law |         42        6.46       60.77-------
                         grandchild |          9        1.38       62.15
                     brother/sister |         80       12.31       74.46------
       brother-in-law/sister-in-law |          6        0.92       75.38
                      father/mother |        123       18.92       94.31----------
        father-in-law/mother-in-law |         11        1.69       96.00---------
                        grandparent |          5        0.77       96.77
                             cousin |          2        0.31       97.08
                       nephew/niece |          6        0.92       98.00
                            co-wife |          6        0.92       98.92
                         aunt/uncle |          3        0.46       99.38
                     other relative |          4        0.62      100.00
------------------------------------+-----------------------------------
                              Total |        650      100.00

*/
disp 9 + 8 + 3 +9+6+5+2+6+6+3+4 //61
disp 61/650 //9.38


	*HHs with Primary Woman only
	use "$roster_bl_balance", clear
	tab b5 if oth_f_adult_fl1 == 1 & ultra_poor == 1 & hh_only_pf ==1
	
/*	

    What is the relation of  to the |
            head of your household? |      Freq.     Percent        Cum.
------------------------------------+-----------------------------------
   other unrelated (please specify) |          4        2.12        2.12
                             spouse |          1        0.53        2.65
                       son/daughter |        125       66.14       68.78----------
stepson/stepdaughter/adopted/foster |          2        1.06       69.84
         son-in-law/daughter-in-law |         23       12.17       82.01----------
                         grandchild |          5        2.65       84.66
                     brother/sister |          4        2.12       86.77----------
       brother-in-law/sister-in-law |          1        0.53       87.30
                      father/mother |          8        4.23       91.53----------
        father-in-law/mother-in-law |         10        5.29       96.83----------
                        grandparent |          1        0.53       97.35
                            co-wife |          3        1.59       98.94
                         aunt/uncle |          1        0.53       99.47
                     other relative |          1        0.53      100.00
------------------------------------+-----------------------------------
                              Total |        189      100.00

*/
disp 4+1+2+5+1+1+3+1+1	//19
disp 19/189 //10.05


	*HHs with Primary Man only - Looking at other adults MALE now
	use "$roster_bl_balance", clear
	tab b5 if oth_m_adult_fl1 == 1 & ultra_poor == 1 & hh_only_pf !=1
	
/*	


    What is the relation of  to the |
            head of your household? |      Freq.     Percent        Cum.
------------------------------------+-----------------------------------
   other unrelated (please specify) |          1        0.23        0.23
                             spouse |          4        0.90        1.13
                       son/daughter |        313       70.81       71.95
         son-in-law/daughter-in-law |          6        1.36       73.30
                         grandchild |          4        0.90       74.21
                     brother/sister |         74       16.74       90.95
       brother-in-law/sister-in-law |          4        0.90       91.86
                      father/mother |         31        7.01       98.87
                             cousin |          2        0.45       99.32
                       nephew/niece |          3        0.68      100.00
------------------------------------+-----------------------------------
                              Total |        442      100.00


*/
disp 442 - (313+6+74+31) // 18
disp 18/442 //4.00


	*HHs with Primary Woman only - Looking at other adults MALE now
	use "$roster_bl_balance", clear
	tab b5 if oth_m_adult_fl1 == 1 & ultra_poor == 1 & hh_only_pf ==1
	
/*	


    What is the relation of  to the |
            head of your household? |      Freq.     Percent        Cum.
------------------------------------+-----------------------------------
   other unrelated (please specify) |          1        0.86        0.86
                             spouse |         24       20.69       21.55
                       son/daughter |         78       67.24       88.79
         son-in-law/daughter-in-law |          2        1.72       90.52
                         grandchild |          2        1.72       92.24
                     brother/sister |          4        3.45       95.69
       brother-in-law/sister-in-law |          1        0.86       96.55
                      father/mother |          1        0.86       97.41
        father-in-law/mother-in-law |          2        1.72       99.14
                             cousin |          1        0.86      100.00
------------------------------------+-----------------------------------
                              Total |        116      100.00

*/	

disp 116 - (78+2+4+1+2) //29
disp 29/116 			//25

*Keep Daughter, daughter in law, Sister, mother, mother in law, Other
			
	/***
\newpage	
\renewcommand{\arraystretch}{0.9}
\small
\centering	
	\begin{longtable}{@{\extracolsep{1pt}}p{4cm}cccccccc}
	\caption{Relation of Adults (excluding PW and PM) to the Head of the Household at Baseline}
		\\[-1.8ex]\hline \\[-1.8ex]
	& \multicolumn{4}{c}{Adult Women} & \multicolumn{4}{c}{Adult Men}	
	\\ \\[-1.8ex]  \cline{2-5} \cline{6-9} \\[-1.8ex] 
	& \multicolumn{2}{p{3cm}}{HHs with Primary Man and Woman} & \multicolumn{2}{p{3cm}}{HHs with Primary Woman Only}
	& \multicolumn{2}{p{3cm}}{HHs with Primary Man and Woman} & \multicolumn{2}{p{3cm}}{HHs with Primary Woman Only}
	\\ \\[-1.8ex]  \cline{2-3} \cline{4-5} \cline{6-7} \cline{8-9} \\[-1.8ex] 
	& \makecell{Freq. } & \makecell{Percent}  & \makecell{Freq. } & \makecell{Percent} & \makecell{Freq. } & \makecell{Percent}  & \makecell{Freq. } & \makecell{Percent}   \\     
	\\[-1.8ex]\hline \\[-1.8ex]
	
	son/daughter 				& 333 	& 51.23 & 125  & 66.14 & 313 & 70.81 & 78 & 67.24 \\ 
	son-in-law/daughter-in-law  & 42 	& 6.46 	& 23   & 12.17 & 6   & 1.36  & 2  & 1.72  \\ 
	brother/sister 				& 80 	& 12.31 & 4    & 2.12  & 74  & 16.74 & 4  & 3.45  \\ 
	father/mother 				& 123  	& 18.92 & 8    & 4.23  & 31  & 7.01  & 1  & 0.86  \\ 
	father-in-law/mother-in-law	& 11 	& 1.69 	& 10   & 5.29  & 0   & 0     & 2  & 1.72  \\ 
	Other						& 61 	& 9.38  & 19   & 10.05 & 18  & 4.00  & 29 & 25.00 \\ 
	\\[-1.8ex]\hline \\[-1.8ex] 
	Total 						& 650 & 100.00	& 189 & 100.00  & 442 & 100.00 & 116 & 100.00
	\\\hline \\[-1.8ex]	
	\end{longtable}
	***/	

		* Looking at other adults FEMALE now, for all households
	use "$roster_bl_balance", clear
	tab b5 if oth_f_adult_fl1 == 1 & ultra_poor == 1 
	
/*

    What is the relation of  to the |
            head of your household? |      Freq.     Percent        Cum.
------------------------------------+-----------------------------------
   other unrelated (please specify) |         13        1.55        1.55
                             spouse |          9        1.07        2.62
                       son/daughter |        458       54.59       57.21
stepson/stepdaughter/adopted/foster |          5        0.60       57.81
         son-in-law/daughter-in-law |         65        7.75       65.55
                         grandchild |         14        1.67       67.22
                     brother/sister |         84       10.01       77.23
       brother-in-law/sister-in-law |          7        0.83       78.07
                      father/mother |        131       15.61       93.68
        father-in-law/mother-in-law |         21        2.50       96.19
                        grandparent |          6        0.72       96.90
                             cousin |          2        0.24       97.14
                       nephew/niece |          6        0.72       97.85
                            co-wife |          9        1.07       98.93
                         aunt/uncle |          4        0.48       99.40
                     other relative |          5        0.60      100.00
------------------------------------+-----------------------------------
                              Total |        839      100.00
*/	
di 839 - (458+65+84+131+21) //80
di 80/839 //9.53

	*  Looking at other adults MALE now, for all households
	use "$roster_bl_balance", clear
	tab b5 if oth_m_adult_fl1 == 1 & ultra_poor == 1 
	
/*

    What is the relation of  to the |
            head of your household? |      Freq.     Percent        Cum.
------------------------------------+-----------------------------------
   other unrelated (please specify) |          2        0.36        0.36
                             spouse |         28        5.02        5.38
                       son/daughter |        391       70.07       75.45
         son-in-law/daughter-in-law |          8        1.43       76.88
                         grandchild |          6        1.08       77.96
                     brother/sister |         78       13.98       91.94
       brother-in-law/sister-in-law |          5        0.90       92.83
                      father/mother |         32        5.73       98.57
        father-in-law/mother-in-law |          2        0.36       98.92
                             cousin |          3        0.54       99.46
                       nephew/niece |          3        0.54      100.00
------------------------------------+-----------------------------------
                              Total |        558      100.00

*/	
di 558 - (391+8+78+32+2)	//47
di 47/558 //8.42
	
	/***	
\renewcommand{\arraystretch}{0.9}
\small
\centering	
	\begin{longtable}{@{\extracolsep{1pt}}p{4cm}cccc}
	\caption{Relation of Adults (excluding PW and PM) to the Head of the Household at Baseline}
		\\[-1.8ex]\hline \\[-1.8ex]
	& \multicolumn{2}{c}{Adult Women} & \multicolumn{2}{c}{Adult Men}	
	\\ \\[-1.8ex]  \cline{2-3} \cline{4-5}  \\[-1.8ex] 
	& \makecell{Freq. } & \makecell{Percent}  & \makecell{Freq. } & \makecell{Percent}   \\     
	\\[-1.8ex]\hline \\[-1.8ex]
	
	son/daughter 				& 458 	& 54.59 & 391  & 70.07  \\ 
	son-in-law/daughter-in-law  &  65 	& 7.75 	& 8    & 1.43  \\ 
	brother/sister 				& 84 	& 10.01 & 78   & 13.98  \\ 
	father/mother 				& 131  	& 15.61 & 32   & 5.73   \\ 
	father-in-law/mother-in-law	& 21 	& 2.50 	& 2    & 0.36   \\ 
	Other						& 80 	& 9.53  &  47  &  8.42 \\ 
	\\[-1.8ex]\hline \\[-1.8ex] 
	Total 						& 839 & 100.00	& 558 & 100.00 
	\\\hline \\[-1.8ex]	
	\end{longtable}
	***/	
	

*------------------------------------------------------------------------------*
* Table  Impact on psy well being Indices, Interaction ...*
*------------------------------------------------------------------------------*
		
	
	
	/***
\newpage	
\renewcommand{\arraystretch}{0.7}
\small
\centering	      
	***/	
		global title_1  "Treatment"
		global title_2 	"Treatment x Male"
		global title_3  "Male"
			
		



	local Panel A
	local indep  pf_pm
	local indep_t t_pf_pm


	use "$wellbeing_index_gender", clear

	
	local i = 1	
	foreach var in $psychological2 {
*Any time

	reg `var' treatment `indep' `indep_t' ${controls}, r	
	gen sample_`Panel' = e(sample)
	*Saving all the coefficients 
	test_interaction L1_C`i'_`Panel' treatment `indep_t'
	stat_estim L1_C`i'_`Panel' treatment
	stat_estim L2_C`i'_`Panel' `indep_t'	
	stat_estim L3_C`i'_`Panel' `indep'	
	
	*control mean	
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 1
	global L1_C`i'_`Panel'_m0 :  di %4.3f `r(mean)'
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 2
	sum `var' if sample_`Panel' == 1 & treatment == 0 & `indep' == 0
	global L2_C`i'_`Panel'_m0 :  di %4.3f `r(mean)' 
		impact_interaction L1_C`i'_`Panel' treatment `indep_t' 1
		
	drop sample_*
		local i = `i' + 1	
	}	

	
	
	texdoc stlog, nolog
	
tex \begin{landscape}	
tex \begin{longtable}{@{\extracolsep{1pt}}p{4cm}ccccccc}
tex \caption{Impact on Scores on dimensions of Psychological Well Being}
tex \\[-1.8ex]\hline \\[-1.8ex]
tex & \makecell{$Psy2_C_1} & \makecell{$Psy2_C_2}  & \makecell{$Psy2_C_3}  & \makecell{$Psy2_C_4}  & \makecell{$Psy2_C_5}  & \makecell{$Psy2_C_6} & \makecell{$Psy2_C_7}      \\ 
tex & (1) & (2) & (3)  & (4) & (5) & (6) & (7)     \\ \hline \\   
	foreach Panel in "A"   { 
tex & \multicolumn{7}{c}{Panel `Panel': \textit{${Panel`Panel'}}}   \\ \\

	local N_line = 3

	forvalues k=1/`N_line' {
tex \hspace*{0.2cm} ${title_`k'}
	forvalues j=1/7 {
tex  & \begin{tabular}[t]{@{}c@{}} ${L`k'_C`j'_`Panel'} \\ (${L`k'_C`j'_`Panel'sd}) \\ $[$${L`k'_C`j'_`Panel'p}$]$ \end{tabular}  
	}
tex  \\ \\[-1.8ex]
	}

tex  N 					  & ${L1_C1_`Panel'_N}    & ${L1_C2_`Panel'_N}     & ${L1_C3_`Panel'_N}    & ${L1_C4_`Panel'_N} 	&  ${L1_C5_`Panel'_N} 	&  ${L1_C6_`Panel'_N}& ${L1_C7_`Panel'_N} 	 \\  
tex Control Mean Female   & ${L2_C1_`Panel'_m0}   & ${L2_C2_`Panel'_m0}    & ${L2_C3_`Panel'_m0}   & ${L2_C4_`Panel'_m0} 	& ${L2_C5_`Panel'_m0} 	& ${L2_C6_`Panel'_m0}& ${L2_C7_`Panel'_m0} 	 \\ 	
tex Control Mean Male     & ${L1_C1_`Panel'_m0}   & ${L1_C2_`Panel'_m0}    & ${L1_C3_`Panel'_m0}   & ${L1_C4_`Panel'_m0} 	& ${L1_C5_`Panel'_m0} 	& ${L1_C6_`Panel'_m0} & ${L1_C7_`Panel'_m0}  \\	
tex Impact Female (\%, SD) & \{${L1_C1_`Panel'imp1_1}\%;${L1_C1_`Panel'imp2_1}\} & \{${L1_C2_`Panel'imp1_1}\%;${L1_C2_`Panel'imp2_1}\} & \{${L1_C3_`Panel'imp1_1}\%;${L1_C3_`Panel'imp2_1}\} & 
tex 						 \{${L1_C4_`Panel'imp1_1}\%;${L1_C4_`Panel'imp2_1}\} & \{${L1_C5_`Panel'imp1_1}\%;${L1_C5_`Panel'imp2_1}\} & \{${L1_C6_`Panel'imp1_1}\%;${L1_C6_`Panel'imp2_1}\} &
tex 						 \{${L1_C7_`Panel'imp1_1}\%;${L1_C7_`Panel'imp2_1}\} \\
tex Impact Male (\%, SD)   & \{${L1_C1_`Panel'imp1_2}\%;${L1_C1_`Panel'imp2_2}\} & \{${L1_C2_`Panel'imp1_2}\%;${L1_C2_`Panel'imp2_2}\} & \{${L1_C3_`Panel'imp1_2}\%;${L1_C3_`Panel'imp2_2}\} & 
tex 						 \{${L1_C4_`Panel'imp1_2}\%;${L1_C4_`Panel'imp2_2}\} & \{${L1_C5_`Panel'imp1_2}\%;${L1_C5_`Panel'imp2_2}\} & \{${L1_C6_`Panel'imp1_2}\%;${L1_C6_`Panel'imp2_2}\} &
tex 						 \{${L1_C7_`Panel'imp1_2}\%;${L1_C7_`Panel'imp2_2}\}  \\
tex Test T + T x Male = 0 & ${L1_C1_`Panel'_test} & ${L1_C2_`Panel'_test}  & ${L1_C3_`Panel'_test} & ${L1_C4_`Panel'_test}  & ${L1_C5_`Panel'_test} & ${L1_C6_`Panel'_test} & ${L1_C7_`Panel'_test}  \\
tex \\ 

}
 
tex  \hline \hline \\[-1.8ex]
tex %%% This is the note. If it does not have the correct margins, edit text below to fit to table size.
tex \multicolumn{8}{p{14cm}}
tex {\textit{Notes}:\footnotesize \hspace{0.1 cm}  }
	
	texdoc stlog close
	/***
	\end{longtable}
	\end{landscape}
***/	
	
	
	/***	
\end{document}
***/











**************************End of Do File*************************************************



