/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	June 22, 2019
Last udpate on: June 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	*Data for analysis dataset "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	global 		data_for_analysis	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	gl profile_info 					"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	
	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"

		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	use "${data_for_analysis}", clear

* Merge district: I (camila) created this file based on the reports google sheet
	merge 1:1 hhid using "/Users/mcayala/Downloads/district.dta", assert(2 3) keep(3) nogen
	keep if ultra_poor == 1
	
* Create variable for district
	rename district_lottery district_lottery2
	gen 	district_lottery = 1 if district_lottery2 == "Dawlatabad"
	replace district_lottery = 2 if district_lottery2 == "Dehadi"
	replace district_lottery = 3 if district_lottery2 == "Nahr"
	replace district_lottery = 4 if district_lottery2 == "Khulm"
	lab val district_lottery a5
	drop district_lottery2
	
	loc het_variable "district_lottery"
	
* Generate dummies and interactions
	foreach var in `het_variable' {
		tab `var', gen(`var'_)
		
		foreach dummy of varlist `var'_* {
			gen treatX`dummy' = `dummy'*treatment
		}
	}
	
* Controls
	global controls					i.PRA_lottery
	global district_inter_bl 		`het_variable'_2 `het_variable'_3 `het_variable'_4 treatX`het_variable'_2 treatX`het_variable'_3 treatX`het_variable'_4

	global cate_outcome 	exp_tot_m_pc_c_ppp tot_lstock_value_ppp wealth_score psy_indexC_sdC_fl1
	global interlist 		district

	
	foreach inter in $interlist {
	*Setting up specific parameters
		if "`inter'"=="district" {
			global title "District"
			local   number  A2
		}
		
		
	foreach var in $cate_outcome {	
		if "`var'"=="exp_tot_m_pc_c_ppp" {
			global subtitle "Per Capita Consumption"
			local 	ytitle 	"ytitle(US PPP, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(25)50 , noticks format(%9.0fc)  labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="tot_lstock_value_ppp" {
			global subtitle "Value of Livestock "
			local 	ytitle 	"ytitle(US PPP, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(500)1000, noticks format(%9.0fc) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="wealth_score" {
			global subtitle "HH Asset Ownership Index (PCA)"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		if "`var'"=="psy_indexC_sdC_fl1" {
			global subtitle "Psy well-being index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}

		

	gen counter = _n if _n <=4

	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	
	*Compute the parametric regression on the interaction variables and save the coefficient / CI
		reg `var' treatment ${`inter'_inter_bl} ${controls} , r
		
		cap mat drop A_`var'_`inter' 
		mat A_`var'_`inter'  = r(table)

	*  Dowlat Abad District
		replace estim 	= _b[treatment] if counter == 1
		replace CI_l 	= A_`var'_`inter'[5,1] 	if counter == 1
		replace CI_h 	= A_`var'_`inter'[6,1]  	if counter == 1
	* Dehdadi District
		replace estim 	= _b[treatment] + _b[treatX`het_variable'_2] 	if counter == 2	
	* Nahre Shahee District
		replace estim 	= _b[treatment] + _b[treatX`het_variable'_3] 	if counter == 3
	* Khulm  District
		replace estim 	= _b[treatment] + _b[treatX`het_variable'_4] 	if counter == 4
		
		
	*Computes confidence interval by testing the significance of the sum of the coefficient and using the usual OLS CI formula
	test treatment + treatX`het_variable'_2 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 2
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 2
	
	test treatment + treatX`het_variable'_3 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 3
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 3
	
	test treatment + treatX`het_variable'_4 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 4
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 4

	*Main graph
	twoway  (bar  estim counter, barwidth(0.8) ) ///
			(rcap CI_l CI_h counter , lcolor(black)) /// 
			(scatter  estim counter,msym(none) mlab(estim) mlabpos(12) mlabcolor(black) mlabsize(vsmall)) ,  ///
			`ytitle' xtitle(" ") ///
			legend(off)  xscale(noline) yscale(noline) ///
			xlabel( 1 "Dawlatabad" 2 "Dehadi" 3 "Nahr" 4 "Khulm", noticks labsize(vsmall)) ///
			`ylabel'  ///
			subtitle("${subtitle}",size(medsmall))  ///
			graphregion(color(white)) 
 
	graph save    "${output_gr}/cate_`var'_`inter'", replace
	drop counter CI_l CI_h estim
		}
		
		graph combine ///
			"${output_gr}/cate_exp_tot_m_pc_c_ppp_`inter'.gph" ///
			"${output_gr}/cate_tot_lstock_value_ppp_`inter'.gph" ///
			"${output_gr}/cate_wealth_score_`inter'.gph" ///			
			"${output_gr}/cate_psy_indexC_sdC_fl1_`inter'.gph" ///			
			,   graphregion(color(white)) title("Treatment Effect by BL ${title}",size(medium))
	
		graph export "${output_gr2}/`number'_CATE_`inter'.pdf" , replace as(pdf)*/
	}
	-
	
*********************************End of dofile***********************************************************************
