/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	June 22, 2019
Last udpate on: June 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	*Data for analysis dataset "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	gl data_for_analysis				"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	gl profile_info 					"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	gl f_empowerment_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta"
	gl f_empowerment_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta"

	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"

		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	*use "${data_for_analysis_fl1}", clear
	use "${f_empowerment_fl1}", clear
		merge 1:1 hhid using "${all_HH_interm_nopii_fl1}", keepusing(a10 a10_o) keep(3) nogen
	
	keep if ultra_poor == 1
	
/* Create variable for ethnic
	tab a10, m
	lab def ethnic_l 1 "Dari + Arabic" 2 "Pashto" 3 "Uzbek + Turkmen"
	gen ethnic = 1 if (a10 == 1 | a10 == .n)
	replace ethnic = 2 if a10 == 2
	replace ethnic = 3 if (a10 == 3 | a10 == 4)
	lab val ethnic ethnic_l*/
	
	tab a10, m nol
	lab def ethnic_l 1 "Pashto" 2 "Dari" 3 "Uzbek" 4 "Turkmen" //5 "Arabic"
	gen ethnic = 1 if a10 == 2
	replace ethnic = 2 if a10 == 1
	replace ethnic = 3 if a10 == 3
	replace ethnic = 4 if a10 == 4
	
	lab val ethnic ethnic_l

	loc het_variable "ethnic"
	
	* Merge on baseline covariate 
	preserve 
		use "${f_empowerment_bl}", clear 
			keep hhid index_sdC_f_empowerment_? index_sdC_all_decisions_? index_sdC_role_prod_act_? index_sdC_social_capital_? index_sdC_social_norms_?
			rename * *_bl
			rename hhid_bl hhid
			tempfile covariates
			save `covariates'
	restore 
	
	merge 1:1 hhid using "`covariates'", keep(1 3)
	
	* Create covariate missingness dummy indicator
	forval i = 1/5 {
		foreach var in index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital index_sdC_social_norms {
			gen `var'_`i'_bl_m = (mi(`var'_`i'_bl))
			replace `var'_`i'_bl = 0 if mi(`var'_`i'_bl)
		}
	}
	
* Generate dummies and interactions
	foreach var in `het_variable' {
		tab `var', gen(`var'_)
		
		foreach dummy of varlist `var'_* {
			gen treatX`dummy' = `dummy'*treatment
		}
	}
	stop
* Controls
	global controls						i.PRA_lottery
	global `het_variable'_inter_bl 		`het_variable'_2 `het_variable'_3 `het_variable'_4 treatX`het_variable'_2 treatX`het_variable'_3 treatX`het_variable'_4

	rename (index_sdC_social_capital index_sdC_social_capital_bl index_sdC_social_capital_bl_miss)  (index_sdC_socap index_sdC_socap_bl index_sdC_socap_bl_miss)

	global cate_outcome 	index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_socap index_sdC_social_norms
	global interlist 		ethnic

	
	foreach inter in $interlist {
	*Setting up specific parameters
		if "`inter'"=="ethnic" {
			global title "Primary language"
		}
		
		
	foreach var in $cate_outcome {	
		if "`var'"=="index_sdC_f_empowerment" {
			global subtitle "Women's Empowerment Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_all_decisions" {
			global subtitle "Decisionmaking Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_role_prod_act" {
			global subtitle "Economic Opportunities Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		if "`var'"=="index_sdC_social_norms" {
			global subtitle "Aspirations for Daughters Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}

		if "`var'"=="index_sdC_socap" {
			global subtitle "Political and Social Capital Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
	gen counter = _n if _n <=4

	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	gen control_mean = .
	gen counter_l = . 
	
	*Compute the parametric regression on the interaction variables and save the coefficient / CI
		reg `var' treatment ${`inter'_inter_bl} ${controls} `var'_bl `var'_bl_miss, r
		
		cap mat drop A_`var'_`inter' 
		mat A_`var'_`inter'  = r(table)

	*  Dowlat Abad District
		replace estim 	= _b[treatment] if counter == 1
		replace CI_l 	= A_`var'_`inter'[5,1] 	if counter == 1
		replace CI_h 	= A_`var'_`inter'[6,1]  	if counter == 1
	* Dehdadi District
		replace estim 	= _b[treatment] + _b[treatX`het_variable'_2] 	if counter == 2	
	* Nahre Shahee District
		replace estim 	= _b[treatment] + _b[treatX`het_variable'_3] 	if counter == 3
		replace estim 	= _b[treatment] + _b[treatX`het_variable'_4] 	if counter == 4
		
	*Computes confidence interval by testing the significance of the sum of the coefficient and using the usual OLS CI formula
	test treatment + treatX`het_variable'_2 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 2
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 2
	
	test treatment + treatX`het_variable'_3 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 3
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 3

		test treatment + treatX`het_variable'_4 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 4
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 4	
		
		format %3.2f estim
		
		* Add N
		qui sum `var' if ethnic == 1
			local N_1 = `r(N)'

		qui sum `var' if ethnic == 2
			local N_2 = `r(N)'	
		
		qui sum `var' if ethnic == 3
			local N_3 = `r(N)'	
			
		qui sum `var' if ethnic == 4
			local N_4 = `r(N)'	
		
		* Add control means 
		qui sum `var'  if treatment == 0 & ethnic == 1 //& e(sample) == 1
			replace control_mean = `r(mean)' if counter == 1
		qui sum `var'  if treatment == 0 & ethnic == 2 //& e(sample) == 1
			replace control_mean = `r(mean)' if counter == 2
		qui sum `var'  if treatment == 0 & ethnic == 3 //& e(sample) == 1
			replace control_mean = `r(mean)' if counter == 3
		qui sum `var'  if treatment == 0 & ethnic == 4 //& e(sample) == 1
			replace control_mean = `r(mean)' if counter == 4
			
		format  %3.2f control_mean

	replace counter_l =  counter - 0.4
			
	*Main graph 
	twoway  (bar control_mean counter_l, barwidth(0.4) color(gs6)) ///
			(bar estim counter, barwidth(0.4) color(navy)) ///
			(rcap CI_l CI_h counter , lcolor(black)) /// 
			(scatter  estim counter,msym(none) mlab(estim) mlabpos(12) mlabcolor(black) mlabsize(vsmall))   ///
			(scatter  control_mean counter_l,msym(none) mlab(control_mean) mlabpos(12) mlabcolor(black) mlabsize(vsmall)),   ///
			`ytitle' xtitle(" ") ///
			legend(order(1 "Control Mean" 2 "Impact") size(small)) ///
			xlabel( 1 `" "Pashto" "(N=`N_1')" "' 2 `" "Dari" "(N=`N_2')" "' 3 `" "Uzbek" "(N=`N_3')" "' 4 `" "Turkmen" "(N=`N_4')" "', noticks labsize(vsmall)) ///
			`ylabel'  ///
			subtitle("${subtitle}",size(medsmall))  ///
			graphregion(color(white)) 
 
	graph save    "${output_gr}/cate_`var'_`inter'_treat", replace
	drop counter counter_l CI_l CI_h estim control_mean
		}
	
		grc1leg "${output_gr}/cate_index_sdC_f_empowerment_`inter'_treat.gph" ///			
			"${output_gr}/cate_index_sdC_all_decisions_`inter'_treat.gph" ///
			"${output_gr}/cate_index_sdC_role_prod_act_`inter'_treat.gph" ///
			"${output_gr}/cate_index_sdC_socap_`inter'_treat.gph" ///
			"${output_gr}/cate_index_sdC_social_norms_`inter'_treat.gph" ///
			,   graphregion(color(white)) title("Treatment Effect by ${title}",size(medium)) ///
			title("Treatment Effect (UP HHs)" "With Baseline Controls") legendfrom("${output_gr}/cate_index_sdC_f_empowerment_`inter'_treat.gph")

		graph export "${output_gr2}/1_CATE_`inter'_blcontrols_aspire.pdf" , replace as(pdf) // allHHs
	}
	
	
*********************************End of dofile***********************************************************************
