/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	June 22, 2019
Last udpate on: June 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	*Data for analysis dataset "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	gl data_for_analysis				"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	gl profile_info 					"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	gl f_empowerment_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta"
	gl f_empowerment_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta"

	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"

		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	*use "${data_for_analysis_fl1}", clear
	use "${f_empowerment_fl1}", clear
		merge 1:1 hhid using "${all_HH_interm_nopii_fl1}", keepusing(a10 a10_o) keep(3) nogen
	
	keep if ultra_poor == 1
	
/* Create variable for ethnic
	tab a10, m
	lab def ethnic_l 1 "Dari + Arabic" 2 "Pashto" 3 "Uzbek + Turkmen"
	gen ethnic = 1 if (a10 == 1 | a10 == .n)
	replace ethnic = 2 if a10 == 2
	replace ethnic = 3 if (a10 == 3 | a10 == 4)
	lab val ethnic ethnic_l*/
	
	tab a10, m nol
	lab def ethnic_l 1 "Pashto" 2 "Dari" 3 "Uzbek" 4 "Turkmen" //5 "Arabic"
	gen ethnic = 1 if a10 == 2
	replace ethnic = 2 if a10 == 1
	replace ethnic = 3 if a10 == 3
	replace ethnic = 4 if a10 == 4
	
	lab val ethnic ethnic_l

	loc het_variable "ethnic"
	
	* Merge on baseline covariate 
	preserve 
		use "${f_empowerment_bl}", clear 
			keep hhid index_sdC_f_empowerment_? index_sdC_f_empowerment_3c_? index_sdC_all_decisions_? index_sdC_role_prod_act_? index_sdC_social_capital_? index_sdC_social_norms_?
			rename index_sdC_f_empowerment_3c* index_sdC_empowerment_3c*
			rename * *_bl
			rename hhid_bl hhid
			tempfile covariates
			save `covariates'
	restore 
	
	merge 1:1 hhid using "`covariates'", keep(1 3)
	
	* Create covariate missingness dummy indicator
	forval i = 1/5 {
		foreach var in index_sdC_f_empowerment index_sdC_empowerment_3c index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital index_sdC_social_norms {
			gen `var'_`i'_bl_m = (mi(`var'_`i'_bl))
			replace `var'_`i'_bl = 0 if mi(`var'_`i'_bl)
		}
	}
	
* Controls
	global controls						i.PRA_lottery

	rename *social_capital* *socap*
	rename index_sdC_f_empowerment_3c_? index_sdC_empowerment_3c_?

	global cate_outcome 	index_sdC_empowerment_3c index_sdC_all_decisions index_sdC_role_prod_act index_sdC_socap index_sdC_social_norms
	global interlist 		ethnic


	global title "Primary language"
		
		
	foreach var in $cate_outcome {	
		if "`var'"=="index_sdC_f_empowerment" {
			global subtitle "Women's Empowerment Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_empowerment_3c" {
			global subtitle "Women's Empowerment Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_all_decisions" {
			global subtitle "Decisionmaking Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_role_prod_act" {
			global subtitle "Economic Opportunities Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		if "`var'"=="index_sdC_social_norms" {
			global subtitle "Aspirations for Daughters Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}

		if "`var'"=="index_sdC_socap" {
			global subtitle "Political and Social Capital Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
	gen counter = _n if _n <=4

	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	gen control_mean = .
	
	*Compute the parametric regression on the interaction variables and save the coefficient / CI
	
		* Pashto 
		reg `var'_1 treatment `var'_1_bl `var'_1_bl_m ${controls}, r
			cap mat drop A_`var'_1 
			mat A_`var'_1  = r(table)

			replace estim 	= _b[treatment]  if counter == 1
			replace CI_l 	= A_`var'_1[5,1] if counter == 1
			replace CI_h 	= A_`var'_1[6,1] if counter == 1
			//local N_1 		= A_`var'_1[7,1] // this gives us DF, not the N itself 

		* Dari 
		reg `var'_2 treatment `var'_2_bl `var'_2_bl_m ${controls}, r
			cap mat drop A_`var'_2 
			mat A_`var'_2  = r(table)

			replace estim 	= _b[treatment]  if counter == 2
			replace CI_l 	= A_`var'_2[5,1] if counter == 2
			replace CI_h 	= A_`var'_2[6,1] if counter == 2
			//local N_2 		= A_`var'_2[7,1]
			
		* Uzbek 
		reg `var'_3 treatment `var'_3_bl `var'_3_bl_m ${controls}, r
			cap mat drop A_`var'_3 
			mat A_`var'_3  = r(table)

			replace estim 	= _b[treatment]  if counter == 3
			replace CI_l 	= A_`var'_3[5,1] if counter == 3
			replace CI_h 	= A_`var'_3[6,1] if counter == 3
			//local N_3 		= A_`var'_3[7,1]
			
		* Turkmen 
		reg `var'_4 treatment `var'_4_bl `var'_4_bl_m ${controls}, r
			cap mat drop A_`var'_4 
			mat A_`var'_4  = r(table)

			replace estim 	= _b[treatment]  if counter == 4
			replace CI_l 	= A_`var'_4[5,1] if counter == 4
			replace CI_h 	= A_`var'_4[6,1] if counter == 4
			//local N_3 		= A_`var'_3[7,1]

		format %3.2f estim
		
		* Add N
		qui sum `var'_1 
			local N_1 = `r(N)'

		qui sum `var'_2 
			local N_2 = `r(N)'	
		
		qui sum `var'_3 
			local N_3 = `r(N)'	
		
		* Add control means [CHECK]
		qui sum `var'_1  if treatment == 0 
			replace control_mean = `r(mean)' if counter == 1
		qui sum `var'_2  if treatment == 0 
			replace control_mean = `r(mean)' if counter == 2
		qui sum `var'_3  if treatment == 0 
			replace control_mean = `r(mean)' if counter == 3
			
		format  %3.2f control_mean
			
	*Main graph 
	twoway  (bar estim counter, barwidth(0.8) ) ///
			(rcap CI_l CI_h counter, lcolor(black)) /// 
			(scatter  estim counter,msym(none) mlab(estim) mlabpos(12) mlabcolor(black) mlabsize(vsmall)),   ///
			`ytitle' xtitle(" ") ///
			legend(off) ///
			xlabel( 1 `" "Pashto" "(N=`N_1')" "' 2 `" "Dari" "(N=`N_2')" "' 3 `" "Uzbek" "(N=`N_3')" "', noticks labsize(vsmall)) ///
			`ylabel'  ///
			subtitle("${subtitle}",size(medsmall))  ///
			graphregion(color(white)) 
 
	graph save    "${output_gr}/cate_`var'_eth_treat", replace
	drop counter CI_l CI_h estim control_mean
		}
	
		graph combine "${output_gr}/cate_index_sdC_empowerment_3c_eth_treat.gph" ///			
			"${output_gr}/cate_index_sdC_all_decisions_eth_treat.gph" ///
			"${output_gr}/cate_index_sdC_role_prod_act_eth_treat.gph" ///
			"${output_gr}/cate_index_sdC_socap_eth_treat.gph" ///
			,   graphregion(color(white)) title("Treatment Effect by ${title}",size(medium)) ///
			title("Treatment Effect (UP HHs)" "With Baseline Controls")

		graph export "${output_gr2}/1_CATE_eth_blcontrols__1230.pdf" , replace as(pdf) // allHHs
	
	
	
*********************************End of dofile***********************************************************************
