/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	June 22, 2019
Last udpate on: June 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	*Data for analysis dataset "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	gl f_empowerment_nup_eth_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_nup_eth_fl1.dta"
	gl f_empowerment_control_eth_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_control_eth_fl1.dta"
	
	gl all_HH_interm_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_nopii_fl1.dta"
	gl data_for_analysis_fl1 				"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"

		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	use "${f_empowerment_nup_eth_fl1}", clear
		merge 1:1 hhid using "${all_HH_interm_nopii_fl1}", keepusing(a10 a10_o) keep(1 3) nogen
		//merge 1:1 hhid using "${data_for_analysis_fl1}", keepusing(pweight) assert(2 3) keep(3)
	
* Merge district: I (camila) created this file based on the reports google sheet
	//merge 1:1 hhid using "/Users/mcayala/Downloads/district.dta", assert(2 3) keep(3) nogen
	
/* Create variable for ethnic
	tab a10, m nol
	lab def ethnic_l 1 "Pashto" 2 "Dari + Arabic" 3 "Uzbek + Turkmen"
	gen ethnic = 2 if (a10 == 1 | a10 == .n)
	replace ethnic = 1 if a10 == 2
	replace ethnic = 3 if (a10 == 3 | a10 == 4)
	lab val ethnic ethnic_l */

	tab a10, m nol
	lab def ethnic_l 1 "Pashto" 2 "Dari" 3 "Uzbek" 4 "Turkmen" 5 "Arabic"
	gen ethnic = 1 if a10 == 2
	replace ethnic = 2 if a10 == 1
	replace ethnic = 3 if a10 == 3
	replace ethnic = 4 if a10 == 4
	replace ethnic = 5 if a10 == .n
	lab val ethnic ethnic_l

	loc het_variable "ethnic"
	
* Generate dummies and interactions
	foreach var in `het_variable' {
		tab `var', gen(`var'_)
		
		foreach dummy of varlist `var'_* {
			gen treatX`dummy' = `dummy'*treatment
		}
	}

* Controls
	global controls					 i.PRA_lottery
	global `het_variable'_inter_bl 	`het_variable'_2 `het_variable'_3 `het_variable'_4 `het_variable'_5 
	
	
	//rename index_sdC_social_capital index_sdC_socap

	global cate_outcome 	index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act //index_sdC_socap //index_sdC_social_norms
	global interlist 		ethnic
	
	foreach inter in $interlist {
	*Setting up specific parameters
		if "`inter'"=="ethnic" {
			global title "Primary language"
		}
		
		
	foreach var in $cate_outcome {	
		if "`var'"=="index_sdC_f_empowerment" {
			global subtitle "Women's Empowerment Index (2 components)"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_all_decisions" {
			global subtitle "Decisionmaking Index"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_role_prod_act" {
			global subtitle "Economic Opportunities Index*"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		if "`var'"=="index_sdC_social_norms" {
			global subtitle "Aspirations for Daughters Index"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}

		if "`var'"=="index_sdC_socap" {
			global subtitle "Political and Social Capital Index*"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
	gen counter = _n if _n <=5

	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	
	*Compute the parametric regression on the interaction variables and save the coefficient / CI
		reg `var' ${`inter'_inter_bl}
		
		cap mat drop A_`var'_`inter' 
		mat A_`var'_`inter'  = r(table)

		replace estim 	= _b[_cons] if counter == 1
		replace estim 	= _b[_cons] + _b[`het_variable'_2] 	if counter == 2	
		replace estim 	= _b[_cons] + _b[`het_variable'_3] 	if counter == 3	
		replace estim 	= _b[_cons] + _b[`het_variable'_4] 	if counter == 4
		replace estim 	= _b[_cons] + _b[`het_variable'_5] 	if counter == 5
	
		format %3.2f estim
		
		qui sum `var' if ethnic == 1
			local N_1 = `r(N)'

		qui sum `var' if ethnic == 2
			local N_2 = `r(N)'	
		
		qui sum `var' if ethnic == 3
			local N_3 = `r(N)'	
			
		qui sum `var' if ethnic == 4
			local N_4 = `r(N)'	
			
		qui sum `var' if ethnic == 5
			local N_5 = `r(N)'	
			
	*Main graph
	*			xlabel( 1 `" "Pashto" "(N=`N_1')" "' 2 `" "Dari+ " "Arabic (N=`N_2')" "' 3 `" "Uzbek+Turkmen" "(N=`N_3')" "' , ///

	twoway  (bar  estim counter, barwidth(0.8) ) ///
			(scatter  estim counter,msym(none) mlab(estim) mlabpos(12) mlabcolor(black) mlabsize(vsmall)) ,  ///
			`ytitle' xtitle(" ") ///
			legend(off)  xscale(noline) yscale(noline) ///
			xlabel( 1 `" "Pashto" "(N=`N_1')" "' 2 `" "Dari" "(N=`N_2')" "' 3 `" "Uzbek" "(N=`N_3')" "' 4 `" "Turkmen" "(N=`N_4')" "' 5 `" "Arabic" "(N=`N_5')" "', ///
			noticks labsize(vsmall)) `ylabel'  ///
			subtitle("${subtitle}",size(medsmall))  ///
			graphregion(color(white)) 
 
	graph save    "${output_gr}/cate_`var'_`inter'_nupcontrol", replace
	drop counter CI_l CI_h estim
		}
		
		graph combine ///	
			"${output_gr}/cate_index_sdC_f_empowerment_`inter'_nupcontrol.gph" ///			
			"${output_gr}/cate_index_sdC_all_decisions_`inter'_nupcontrol.gph" ///
			"${output_gr}/cate_index_sdC_role_prod_act_`inter'_nupcontrol.gph" ///
			,   graphregion(color(white)) title("Treatment Effect by ${title}",size(medium)) title("NUP Women Empowerment Index and Components" "by Ethnicity at Follow-Up") subtitle("Baseline-comparable Index Construction") note("*Economic Opportunities Index excludes mobile phone ownership for which data are not availabe at baseline.", size(vsmall))
			
		graph export "${output_gr2}/2_`inter'_nup_blcomp.pdf" , replace as(pdf)
	}
	
	
*********************************End of dofile***********************************************************************
