/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	June 22, 2019
Last udpate on: June 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	gl f_empowerment_pashto_bl		"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_pashto_bl.dta" // pashto-control standardized 
	
	
	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"

		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	use "${f_empowerment_pashto_bl}", clear
	
	tab a10, m nol
	lab def ethnic_l 1 "Pashto" 2 "Dari" 3 "Uzbek" 4 "Turkmen" 5 "Arabic"
	gen ethnic = 1 if a10 == 2
	replace ethnic = 2 if a10 == 1
	replace ethnic = 3 if a10 == 3
	replace ethnic = 4 if a10 == 4
	replace ethnic = 5 if a10 == -97
	lab val ethnic ethnic_l

	loc het_variable "ethnic"
	
* Gen "other" dummy to interact (so that Pashto can come first)
	gen other = (pashto == 0)
	
	rename index_sdC_social_capital index_sdC_socap

* Controls	
	global cate_outcome 	index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_socap index_sdC_social_norms

	global title "Primary language"

	foreach var in $cate_outcome {	
		if "`var'"=="index_sdC_f_empowerment" {
			global subtitle "Women's Empowerment Index"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.4(0.20)0.8 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_all_decisions" {
			global subtitle "Decisionmaking Index"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.4(0.20)0.8 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_role_prod_act" {
			global subtitle "Economic Opportunities Index"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.4(0.20)0.8 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		if "`var'"=="index_sdC_social_norms" {
			global subtitle "Aspirations for Daughters Index"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.4(0.20)0.8 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}

		if "`var'"=="index_sdC_socap" {
			global subtitle "Political and Social Capital Index"
			local 	ytitle 	"ytitle(Standard Deviation of Pashto, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.4(0.20)0.8 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
	gen counter = _n if _n <=2

	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	
	*Compute the parametric regression on the interaction variables and save the coefficient / CI
		reg `var' other
		
		cap mat drop A_`var' 
		mat A_`var'  = r(table)

		* Get the means 
		replace estim 	= _b[_cons] 				if counter == 1
		replace estim 	= _b[_cons] + _b[other] 	if counter == 2	

		
		format %3.2f estim
		
		* Get the CIs for the means 
		replace CI_l 	= A_`var'[5,2] 	if counter == 1
		replace CI_h 	= A_`var'[6,2]  if counter == 1
		
		replace CI_l 	= A_`var'[5,1] 	if counter == 2
		replace CI_h 	= A_`var'[6,1]  if counter == 2
		
		* Add N
		qui sum `var' if other == 0 
			local N_1 = `r(N)'

		qui sum `var' if other == 1
			local N_2 = `r(N)'	
	
	*Main graph
	twoway  (bar  estim counter, barwidth(0.8) ) ///
			(rcap CI_l CI_h counter, lcolor(black)) /// 
			(scatter  estim counter,msym(none) mlab(estim) mlabpos(12) mlabcolor(black) mlabsize(vsmall)) ,  ///
			`ytitle' xtitle(" ") ///
			legend(off)  xscale(noline) yscale(noline) ///
			xlabel( 1 `" "Pashto" "(N=`N_1')" "' 2 `" "Other" "(N=`N_2')" "', noticks labsize(vsmall)) ///
			`ylabel'  ///
			subtitle("${subtitle}",size(medsmall))  ///
			graphregion(color(white)) 
 
	graph save    "${output_gr}/cate_`var'_up_bl", replace
	drop counter CI_l CI_h estim
		}
		
		graph combine ///	
			"${output_gr}/cate_index_sdC_f_empowerment_up_bl.gph" ///			
			"${output_gr}/cate_index_sdC_all_decisions_up_bl.gph" ///
			"${output_gr}/cate_index_sdC_role_prod_act_up_bl.gph" ///
			"${output_gr}/cate_index_sdC_socap_up_bl.gph" ///
			"${output_gr}/cate_index_sdC_social_norms_up_bl.gph" ///
			,   graphregion(color(white)) title("Treatment Effect by ${title}",size(medium)) title("UP Women Empowerment Index and Components by Ethnicity at Baseline") note("*Other ethnicities include: Dari, Uzbek, Turkmen, and Arabic.", size(vsmall))

			
		graph export "${output_gr2}/3_up_pashto_bl_${date}.pdf" , replace as(pdf)
	
	
*********************************End of dofile***********************************************************************
