/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	June 22, 2019
Last udpate on: June 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	*Data for analysis dataset "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	gl data_for_analysis_fl1 			"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	gl data_for_analysis_bl				"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	gl profile_info 					"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	gl f_empowerment_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta"
	gl f_empowerment_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta"

	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"

		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	*use "${data_for_analysis_fl1}", clear
	use "${f_empowerment_fl1}", clear
		merge 1:1 hhid using "${all_HH_interm_nopii_fl1}", keepusing(a10 a10_o) keep(3) nogen
	
	keep if ultra_poor == 1
	
	tab a10, m nol
	lab def ethnic_l 1 "Pashto" 2 "Dari" 3 "Uzbek" 4 "Turkmen" 5 "Arabic"
	gen ethnic = 1	   if a10 == 2
	replace ethnic = 2 if a10 == 1
	replace ethnic = 3 if a10 == 3
	replace ethnic = 4 if a10 == 4
	replace ethnic = 5 if a10 == .n
	lab val ethnic ethnic_l
	
* Drop Arabic speakers for now 
	drop if ethnic == 5
	
* Generate ethnicity dummies	
	tab ethnic, gen(ethnic_)
	
	foreach dummy of varlist ethnic_* {
			gen treatX`dummy' = `dummy'*treatment
	}
	
* Merge on baseline covariate 
	preserve 
		use "${f_empowerment_bl}", clear 
			merge 1:1 hhid using "${data_for_analysis_bl}", keepusing(exp_tot_m_pc_ppp) keep(1 3) nogen
			keep hhid index_sdC_f_empowerment_? index_sdC_f_empowerment_3c_? index_sdC_all_decisions_? index_sdC_role_prod_act_? index_sdC_social_capital_? index_sdC_social_norms_? exp_tot_m_pc_ppp
			rename index_sdC_f_empowerment_3c* index_sdC_empowerment_3c*
			rename * *_bl
			rename hhid_bl hhid
			tempfile covariates
			save `covariates'
	restore 
	
	merge 1:1 hhid using "`covariates'", keep(1 3)
	
* Create covariate missingness dummy indicator
	foreach var in index_sdC_f_empowerment_p index_sdC_empowerment_3c_p index_sdC_all_decisions_p index_sdC_role_prod_act_p index_sdC_social_capital_p index_sdC_social_norms_p exp_tot_m_pc_ppp {
			gen `var'_bl_m = (mi(`var'_bl))
			replace `var'_bl = 0 if mi(`var'_bl)
	}

* Rename incides where the name will be too long 	
	rename *social_capital* *socap*
	rename index_sdC_f_empowerment_3c_? index_sdC_empowerment_3c_?

* Controls
	global controls						i.PRA_lottery
	global ethnic_inter 				ethnic_2 ethnic_3 ethnic_4 treatXethnic_2 treatXethnic_3 treatXethnic_4 
	global cate_outcome 				index_sdC_empowerment_3c index_sdC_all_decisions index_sdC_role_prod_act index_sdC_socap index_sdC_social_norms

	global title "Primary language"
		
	foreach var in $cate_outcome {	
		if "`var'"=="index_sdC_f_empowerment" {
			global subtitle "Women's Empowerment Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.20)1.0 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_empowerment_3c" {
			global subtitle "Women's Empowerment Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.20)1.0 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_all_decisions" {
			global subtitle "Decisionmaking Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.20)1.0 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="index_sdC_role_prod_act" {
			global subtitle "Economic Opportunities Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.20)1.0 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		if "`var'"=="index_sdC_social_norms" {
			global subtitle "Aspirations for Daughters Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.20)1.0 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}

		if "`var'"=="index_sdC_socap" {
			global subtitle "Political and Social Capital Index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(-0.6(0.20)1.0 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		
	gen counter = _n if _n <=4

	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	
	*Compute the parametric regression on the interaction variables and save the coefficient / CI
	
		reg `var'_p treatment `var'_p_bl `var'_p_bl_m ${ethnic_inter} ${controls} exp_tot_m_pc_ppp_bl exp_tot_m_pc_ppp_bl_m, r
		
		cap mat drop A_`var'
		mat A_`var'  = r(table)
		
		* Get the estimates 
		replace estim 	= _b[treatment] 						if counter == 1
		replace estim 	= _b[treatment] + _b[treatXethnic_2] 	if counter == 2	
		replace estim 	= _b[treatment] + _b[treatXethnic_3] 	if counter == 3		
		replace estim 	= _b[treatment] + _b[treatXethnic_4] 	if counter == 4
		
		format %3.2f estim
		
		* Get the CIs for the means 
		replace CI_l 	= A_`var'[5,1]  if counter == 1
		replace CI_h 	= A_`var'[6,1]  if counter == 1
		
	*Computes confidence interval by testing the significance of the sum of the coefficient and using the usual OLS CI formula
	test treatment + treatXethnic_2 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 2
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 2
	
	test treatment + treatXethnic_3 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 3
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 3
		
	test treatment + treatXethnic_4 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 4
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 4
	
		format %3.2f estim
		
		* Add N
		qui sum `var'_p if ethnic == 1
			local N_1 = `r(N)'

		qui sum `var'_p if ethnic == 2
			local N_2 = `r(N)'	
		
		qui sum `var'_p if ethnic == 3
			local N_3 = `r(N)'	
			
		qui sum `var'_p if ethnic == 4
			local N_4 = `r(N)'	
			
	*Main graph 
	twoway  (bar estim counter, barwidth(0.8) ) ///
			(rcap CI_l CI_h counter, lcolor(black)) /// 
			(scatter  estim counter, msym(none) mlab(estim) mlabpos(12) mlabcolor(black) mlabsize(vsmall)),   ///
			`ytitle' xtitle(" ") ///
			legend(off) ///
			xlabel( 1 `" "Pashto" "(N=`N_1')" "' 2 `" "Dari" "(N=`N_2')" "' 3 `" "Uzbek" "(N=`N_3')" "' 4 `" "Turkmen" "(N=`N_4')" "', noticks labsize(vsmall)) ///
			`ylabel'  ///
			subtitle("${subtitle}",size(medsmall))  ///
			graphregion(color(white)) 
 
	graph save    "${output_gr}/cate_`var'_eth_treat", replace
	drop CI_l CI_h estim counter
		}
	
		graph combine "${output_gr}/cate_index_sdC_empowerment_3c_eth_treat.gph" ///			
			"${output_gr}/cate_index_sdC_all_decisions_eth_treat.gph" ///
			"${output_gr}/cate_index_sdC_role_prod_act_eth_treat.gph" ///
			"${output_gr}/cate_index_sdC_socap_eth_treat.gph" ///
			,   graphregion(color(white)) title("Treatment Effect by ${title}",size(medium)) ///
			title("Treatment Effect (UP HHs)" "With Baseline Controls (Outcomes and Total Consumption)") ycommon

		graph export "${output_gr2}/1_CATE_eth_blcontrols_${date}.pdf" , replace as(pdf)
	
	
	
*********************************End of dofile***********************************************************************


	
	
	
	
	
	
	
	
	
	
	
	
	
	
