/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	June 22, 2019
Last udpate on: June 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the Conditional Average Treatment Effect for the main outcomes 

CONTENT:		

INPUTS:     	*Data for analysis dataset "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

OUTPUTS:		

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000

	* Inputs
	global 		data_for_analysis	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	
	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(left) justification(left)) yscale(noline) legend(region(lc(none) fc(none)))

	* Outputs
		global output_gr 		"${TUP_DB}/IE_Main_paper/Output/Raw"
		global output_gr2 		"${TUP_DB}/IE_Main_paper/Output/Final/Figures"

		
********************************************************************************
	** Part 1: Create the different graphs
********************************************************************************

* Open dataset
	use "${data_for_analysis}", clear

keep if ultra_poor == 1

	
*----------------*
* Create indices *
*----------------*	

	* Human Security - Experiences
	*-----------------------------
	
		* Number of preventive measures
			egen 	num_preventive = rowtotal(s8_1 s8_2 s8_3 s8_4 s8_5 s8_6 s8_7 s8_8 s8_9 s8__97)
			replace num_preventive = . if s8__98 == 1

		loc experience_vars "s4 s5 s6 s7 num_preventive s9"
	
	* Human Security - Experiences
	*-----------------------------
			
		loc perception_vars "s14 s15"
	
	* Control dummy
		gen 	control = treatment==0
		replace control = . if mi(treatment)
		lab var control "HH is part of control group"


	loc experience_l	"Human Security - Experiences"
	loc perception_l	"Human Security - Perceptions"

	
	gl all "experience perception"

	foreach index in $all {
		display "`index'"
		des ``index'_vars'
		egen index_sdC_`index' = weightave(``index'_vars'), normby(control)
		lab var index_sdC_`index' "``index'_l'"	
	}	
		egen index_sdC_human_sec = weightave(index_sdC_experience index_sdC_perception), normby(control)
		lab var index_sdC_human_sec "Human Security"
	
	foreach var in experience perception human_sec {
		xtile 	`var'_q = index_sdC_`var', nq(3)
		replace `var'_q = `var'_q - 1
	}
	
	loc het_variable "experience_q perception_q human_sec_q"
	
* Generate dummies and interactions
	foreach var in `het_variable' {
		tab `var', gen(`var'_)
		
		foreach dummy of varlist `var'_* {
			gen treatX`dummy' = `dummy'*treatment
		}
	
	
* Controls
	global controls					i.PRA_lottery
	global `var'_inter_bl 		`var'_2 `var'_3 treatX`var'_2 treatX`var'_3 
	di "${`var'_inter_bl}"
	}
	

	rename tot_lstock_value_ppp lstock_value_ppp
	rename exp_tot_m_pc_c_ppp exp_tot_ppp
	rename psy_indexC_sdC_fl1 psy_index
	global cate_outcome 	exp_tot_ppp lstock_value_ppp wealth_score psy_index
	global interlist 		experience_q perception_q human_sec_q

	
	foreach inter in $interlist {
	*Setting up specific parameters
		if "`inter'"=="experience_q" {
			global title "Human Security - Experiences"
		}
		
		if "`inter'"=="perception_q" {
			global title "Human Security - Perceptions"
		}
		if "`inter'"=="human_sec_q" {
			global title "Human Security - Experiences and Perceptions"
		}			
				
			
	foreach var in $cate_outcome {	
		if "`var'"=="exp_tot_ppp" {
			global subtitle "Per Capita Consumption"
			local 	ytitle 	"ytitle(US PPP, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(25)50 , noticks format(%9.0fc)  labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="lstock_value_ppp" {
			global subtitle "Value of Livestock "
			local 	ytitle 	"ytitle(US PPP, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(500)1000, noticks format(%9.0fc) labsize(vsmall) angle(0))"
		}
		
		if "`var'"=="wealth_score" {
			global subtitle "HH Asset Ownership Index (PCA)"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}
		if "`var'"=="psy_index" {
			global subtitle "Psy well-being index"
			local 	ytitle 	"ytitle(Standard Deviation of Control, margin(medsmall) size(small))"
			local 	ylabel 	"ylabel(0(0.30)0.9 0 "0", noticks format(%9.2f) labsize(vsmall) angle(0))"
		}


	gen counter = _n if _n <=3

	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	
	*Compute the parametric regression on the interaction variables and save the coefficient / CI
		reg `var' treatment ${`inter'_inter_bl} ${controls} , r
		
		cap mat drop A_`var'_`inter' 
		mat A_`var'_`inter'  = r(table)

	*  Dowlat Abad District
		replace estim 	= _b[treatment] if counter == 1
		replace CI_l 	= A_`var'_`inter'[5,1] 	if counter == 1
		replace CI_h 	= A_`var'_`inter'[6,1]  	if counter == 1
	* Dehdadi District & Nahre Shahee District
		replace estim 	= _b[treatment] + _b[treatX`inter'_2] 	if counter == 2	
	* Khulm  District
		replace estim 	= _b[treatment] + _b[treatX`inter'_3] 	if counter == 3
		
		
	*Computes confidence interval by testing the significance of the sum of the coefficient and using the usual OLS CI formula
	test treatment + treatX`inter'_2 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 2
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 2
	
	test treatment + treatX`inter'_3 = 0
		replace CI_h 	= estim * (1 + invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))  	if counter == 3
		replace CI_l 	= estim * (1 - invttail(r(df_r),0.025)/invttail(r(df_r),r(p)/2))	if counter == 3
	

	*Main graph
	twoway  (bar  estim counter, barwidth(0.8) ) ///
			(rcap CI_l CI_h counter , lcolor(black)) /// 
			(scatter  estim counter,msym(none) mlab(estim) mlabpos(12) mlabcolor(black) mlabsize(vsmall)) ,  ///
			`ytitle' xtitle(" ") ///
			legend(off)  xscale(noline) yscale(noline) ///
			xlabel( 1 "Bottom third" 2 "Middle third" 3 "Top third", noticks labsize(vsmall)) ///
			`ylabel'  ///
			subtitle("${subtitle}",size(medsmall))  ///
			graphregion(color(white)) 
 
	graph save    "${output_gr}/cate_`var'_`inter'", replace
	drop counter CI_l CI_h estim
		}
		
		graph combine ///
			"${output_gr}/cate_exp_tot_ppp_`inter'.gph" ///
			"${output_gr}/cate_lstock_value_ppp_`inter'.gph" ///
			"${output_gr}/cate_wealth_score_`inter'.gph" ///			
			"${output_gr}/cate_psy_index_`inter'.gph" ///			
			, name(`inter')  graphregion(color(white)) title("Treatment Effect by ${title}",size(medium))
	
		graph export "${output_gr2}/CATE_`inter'.pdf" , replace as(pdf)
	}
	
	
	-
	
*********************************End of dofile***********************************************************************
