/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 5, 2019
Last udpate on: Mar 5, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates consumption variable

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl consumption_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/consumption_fl1.dta"
	gl current_roster_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1.dta"
	gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl market_imputed_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"
	gl nonfood_consumption_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/nonfood_consumption_fl1.dta"
	gl TUP_livestock_fl1		"${TUP_MDC}/Followup_1/DataSets/Intermediate/r_livestockrecd_tup_fl1.dta"
	gl TUP_sick_livestock_fl1	"${TUP_MDC}/Followup_1/DataSets/Intermediate/r_livestocksick_tup_fl1.dta"
	gl TUP_sold_livestock_fl1	"${TUP_MDC}/Followup_1/DataSets/Intermediate/r_livestocksold_tup_fl1.dta"
	gl TUP_dead_livestock_fl1	"${TUP_MDC}/Followup_1/DataSets/Intermediate/r_livestockdead_tup_fl1.dta"
	gl TUP_animal_products_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/rb_animalproduct_tup_fl1.dta"	
	gl fl1_profile_info_nopii "${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"

	
* Outputs
	gl implementation_stats_fl1	"${TUP_DB}/Followup_1/Output/Raw/implementation_stats_fl1.xlsx"


********************************************************************************
	** Part 1: TUP elements
********************************************************************************

use "${all_HH_nopii_fl1}", clear

* Merging treatment and PRA
	merge 1:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment PRA_lottery) keep(1 3) nogen
	keep if ultra_poor == 1

* Fix labels and correct denominator
	loc element_vars "r80 r81 r13 r54 r1 r3 r9 r11 r16 r24"
	
	loc r80_l "Is aware of the CHA TUP project"
	loc r81_l "Received any of the project's benefits"
	loc r13_l "Received livestock"
	loc r54_l "Received food supplement"
	loc r1_l "Received the animal rearing training"
	loc r3_l "Received the monthly stipend support"
	loc r9_l "Attended the health and hygiene training"
	loc r11_l "Attended the training for Saving and Livelihood"
	loc r16_l "Was visited by CHA project staff"
	loc r24_l "Received support to enroll children in school"
	
	foreach var of local element_vars {
		lab var `var' "``var'_l'"
		if !inlist("`var'", "r81") {
			di "`var' this works"
			replace `var'=0 if mi(`var')
		}
	}
	
* Export table
	tempfile t_c
	local rank 0
	
	foreach var of local element_vars  { 
		preserve
			gen count = !mi(`var')
			collapse (mean) mean = `var' (sum) N = count, by(treatment)
			loc rank (`rank' + 1)
			qui gen rank  = `rank'
			qui gen var  = "`var'"
			qui gen label = "``var'_l'"
			qui reshape wide mean N, i(var label) j(treatment)
			keep rank var label mean? N?
			order rank var label mean? N?
			if "`var'" != "r80" {
				qui append using `t_c'
			}
			qui save `t_c', replace
		restore
	}
	
	use `t_c', clear
	sort rank
	order var label N0 mean0 N1 mean1
	drop rank
	export excel using "${implementation_stats_fl1}", sheet("TUP elements (raw)") sheetreplace
	
********************************************************************************
	** Part 2: TUP livestock
********************************************************************************

use "${TUP_livestock_fl1}", clear

* Get treatment variable
	merge m:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment) keep(3) nogen
	
* Merge info for sick livestock
	merge 1:1 hhid type_livestock using "${TUP_sick_livestock_fl1}", assert(2 3) keep(3) nogen keepus(r30 r31 r34 r34_o r35* r35_o r36)
	
* Merge info for sold livestock
	merge 1:1 hhid type_livestock using "${TUP_sold_livestock_fl1}", assert(2 3) keep(3) nogen keepus(r37 r38 r39 r41_*)
	replace r38=. if r38>10

* Merge info for dead livestock
	merge 1:1 hhid type_livestock using "${TUP_dead_livestock_fl1}", assert(2 3) keep(3) nogen keepus(r46 r47)	
	
* Keep only the ones we have information
	keep if r25==1 
	isid hhid //no household received more than one type of livestock
	keep if treatment == 1
	
* sickness
	tab r34
	
* Fix denominator
	* Sick livestock
		replace r31 = 0 if r30 == 0
	
	* Sold livestock
		replace r38 = 0 if r37 == 0
		
	* Dead livestocl
		replace r47 = 0 if r46 == 0
	
* Generate variables for stats
	tab type_livestock, gen(livestock_)
	gen pregnant_breastfeed = inlist(r82, 1, 2, 3)
	
	loc livestock_vars "livestock_1 livestock_2 livestock_3 r26_grown r26_baby r27_grown r27_baby pregnant_breastfeed r28 r74 r30 r31 r37 r38 r39 r41_1 r41_2 r41_3 r41_4 r41_5 r41_6 r41_7 r41_8 r41_9 r41_10 r41__97 r46 r47"
	
	loc livestock_1_l "Received cows"
	loc livestock_2_l "Received goats"
	loc livestock_3_l "Received sheep"
	loc r26_grown_l "Total grown livestock received"
	loc r26_baby_l "Total baby livestock received"
	loc r27_grown_l "Total female grown livestock received"
	loc r27_baby_l "Total female livestock received"
	loc pregnant_breastfeed_l "Any livestock is pregnant or breastfeeding"
	loc r28_l "Total living babies the livestock gave birth to"
	loc r74_l "Total livestock still owned"
	loc r30_l "Any livestock got sick in a way that affected its productivity"
	loc r31_l "Total livestock that got sick"
	loc r37_l "Sold any livestock or the babies they gave birth to"
	loc r38_l "Total livestock sold"
	loc r39_l "Total earning from sale of livestock"
	loc r46_l "Any of the livestock or the babies they gave birth to died"
	loc r47_l "Total livestock that died"
	

	foreach var of local livestock_vars {
		if inlist("`var'", "r41_1", "r41_2", "r41_3", "r41_4", "r41_5") {
		}
		else if inlist("`var'", "r41_6", "r41_7", "r41_8", "r41_9", "r41_10", "r41__97") {
		}
		else {
			lab var `var' "``var'_l'"
		}
		
	}
	
* Export table  
	tempfile livestock
	local rank 0

	foreach var of local livestock_vars  { 
		preserve
			local l_`var' : variable label `var'
			gen count = !mi(`var')
			collapse (mean) mean = `var' (sum) N = count
			loc rank (`rank' + 1)
			qui gen rank  = `rank'
			qui gen var  = "`var'"
			qui gen label = "`l_`var''"
			keep rank var label mean N
			order rank var label mean N
			if "`var'" != "livestock_1" {
			qui append using `livestock'
			}
			qui save `livestock', replace
		restore
	}
	
*----------------------------------------*
* Additional variables from main dataset *
*----------------------------------------*

use "${all_HH_nopii_fl1}", clear

	* Get treatment variable
		merge 1:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment) keep(3) nogen

keep if treatment == 1
* Generate variables for stats
	gen 	r21_0 = 1 if inlist(r21,0,1)
	replace r21_0 = 0 if inlist(r21,2)
	gen 	r21_1 = 1 if inlist(r21,1)
	replace r21_1 = 0 if inlist(r21,0)
	
	loc livestock_vars "r51 r52_1 r52_2 r52_3 r52_4 r52__97 r55 r5 r6 r21_0 r21_1"
	
	loc r51_l "Any livestock was replaced by CHA"
	loc r55_l "Times received food supplement"
	loc r5_l "Average stipend received per month (Afghani)"
	loc r6_l "Times received the stipend"
	loc r21_0_l "Has a TUP ID"
	loc r21_1_l "Used TUP ID to refer to public health institutions"
	

	foreach var of local livestock_vars {
		if inlist("`var'", "r52_1", "r52_2", "r52_3", "r52_4", "r52__97") {
		}
		else {
			lab var `var' "``var'_l'"
		}
		
	}	
	
* Export table  

	foreach var of local livestock_vars  { 
		preserve
			local l_`var' : variable label `var'
			gen count = !mi(`var')
			collapse (mean) mean = `var' (sum) N = count
			loc rank (`rank' + 1)
			qui gen rank  = `rank'
			qui gen var  = "`var'"
			qui gen label = "`l_`var''"
			keep rank var label mean N
			order rank var label mean N
			if "`var'" != "r51_l" {
			qui append using `livestock'
			}
			qui save `livestock', replace
		restore
	}
	
	use `livestock', clear
	sort rank
	order var label N mean
	drop rank
	export excel using "${implementation_stats_fl1}", sheet("TUP livestock (raw)") sheetreplace	
	
	
	-
		
*----------*
* Products *
*----------*
		use "${TUP_livestock_fl1}", clear

	* Get treatment variable
		merge m:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment) keep(3) nogen
		
	* Keep only the ones we have information
		keep if r25==1	& treatment == 1
		tempfile sample
		save 	`sample'
	
		
use "/Volumes/Camila/Dropbox/World Bank/TUP/DataWork/Followup_1/DataSets/Intermediate/TUP_animal_products_fl1.dta", clear
	* Get treatment variable
		merge m:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment) keep(3) nogen
		keep if treatment ==1
merge m:1 hhid using 	`sample', assert(3) nogen
keep if r73 == 1
tab product

* dummy if they sold production
replace r75 = .d if round(r75,0.01)==.99
replace r76 = .d if r75 == .d

gen sold = 1 if r75 > 0 & !mi(r75)
replace sold = 0 if r75== 0
bys hhid: egen sold_hh = max(sold)
bys hhid: gen count = _n
tab sold_hh if count == 1

bys hhid: egen revenue = sum(r76)
sum revenue if count == 1 & sold_hh==1
sum revenue if count == 1 & sold_hh==1, d

*---------*
* Stipend *
*---------*


use "${all_HH_nopii_fl1}", clear

	* Get treatment variable
		merge 1:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment) keep(3) nogen

keep if treatment == 1

preserve
collapse (mean) r7_1 r7_2 r7_3 r7_4 r7_5 r7_6 r7_7 r7_8 r7_9 r7_10 r7_11 r7_12 r7_13 r7__97 r7__99
restore
collapse (mean) r8_1 r8_2 r8_3 r8_4 r8_5 r8_6 r8_7 r8_8 r8_9 r8_10 r8_11 r8_12 r8_13 r8__97 r8__99


tab1 r21 r22 r23 r24

*-----------------------*
* Livestock still owend *
*-----------------------*

	
use "${TUP_livestock_fl1}", clear

* Get treatment variable
	merge m:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment) keep(3) nogen
		
* Keep only the ones we have information
	keep if r25==1 
	isid hhid //no household received more than one type of livestock
	keep if treatment == 1	
	
	collapse (mean) r74, by(type_livestock)
	
*-----------------*
* Livestock stock *
*-----------------*

	gl data_for_analysis_bl				"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	gl data_for_analysis	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

	use "${data_for_analysis_bl}", clear
	
* Keep relevant variables
		keep hhid k6* k7* k8* treatment
		
gen ultra_poor = 1 if hhid <5000
replace ultra_poor = 0 if hhid >5000
tab k6_1 ultra_poor, m		
drop if ultra_poor == 0
			 
			 	   
	* Rename so we can create the new variables
		forval varnum=1/17 {
			display "k6_`varnum'"
			replace k6_`varnum' = 0 if k6_`varnum' == .n
			rename k6_`varnum' k6_`varnum'_old
		}
		
	* Create variables
		forval asset=1/17 {
			gen k6_`asset' =  .
				forval varnum=1/17 {
					display "k6_`varnum'_old"
					tab k6_`varnum'_old if k6_`varnum'_old==`asset' | mi(k6_`varnum'_old), m
					replace k6_`asset' = 1 if k6_`varnum'_old==`asset'
					replace k6_`asset' = 0 if k6_`varnum'_old!=`asset' & !mi(k6_`varnum'_old) & mi(k6_`asset')
					replace k6_`asset' = .r if k6_`varnum'_old==.r
					replace k6_`asset' = .d if k6_`varnum'_old==.d
					tab k6_`asset', m
				}
		}
	

	* Reshape
		drop *_old k6_17 k6_16
		reshape long k6_ k7_ k8_ , i(hhid) j(livestock)		
		rename *_ *
				   
	* Cleaning			
		* Recode -98 and -99
			recode livestock (99=-99)
		
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in k7 k8 {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}
			
		* Labels
			lab var hhid "Household ID"
			lab var livestock "Livestock"
			lab var k6 "Does your household own any of the following livestock:"
			lab var k6_o1 "If other, please specify."
			lab var k6_o2 "If other, please specify."
			
		* Label define
			lab def livestock_l 1 "Cows" 2 "Bulls" 3 "Horses" 4 "Donkeys" 5 "Goats" ///
								6 "Sheep" 7 "Chickens" 8 "Ducks" 9 "Turkeys" ///
								10 "Gooses" 11 "Rabbits" 12 "Guinea fowl" 13 "Bee hives" ///
								14 "Other animal 1 (please specify)" ///
								15 "Other animal 2 (please specify)" 0 "None" ///
								-99 "Don’t Know "
			lab val livestock livestock_l
			
		* Drop if "none" or "don't know"
	drop if inlist(livestock, -99, 0)

* Drop household without this information (no MHHH survey -- 34 households)
	drop if mi(k6)
	
* Does the household own?
	gen lstock_yes = k6
	
* Quantity owned
	gen 	lstock_num = k7 
	replace lstock_num = 0 if k6==0	
	
	drop k6 k6_o1 k6_o2 k7  k8
	rename * *_
	rename (hhid_ livestock_ treatment_) (hhid livestock treatment)
	reshape wide lstock_yes_ lstock_num_ , i(hhid) j(livestock)
	
* Labeling and renaming
	loc	lstock1		cow 
	loc	lstock2		bull
	loc	lstock3		horse
	loc	lstock4		donkey
	loc	lstock5		goat
	loc	lstock6		sheep
	loc	lstock7		chicken
	loc	lstock8		duck
	loc	lstock9		turkey
	loc lstock10	goose
	loc lstock11	rabbit
	loc lstock12	guineafowl
	loc lstock13	beehive
	loc lstock14	otherlstock1
	loc lstock15	otherlstock2
	
	loc lstock_yes_l "HH owns any"
	loc lstock_num_l "Number of owned"
	
	loc vars "lstock_yes lstock_num "
	
	foreach var of local vars {
		forval lstocknum=1/15 {
			rename `var'_`lstocknum' `var'_`lstock`lstocknum''
			lab var `var'_`lstock`lstocknum'' "``var'_l' `lstock`lstocknum''"
			if inlist("`var'", "lstock_value", "lstock_value_w", "lstock_value_yes", "lstock_value_w_yes", "lstock_value_goat") {
				lab var `var'_`lstock`lstocknum'' "Total value of `lstock`lstocknum'' ``var'_l'"
				*histogram `var'_`lstock`lstocknum'' if lstock_yes_`lstock`lstocknum''==1, percent name(graph_`var'_`lstocknum', replace)
			}
		}
	}			
	
	gen baseline = 1
	tempfile lstock_num_bl
	save	`lstock_num_bl'
	
	use "${data_for_analysis}", clear
	drop baseline
	gen baseline = 0
	
	append using `lstock_num_bl'
	bys hhid: gen count = _N
	drop if count != 2
	
		collapse (mean) lstock_num_cow lstock_num_bull lstock_num_horse lstock_num_donkey ///
	lstock_num_goat lstock_num_sheep lstock_num_chicken lstock_num_duck lstock_num_turkey ///
	lstock_num_goose lstock_num_rabbit lstock_num_guineafowl lstock_num_beehive ///
	lstock_num_otherlstock1 lstock_num_otherlstock2, by(baseline treatment)

	
*-----------------*
* others *
*-----------------*
	
use "${data_for_analysis_bl}", clear
keep hhid child_in_schooling_age
tempfile school_age
save	`school_age'

use "${all_HH_nopii_fl1}", clear

	* Get treatment variable
		merge 1:1 hhid using "${fl1_profile_info_nopii}", keepus(treatment) keep(3) nogen
		merge 1:1 hhid using `school_age', keep(1 3)
		
keep if treatment == 1


tab1 r21 r22 r23 
tab1 r24 if child_in_schooling_age>0 & !mi(child_in_schooling_age)
	
	
/*

	use "${data_for_analysis}", clear
	
	collapse (mean) lstock_num_cow lstock_num_bull lstock_num_horse lstock_num_donkey ///
	lstock_num_goat lstock_num_sheep lstock_num_chicken lstock_num_duck lstock_num_turkey ///
	lstock_num_goose lstock_num_rabbit lstock_num_guineafowl lstock_num_beehive lstock_num_otherlstock1 lstock_num_otherlstock2
