/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Nov 13, 2018
Last udpate on: Feb 17, 2018

Written by:  	Rebecca de Guttry and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans the endline database for the Lady of the Household,
				Male Head of the Household and Targeting. 
		


CONTENT:		Part 0: Create globals for directories and files 
				Part 1: Importing and basic SurveyCTO cleaning raw data
				Part 2: Define programs to be used for cleaning
				Part 3: Basic cleaning for each dataset
				Part 4: Merge and append of all HH-level surveys
				
INPUTS:   		
  	

OUTPUTS:     	


Notes 10/2020:

	NB: b13 renamed b11 to follow the survey 
	
	NB3: may want to rethink changing file names since it creates more things to edit further down the line...
			e.g., "all_HH_interm_nopii_fl1.dta" is often called to pull some variables from there, but the "new" 
			equivalent file is called "all_HH_nopii_fl1.dta"
			
	NB4: there are some vars generated by (constructed in) SCTO that are used in the roster cleaning do-file,
			e.g., hh_mem, hh_head_gender, respondent_gender, time_collection time_endinteraction, hhh_name2 lady_hh2
				
	rename "hh_mem" (SCTO-generated var) to "b3" (which matches the Questionnaire)	
	
	Question: we should probably drop "matched_labresults" from public data?
	
	"Saveold" us not working because some var labels are too long for Stata 13... thought the limit was 80 in v.13, but apparently not.
	
	
				
				
*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Intermediate data no PII - All surveys
		global LHH_allsvys_raw_fl1_nopii "${TUP_DB}/Followup_1/DataSets/Raw/LHH_allsvys_raw_fl1_nopii.dta"
		*global LHH_allsvys_raw_fl1_nopii "${Dropbox}/\DataWork_CodeReview2\Followup_1\DataSets\Raw/LHH_allsvys_raw_fl1_nopii.dta"
		global MHHH_allsvys_raw_fl1_nopii "${TUP_DB}/Followup_1/DataSets/Raw/MHHH_allsvys_raw_fl1_nopii.dta"
		*global MHHH_allsvys_raw_fl1_nopii "${Dropbox}/\DataWork_CodeReview2\Followup_1\DataSets\Raw/MHHH_allsvys_raw_fl1_nopii.dta"
		global Targ_allsvys_raw_fl1_nopii "${TUP_DB}/Followup_1/DataSets/Raw/Targ_allsvys_raw_fl1_nopii.dta"
		*global Targ_allsvys_raw_fl1_nopii "${Dropbox}/\DataWork_CodeReview2\Followup_1\DataSets\Raw/Targ_allsvys_raw_fl1_nopii.dta"

	* Village anonymized
		gl village_anonymized 	"${TUP_DB_PII}/Profile_and_merging\DataSets\Intermediate/village_anonymized.dta" 
				
	* Profile information 	
		global profile_info "${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"

	* Cortisol results
		gl cortisol_results_fl1 "${TUP_DB}/Followup_1/DataSets/Intermediate/cortisol_results_fl1.dta"

	* Codebook
		gl codebook				"${TUP_DB}/Followup_1/Documentation/"

* Outputs
	
	* Intermediate data no PII - Stata format
		global LHH_interm_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/LHH_interm_nopii_fl1.dta"
		global MHHH_interm_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/MHHH_interm_nopii_fl1.dta"
		global Targ_interm_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/Targ_interm_nopii_fl1.dta"
	
	* MDC data (with roster vars)
		global LHH_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/LHH_nopii_fl1.dta"
		global MHHH_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/MHHH_nopii_fl1.dta"
		global Targ_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/Targ_nopii_fl1.dta"
		
	* MDC data (NO roster vars)
		global MHHH_norost_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/MHHH_norost_nopii_fl1.dta"
		global all_HH_interm_rost_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_rost_nopii_fl1.dta" // WITH roster variables 

	* All households
		gl all_HH_interm_nopii_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_nopii_fl1.dta"
		gl all_HH_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta" // this is merged/appended MDC data WITHOUT roster variables

********************************************************************************
	** Part 2: Define programs to be used for cleaning
********************************************************************************

 cap program drop hh_svy_clean
 program define hh_svy_clean
		
	set trace on	
		
	* HH ID
		clonevar hhid = hh_id //  HH id
			lab var hhid "Household ID"
			assert !mi(hhid)
			assert !inlist(hhid,1000,5000) // assert no test surveys
			drop hh_id
	
	* Survey
		drop survey // preloaded in survey
		gen survey = ${survey}
			lab define survey 1 "LHH" 2 "MHHH" 3 "Targeting" 
			lab val survey survey
			lab var survey "Type of survey administered"
	
	* Enumerator ID, name, and gender
		clonevar enum_id	= a2
			lab var enum_id "Interviewer ID"
			assert !mi(enum_id)
		decode enum_id, gen(enum_name)
			lab var enum_name "Interviewer name"
			assert !mi(enum_name)
			drop enum_id enum_name
			label drop a2

	* Supervisor ID and name
		clonevar super_id	= a3
			lab var super_id "Supervisor ID"
			assert !mi(super_id)
		decode super_id, gen(super_name)
			lab var super_name "Supervisor name"
			assert !mi(super_name)
			drop super_id super_name
			label drop a3
			
	* Date
		drop date
		gen date=date(date_f,"DMY")

		* For the ones where date has a different format
			tempvar date_t
			gen `date_t' = date(date_f, "YMD")
			replace date=`date_t' if mi(date)
			format date %td
			lab var date "Survey date"
				drop date_f
	
	* Consent vars
		clonevar consent_svy = a12
			lab var consent_svy "Survey was consented"
		
		if inlist(${survey},1,2) { // LHH and MHHH
			lab var a12_saliva "Collection of a saliva sample was consented"
		}
		if inlist(${survey},1,3) { // LHH and Targeting
			lab var a12_mobile "Collection and use of mobile phone usage data was consented"
		}

		* Check that there is no conflicting consent info
			// If this assert fails:
				// deactivate the "preserve"
				// find the survey that violates the command:
					// bys hhid (consent_svy): gen test=(consent_svy[1]==consent_svy[_N])
					// br hhid key date a12 a6 if test==0
				// report issue in Issues tab with ID = svy_consent_[hhid] (e.g., LHH_consent_1234)
				// add survey keys to the list of conflicting consent issues pending resolution
				// once the issue is resolved, remove from the list
			preserve
				global pending_conflicting_consent "inlist(key, "")" 
				keep if !${pending_conflicting_consent}
				keep if !mi(consent_svy)
				bys hhid (consent_svy): assert consent_svy[1]==consent_svy[_N]
			restore
	
	* Survey complete
		gen complete = (consent_svy==1)
			lab var complete "Survey was completed"
			lab val complete yesno
	
	* Respondent gender
		gen respondent_gender = . // filled out below differently for each survey
			lab var respondent_gender "Respondent gender (calculated)"
			lab val respondent_gender gender
		if ${survey}==1 { // LHH
			replace respondent_gender = 2 if (a8==1 | a9==1) // if LHH is available or not at home
			replace respondent_gender = 1 if (a8_m==1 | a9_m==1) // if MHHH is available or not at home
		} 
		if ${survey}==2 { // MHHH
			replace respondent_gender = 1
		}
		if ${survey}==3 { // Targeting
			forval index = 1/20 {
				destring respondent_sex_`index',replace
				assert mi(respondent_gender) if !mi(respondent_sex_`index')
				replace respondent_gender = respondent_sex_`index' if !mi(respondent_sex_`index')
			}
		}
		assert !mi(respondent_gender) if complete==1
		
		label val respondent_gender b6_1
		
 
	* Time vars
	
	* For those time vars localized by SurvyeCTO, convert back to Afghanistan time 
		/* Note from SurveyCTO support team: 
			Time, datetime and date fields values are localised. This includes 
			any value which is a recognised time value. The exception might be 
			if a time value is stored as a string, as in the expression, 
			once(format-date-time(now(), '%Y-%b-%e %H:%M:%S')) */
		
		* Vars to be converted to Afghanistan time
			// time fields (type=time)
				loc timefields "time_a time_f a18_v a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17 a8_m_av_time"
			foreach var in `timefields' {
				cap confirm var `var' 
				if !_rc { // if var exists
					gen double `var'_d = clock(`var', "hms") + (3600000 * $time_diff)
					format `var'_d %tc_HH:MM
					loc l`var' : var lab `var'
					drop `var'
					rename `var'_d `var'
					lab var `var' "`l`var''"
				}
			}
			
			// SurveyCTO automatic vars
				loc sctovars "starttime endtime submissiondate"
			foreach var in `sctovars' {
					replace `var' = `var' + (3600000 * $time_diff)
				} 
		
		* Other times (formatted, so not localized)
			// format-date-time(now(),'%H:%M')
				loc times "time time_collection"
			// once(format-date-time(now(),'%H:%M'))
				loc times_once "time_collection_2"
					
			foreach var in `times' `times_once'  {
				cap confirm var `var' 
				if !_rc { // if var exists
					gen double `var'_d = clock(`var', "hm")
					format `var'_d %tc_HH:MM
					loc l`var' : var lab `var'
					drop `var'
					rename `var'_d `var'
					lab var `var' "`l`var''"
				}
			}

		* Timestamps (formatted, so not localized)
			// format-date-time(now(), '%Y-%b-%e %H:%M:%S')
				loc timestamps "time_startinteraction0 time_startinteraction time_start_b time_end_b time_begin_k time_end_k time_begin_r time_end_r time_begin_c time_end_c time_begin_e time_end_e time_begin_l time_end_l time_begin_f imm_t0 imm_t1 time_end_f time_begin_h time_end_h time_begin_i time_end_i time_begin_n time_end_n time_begin_u1 time_end_u1 time_begin_s time_end_s time_begin_t time_end_t time_begin_u2 time_end_u2 time_begin_j time_end_j time_begin_m time_end_m time_begin_m_m time_end_m_m time_begin_d time_end_d time_begin_g time_end_g time_begin_v time_end_v time_begin_saliva time_endinteraction time_begin_do time_end_do time_begin_q time_end_q"
			// once(format-date-time(now(), '%Y-%b-%e %H:%M:%S'))
				loc timestamps_once "time_startinteraction0_2 time_startinteraction_2 time_start_b_2 time_begin_k_2 time_begin_r_2 time_begin_c_2 time_begin_e_2 time_begin_l_2 time_begin_f_2 time_begin_h_2 time_begin_i_2 time_begin_n_2 time_begin_u1_2 time_begin_s_2 time_begin_t_2 time_begin_u2_2 time_begin_j_2 time_begin_m_2 time_begin_d_2 time_begin_g_2 time_begin_v_2 time_begin_saliva_2 time_begin_do_2 time_begin_q_2"
			
			foreach var in `timestamps' `timestamps_once'  {
				cap confirm var `var' 
				if !_rc { // if var exists
					gen double `var'_d = clock(`var', "YMDhms")
					format `var'_d %tc_HH:MM:SS
					loc l`var' : var lab `var'
					drop `var'
					rename `var'_d `var'
					lab var `var' "`l`var''"
				}
			}
		* Rename timestamp of start of roster section to match other names
			if inlist($survey,1,3) {
				rename time_start_b time_begin_b
				rename time_start_b_2 time_begin_b_2
			} 
		
	* Check that complete submissions are isid based on hhid 
		//  If it fails: 
			// deactivate the "preserve" command
			// find the survey that violates the command
				// duplicates tag hhid,gen(dup)
				// br survey hhid date key if dup!=0
			// add a new issue with ID: "dup_[svy]_[hhid]" (e.g., dup_MHHH_2001")
			// add the problematic ID to the list of IDs pending resolution
			// once the issue is resolved, remove it from the list of IDs pending resolution
		preserve
			keep if complete==1
			global pending_dup_key "inlist(key,"")"
			global pending_dup_hhid "inlist(hhid,)"
				// list of surveys pending resolution (pending issues: )
			drop if ${pending_dup_key}
			*isid hhid // no duplicates
		restore
	
	* Flag for duplicate survey 
		gen hhid_dup_flag=(${pending_dup_key})
			lab var hhid_dup_flag "FLAG - Duplicate complete survey (pending resolution)"
			lab val hhid_dup_flag yes_no
			
	* Check that not consented surveys are isid based on hhid
		preserve
			keep if consent_svy == 0 
			global pending_dup_noconsent_key "inlist(key,"")" 
				// list of surveys pending resolution (pending issues:)
			drop if ${pending_dup_noconsent_key}
			*isid hhid // no duplicates
		restore	

	/* Flag HH that moved (based on records)
		gen HH_moved = ""
			replace HH_moved = HH_moved + "Issue = hh_status_1327" if hhid==1327
			replace HH_moved = HH_moved + "Issue = hh_status_1343" if hhid==1343	
			replace HH_moved = HH_moved + "Issue = hh_status_1961" if hhid==1961	
			replace HH_moved = HH_moved + "Issue = hh_status_1497" if hhid==1497	*/
			
	* Keep only consented surveys
		keep if complete==1
		
	* Remove incorrect HH
		merge 1:1 hhid using ${profile_info}, keepusing(ultra_poor flag_no_right_hh) nogen keep(1 3)
			drop if flag_no_right_hh == 1 
			drop flag_no_right_hh
	
	* Drop helping vars constructed above and rename village (want MDC data varnames to match survey)
		cap drop consent_svy
		cap drop consent_phone
		cap drop consent_saliva
		drop complete hhid_dup_flag
		rename village a6
	* We use SCTO constructed hh_mem, but rename it to b3 which is the number of HH members in the survey
		cap drop b3
		cap noi rename hh_mem b3
			
	* Anonymize district
		label drop a5
		
	* Note: All other re-labeling will be done using IEcodebook in Excel		
		label var time "Survey time"
	
	set trace off	

 end
 
********************************************************************************
	** Part 3: Basic cleaning for each dataset
********************************************************************************
 
*-------------------------------------------------------------------------------
* 3.1. LHH
*-------------------------------------------------------------------------------
use "${LHH_allsvys_raw_fl1_nopii}", clear
 
	*-----------------------*
	* A. Generate variables * 
	*-----------------------*
	
	* Common cleaning defined in section 2
		global survey 1
		hh_svy_clean
	
	* Destring various vars
		destring hh_head_gender,replace
			lab var hh_head_gender "HH head gender (from LHH roster, SurveyCTO-captured)"
			lab val hh_head_gender b6_1
			assert !mi(hh_head_gender)
		
	* Drop GPS 
		drop a1latitude a1longitude q8latitude q8longitude
	
	* Drop tags
		drop tag_saliva_complete tag_mobile_complete tag_ec_complete tag_direct_obs_complete cleaning_notes
	
	* Drop SCTO-generated variables not used: _cal_, index, repeat, count, timebegin, etc.
		** Keep: hh_mem_left_* - used to reshape data long for rosters 
		drop index_roster* *_cal_* left_index_* index_1 - index_oldroster_20 index_sick* index_sold* index_dead* *repeat* *count* *_id_* hh_mem_old time_begin* time_end_* ///
			time_collection_2* time_startinteraction0*  time_startinteraction* time_startinteraction0_2* ///
			time_startinteraction_2* deviceid* subscriberid* simid* devicephonenum*
	
		drop in_sample* no_lady* baseline oldnumberhh namenumber_* num_still_here* any_left_hh* max_newmembers* new_members* ///
			relationship_respondent_* age_daughter_* age_son_* age_daughter_position_* ///
			age_son_position_* age_lessthan5_position_* binary_lessthan5_* respondent_sex* lady_hh_gender* ys_age_position ///
			yd_age_position age_ys age_yd max_age_lessthan5_position max_age_lessthan5 a8_m_notav_perm_1 ///
			dkna_crop crop_name_* crop_max_k17_* crop_max_k19_* crop_max_k20_* crop_max_k21_* k17_v99_* k17_v_* k19_v99_* k19_v_* k20_v_* k20_v99_* k21_v_* k40_v_* ///
			k22_v dkna_business business_name_* own_business position_* nameofagecalcfield_* crop_* business_* ///
			activities_*_name_*_* dkna_livestock livestock_name_* livestock_max_k8_* k7_o_v_* k8_v_* dkna_produce produce_name_* produce_max_k10_* produce_max_k12_* ///
			produce_max_k13_* k10_v_* k12_v_* k13_v_* k38_v tot_cows* tot_calves* tot_goats* tot_baby_goats* tot_sheep* tot_lambs* tot_cows_calves* tot_goats_babygoats* tot_sheep_lambs* tot_livestock* ///
			sick* type_livestock_sick_* sick_relevance_* sick_relevance2_* tot_sold sold* type_livestock_sold_* sold_relevance_* sold_relevance2_* ///
			tot_dead dead1 dead2 dead3 type_livestock_dead_* dead_relevance_* dead_relevance2_* type_livestock_dead_* dead_relevance_* cows_now goats_now sheep_now ///
			r26*_v r28*_v r38*_v r47*_v dkna_produce_tup produce_name_tup_* r5_c r5_v health_name_diff savings_name_diff bread_name_* meat_name_* dairy_name_* ///
			oil_name_* vegetables_name_* fruit_name_* sweets_name_* beverages_name_* spices_name_* asset_name_* s1_c randnum* loan_relationship_*  m4_v_* haveacct gifts_name_* ///
			giftsrec_name_* event_name_* phone_lines phone_roster_* firstnumbers_* barcode_list* barcode_list_text* num_activities* instancename* formdef_version* submissiondate* starttime* endtime* ///
			imm_t1 imm_t0 a15_m a15 livestock_* cows goats sheep tot_sick time_f
			
			unab  b8 : b8_* 
			local b8_keep "b8_1	b8_2	b8_3	b8_4	b8_5	b8_6	b8_7	b8_8	b8_9	b8_10	b8_11	b8_12	b8_13	b8_14	b8_15	b8_16	b8_17	b8_18	b8_19	b8_20 b8_month_1	b8_month_2	b8_month_3	b8_month_4	b8_month_5	b8_month_6	b8_month_7	b8_month_8	b8_month_9	b8_month_10	b8_month_11	b8_month_12	b8_month_13	b8_month_14	b8_month_15	b8_month_16	b8_month_17	b8_month_18	b8_month_19	b8_month_20	b8_month_21	b8_month_22	b8_month_23	b8_month_24	b8_month_25	b8_month_26	b8_month_27	b8_month_28	b8_month_29	b8_month_30	b8_month_31	b8_month_32	b8_month_33"
			local b8_drop : list local b8 - local b8_keep
			drop `b8_drop'
			
		* Rename to match the survey
			forval i = 1/20 {
				rename b8_`i' b8_year_`i'
			}
			 
	* Drop "Other, specify values" in Dari
		drop  a9_o a9_o_m b20_o_* b5_o_* a15_m_o* a15_o* b5_o_* b5_ladyhh_o_* b27_o_* b28_o_* b15_o_* k15_o1* k15_o2* k23_a_o1* k23_a_o2* k30_o_* k30_1o* k6_o1 k6_o2 k9_o1 k9_o2 r14_2_o r14_3_o r34_o_1 r35_o_1 r36_o_1 r41_o_1 ///
			r52_o r60_o r66_o r67_o r73_o1 r73_o2 r61_o r62_o r63_o r64_o r2_2_o r2_3_o r4_2_o r4_3_o r7_o r8_o r10_2_o r10_3_o r12_2_o r12_3_o r17_o r19_o r20_o c3_o c3_s_o_* c4_o c4_s_o_* c5_o c5_s_o_* c6_o c6_s_o_* ///
			c7_o c7_s_o_* c8_o c8_s_o_* c9_o c9_s_o_* c10_o c10_s_o_* c11_o c11_s_o_* e1_o e4_o e5_o e6_o e7_o e9_o e8_o l1_o f8_o f9_o f12_o f13_o f4_o f19_o f21_o f22_o i1_s_o i2_s_o i3_s_o i1_d_o i2_d_o i3_d_o ///
			s8_o u9a_o* u9b_o* j2_o* m21_o m24_o m22_o m2_o_* m2_roster_o_* m3_o_* m6_o m6_a_o m11_o m12_o m12_h_o m12_other_o m13_o m17_o m27_o m28_o m31_a_a_o m32_o d1_o d3_o_r_* d3_o_u_* d8_o d10_o_r_* d13_o g2_o_* ///
			o1_b_o o3_o v4_o_* e12_o e14_o e15_o e16_o r79_o a11_o* a15_m_o r34_o_2 r35_o_2 r36_o_2 r34_o_3 r35_o_3 r36_o_3 r41_o_2 r41_o_3 d6_o q7
			
	* Destring all numeric variables 
		qui: destring *, replace
		
	* Rename to match the survey 
		rename b13_* b11_*
		
	* Apply codebook templates
		** LHH first
		cap noi iecodebook apply using "${codebook}\lhh_template.xlsx" ///
			, drop miss(.d "Don't Know" .r "Refused")
		
		label var hhh_name2 "Roster position of the MHHH (SurveyCTO-captured)"
		label var lady_hh2 "Roster position of the LHHH (SurveyCTO-captured)"
		label var time_collection "Time of sample collection (SurveyCTO-captured)"
			
	* Save intermediate dataset
	* Order variables to match paper survey order 
		order hhid, first 
		order date_a, after(date_v)
		order a6, after(a5)
		order a8_m_av_date a8_m_av_time, after(a8_m_av)
		order a18_v, after(a18)
		order date date_v date_a time time_v time_a a2, before(a3)
		order r40_1 r40_2 r40_3, before(r41_1_1)
		order r48_1 r48_2 r48_3, after(r47c) 
		order a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17, after(a19_6) 
		order r36_1_1 r36_1_2 r36_1_3, after(r36_3) 
		order r53, after(r52__97)
		order ultra_poor, after(hhid)
		order hh_head_gender respondent_gender time_collection time_endinteraction, last // constructed / SCTO vars we need 
	
	* For 3 male respondents, need to make sure question asked to the female are missing 
		unab female_vars : h1 - i4_d k24_* n1 n2 s10 s21 s12 s13 
		
		di "`female_vars'"
		
		foreach var of local female_vars {
			cap noi replace `var' = . if respondent_gender == 1 
			cap noi replace `var' = "" if respondent_gender == 1 
			assert mi(`var') if respondent_gender == 1 
		}
				
		
	* Save
		if	`c(stata_version)'>=14	{
			save "${LHH_interm_nopii_fl1}", replace
			*saveold "${LHH_interm_fl1_nopii}", replace v(13) // some variable labels in the Codebook are too long for Stata 13
		}
		else {
			save "${LHH_interm_nopii_fl1}", replace
		}
		
	
*-------------------------------------------------------------------------------
* 3.2. MHHH
*-------------------------------------------------------------------------------

use "${MHHH_allsvys_raw_fl1_nopii}", clear
 
	*-----------------------*
	* A. Generate variables * 
	*-----------------------*
	
	* Common cleaning defined in section 2
		global survey 2
		hh_svy_clean
	 
	* Drop GPS 
		drop a1latitude a1longitude q8latitude q8longitude 
	
	* Drop tags
		drop tag_saliva_complete
	
	* Drop SCTO-generated variables not used: _cal_, index, repeat, count, timebegin, etc.
		drop *repeat* *count* *_id_* time_begin* time_end_* time_collection_2 ///
			time_collection_2* time_startinteraction0*  time_startinteraction* time_startinteraction0_2* ///
			time_startinteraction_2* deviceid* subscriberid* simid* devicephonenum*
	
		drop in_sample no_lady dkna_crop crop_name_* crop_max_k17_* crop_max_k19_* crop_max_k20_* crop_max_k21_* k17_v_* k19_v_* k20_v_* k21_v_* k40_v_* ///
			k22_v dkna_business business_name_* own_business crop_* business_* ///
			dkna_livestock livestock_name_* livestock_max_k8_* k7_o_v_* k8_v_* dkna_produce produce_name_* produce_max_k10_* produce_max_k12_* ///
			produce_max_k13_* k10_v_* k12_v_* k13_v_* k38_v randnum* barcode_list* barcode_list_text* num_activities* instancename* formdef_version* submissiondate* starttime* endtime* ///
			livestock_* time_f activities_name_* dkna_activities livestock crop business
			 
	* Drop "Other, specify values" in Dari
		drop  a9_o k15_o1* k15_o2* k23_a_o1* k23_a_o2* k6_o1 k6_o2 k9_o1 k9_o2 ///
			 u9a_o* u9b_o* j2_o* a11_o* q7
		
	* Destring all numeric variables 
		qui: destring *, replace

	* Save intermediate dataset
	* Order variables to match paper survey order 
		order hhid ultra_poor, first 
		order a6, after(a5)
		order a18_v, after(a18)
		order date date_v date_a time time_v time_a a2, before(a3)
		order a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17, after(a19_6) 
		order a8_m_respondent a8_m_gender_v, after(a12)
		order respondent_gender time_collection time_endinteraction, last // constructed / SCTO vars we need 
	
	* Apply codebook templates
		cap noi iecodebook apply using "${codebook}\mhhh_template.xlsx" ///
			, drop miss(.d "Don't Know" .r "Refused")
		
		label var time_collection "Time of sample collection (SurveyCTO-captured)"
	
	* Drop vars missing on all obs
		*missings dropvars, force
		
	* Keep consented surveys only	
		keep if a12 == 1

	* Save
		if	`c(stata_version)'>=14	{
			save "${MHHH_interm_nopii_fl1}", replace 
			*saveold "${MHHH_interm_fl1_nopii}", replace v(13)
		}
		else {
			save "${MHHH_interm_nopii_fl1}", replace
		}

*-------------------------------------------------------------------------------
* 3.3. Targeting
*-------------------------------------------------------------------------------

use "${Targ_allsvys_raw_fl1_nopii}", clear
 		
	*-----------------------*
	* A. Generate variables * 
	*-----------------------*
	
	* Common cleaning defined in section 0
		global survey 3
		hh_svy_clean
			 
	* Drop GPS 
		drop a1latitude a1longitude q8latitude q8longitude
		
	* Drop tags
		drop tag_mobile_complete tag_ec_complete 
		
	* Drop SCTO-generated variables not used: _cal_, index, repeat, count, timebegin, etc.
		** Keep: hh_mem, and index_roster used in rosters 
		drop *_cal_* *repeat* *count* *_id_* time_begin* time_end* ///
			time_startinteraction0*  time_startinteraction* time_startinteraction0_2* ///
			time_startinteraction_2* deviceid* subscriberid* simid* devicephonenum*
		
		drop index_roster* hh_head_gender* in_sample* no_lady* namenumber_* ///
			relationship_respondent_* age_daughter_* age_son_* age_daughter_position_* ///
			age_son_position_* age_lessthan5_position_* binary_lessthan5_* respondent_sex* lady_hh_gender* ys_age_position ///
			yd_age_position age_ys age_yd max_age_lessthan5_position max_age_lessthan5 ///
			dkna_crop crop_name_* crop_max_k17_* crop_max_k19_* crop_max_k20_* crop_max_k21_* k17_v_* k19_v_* k20_v_* k21_v_* k40_v_* ///
			k22_v dkna_business business_name_* own_business position_* nameofagecalcfield_* crop_* business_* ///
			activities_*_name_*_* dkna_livestock livestock_name_* livestock_max_k8_* k7_o_v_* k8_v_* dkna_produce produce_name_* produce_max_k10_* produce_max_k12_* ///
			produce_max_k13_* k10_v_* k12_v_* k13_v_* k38_v bread_name_* meat_name_* dairy_name_* ///
			oil_name_* vegetables_name_* fruit_name_* sweets_name_* beverages_name_* spices_name_* asset_name_* s1_c randnum* loan_relationship_*  m4_v_* haveacct gifts_name_* ///
			giftsrec_name_* phone_lines phone_roster_* firstnumbers_* instancename* formdef_version* key* submissiondate* starttime* endtime* ///
			a15_m a15 livestock_* time_f
	
	* Drop identifiable info
		drop a8_m_name_o*
			
		unab  b8 : b8_* 
		local b8_keep "b8_1	b8_2 b8_3 b8_4 b8_5 b8_6 b8_7 b8_8 b8_9 b8_10 b8_11 b8_12 b8_13 b8_14 b8_15 b8_16 b8_17 b8_18 b8_19 b8_20 b8_21 b8_22 b8_23 b8_24 b8_25 b8_26 b8_27 b8_28 b8_29 b8_30 b8_31 b8_32 b8_33 b8_month_1 b8_month_2	b8_month_3	b8_month_4	b8_month_5	b8_month_6	b8_month_7	b8_month_8	b8_month_9	b8_month_10	b8_month_11	b8_month_12	b8_month_13	b8_month_14	b8_month_15	b8_month_16	b8_month_17	b8_month_18	b8_month_19	b8_month_20	b8_month_21	b8_month_22	b8_month_23	b8_month_24	b8_month_25	b8_month_26	b8_month_27	b8_month_28	b8_month_29	b8_month_30	b8_month_31	b8_month_32	b8_month_33"
		local b8_drop : list local b8 - local b8_keep
		drop `b8_drop'
			
		* Rename to match the survey
			forval i = 1/33 {
				rename b8_`i' b8_year_`i'
			}
	 	
		* Drop "Other, specify values" in Dari
		drop  a9_o a9_o_m b5_o_* a15_m_o* a15_o* b5_o_* b5_ladyhh_o_* b27_o_* b28_o_* b15_o_* k15_o1* k15_o2* k23_a_o1* k23_a_o2* k30_o_* k30_1o* k6_o1 k6_o2 k9_o1 k9_o2 r14_2_o r14_3_o ///
			r2_2_o r2_3_o r4_2_o r4_3_o c3_o c3_s_o_* c4_o c4_s_o_* c5_o c5_s_o_* c6_o c6_s_o_* ///
			c7_o c7_s_o_* c8_o c8_s_o_* c9_o c9_s_o_* c10_o c10_s_o_* c11_o c11_s_o_* e1_o e4_o e5_o e6_o e7_o e9_o e8_o l1_o ///
			s8_o u9a_o* u9b_o* m21_o m24_o m22_o m2_o_* m2_roster_o_* m3_o_* m6_o m6_a_o m11_o m12_o m12_h_o m12_other_o m13_o m17_o m27_o m28_o m31_a_a_o m32_o d1_o d3_o_r_* d3_o_u_* d8_o d10_o_r_* d13_o ///
			v4_o_* e12_o e14_o e15_o e16_o a11_o* a15_m_o d6_o q7
	
		* Destring all numeric variables 
			qui: destring *, replace
					
	* Save intermediate dataset 
	* Order variables to match paper survey order 
		order hhid ultra_poor, first 
		order date_a, after(date_v)
		order a6, after(a5)
		order date date_v date_a time time_v time_a a2, before(a3)
				
	* Apply codebook templates [lhh_template as well since variables match]
		cap noi iecodebook apply using "${codebook}\targ_template.xlsx" ///
			, drop miss(.d "Don't Know" .r "Refused")
		
		label var hhh_name2 "Roster position of the MHHH (SurveyCTO-captured)"
		label var lady_hh2 "Roster position of the LHHH (SurveyCTO-captured)"
			
		* Manual correction for m32__99                                      
		rename m32__99 m32__98

	* Drop vars missing on all obs
		*missings dropvars, force
		
	* Keep consented surveys only
		keep if a12 == 1
	
	* Save
		if	`c(stata_version)'>=14	{
			save "${Targ_interm_nopii_fl1}", replace
			*saveold "${Targ_interm_fl1_nopii}", replace v(13)
		}
		else {
			save "${Targ_interm_nopii_fl1}", replace
		} 
		 
		 

*---------------------*
* Additional cleaning *
*---------------------*

foreach dataset in LHH MHHH Targ {	
	di "`dataset'"
				
	use "${`dataset'_interm_nopii_fl1}", clear

		* Extended missing for multiple selection
			loc r61_ch "1 2 3 4 5 6 _97"
			loc r61_miss_val "99"		
			loc r62_ch "1 2 3 4 5 6 _97"
			loc r62_miss_val "99"
			loc r63_ch "1 2 3 4 5 6 _97"
			loc r63_miss_val "99"
			loc r64_ch "1 2 3 4 5 6 _97"
			loc r64_miss_val "99"
			loc r7_ch "1 2 3 4 5 6 7 8 9 10 11 12 13 _97"
			loc r7_miss_val "99"
			loc r8_ch "1 2 3 4 5 6 7 8 9 10 11 12 13 _97"
			loc r8_miss_val "99"
			loc r8_ch "1 2 3 4 5 6 7 8 9 10 11 12 13 _97"
			loc r8_miss_val "99"
			loc r20_ch "1 2 3 4 5 6 7 _97"
			loc r20_miss_val "99"
			loc f3_a_ch "0 1 2 3 4"
			loc f3_a_miss_val "99"
			loc f8_ch "1 2 3 4 5 6 7 _97"
			loc f8_miss_val "99"
			loc f9_ch "1 2 3 4 5 6 7 8 9 10 _97"
			loc f9_miss_val "98 99"		
			loc f12_ch "1 2 3 4 5 6 7 _97"
			loc f12_miss_val "99"		
			loc f13_ch "1 2 3 4 5 6 7 8 9 10 _97"
			loc f13_miss_val "98 99"		
			loc f4_ch "1 2 3 4 _97"
			loc f4_miss_val "98 99"		
			loc f15_ch "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15"
			loc f15_miss_val "98 99"		
			loc f16_ch "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15"
			loc f16_miss_val "98 99"		
			loc f19_ch "1 2 3 4 5 _97"
			loc f19_miss_val "98 99"		
			loc i2_s_ch "1 2 3 4 _97"
			loc i2_s_miss_val "98 99"
			loc i2_d_ch "1 2 3 4 _97"
			loc i2_d_miss_val "98 99"		
			loc t2_ch "1 2"
			loc t2_miss_val "99"			
			loc m21_ch "1 2 3 4 5 6 7 _97"
			loc m21_miss_val "99"		
			loc m22_ch "0 1 2 3 4 5 6 7 8 9 10 _97"
			loc m22_miss_val "98 99"		
			loc m6_ch "1 2 3 4 5"
			loc m6_miss_val "98 99"		
			loc m6_a_ch "1 2 3 4 5 6 7 8 9 10 _97"
			loc m6_a_miss_val "98 99"		
			loc m11_ch "1 2 _97"
			loc m11_miss_val "98 99"		
			loc m12_ch "1 2 3 4 5 _97"
			loc m12_miss_val "98"		
			loc m12_h_ch "1 2 3 4 5 _97"
			loc m12_h_miss_val "98"		
			loc m12_other_ch "1 2 3 4 5 _97"
			loc m12_other_miss_val "98"		
			loc m13_ch "1 2 3 4 5 6 7 8 9 10 _97"
			loc m13_miss_val "98 99"		
			loc m17_ch "1 2 3 4 5 6 _97"
			loc m17_miss_val "99"
			loc m31_a_a_ch "1 2 3 4 _97"
			loc m31_a_a_miss_val "98"
			loc m32_ch "0 1 2 3 4 5 6 7 8 9 _97"
			loc m32_miss_val "98"
			loc o3_ch "0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 _97"
			loc o3_miss_val "98 99"
			loc a13_saliva_ch "1 2 3 4 5 6 7"
			loc a13_saliva_miss_val "99"
			loc s8_ch "1 2 3 4 5 6 7 8 9 _97"
			loc s8_miss_val "98"
			loc k15_ch "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 _98"
			loc k15_miss_val "99"
			loc k23_a_ch "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 _98"
			loc k23_a_miss_val "99"
			loc m2_roster "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30	31 32 33 34 35"
			loc m2_roster_miss_val "98 99"
			
			loc vars_ext_miss "r61 r62 r63 r64 r7 r8 r20 f3_a f8 f9 f12 f13 f4 f15 f16 f19 i2_s i2_d t2 m21 m22 m6 m6_a m11 m12 m12_h m12_other m13 m17 m27 m31_a_a m32 o3 a13_saliva k15 m2_roster"
			
			foreach var of local vars_ext_miss {
				cap confirm var `var' 
					if !_rc { // if var exists
					foreach miss_value of local `var'_miss_val {
						foreach choice of local `var'_ch {
							replace `var'_`choice' = .d if `var'__`miss_value' == 1 
							}
						}
					}
				}
				
		/* Merge saliva results (LHH and MHH only)
			merge 1:1 hhid using "${cortisol_results_fl1}", assert(1 3) gen(merge_cortisol)
			tab merge_cortisol a12_saliva,m
			*tab merge_cortisol consent_saliva_m, m
			drop merge_cortisol
		
			
			/*
				Result                           # of obs.
				-----------------------------------------
				not matched                         1,413
					from master                     1,413  
					from using                          0  

				matched                             1,082  
				-----------------------------------------

			*/ */
			
		
		* Replace .99 to missing
			loc var_99 k38
			tab `var_99', m
			*count if round(`var_99',0.01)==.99
			*assert r(N)==2
			replace `var_99'=.d if round(`var_99',0.01)==.99

			loc var_99 k14
			tab `var_99', m
			*count if round(`var_99',0.01)==.99
			*assert r(N)==2
			replace `var_99'=.d if round(`var_99',0.01)==.99	
			
	**********Short cleaning for loans/savings variables that are in the main dataset
			*Cleaning the variables 
		if "`dataset'" != "MHHH" {
			replace m5 = -99 if hhid == 1903 /*Issue, value of m5 is 0.99, probably mistake for -99*/
			replace m20 = -99 if hhid == 1894 /*Issue, value of m20 is 0.99, probably mistake for -99*/
		}
		
		*** Cleaning missing values originally in "preparing_and_cleaning_rosters_fl1.do"
		qui ds, has(type numeric) // Apply extended missing values to all numeric vars
			foreach v in `r(varlist)' {
				replace `v' = .r if `v' == -98
				replace `v' = .d if `v' == -99
				replace `v' = .n if `v' == -97 // use ".n" for "other", since ".o" is used for outliers
				replace `v' = .n if `v' == -96 // use ".n" for N/A as well
		}
		
		* Replace .99 as extended missing .d (don't know)
		unab k17 : k17_*
		unab k19 : k19_*
		unab k20 : k20_*
		unab k21 : k21_*
		unab k32 : k32_*
		unab k43 : k43_*
		unab k34 : k34_*
		unab k8  : k8_*
		unab k10 : k10_*
		unab k12 : k12_*
		unab k13 : k13_*
		
			foreach var in `k17' `k19' `k20' `k21' `k32' `k43' `k34' `k8' `k10' `k12' `k13' {
				cap confirm var `var' 
					if !_rc {
						replace `var'=.d if round(`var',0.01)==.99
					}			
			}
		
		* Replace .98 to missing
			foreach var in `k10' `k12' {
				cap confirm var `var' 
					if !_rc {
						replace `var'=.r if round(`var',0.01)==.98
					}
			}				
		
		
			foreach var99 in r40_1 r40_2 r40_3 r48_1 r48_2 r48_3 {
				cap confirm var99 `var99' 
					if !_rc {
						replace `var99' = .d if `var99' == date("01jan2010", "DMY") // jan2010 was -99
					}
			}
			
		
		* Extended missing for multiple selection
			forv member = 1(1)35 {
				forv loan = 1(1)10 {
				cap confirm var m2_roster_`member'_`loan'
					if !_rc {
						replace m2_roster_`member'_`loan' = .d if m2_roster__99_`loan' == 1 // fix varlabel in codebook - all loans say "loan 1"
						replace m2_roster_`member'_`loan' = .r if m2_roster__98_`loan' == 1 // fix varlabel in codebook - all loans say "loan 1"
					}
				}
			}
			

			foreach purpose in 1 2 3 4 5 6 7 8 9 _97 {
				forv loan = 1(1)10 {
					cap confirm var m3_`purpose'_`loan'
					if !_rc {
						replace m3_`purpose'_`loan' = .d if m3__98_`loan' == 1 
						*replace m3_`purpose'_`loan' = .n if m3__97_`loan' == 1 // ".o" is also used for outliers!!
					}
				}
			}	
			
			* Extended missing for multiple selection
			foreach relationship in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 _97 {
				forval gift = 1(1)10 {
					cap confirm var d3_`relationship'_`gift' 
					if !_rc {
						replace d3_`relationship'_`gift' = .d if d3__99_`gift' == 1 
						replace d3_`relationship'_`gift' = .r if d3__98_`gift' == 1 
					}
				}
			}
			
			* Extended missing for multiple selection
			foreach giver in 1 2 3 4 5 6 7 8 9 10 11 12 _97 {
					forval gift = 1(1)19 {
						cap confirm var d10_`giver'_`gift'
						if !_rc {
								replace d10_`giver'_`gift' = .d if d10__99_`gift' == 1 
								replace d10_`giver'_`gift' = .r if d10__98_`gift' == 1 
						}
					}
			}
			
			* Extended missing for multiple selection
			foreach copelist in 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 _97 {
				forval shock = 1(1)19 {
					cap confirm var g2_`copelist'_`shock' 
					if !_rc {
						replace g2_`copelist'_`shock' = .d if g2__99_`shock' == 1 
						replace g2_`copelist'_`shock' = .r if g2__98_`shock' == 1 
					}
				}
			}
			
			forval activity = 0/9 {
				cap confirm var k1_1_`activity' 
					if !_rc {
						replace k1_1_`activity' = .r if  k1_1__98 == 1 
						replace k1_1_`activity' = .d if  k1_1__99 == 1
					}
			}
		
		
		* Renaming variables where -98 mean "None"			
			cap noi rename (k15__99 k15__98) (k15_99 k15_0) // in this questions -98 means "None"
			cap noi rename (k23_a__99 k23_a__98) (k23_a_99 k23_a_0) // in this questions -98 means "None"
			cap noi rename (k6__99 k6__98) (k6_99 k6_0) // in this question -98 means "None"
			cap noi rename (k9__99 k9__98) (k9_99 k9_0) // in this question -98 means "None"
			cap noi rename (r73__99 r73__98) (r73_99 r73_0) // in this question -98 means "None"
			
		* Rename MHHH variables 
			if "`dataset'" == "MHHH" {
				rename * *_m
				rename hhid_m hhid
			}

		* Save data WITH roster variables 
			if	`c(stata_version)'>=14	{
			save "${`dataset'_nopii_fl1}", replace
		}
			else {
				save "${`dataset'_nopii_fl1}", replace
			}	
}



********************************************************************************
	** Part X: Merge and append data before rosters are cleaned 
********************************************************************************

	* Prepare Targeting data for merge 
	use "${Targ_nopii_fl1}", clear 
		tostring m11 m17 k24_14 r2 r4 r14 m3_?, replace

		save, replace
		
	* Start with LHH
	use "${LHH_nopii_fl1}", clear
		
	* Merge MHH
		merge 1:1 hhid using "${MHHH_nopii_fl1}"
		drop if _merge ==2
		drop _merge
		
	* For these household, hh head was incorrectly identified. We replaced HH head gender
		replace hh_head_gender = 1 if inlist(hhid, 2074, 1957, 1982, 2121)  
		
********************************************************************************
* For those households with male HH head, we replace the relevant modules
********************************************************************************
			
		* Tag the ones who need to be replaced
			* 796 HHs with male head of the households. For 698 of those, we took the
			* info from MHHH, from 63 we took it from the LHH, for the remaining 35,
			* we don't have information
				gen m_k15 = mi(k15)
				gen m_k15_m = mi(k15_m)
				tab hh_head_gender
				tab m_k15 m_k15_m if hh_head_gender==1
					/*
					           |        m_k15_m
						 m_k15 |         0          1 |     Total
					-----------+----------------------+----------
							 0 |       127         63 |       190 
							 1 |       571         35 |       606 
					-----------+----------------------+----------
						 Total |       698         98 |       796 
					*/
				gen replace_modules = (hh_head_gender==1 & m_k15_m==0)
				
		* Replace vars
			loc vars_replace "k15 k15_1 k15_2 k15_3 k15_4 k15_5 k15_6 k15_7 k15_8 k15_9 k15_10 k15_11 k15_12 k15_13 k15_14 k15_15 k15_16 k15_17 k15_18 k15_19 k15_20 k15_21 k15_22 k15_23 k15_24 k15_25 k15_26 k15_27 k15_0 k15_99 k15_o1 k15_o2 dk k16_1 k17_1 k17_v_1 k19_1 k19_v_1 k20_1 k20_v_1 k21_1 k21_v_1 k40_1 k40_v_1 crop_id_2 crop_name_2 crop_max_k17_2 crop_max_k19_2 crop_max_k20_2 crop_max_k21_2 k16_2 k17_2 k17_v_2 k19_2 k19_v_2 k20_2 k20_v_2 k21_2 k21_v_2 k40_2 k40_v_2 crop_id_3 crop_name_3 crop_max_k17_3 crop_max_k19_3 crop_max_k20_3 crop_max_k21_3 k16_3 k17_3 k17_v_3 k19_3 k19_v_3 k20_3 k20_v_3 k21_3 k21_v_3 k40_3 k40_v_3 crop_id_4 crop_name_4 crop_max_k17_4 crop_max_k19_4 crop_max_k20_4 crop_max_k21_4 k16_4 k17_4 k17_v_4 k19_4 k19_v_4 k20_4 k20_v_4 k21_4 k21_v_4 k40_4 k40_v_4 crop_id_5 crop_name_5 crop_max_k17_5 crop_max_k19_5 crop_max_k20_5 crop_max_k21_5 k16_5 k17_5  k17_v_5 k19_5 k19_v_5 k20_5 k20_v_5 k21_5 k21_v_5 k40_5 k40_v_5 crop_id_6 crop_name_6 crop_max_k17_6 crop_max_k19_6 crop_max_k20_6 crop_max_k21_6 k16_6 k17_6 k17_v_6 k19_6 k19_v_6 k20_6 k20_v_6 k21_6 k21_v_6 k40_6 k40_v_6 crop_id_7 crop_name_7 crop_max_k17_7 crop_max_k19_7 crop_max_k20_7 crop_max_k21_7 k16_7 k17_7 k17_v_7 k19_7 k19_v_7 k20_7 k20_v_7 k21_7 k21_v_7 k40_7 k40_v_7 crop_id_8 crop_name_8 crop_max_k17_8 crop_max_k19_8 crop_max_k20_8 crop_max_k21_8 k16_8 k17_8 k17_v_8 k19_8 k19_v_8 k20_8 k20_v_8 k21_8 k21_v_8 k40_8 k40_v_8 crop_id_9 crop_name_9 crop_max_k17_9 crop_max_k19_9 crop_max_k20_9 crop_max_k21_9 k16_9 k17_9 k17_v_9 k19_9 k19_v_9 k20_9 k20_v_9 k21_9 k21_v_9 k40_9 k40_v_9 crop_id_10 crop_name_10 crop_max_k17_10 crop_max_k19_10 crop_max_k20_10 crop_max_k21_10 k16_10 k17_10 k17_v_10 k19_10 k19_v_10 k20_10 k20_v_10 k21_10 k21_v_10 k40_10 k40_v_10 crop_id_11 crop_name_11 crop_max_k17_11 crop_max_k19_11 crop_max_k20_11 crop_max_k21_11 k16_11 k17_11 k17_v_11 k19_11 k19_v_11 k20_11 k20_v_11 k21_11 k21_v_11 k40_11 k40_v_11 crop_id_12 crop_name_12 crop_max_k17_12 crop_max_k19_12 crop_max_k20_12 crop_max_k21_12 k16_12 k17_12 k17_v_12 k19_12 k19_v_12 k20_12 k20_v_12 k21_12 k21_v_12 k40_12 k40_v_12 crop_id_13 crop_name_13 crop_max_k17_13 crop_max_k19_13 crop_max_k20_13 crop_max_k21_13 k16_13 k17_13 k17_v_13 k19_13 k19_v_13 k20_13 k20_v_13 k21_13 k21_v_13 k40_13 k40_v_13 crop_id_14 crop_name_14 crop_max_k17_14 crop_max_k19_14 crop_max_k20_14 crop_max_k21_14 k16_14 k17_14 k17_v_14 k19_14 k19_v_14 k20_14 k20_v_14 k21_14 k21_v_14 k40_14 k40_v_14 crop_id_15 crop_name_15 crop_max_k17_15 crop_max_k19_15 crop_max_k20_15 crop_max_k21_15 k16_15 k17_15 k17_v_15 k19_15 k19_v_15 k20_15 k20_v_15 k21_15 k21_v_15 k40_15 k40_v_15 crop_id_16 crop_name_16 crop_max_k17_16 crop_max_k19_16 crop_max_k20_16 crop_max_k21_16 k16_16 k17_16 k17_v_16 k19_16 k19_v_16 k20_16 k20_v_16 k21_16 k21_v_16 k40_16 k40_v_16 crop_id_17 crop_name_17 crop_max_k17_17 crop_max_k19_17 crop_max_k20_17 crop_max_k21_17 k16_17 k17_17 k17_v_17 k19_17 k19_v_17 k20_17 k20_v_17 k21_17 k21_v_17 k40_17 k40_v_17 crop_id_18 crop_name_18 crop_max_k17_18 crop_max_k19_18 crop_max_k20_18 crop_max_k21_18 k16_18 k17_18 k17_v_18 k19_18 k19_v_18 k20_18 k20_v_18 k21_18 k21_v_18 k40_18 k40_v_18 crop_id_19 crop_name_19 crop_max_k17_19 crop_max_k19_19 crop_max_k20_19 crop_max_k21_19 k16_19 k17_19 k17_v_19 k19_19 k19_v_19 k20_19 k20_v_19 k21_19 k21_v_19 k40_19 k40_v_19 crop_id_20 crop_name_20 crop_max_k17_20 crop_max_k19_20 crop_max_k20_20 crop_max_k21_20 k16_20 k17_20 k17_v_20 k19_20 k19_v_20 k20_20 k20_v_20 k21_20 k21_v_20 k40_20 k40_v_20 crop_id_21 crop_name_21 crop_max_k17_21 crop_max_k19_21 crop_max_k20_21 crop_max_k21_21 k16_21 k17_21 k17_v_21 k19_21 k19_v_21 k20_21 k20_v_21 k21_21 k21_v_21 k40_21 k40_v_21 crop_id_22 crop_name_22 crop_max_k17_22 crop_max_k19_22 crop_max_k20_22 crop_max_k21_22 k16_22 k17_22 k17_v_22 k19_22 k19_v_22 k20_22 k20_v_22 k21_22 k21_v_22 k40_22 k40_v_22 crop_id_23 crop_name_23 crop_max_k17_23 crop_max_k19_23 crop_max_k20_23 crop_max_k21_23 k16_23 k17_23 k17_v_23 k19_23 k19_v_23 k20_23 k20_v_23 k21_23 k21_v_23 k40_23 k40_v_23 crop_id_24 crop_name_24 crop_max_k17_24 crop_max_k19_24 crop_max_k20_24 crop_max_k21_24 k16_24 k17_24 k17_v_24 k19_24 k19_v_24 k20_24 k20_v_24 k21_24 k21_v_24 k40_24 k40_v_24 crop_id_25 crop_name_25 crop_max_k17_25 crop_max_k19_25 crop_max_k20_25 crop_max_k21_25 k16_25 k17_25 k17_v_25 k19_25 k19_v_25 k20_25 k20_v_25 k21_25 k21_v_25 k40_25 k40_v_25 crop_id_26 crop_name_26 crop_max_k17_26 crop_max_k19_26 crop_max_k20_26 crop_max_k21_26 k16_26 k17_26 k17_v_26 k19_26 k19_v_26 k20_26 k20_v_26 k21_26 k21_v_26 k40_26 k40_v_26 crop_id_27 crop_name_27 crop_max_k17_27 crop_max_k19_27 crop_max_k20_27 crop_max_k21_27 k16_27 k17_27 k17_v_27 k19_27 k19_v_27 k20_27 k20_v_27 k21_27 k21_v_27 k40_27 k40_v_27 k22 k22_v k23_a k23_a_1 k23_a_2 k23_a_3 k23_a_4 k23_a_5 k23_a_6 k23_a_7 k23_a_8 k23_a_9 k23_a_10 k23_a_11 k23_a_12 k23_a_13 k23_a_14 k23_a_15 k23_a_0 k23_a_99 k23_a_o1 k23_a_o2 dkna_business business_repeat_count business_id_1 business_name_1 k24_1 k24_3_1 k24_2_1 k24_1_1 k24_0_1 k26_y_1 k27_1 k28_1 k29_1 k31_1 k32_1 k33_1 k43_1 k34_1 k35_1 k25_1 business_id_2 business_name_2 k24_2 k24_3_2 k24_2_2 k24_1_2 k24_0_2 k26_y_2 k27_2 k28_2 k29_2 k31_2 k32_2 k33_2 k43_2 k34_2 k35_2 k25_2 business_id_3 business_name_3 k24_3 k24_3_3 k24_2_3 k24_1_3 k24_0_3 k26_y_3 k27_3 k28_3 k29_3 k31_3 k32_3 k33_3 k43_3 k34_3 k35_3 k25_3 business_id_4 business_name_4 k24_4 k24_3_4 k24_2_4 k24_1_4 k24_0_4  k26_y_4 k27_4 k28_4 k29_4 k31_4 k32_4 k33_4 k43_4 k34_4 k35_4 k25_4 business_id_5 business_name_5 k24_5 k24_3_5 k24_2_5 k24_1_5 k24_0_5 k26_y_5 k27_5 k28_5 k29_5 k31_5 k32_5 k33_5 k43_5 k34_5 k35_5 k25_5 business_id_6 business_name_6 k24_6 k24_3_6 k24_2_6 k24_1_6 k24_0_6 k26_y_6 k27_6 k28_6 k29_6 k31_6 k32_6 k33_6 k43_6 k34_6 k35_6 k25_6 business_id_7 business_name_7 k24_7 k24_3_7 k24_2_7 k24_1_7 k24_0_7 k26_y_7 k27_7 k28_7 k29_7 k31_7 k32_7 k33_7 k43_7 k34_7 k35_7 k25_7 business_id_8 business_name_8 k24_8 k24_3_8 k24_2_8 k24_1_8 k24_0_8 k26_y_8 k27_8 k28_8 k29_8 k31_8 k32_8 k33_8 k43_8 k34_8 k35_8 k25_8 business_id_9 business_name_9 k24_9 k24_3_9 k24_2_9 k24_1_9 k24_0_9 k26_y_9 k27_9 k28_9 k29_9 k31_9 k32_9 k33_9 k43_9 k34_9 k35_9 k25_9 business_id_10 business_name_10 k24_10 k24_3_10 k24_2_10 k24_1_10 k24_0_10 k26_y_10 k27_10 k28_10 k29_10 k31_10 k32_10 k33_10 k43_10 k34_10 k35_10 k25_10 business_id_11 business_name_11 k24_11 k24_3_11 k24_2_11 k24_1_11 k24_0_11 k26_y_11 k27_11 k28_11 k29_11 k31_11 k32_11 k33_11 k43_11 k34_11 k35_11 k25_11 business_id_12 business_name_12 k24_12 k24_3_12 k24_2_12 k24_1_12 k24_0_12 k26_y_12 k27_12 k28_12 k29_12 k31_12 k32_12 k33_12 k43_12 k34_12 k35_12 k25_12 business_id_13 business_name_13 k24_13 k24_3_13 k24_2_13 k24_1_13 k24_0_13 k26_y_13 k27_13 k28_13 k29_13 k31_13 k32_13 k33_13 k43_13 k34_13 k35_13 k25_13 business_id_14 business_name_14 k24_14 k24_3_14 k24_2_14 k24_1_14 k24_0_14 k26_y_14 k27_14 k28_14 k29_14 k31_14 k32_14 k33_14 k43_14 k34_14 k35_14 k25_14 business_id_15 business_name_15 k24_15 k24_3_15 k24_2_15 k24_1_15 k24_0_15 k26_y_15 k27_15 k28_15 k29_15 k31_15 k32_15 k33_15 k43_15 k34_15 k35_15 k25_15 own_business k6 k6_1 k6_2 k6_3 k6_4 k6_5 k6_6 k6_7 k6_8 k6_9 k6_10 k6_11 k6_12 k6_13 k6_14 k6_15 k6_0 k6_99 k6_o1 k6_o2 dkna_livestock livestock_repeat_count livestock_id_1 livestock_name_1 livestock_max_k8_1 k7_1 k7_o_1 k7_o_v_1 k8_1 k8_v_1 livestock_id_2 livestock_name_2 livestock_max_k8_2 k7_2 k7_o_2 k7_o_v_2 k8_2 k8_v_2 livestock_id_3 livestock_name_3 livestock_max_k8_3 k7_3 k7_o_3 k7_o_v_3 k8_3 k8_v_3 livestock_id_4 livestock_name_4 livestock_max_k8_4 k7_4 k7_o_4 k7_o_v_4 k8_4 k8_v_4 livestock_id_5 livestock_name_5 livestock_max_k8_5 k7_5 k7_o_5 k7_o_v_5 k8_5 k8_v_5 livestock_id_6 livestock_name_6 livestock_max_k8_6 k7_6 k7_o_6 k7_o_v_6 k8_6 k8_v_6 livestock_id_7 livestock_name_7 livestock_max_k8_7 k7_7 k7_o_7 k7_o_v_7 k8_7 k8_v_7 livestock_id_8 livestock_name_8 livestock_max_k8_8 k7_8 k7_o_8 k7_o_v_8 k8_8 k8_v_8 livestock_id_9 livestock_name_9 livestock_max_k8_9 k7_9 k7_o_9 k7_o_v_9 k8_9 k8_v_9 livestock_id_10 livestock_name_10 livestock_max_k8_10 k7_10 k7_o_10 k7_o_v_10 k8_10 k8_v_10 livestock_id_11 livestock_name_11 livestock_max_k8_11 k7_11 k7_o_11 k7_o_v_11 k8_11 k8_v_11 livestock_id_12 livestock_name_12 livestock_max_k8_12 k7_12 k7_o_12 k7_o_v_12 k8_12 k8_v_12 livestock_id_13 livestock_name_13 livestock_max_k8_13 k7_13 k7_o_13 k7_o_v_13 k8_13 k8_v_13 livestock_id_14 livestock_name_14 livestock_max_k8_14 k7_14 k7_o_14 k7_o_v_14 k8_14 k8_v_14 livestock_id_15 livestock_name_15 livestock_max_k8_15 k7_15 k7_o_15 k7_o_v_15 k8_15 k8_v_15 k36 k37 k38 k38_v k9 k9_1 k9_2 k9_3 k9_4 k9_5 k9_6 k9_7 k9_8 k9_0 k9_99 k9_o1 k9_o2 dkna_produce produce_repeat_count produce_id_1 produce_name_1 produce_max_k10_1 produce_max_k12_1 produce_max_k13_1 k10_1 k10_v_1 k12_1 k12_v_1 k13_1 k13_v_1 produce_id_2 produce_name_2 produce_max_k10_2 produce_max_k12_2 produce_max_k13_2 k10_2 k10_v_2 k12_2 k12_v_2 k13_2 k13_v_2 produce_id_3 produce_name_3 produce_max_k10_3 produce_max_k12_3 produce_max_k13_3 k10_3 k10_v_3 k12_3 k12_v_3 k13_3 k13_v_3 produce_id_4 produce_name_4 produce_max_k10_4 produce_max_k12_4 produce_max_k13_4 k10_4 k10_v_4 k12_4 k12_v_4 k13_4 k13_v_4 produce_id_5 produce_name_5 produce_max_k10_5 produce_max_k12_5 produce_max_k13_5 k10_5 k10_v_5 k12_5 k12_v_5 k13_5 k13_v_5 produce_id_6 produce_name_6 produce_max_k10_6 produce_max_k12_6 produce_max_k13_6 k10_6 k10_v_6 k12_6 k12_v_6 k13_6 k13_v_6 produce_id_7 produce_name_7 produce_max_k10_7 produce_max_k12_7 produce_max_k13_7 k10_7 k10_v_7 k12_7 k12_v_7 k13_7 k13_v_7 produce_id_8 produce_name_8 produce_max_k10_8 produce_max_k12_8 produce_max_k13_8 k10_8 k10_v_8 k12_8 k12_v_8 k13_8 k13_v_8 k41 k14"
		
			foreach var of local vars_replace {
				cap confirm var `var' 
				if !_rc {
					di "`var'"
					cap noi replace `var' = `var'_m if replace_modules==1
					cap noi drop `var'_m 
				}
			}
			
		* Gen variable for respondent of that section
			gen 	respondent_productive_act = 1 if replace_modules==1
			replace respondent_productive_act = 2 if hh_head_gender==2
			replace respondent_productive_act = 2 if hh_head_gender==1 & (m_k15_m==1 & m_k15==0) 
			lab var respondent_productive_act "Respondent of the productive activities module"
			lab def respondent_productive_act_l 1 "MHHH" 2 "LHH"
			lab val respondent_productive_act respondent_productive_act_l
			order 	respondent_productive_act, before(k15)
			drop 	m_k15 m_k15_m replace_modules k15
		
	* Append Targeting 	
		tostring i34_da k30_13 m11 k24_3 k24_5 k24_14, replace 
		append using "${Targ_nopii_fl1}"
		
	* Order roster vars from Targeting 
		order b5_21 - b15_b_33, after(b15_b_20)
		order k5_1_21 - k30_2_33_9, after(k30_2_20_9)

	* Fix ultra_poor
		cap drop ultra_poor 
			gen ultra_poor = 1 if survey == 1 
			replace ultra_poor = 0 if survey == 3 
			label var ultra_poor "HH is ultra-poor"
		
	* Drop MHH data from the LHH dataset after replacement is made 
		unab todrop : *_m
		local tokeep a8_m a9_m a12_m a12_saliva_m ///
		 sample_barcode_m barcode_miss_m barcode_text1_m barcode_text2_m barcode_pic_m key_m // cortisol variables
		
		local dropthis : list todrop - tokeep
		drop `dropthis'
		
	* Save data
		save "${all_HH_interm_rost_nopii_fl1}", replace 
		

********************************************************************************
	** Part 5: Clean and save roster datasets
********************************************************************************

	* Prepare roster datasets [from all_HH_interm_rost_nopii_fl1 and MHHH_nopii_fl1]
		do "${fl1_do}/Cleaning/preparing_and_cleaning_rosters_fl1.do"
	
	* Drop roster variables from main dataset(s)
		use "${MHHH_nopii_fl1}", clear 
			rename *_m *
			do "${fl1_do}/Cleaning/roster_vars_todrop_fl1.do"
				rename * *_m
				rename hhid_m hhid
				save "${MHHH_norost_nopii_fl1}", replace
				
		use "${all_HH_interm_rost_nopii_fl1}", clear 

			do "${fl1_do}/Cleaning/roster_vars_todrop_fl1.do"
			
	* Merge MHH back on
		merge 1:1 hhid using "${MHHH_norost_nopii_fl1}", gen(merge_mhhh)
			drop if merge_mhhh ==2
			drop ultra_poor_m
			label var merge_mhhh "Result of matching LHH (master) with MHHH (using)"
			
	* Save all_HH_interm_nopii_fl1.dta with MHHH merged on prior to running cortisol results 		
		save "${all_HH_interm_nopii_fl1}", replace 
	
	* Clean cortisol results
		do "${fl1_do}/Cleaning/preparing_and_cleaning_cortisol_results_fl1.do" 
		 
		* Merge saliva results (LHH and MHH only)
			use "${all_HH_interm_nopii_fl1}", clear 
			
			merge 1:1 hhid using "${cortisol_results_fl1}", assert(1 3) gen(merge_cortisol)
			tab merge_cortisol a12_saliva, m
			*tab merge_cortisol consent_saliva_m, m 
			
			drop merge_cortisol
		
			drop barcode* *barcode* key* cortisol_notes* matched_labresults* key_m
			
				
********************************************************************************
	** Part 6: Drop variables in roster datasets from the main files
********************************************************************************
		
		*Looking at outliers for total loans (m5 variable) and saving variable
		qui do "${fl1_do}/Cleaning/saving_outliers_fl1.do" // this uses loan outlier flag from the loan roster
	
		* Label remaining vars
		label var time_endinteraction "Time of end of LHH survey (SurveyCTO-captured)"
		label var time_endinteraction_m "Time of end of MHHH survey (SurveyCTO-captured)"
	
		/* Re-order variables such that they match the new alphabetical order of the survey
		
			MODULE 1: SALIVA SAMPLE COLLECTION (A): a12_saliva - a17, after(a13)
			MODULE 2: HOUSEHOLD ROSTER (B)
			MODULE 3: CONSUMPTION (C): c1 - c14_7, after(a8_m_notav_perm)
			MODULE 4: TRANSFERS AND SAFETY NETS (D): 
			MODULE 5: HOUSING CHARACTERISTICS (E): ec - e16, after(e11) 
			MODULE 6: HEALTH AND HEALTH-SEEKING (F)
			MODULE 7: SHOCKS (G)
			MODULE 8: WOMEN'S DECISION MAKING ON HOUSEHOLD EXPENDITURES (H)
			MODULE 9: ASPIRATIONS, PERCEPTIONS AND PSYCHOLOGICAL WELL-BEING (I)
			MODULE 10: ENTREPRENEURSHIP (J) (IF HOUSEHOLD HEAD IS FEMALE OR HH DOES NOT HAVE A LADY OF THE HH): j6 - j5, after(i47) 
			MODULE 11: PRODUCTIVE ACTIVITIES (K): k22 - k14, after(j5)
			MODULE 12: OTHER ASSET OWNERSHIP (L)
			MODULE 13: CREDIT AND SAVINGS (M): m37 - m32__98, after(k14)
			MODULE 14: SOCIAL PARTICIPATION AND AWARENESS (N), CONFLICT AND VIOLENCE (O): n1 n2, after(m32__98) o1 - o3__99, after(n2)
			MODULE 15: TUP MONITORING AND COMPLIANCE (R): r80 - r24, after(o3__99) consent_direct_obs - r79, after(r24)
			MODULE 16: FRAGILITY (S), MIGRATION (T), RELIGION (U-1) AND COMMUNITY & EMOTIONS (U-2): u1 - u4, after(t11)
			MODULE 17: MOBILE PHONE USAGE (V)	 */

			* LHH, Targeting re-ordering
			order a12_saliva - a17, after(a13)
			order c1 - c14_7, after(a8_m_notav_perm)
			order d6 d13, after(c14_7)
			order ec - e16, after(e11)
			order j6 - j5, after(i47) 
			order respondent_productive_act k22 - k38, after(j5)
			order m37 - m32__98, after(k38)
			order n1 n2, after(m32__98)
			order o1 - o3__99, after(n2)
			order r80 - r24, after(o3__99)
			order consent_direct_obs - r79, after(r24)
			order u1 - u4, after(t11)
			order cortisol_result, after(time_collection)
			
			* MHHH re-ordering
			order a12_saliva_m, before(a13_saliva_m)
			order j6_m - j5_m, after(i47_m) 
			order k22_m - k38_m, after(j5_m)
			order u1_m - u4_m, after(t11_m)			
			order cortisol_result_m, after(time_collection_m)
			order s22_m s23_m s24_m, before(t1_m)
			
			cap label drop a5
			
		* Add treatment variables, weights used in analysis (embargo until publication)
			merge 1:1 hhid using ${profile_info}, keepusing(treatment PRA_lottery pweight pweight_CWR WealthRankingCategory_v) nogen keep(3)
				order ultra_poor treatment, after(hhid)
				order PRA_lottery WealthRankingCategory_v pweight_CWR pweight, last 
				
		* Save datasets with roster variables dropped
			save "${all_HH_nopii_fl1}", replace

			
		* Drop "flag_outlier" variable in the loans roster (since it was needed above to run "saving_outliers_fl1.do")
			use "${loans_fl1}", clear 
				drop flag_outlier
			
				save, replace 
				
				
