/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Nov 13, 2018
Last udpate on: Feb 17, 2018

Written by:  	Rebecca de Guttry and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Prepares the endline database for the Lady of the Household,
				Male Head of the Household and Targeting, doing modification and
				corrections based on field reports.

CONTENT:		Part 0: Create globals for directories and files 
				Part 2: Basic cleaning for each dataset based on field reports
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 1: Create globals for directories and files 
********************************************************************************

* Inputs
	* LHH, MHHH, Targeting surveys
		gl LHH_raw_fl1_pii "${TUP_DB_PII}/Followup_1/DataSets/Raw/LHH_raw_fl1_pii.dta"
		gl MHHH_raw_fl1_pii "${TUP_DB_PII}/Followup_1/DataSets/Raw/MHHH_raw_fl1_pii.dta"
		gl Targ_raw_fl1_pii "${TUP_DB_PII}/Followup_1/DataSets/Raw/Targ_raw_fl1_pii.dta"

	* Village anonymized
		gl village_anonymized 				"${TUP_DB_PII}/Profile_and_merging\DataSets\Intermediate/village_anonymized.dta" 
		
* Outputs
	
	* Raw data no PII - All surveys
		global LHH_allsvys_raw_fl1_nopii "${TUP_DB}/Followup_1/DataSets/Raw/LHH_allsvys_raw_fl1_nopii.dta"
		global MHHH_allsvys_raw_fl1_nopii "${TUP_DB}/Followup_1/DataSets/Raw/MHHH_allsvys_raw_fl1_nopii.dta"
		global Targ_allsvys_raw_fl1_nopii "${TUP_DB}/Followup_1/DataSets/Raw/Targ_allsvys_raw_fl1_nopii.dta"
 
********************************************************************************
	** Part 2: Basic cleaning for each dataset based on field reports
********************************************************************************
 
*-------------------------------------------------------------------------------
* 2.1. Lady of the Household
*-------------------------------------------------------------------------------

use "${LHH_raw_fl1_pii}", clear
 
	*-----------------------*
	* A. Manual corrections * 
	*-----------------------*
 					
	* Two surveys where they selected that the roster does not match
	* Preloaded data has been deleted, these survey are not needed
		drop if key=="uuid:be1888fa-b703-4682-b424-83e4b64a8a84"
		drop if key=="uuid:9e5e6506-5a58-43a1-ad86-1d0f570f6d28"
		drop if key=="uuid:97945ee4-861d-496f-a86f-087e2402eb09"
		
	* Surveys where the HH has moved away (will get the non-response survey)
		drop if key=="uuid:b590b05e-d91e-43e9-91bf-0880fbd6efec" // see issue = scenario_LHH_1504
		drop if key=="uuid:04ae22bc-2292-4133-bc3e-5de8a0c48e91" // see issue = scenario_LHH_1820
		drop if key=="uuid:aff84a18-de6c-45df-b58b-8ffe65f71f7d" // see issue = scenario_LHH_1444
		drop if key=="uuid:446e7c0c-c357-4cfa-a024-1b5ec03f7601" // see issue = scenario_LHH_1648
		drop if key=="uuid:3763a635-af04-4df9-991a-7e99253c30e9" // see issue = scenario_LHH_2026
		drop if key=="uuid:64bf068d-9da9-4fcc-9255-7a86b0afeb96"
		drop if key=="uuid:5649d710-b930-465e-a3e3-c7a09e5e9ad7"
		drop if key=="uuid:013f50d3-9acb-4b81-b498-6fd3f4da30a5" // see issue = scenario_LHH_1248
		drop if key=="uuid:cde479a8-7c99-44e0-801b-7cf5623526a8" // see issue = scenario_LHH_1527 LHH died and no MHH
		drop if key=="uuid:01b26f8c-8bd6-48fe-9df9-bb92f87c5b08" // see issue = scenario_LHH_1456
		drop if key=="uuid:1a0aa2a1-5d2e-400c-b0c1-9d6bb8dde8cf" // see issue = hh_status_2108
			
	* Drop one of two pairs of identical surveys that were duplicates because of incomplete submission problem
		drop if key=="uuid:adb0e53f-c944-4c7c-bfdf-f404cd4568fa"
		drop if key=="uuid:fea9c69a-5742-4c05-bcca-2b35539dd52b"
		drop if key=="uuid:3a46c7ea-1e89-4e5e-b370-2fd099053bbc"
		drop if key=="uuid:e25df899-3409-4a89-bd20-50fd52450e98"
		drop if key=="uuid:8949e2ba-b466-4293-9016-9ea0f710f61f"
			
	* Drop one of two pairs of identical surveys that were duplicates
		drop if key == "uuid:66d47a1c-ac8b-486e-8f3f-a507baef0584"
		drop if key == "uuid:cacdfc86-33ff-4139-abec-8484a75b737a"
					
	* Drop one survey that is duplicate because surveyors went twice after not consented
		drop if key=="uuid:ccbd1423-a991-4423-837c-321e12edd2f4" // see issue = scenario_LHH_1916	
		drop if key=="uuid:2b38d714-b24e-4e61-853b-ecf97afea46b"
		drop if key=="uuid:64be5a0c-cc52-43d2-99b9-28f51ac0ed1b"
					
	* Drop duplicated survey because they went twice 
		drop if key=="uuid:04820e94-0971-439a-81ef-41b624de6ddd" // see issue = dup_LHH_1674
		drop if key=="uuid:57935b81-618c-4ad8-803b-81039215ab9d" // see issue = dup_LHH_1855
		drop if key=="uuid:f6ba3a39-b0dd-47fa-9ba2-829471867427" // see issue = dup_LHH_2194
		drop if key=="uuid:9ea05029-7526-4b7d-8809-23e112af0964" // see issue = dup_LHH_2063
		drop if key=="uuid:b383677c-3f98-4885-a06c-8f844dd19cce" // see issue = scenario_LHH_1550 --> overlap of teams
		drop if key=="uuid:a38506fb-063c-4533-97dd-4337658cb3f0" // see issue = dup_LHH_1259
		drop if key=="uuid:4a13508c-35ff-4f57-8052-457438e7baa9" // see issue = dup_LHH_1523			
		drop if key=="uuid:9170c294-fb8f-45a2-9572-5308ebb147a9" // see issue = dup_LHH_1449
		drop if key=="uuid:fb596503-e6c8-4382-949f-7e1b535d4021" // see issue = dup_LHH_1772
		drop if key=="uuid:e230be27-d815-4d1b-a9ea-54e691a58d72" // see issue = dup_LHH_1616
        drop if key=="uuid:b58da99a-a3da-4c3c-b519-3a53b4f73510" // see issue = dup_LHH_1770

	* They got consent after revisit
		drop if key=="uuid:41903cbc-3015-47ef-9a32-d35aa4717e4d" // see issue = LHH_consent_1705
		drop if key=="uuid:09c507ed-0d62-490e-8cae-699ab294bac0" // see issue = LHH_consent_1357
		
	* Drop survey incorrectly conducted
		drop if key=="uuid:56c05969-83dd-48f4-bb97-9d03641e6ce2" // see issue = dup_LHH_2112
		drop if key=="uuid:6c747b62-8453-436e-b695-dbaf54e0201b" // see issue = dup_LHH_2129
		drop if key=="uuid:9fedfc42-5fbe-4b32-847e-625eb981aebb" // see issue = dup_LHH_1988
			
	* Surveys we asked them to repeat
	
		* In some cases, for these households some modules were not done in the second
		* survey, but in the first one (that we dropped). We recover the information
		* of these modules from the first survey.
			*keep if inlist(hh_id, 1052, 1436, 1473, 1573, 1715, 1822, 1841, 1915, 1920, 1966, 2008)
			sort hh_id
			rename consent_direct_obs a12_direct_obs
			rename ec a12_ec
			br hh_id a12 a12_mobile a12_saliva a12_ec a12_direct_obs key if inlist(hh_id, 1052, 1436, 1473, 1573, 1715, 1822, 1841, 1915, 1920, 1966, 2008)
		
		* Drop one incomplete
			drop if key=="uuid:c1bd662d-22aa-425b-a372-758400345b05"
			
		* Tag the ones to drop
			gen 	drop_repeat = .
			replace drop_repeat = 1 if inlist(key, "uuid:176ddcd2-4ba0-4d73-b7fd-2079d6061716", "uuid:a467d978-95f4-465c-8463-8b5956ba4270", "uuid:712ee247-22c5-41ef-92f9-81ef4d21af0c", "uuid:a074e32f-b399-4120-a4ef-9e37c8c7e6ca", "uuid:8cb8ca2e-3fd6-48b9-9521-cc0ccf57069f")
			replace drop_repeat = 1 if inlist(key, "uuid:a2dad13b-bb71-48c3-8e26-989bc8ffdd4f", "uuid:f3af73ff-42c8-45fb-864f-126fd8085705", "uuid:a3939c2e-bc47-4ece-870d-6bc127ca86d6", "uuid:a9d04ebf-6f1e-4cbb-965a-0d39b25df2b0", "uuid:9bfd12e5-13e9-44ac-8d3d-7b06c4610163", "uuid:080e3b93-27fb-4b40-bf7b-645301a451cd")
			replace drop_repeat = 0 if mi(drop_repeat) & inlist(hh_id, 1052, 1436, 1473, 1573, 1715, 1822, 1841, 1915, 1920, 1966, 2008)
		
		* Tag the ones that need to be completed
			foreach module in saliva mobile ec direct_obs {
				display "Module `module'"
				*br hh_id drop_repeat a12_`module'
				bys hh_id: egen max_a12_`module' = max(a12_`module')
				bys hh_id: egen min_a12_`module' = min(a12_`module')
				gen dif_a12_`module' = max_a12_`module'!=min_a12_`module'
				drop max_a12_`module' min_a12_`module'
					
				gen `module'_complete = (drop_repeat==0 & a12_`module'==0 & dif_a12_`module'==1) // The one we keep is the incomplete
				bys hh_id: egen tag_`module'_complete = max(`module'_complete)
				drop `module'_complete
			}
			lab var tag_mobile_complete "Module of mobile phone was completed from an older survey"
			lab var tag_saliva_complete "Module of saliva was completed from an older survey"
			lab var tag_direct_obs_complete "Module of direct obs was completed from an older survey"
			lab var tag_ec_complete "Module of direct obs was completed from an older survey"

		* Replace variables
			loc saliva_vars "a12_saliva time_begin_saliva time_begin_saliva_2 a12_saliva a13_saliva time_collection time_collection_2 a18 a18_v sample_barcode barcode_miss barcode_list barcode_text1 barcode_text2 barcode_list_text barcode_pic a19 num_activities a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17 time_endinteraction"
			*br hh_id drop_repeat dif_a12_saliva tag_saliva_complete `saliva_vars'

			loc mobile_vars "a12_mobile time_begin_v time_begin_v_2 v1 phone_lines phone_numbers_count phone_roster_1 v2_1 phone_roster_2 v2_2 phone_roster_3 v2_3 phone_roster_4 v2_4 phone_roster_5 v2_5 phone_repeat_count v2_roster_1 v3_1 v4_1 v4_o_1 firstnumbers_1 v5_1 v2_roster_2 v3_2 v4_2 v4_o_2 firstnumbers_2 v5_2 v2_roster_3 v3_3 v4_3 v4_o_3 firstnumbers_3 v5_3 v2_roster_4 v3_4 v4_4 v4_o_4 firstnumbers_4 v5_4 v2_roster_5 v3_5 v4_5 v4_o_5 firstnumbers_5 v5_5 time_end_v"
			*br hh_id drop_repeat dif_a12_mobile tag_mobile_complete `mobile_vars'

			loc direct_obs_vars "a12_direct_obs r68 r69 r70 r71 r72 r77 pic1 pic2 pic3 r78 r79 r79_o"
			*br hh_id drop_repeat dif_a12_direct_obs tag_direct_obs_complete `direct_obs_vars'
				
			loc ec_vars "a12_ec e12 e12_o e13 e14 e14_o e15 e15_o e16 e16_o"
			
			foreach module in saliva mobile direct_obs ec {
				display "Module `module'"
				sort hh_id a12_`module', stable
				foreach var of local `module'_vars {
					bys hh_id (a12_`module'): replace `var' = `var'[_n+1] if tag_`module'_complete==1 & drop_repeat==0
				}
			}	
			rename a12_direct_obs consent_direct_obs
			rename a12_ec ec
			drop dif_a12_saliva dif_a12_mobile dif_a12_direct_obs dif_a12_ec
			
		* Drop repeated surveys
			drop if drop_repeat==1
			drop drop_repeat
			
	* Replace consent for no-consent when necessary
		* See issues = scenario_LHH_1964, scenario_LHH_1031 and scenario_LHH_1275
		global no_consent_replace "inlist(key, "uuid:dcb28de5-da7d-4fc4-b7a4-8a82c3e0b592", "uuid:ac1d8509-c8fa-4223-bc51-6a694319ff2f", "uuid:dedd2557-8e34-4047-abb3-f7584c31a957")"
		replace a8 = 1 if $no_consent_replace
		replace a12 = 0 if $no_consent_replace
	
	* Notes for cleaning
		gen cleaning_notes = ""
			lab var cleaning_notes "Notes to take into account when cleaning"
			replace cleaning_notes = cleaning_notes + "*** Issue hh_type_2074: the HH head was incorrectly identified. The HH head is the husband." if key=="uuid:7a5e3bff-c4f7-4284-8a4b-dd9ef45ee454"
			replace cleaning_notes = cleaning_notes + "*** Issue LHH_1924_enum_gender: This a survey filled out by a male HH head. Filter questions were incorrectly selected." if key=="uuid:713ffaf4-06d0-43a9-bc21-b4582108add4"
			replace cleaning_notes = cleaning_notes + "*** Issue hh_type_1957: the HH head was incorrectly identified. The HH head is the husband." if key=="uuid:e6bb3191-af43-4fd3-9030-b50dc8e1fa41"

	* Village
		merge m:1 a6 using "${village_anonymized}", assert(3) nogen
	
	*-------------------*
	* B. Anonymize data * 
	*-------------------*

	drop a1altitude a1accuracy a1_cal a2_name a2_v a3_name a3_v hhhead_name_file ///
	father_spouse_name_file new_hhhead_name1 new_hhhead_fname new_hhhed_nickname ///
	new_hhhead_name name_* fname_* nickname_* full_name_* hh_name_* hh_members_* ///
	leave_name_* stay_name_* b17_oldroster_* name2_* fname2_* nickname2_* full_name2_* ///
	a8_m_name_o a8_m_fname_o a8_m_nickname_o a8_m_full_name_o a8_name_o a8_fname_o ///
	a8_nickname_o a8_full_name_o hhh_name lady_hh preload_name benef_name_coalesce ///
	namefromearlier_*  a6 a14 v2*   *_fname *_nickname labor_name_* /// a5
	livestock_sel trainee_sel stipend_sel health_sel savings_sel health_name_other ///
	savings_name_other stipend_name_other livestock_name_other trainee_name_other ///
	stipend_name_other savings_name_other q8altitude q8accuracy q8_cal ///
	livestockcare_name r14_o_name trainee_name r2_o_name r4_o_name stipend_name ///
	r10_o_name health_name r12_o_name savings_name
	
	* Save dataset with all surveys
		if	`c(stata_version)'>=14	{
			saveold "${LHH_allsvys_raw_fl1_nopii}", replace v(13)
		}
		else {
			save "${LHH_allsvys_raw_fl1_nopii}", replace
		}

*-------------------------------------------------------------------------------
* 2.2. Male Head of the Household
*-------------------------------------------------------------------------------

use "${MHHH_raw_fl1_pii}", clear
 
	*-----------------------*
	* A. Manual corrections * 
	*-----------------------*

	* Momentarily drop eight complete surveys that were filled by LHH with a female enumerator.
		** These were reported by Abobaker in googledoc.
		** ~~TO DO~~: later, replace the productive activities section in the LHH with the MHHH survey
		drop if inlist(key,"uuid:86968890-e129-42e7-9fc8-ff75cf990ef0","uuid:c496f35d-88dd-4bbc-806f-48207444b2a2","uuid:4fecd2f4-c120-49f6-8c08-9309b043d639","uuid:ee48c9df-5cd7-45c2-aacc-821fd3dd25fe")
		drop if inlist(key,"uuid:ab63a92d-dd11-4e97-a766-b243a2c8fdfd","uuid:d66dba23-fa53-4426-90ea-fe5f5d6eb6cd","uuid:081686ad-a074-42a4-8d60-2bb33eba1e83","uuid:06fb22dd-63d6-4dfe-9c70-54c6ed1fa184")

	* Drop one survey filled out by a female enumerator (incomplete)
		drop if key=="uuid:6c2aad2c-f30f-4356-b783-ad74332cb8fa"
		
	* Drop one of two pairs of surveys that are identical after accepting an incomplete submission (one relates to dup_MHHH_2188)
		drop if key=="uuid:3580005d-6601-4d35-bec4-e207acf761c6"
		drop if key=="uuid:d487c401-b47e-4f99-a106-054d21cd5a5a"
		drop if key=="uuid:c8873f27-cebd-4190-b266-c93e5337e395"
		drop if key=="uuid:dacf61c4-ecdd-4c44-8ce0-43fd05d9d45a"
		drop if key=="uuid:ff487424-2662-4351-bc79-a671fde05def"
		drop if key=="uuid:2866f284-bb3a-4c20-b8d0-40e5be8ff51a"
		drop if key=="uuid:538a21fd-8564-4026-87eb-03a8987fa6eb"

	* Drop an incomplete survey filled out by a female enumerator to a HH that has moved away (see issue gender_MHHH_1504)
		drop if key=="uuid:ff36af79-ecf0-4fb9-ad54-b69a2969a757"
		
	*  Drop one survey that are duplicate because supervisor was not satisfied with quality
		* and sent surveyors back (see issues: dup_mhhh_1977)
		drop if key=="uuid:8f0b43bc-3846-450a-ba11-a1e732bd1a54"
		drop if key=="uuid:f11983a1-b512-4817-b913-a1202226a4ae" // see issue = dup_LHH_1259
		drop if key=="uuid:00ec97f3-22e4-4713-9315-e12b8c796101" // see issue = dup_LHH_1523
		drop if key=="uuid:214ddc3a-f347-4d4b-89a7-cb2bf2352a17" // see issue = dup_MHHH_1855	
			
	* Drop cases where they submit MHHH when they should have submitted LHH filled out by Male household head
		drop if key=="uuid:e3d1809a-0463-4964-aada-80da9257a643" // see issue = scenario_LHH_1338
		drop if key=="uuid:8318f602-0d55-4de2-9718-5df22514c852" // see issue = LHH_1924_enum_gender and scenario_LHH_1924
		drop if key=="uuid:58a1cfb1-d01f-4db8-b657-6059779be994" // see issue = hh_type_1817
		drop if key=="uuid:1184813d-034b-498e-b5e3-bd91daeb0c6a" // see issue = hh_type_1836
		drop if key=="uuid:84a398b6-0332-4633-86b6-cb41f55ee48b" // see issue = hh_type_1505
	
	* Drop surveys where a MHHH was submitted for a female-led HH (confirmed by Abobaker that the house is female-led)
		drop if key=="uuid:6bd6dcb5-bbd0-46e1-8d22-5f28bab028f9" // see issue = hh_type_1715
		drop if key=="uuid:f80282a2-ae98-4118-9102-50aadbffa1cf"  // see issue = hh_type_1109
		drop if key=="uuid:2cc2a377-67d0-414e-9d36-058ca3432bc8"  // see issue = hh_type_1022
		drop if key=="uuid:8de2680f-9b70-4fe2-86e3-1b3fa3ec945e"  // see issue = hh_type_1287
		drop if key=="uuid:5a9e4c5e-fdc3-40d9-b8e4-68034578df2c" // see issue = hh_type_1184
		drop if key=="uuid:429307ea-c78f-4ccf-9c19-ca38ba301b46" // see issue = hh_type_2048
		drop if key=="uuid:ba5cd3b7-d448-4a22-b8fb-1ea7a3d94d7e" // see issue = hh_type_1743
		drop if key=="uuid:0b07789c-ae87-47dc-abc3-afe8b02a42d3" // see issue = hh_type_1989
		drop if key=="uuid:8a5b66be-2c03-4f96-98a4-8431864cea07" // see issue = hh_type_1554
		drop if key=="uuid:aea041cb-d35a-4a82-9d57-ee9e3bcb99f9" // see issue = hh_type_2118
		drop if key=="uuid:b89cf591-ceb1-4d52-b91e-4887c170149d" // see issue = hh_type_1997
		
	* Drop survey with no consent, which they got the consent later
		drop if key=="uuid:2c0d6f56-1dcb-4865-b1b4-269cb956f2c9" // see issue = MHHH_consent_1375
		
	* Drop survey done twice
		drop if key=="uuid:ce99b8c3-4740-468e-aece-e768de4af1d9" // see issue = dup_MHHH_2160
		drop if key=="uuid:65c78731-bd86-472b-9bf3-114af0e82843" // see issue = dup_MHHH_1315
		drop if key=="uuid:27b1e77d-f80e-46bd-94e7-d1a5fb19a454" // see issue = dup_MHHH_1952
		drop if key=="uuid:0ba3b1bf-48cc-44c0-9133-2e49f969de91" // see issue = dup_MHHH_1326
	
	* Surveys we asked them to repeat
		* In some cases, for these households some modules were not done in the second
		* survey, but in the first one (that we dropped). We recover the information
		* of these modules from the first survey.
		* See list in "TUP_Afghanistan/Data Analysis/Follow-Up/Follow Up R1/Outputs/Other/surveys_redo_17Sep2018_done.xlsx"
			*keep if inlist(hh_id, 1138, 1268, 1302, 1522, 2071, 2103, 2160)
			sort hh_id
			br hh_id a12 a12_saliva key
			
		* Drop one incomplete
			drop if key=="uuid:66b08e54-8c00-4ed8-a712-80a50f618586"
			drop if key=="uuid:f56988e8-79c6-4a45-ac03-01ced4e3562b"
			duplicates tag hh_id if inlist(hh_id, 1138, 1268, 1302, 1522, 2071, 2103, 2160), gen(dup)
			assert dup==1 |  dup==.
			drop dup

		* Tag the ones to drop
			gen 	drop_repeat = .
			replace drop_repeat = 1 if inlist(key, "uuid:b5e573c6-7f11-4ff7-a715-6b79e16407dc", "uuid:4baceaa4-2378-423d-9fae-2e3dbf6385d7", "uuid:60686a3a-33b3-447e-9479-96492a10729f", "uuid:f56988e8-79c6-4a45-ac03-01ced4e3562b", "uuid:95a8b7bc-893f-4d93-af1c-c35717cdf205", "uuid:8cb2a83a-aaa0-40cb-aed0-69616f7d6ffb", "uuid:82ab1a10-26d1-404d-8114-530f5573d063", "uuid:f11b8c7e-384b-4bf6-b809-7ad5d1e8487d")
			replace drop_repeat = 0 if mi(drop_repeat) & inlist(hh_id, 1138, 1268, 1302, 1522, 2071, 2103, 2160)
		
		* Tag the ones that need to be completed
			foreach module in saliva {
				display "Module `module'"
				*br hh_id drop_repeat a12_`module' if !mi(drop_repeat)
				bys hh_id: egen max_a12_`module' = max(a12_`module')
				bys hh_id: egen min_a12_`module' = min(a12_`module')
				gen dif_a12_`module' = max_a12_`module'!=min_a12_`module'
				drop max_a12_`module' min_a12_`module'
					
				gen `module'_complete = (drop_repeat==0 & a12_`module'==0 & dif_a12_`module'==1) // The one we keep is the incomplete
				bys hh_id: egen tag_`module'_complete = max(`module'_complete)
				drop `module'_complete
			}
			lab var tag_saliva_complete "Module of saliva was completed from an older survey"

		* Replace variables
			loc saliva_vars "a12_saliva time_begin_saliva time_begin_saliva_2 a12_saliva a13_saliva time_collection time_collection_2 a18 a18_v sample_barcode barcode_miss barcode_list barcode_text1 barcode_text2 barcode_list_text barcode_pic a19 num_activities a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17 time_endinteraction"
			*br hh_id drop_repeat dif_a12_saliva tag_saliva_complete `saliva_vars'

			foreach module in saliva {
				display "Module `module'"
				sort hh_id a12_`module', stable
				foreach var of local `module'_vars {
					bys hh_id (a12_`module'): replace `var' = `var'[_n+1] if tag_`module'_complete==1 & drop_repeat==0
				}
			}	
	
		* Drop repeated surveys
			drop if drop_repeat==1
			drop drop_repeat dif_a12_saliva
			 
	* Village
		merge m:1 a6 using "${village_anonymized}", assert(2 3) nogen keep(3)
		
	*-------------------*
	* B. Anonymize data * 
	*-------------------*

	drop a1altitude a1accuracy a1_cal a2_name a2_v a3_name a3_v hhhead_name_file ///
	father_spouse_name_file new_hhhead_name1 new_hhhead_fname new_hhhed_nickname ///
	new_hhhead_name a8_m_name_o a8_m_fname_o a8_m_nickname_o a8_m_full_name_o  /// a5
	a6 respondent_name_o respondent_fname_o respondent_nickname_o respondent_full_name_o ///
	q8altitude q8accuracy q8_cal
	
	* Save dataset with all surveys
		if	`c(stata_version)'>=14	{
			saveold "${MHHH_allsvys_raw_fl1_nopii}", replace v(13)
		}
		else {
			save "${MHHH_allsvys_raw_fl1_nopii}", replace
		}

*-------------------------------------------------------------------------------
* 2.3. Targeting
*-------------------------------------------------------------------------------

use "${Targ_raw_fl1_pii}", clear
 
	*-----------------------*
	* A. Manual corrections * 
	*-----------------------*
	
	* Drop four surveys that are duplicate because supervisor was not satisfied with quality
		* and sent surveyors back
		drop if key=="uuid:caaba285-5260-402c-8c4d-51e985ef0867" // see issue = dup_targ_5392
		drop if key=="uuid:4cfe8472-7116-41da-b2a8-2a0d3fabbb28" // see issue = dup_targ_5505
		drop if key=="uuid:86964517-db72-4fab-9c27-0085072953b6" // see issue = dup_targ_6001
		drop if key=="uuid:080f20b4-81b9-470e-821b-9337ca28c948" // see issue = dup_targ_5667
		drop if key=="uuid:9502ae35-5158-4a86-9f44-8bfb1f49c70e" // see issue = dup_targ_5732
		drop if key=="uuid:ff90ec4e-a984-4ecc-9dc1-2f95dd5f45eb" // see issue = dup_Targ_6025		
		drop if key=="uuid:35e7ac6d-5efb-44e8-843a-6d244e8109ee" // see issue = dup_targ_5896

	* Drop one survey that is duplicate because surveyors went twice after not consented
		drop if key=="uuid:8e52402b-20d8-4460-b3df-fbf7dcd852c6" // see issue = dup_targ_5576
	
	* Drop one survey where supervisor convinced respondent to consent after a no consent was submitted
		drop if key=="uuid:49f9943d-d7da-4383-85ce-ea2fb11f3f46" // see issue = targ_consent_5959
	
	* Drop survey that was incorrectly conducted
		drop if key=="uuid:a4153169-46c6-4c98-b4e9-97f42f390b51" // see issue = hh_status_5956
		drop if key=="uuid:984982ea-da3f-42ed-a3f3-6ff31081acd3" // see issue = dup_Targ_5938
		drop if key=="uuid:b4291caf-6efe-4b6a-bb96-3e58435e4382" // see issue = dup_Targ_5868
		drop if key=="uuid:909a005b-c3c7-4865-8fc5-b5cd4f2f726e" // see issue = dup_Targ_5136
		drop if key=="uuid:3b08378d-ea88-42b8-9c30-52321dc39850" // see issue = dup_Targ_5797
		drop if key=="uuid:2e44caea-1ccb-43c4-8e2f-5be07aba8920" // see issue = targ_consent_6500
		drop if key=="uuid:53c81cbc-564d-44aa-88b2-71f42f7ef690" // see issue = dup_Targ_5375
		drop if key=="uuid:e39f8d05-8cac-4070-97f8-902fcacc8794" // see issue = dup_Targ_6588
		drop if key=="uuid:aab8fa5e-4edd-4be8-89f9-9c84359c2c4b" // see issue = dup_Targ_6552
		drop if key=="uuid:c8f0f18d-c2b8-432e-91b3-354e687379a2" // see issue = dup_Targ_5804
	
	* Surveys we asked them to repeat
		* In some cases, for these households some modules were not done in the second
		* survey, but in the first one (that we dropped). We recover the information
		* of these modules from the first survey.
		* See list in "TUP_Afghanistan/Data Analysis/Follow-Up/Follow Up R1/Outputs/Other/surveys_redo_17Sep2018_done.xlsx"
			*keep if inlist(hh_id, 5133, 5686, 5734, 5872, 5874, 5906, 6097, 6113, 6241, 6364, 6405, 6428, 6567)
			sort hh_id
			rename ec a12_ec
			br hh_id a12 a12_mobile a12_ec key
			
		* Drop one incomplete
			duplicates tag hh_id if inlist(hh_id, 5133, 5686, 5734, 5872, 5874, 5906, 6097, 6113, 6241, 6364, 6405, 6428, 6567), gen(dup)
			assert dup==1 |  dup==.
			drop dup

		* Tag the ones to drop
			gen 	drop_repeat = .
			replace drop_repeat = 1 if inlist(key, "uuid:6541233a-5761-4f51-9878-a7705c4559e2", "uuid:376a8731-f3f3-4f71-8cd2-e29bcd2543fd", "uuid:5e963f37-1471-4cd0-be73-e1b8205d9519", "uuid:00853a5f-068d-42d5-9e35-5cda9bf77d3a", "uuid:cfa8adff-4c88-4213-87ad-7590de4ad114", "uuid:f6729faf-bfd5-4810-b5bc-4edd6916a964", "uuid:950b01c9-1552-4e54-a068-4ea8fd84591b")
			replace drop_repeat = 1 if inlist(key, "uuid:d24551df-bbbc-4277-abad-ef98ed5f81c4", "uuid:ab176525-af97-4fb9-bd24-67a0c5d77f45", "uuid:5a7cb2f3-b264-4c9d-aa6c-d3989e700e8d", "uuid:a85eba25-2c7b-44c9-bf46-0fc1028fbf8c", "uuid:e60339a5-67f1-4854-93e6-63dab5a2b150", "uuid:5a64ed61-bc3a-4e32-826d-7de074038d5f")
			replace drop_repeat = 0 if mi(drop_repeat) & inlist(hh_id, 5133, 5686, 5734, 5872, 5874, 5906, 6097, 6113, 6241, 6364, 6405, 6428, 6567)
		
		* Tag the ones that need to be completed
			foreach module in mobile ec {
				display "Module `module'"
				*br hh_id drop_repeat a12_`module' if !mi(drop_repeat)
				bys hh_id: egen max_a12_`module' = max(a12_`module')
				bys hh_id: egen min_a12_`module' = min(a12_`module')
				gen dif_a12_`module' = max_a12_`module'!=min_a12_`module'
				drop max_a12_`module' min_a12_`module'
					
				gen `module'_complete = (drop_repeat==0 & a12_`module'==0 & dif_a12_`module'==1) // The one we keep is the incomplete
				bys hh_id: egen tag_`module'_complete = max(`module'_complete)
				drop `module'_complete
			}
			lab var tag_mobile_complete "Module of mobile phone was completed from an older survey"
			lab var tag_ec_complete "Module of direct obs was completed from an older survey"

		* Replace variables
			loc mobile_vars "a12_mobile time_begin_v time_begin_v_2 v1 phone_lines phone_numbers_count phone_roster_1 v2_1 phone_roster_2 v2_2 phone_roster_3 v2_3 phone_roster_4 v2_4 phone_roster_5 v2_5 phone_repeat_count v2_roster_1 v3_1 v4_1 v4_o_1 firstnumbers_1 v5_1 v2_roster_2 v3_2 v4_2 v4_o_2 firstnumbers_2 v5_2 v2_roster_3 v3_3 v4_3 v4_o_3 firstnumbers_3 v5_3 v2_roster_4 v3_4 v4_4 v4_o_4 firstnumbers_4 v5_4 v2_roster_5 v3_5 v4_5 v4_o_5 firstnumbers_5 v5_5 time_end_v"
			*br hh_id drop_repeat dif_a12_mobile tag_mobile_complete `mobile_vars'

			loc ec_vars "a12_ec e12 e12_o e13 e14 e14_o e15 e15_o e16 e16_o"

			foreach module in mobile ec {
				display "Module `module'"
				sort hh_id a12_`module', stable
				foreach var of local `module'_vars {
					bys hh_id (a12_`module'): replace `var' = `var'[_n+1] if tag_`module'_complete==1 & drop_repeat==0
				}
			}	
	
		* Drop repeated surveys
			drop if drop_repeat==1
			drop drop_repeat dif_a12_mobile dif_a12_ec
			rename a12_ec ec			

	* Replace wrong ID
		replace hh_id = 5134 if key=="uuid:bf80d355-394a-49c5-846d-a2251acea548" // see issue = dup_Targ_5083
		
	* Village
		merge m:1 a6 using "${village_anonymized}", assert(1 2 3) nogen keep(1 3)
		
	*-------------------*
	* B. Anonymize data * 
	*-------------------*

	drop a1altitude a1accuracy a1_cal a2_name a2_v a3_name a3_v hhhead_name_file ///
	father_spouse_name_file new_hhhead_name1 new_hhhead_fname new_hhhed_nickname /// 
	new_hhhead_name name_* fname_* nickname_* full_name_* hh_name_*  a6 a14 v2* /// a5
	a8_m_name_o a8_m_fname_o a8_m_nickname_o a8_m_full_name_o a8_name_o a8_fname_o ///
	a8_nickname_o a8_full_name_o hhh_name lady_hh preload_name namefromearlier_* ///
	labor_name_* *_name *_fname *_nickname stipend_name_other livestock_name_other ///
	trainee_name_other q8altitude q8accuracy q8_cal

	* Save dataset with all surveys
		if	`c(stata_version)'>=14	{
			saveold "${Targ_allsvys_raw_fl1_nopii}", replace v(13)
		}
		else {
			save "${Targ_allsvys_raw_fl1_nopii}", replace
		}
	