/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	February 6, 2019
Last udpate on: June 17, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Cleans the psychological well being variables for the endline


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - General Cleaning
				Part 2 - Cleaning and checking the time variables linked to the cortisol analysis 
				Part 3 - Recoding psychological well being questions and creating variables to allow comparisons
				Part 4 - Invert so that "positive" outcomes go with higher values for all variables (this requires to look into individual questions for each measure)
				Part 5 - Saving dataset
							

				INPUTS:      	"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
								

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

	* Input files
		global inputdata "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_nopii_fl1.dta"

		*ado files

		* Output files: 
	* if "`c(username)'" == "escan" { // Outputs are saved in Dropbox
	 
	/* }

		if "`c(username)'" != "escan" { // Outputs are saved in local GitHub

		global wellbeing_clean "${fl1_dt}/Intermediate/all_wellbeing_clean_nopii_fl1.dta"
		
		}
		*/
		
		global id  hhid survey 
	
		global psy_f i5 i7 i10 i11 i12 i16 i23 i25 i26 i27 i28_a i28_b i28_c i28_d i28_e i28_f ///
						i28_g i28_h i28_i i28_j i34 i35 i37 i38 i39 i43 i44 i45 i46 i47 

		global psy_m i5_m i7_m i10_m i11_m i12_m i16_m i23_m i25_m i26_m i27_m i28_a_m i28_b_m i28_c_m i28_d_m i28_e_m i28_f_m ///
						i28_g_m i28_h_m i28_i_m i28_j_m i34_m i35_m i37_m  i38_m i39_m i43_m i44_m i45_m i46_m i47_m

		global cortisol_var time_collection* a18* a18_v* a19* a16* a17*
		global time_var time_collection a18_v a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17
		global time_var2 time_collection a18_v a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 

		
********************************************************************************
	** Part 1: General Cleaning
********************************************************************************

		//use "${inputdata}", clear
		
		local wellvars $id $psy_f $psy_m $cortisol_var  a8_m_gender_v_m a5 a6 hh_head_gender respondent_gender time_endinteraction time_endinteraction_m

		*Replace the - 98 and -99 for I don't know and don't answer with .d and .r 
	foreach y of varlist `wellvars' {
	cap confirm numeric variable `y'
	if !_rc {
		replace `y' = .r if `y' == -98
		replace `y' = .d if `y' == -99
		}
			}

********************************************************************************
	** Part 2: Cleaning and checking the time variables linked to the cortisol analysis 
********************************************************************************

		*Putting time variables in hours 
	foreach var in $time_var {
		foreach suffix in "" "_m" {
			gen hour_`var'`suffix' = hh(`var'`suffix') + mm(`var'`suffix') / 60
			sum hour_`var'
			label var hour_`var'`suffix' "`var'`suffix' in hours"			
		}
	} 
	
		*Testing for the correction of time collection 
		gen test_time	 	= hour_a18_v   - hour_time_collection 	if a18 	 == 0
		gen test_time_m 	= hour_a18_v_m - hour_time_collection_m if a18_m == 0
		
		*Three values look really off: hhid 1221 1614 1816. For these, we keep the time collection as it is more consistent with the survey time.  
		replace a18_v = time_collection if a18 == 0 & (hhid == 1221 | hhid == 1614 | hhid == 1816)
		
		*Checking on all the other time questions, making sure that nothing happened after the end of the interaction
	foreach suffix in "" "_m" {
		gen hour_time_endinteraction`suffix' = hh(time_endinteraction`suffix') + mm(time_endinteraction`suffix') / 60
		
		foreach var in $time_var2 {
			gen issue_`var'`suffix' = 0
			replace issue_`var'`suffix' = 1 if hour_time_endinteraction`suffix' < hour_`var'`suffix' & !mi(hour_`var'`suffix')
			label var issue_`var'`suffix' "`var' recorded as done after the interaction - inconsistent"
			tab issue_`var'`suffix'
		}
	}

		*Replacing to missing the time variables that are recorded as happening after interaction
	foreach var in $time_var2 { 
		gen hour_`var'_mis`suffix' = hour_`var'`suffix' if !(issue_`var'`suffix' == 1)	
		label var hour_`var'_mis`suffix' "`var' with doubtful observations put to missing"
		rename hour_`var'`suffix' hour_`var'_nomiss`suffix'
		rename hour_`var'_mis`suffix' hour_`var'`suffix'
	}


		* Drop constructed variables generated in this file for cleaning (to be re-constructed in "LHH_MHH_Psywellbeing_construct")
	drop *hour* *issue* test_time* time_endinteraction time_endinteraction_m
	
*********************************End of dofile***********************************************************************
