/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Apr 14, 2020
Last udpate on: Apr 14, 2020

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision for MDC: 	Drop "flag_outlier" vars at the bottom of the do-file. Rename a2 a2.

********************************************************************************			

THIS DO FILE: 	Cleans business from gross outliers

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

*use "$businesses_fl1", clear
	
* Get ultra-poor variable 
	merge m:1 hhid using "${all_HH_interm_rost_nopii_fl1}", assert(3) nogen keepus(ultra_poor a2)
	
* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""
	
* Replace .99 as extended missing .d (don't know)
	foreach var in k28 k32  k33 k43 k34 {
		count if round(`var',0.01)==.99
		replace flag_outlier = 1 if round(`var',0.01)==.99
		replace flag_outlier_why = ".99 typed instead of -99" if round(`var',0.01)==.99
		replace `var'=.d if round(`var',0.01)==.99
		tab a2 if `var'== 99
		replace flag_outlier = 1 if `var'== 99
		replace flag_outlier_why = "99 typed instead of -99" if `var'== 99
		replace `var'=.d if `var'== 99
	}
	
	foreach var in k28 k32  k33 k43 k34 {
		count if round(`var',0.01)==.98
		replace flag_outlier = 1 if round(`var',0.01)==.98
		replace flag_outlier_why = ".98 typed instead of -98" if round(`var',0.01)==.98
		replace `var'=.r if round(`var',0.01)==.98
		tab a2 if `var'== 98
		replace flag_outlier = 1 if `var'== 98
		replace flag_outlier_why = "98 typed instead of -98" if `var'== 98
		replace `var'=.d if `var'== 98
	}		
	
*-------------------------------------*
* K32: REVENUES FROM THE LAST 4 WEEKS *
*-------------------------------------*
	/*
		local reps 1/15
		local roster business
		local yes_var k23_a
		local graph_var k32
		
		local value_label_item: value label `roster'
		forvalues item = `reps' {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1, percent name("up_`item'", replace) title("`l_`item'' - Ultra-poor") note(N=`r(N)')
			}
		}
	*/
	
	sort ultra_poor k32 
	
* 1) Selling crafts (baskets, pots, etc.)
	local i = 1
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious

* 2) Repairing bicycles
	local i = 2
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious

* 3) Selling prepared foods/run restaurant
	local i = 3
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 4) Selling raw produce (that is NOT cultivated by respondent but purchased elsewhere)
	local i = 4
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 5) Providing transportation
	local i = 5
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 6) Making bricks
	local i = 6
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
	* One outlier. 100k Afs in revenues and costs in the past 4w
	replace flag_outlier = 1 if hhid == 5879 & business == 6
	replace k32 = .o if hhid == 5879 & business == 6
	replace k34 = .o if hhid == 5879 & business == 6
	
* 7) Butchering
	local i = 7
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 8) Doing carpentry
	local i = 8
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 9) Selling clothes and sheets
	local i = 9
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Few obs
	
* 10) Building thatch or iron sheet roofs
	local i = 10
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 11) Constructing houses/buildings
	local i = 11
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 12) Drilling boreholes/building latrines
	local i = 12
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 13) Collecting and selling firewood
	local i = 13
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 14) Other 1 (please specify)
	local i = 14
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 15) Other 2 (please specify)
	local i = 15
	local var k32
	local item business
	local yes_var k23_a
	local other_vars k35 k25 k34
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
drop ultra_poor a2 flag_outlier*