/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Apr 14, 2020
Last udpate on: Apr 14, 2020

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision for MDC: Drop "flag_outlier" vars in the end of the do-file. Rename a2 a2.

********************************************************************************			

THIS DO FILE: 	Cleans crops from gross outliers

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/
	
gl crops_bl	"${TUP_DB}/Baseline/DataSets/Intermediate/k_c_crops_bl.dta"

preserve

* Prepare baseline info
	use "${crops_bl}", clear
	rename * *_bl
	rename (hhid_bl crop_bl) (hhid crop)
	tempfile baseline
	save	`baseline'

restore

*use "$crops_fl1", clear

* Merge baseline
	merge 1:1 hhid crop using `baseline', keep(1 3) nogen
	
* Get ultra-poor variable 
	merge m:1 hhid using "${all_HH_interm_rost_nopii_fl1}", assert(3) nogen keepus(ultra_poor a2)
	
* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""
	
* Replace .99 as extended missing .d (don't know)
	foreach var in k17 k19 k20 k21 k40 {
		count if round(`var',0.01)==.99
		replace flag_outlier = 1 if round(`var',0.01)==.99
		replace flag_outlier_why = ".99 typed instead of -99" if round(`var',0.01)==.99
		replace `var'=.d if round(`var',0.01)==.99
	}
	
* All measures are in harvesting period, so we get comparable measures getting the 4-week estimates
	foreach var in k17 k19 k20 k21 k40 {
		gen `var'_4w = `var'*k16/13
	}
	
*---------------------------------------------*
* K17: KGS PRODUCED IN LAST HARVESTING PERIOD *
*---------------------------------------------*
	/*
		local reps 1/27
		local roster crop
		local yes_var k15
		local graph_var k17_4w
		
		local value_label_item: value label `roster'
		forvalues item = `reps' {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1, percent name("up_`item'", replace) title("`l_`item'' - Ultra-poor") note(N=`r(N)')
			}
		}
	*/
	
	sort ultra_poor k17_4w
	
* 1) Wheat
	local i = 1
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
	* No obvious outliers
	
* 2) Vetch: Not enough observations
	
* 3) Maize
	local i = 3
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
	* No obvious outliers
	
* 4) Barley
	local i = 4
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 5) Rice: No obs
	
* 6) Weed
	local i = 6
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
	* One outlier: UP household producing 1000 KGs per month
	replace flag_outlier = 1 if hhid == 1010 & crop == 6
	replace k17 = .o if hhid == 1010 & crop == 6
	replace k19 = .o if hhid == 1010 & crop == 6

* 7) Sesame
	local i = 7
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not enough obs

* 8) Clover
	local i = 8
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not enough obs

* 9) Millet
	local i = 9
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not enough obs

* 10) Sharsham: no obs

* 11) Sugarcane: no obs
	
* 12) Cotton
	local i = 12
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious

* 13) Caraway-seed
	local i = 13
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not enough obs
	
* 14) Potato: Only one obs
* 15) Cereal: No obs

* 16) Eggplant
	local i = 16
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 17) Tomato
	local i = 17
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
	* Two outliers. Over 300 Kgs in 4 weeks...and 4,200 and 2,100 in the croping season
	replace flag_outlier = 1 if inlist(hhid, 6475, 1454) & crop == 17
	replace k17 = .o if inlist(hhid, 6475, 1454) & crop == 17
	replace k19 = .o if inlist(hhid, 6475, 1454) & crop == 17
	
* 18) Onion
	local i = 18
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 19) Okra
	local i = 19
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
	* One obvious outlier. 2.500 kgs in 4weeks
	replace flag_outlier = 1 if inlist(hhid, 6475) & crop == 19
	replace k17 = .o if inlist(hhid, 6475) & crop == 19
	replace k19 = .o if inlist(hhid, 6475) & crop == 19

* 20) Fruits from a tree
	local i = 20
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
	* One outlier. 210 kgs in 4weeks
	replace flag_outlier = 1 if inlist(hhid, 5588) & crop == 20
	replace k17 = .o if inlist(hhid, 5588) & crop == 20
	replace k19 = .o if inlist(hhid, 5588) & crop == 20

* 21) Grape
	local i = 21
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 22) Mellon
	local i = 22
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not enough observations
	
* 23) Opium: Only one observation

* 24) Zaghar
	local i = 24
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not enough observations
	
* 25) Saffron: No obs

* 26) Other 1 ( please specify)
	local i = 26
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'

	* One outlier. 553 kgs in 4weeks
	replace flag_outlier = 1 if inlist(hhid, 5588) & crop == 26
	replace k17 = .o if inlist(hhid, 5588) & crop == 26
	replace k19 = .o if inlist(hhid, 5588) & crop == 26

* 27) Other 2 (please specify)
	local i = 27
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not enough obs
	
	
*----------------------------*
* K20: EARNING FROM SELLINGS *
*----------------------------*

* We use the median, so it shouldn't depend much in outliers

	* Get unit price
		gen k20_unit = k20/k19
	/*
		local reps 1/27
		local roster crop
		local yes_var k15
		local graph_var k20_unit
		
		local value_label_item: value label `roster'
		forvalues item = `reps' {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1, percent name("up_`item'", replace) title("`l_`item'' - Ultra-poor") note(N=`r(N)')
			}
		}
	*/
	
	sort ultra_poor k20_unit	
	
* 1) Wheat
	local i = 1
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	sum `var' if `yes_var' == 1 & `item' == `i' & k20_unit < 500, d // changes median
	
	* Some big values. Mostly from one enumaretor
	replace flag_outlier = 3 if crop == 1 & k20_unit>=500 & !mi(k20_unit) & a2==7
	replace k20 = .o if crop == 1 & k20_unit>=500 & !mi(k20_unit) & a2==7
	
* 2) Vetch: Not enough observations
* 3) Maize: Not enough observations
	
* 4) Barley
	local i = 4
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	sum `var' if `yes_var' == 1 & `item' == `i' & k20_unit < 500, d // changes median
	
	* Some big values. Mostly from one enumaretor
	replace flag_outlier = 3 if crop == 4 & k20_unit>=500 & !mi(k20_unit) & a2==7
	replace k20 = .o if crop == 4 & k20_unit>=500 & !mi(k20_unit) & a2==7
	
* 5) Rice: No obs
	
* 6) Weed: Not enough obs
* 7) Sesame: Not enough obs
* 8) Clover: Not enough obs
* 9) Millet: Not enough obs
* 10) Sharsham: no obs
* 11) Sugarcane: no obs
	
* 12) Cotton
	local i = 12
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	sum `var' if `yes_var' == 1 & `item' == `i' & k20_unit < 1400, d // changes median

	* One outlier of 1400 Afs per unit
	replace flag_outlier = 1 if crop == 12 & k20_unit==1400 & !mi(k20_unit)
	replace k20 = .o if crop == 12 & k20_unit==1400 & !mi(k20_unit)
	
	
* 13) Caraway-seed: Not enough obs
* 14) Potato: Only one obs
* 15) Cereal: No obs

* 16) Eggplant
	local i = 16
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 17) Tomato
	local i = 17
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 18) Onion
	local i = 18
	local var k17_4w
	local item crop
	local yes_var k15
	local other_vars k16 k17
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 19) Okra
	local i = 19
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
* 20) Fruits from a tree
	local i = 20
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	
* 21) Grape
	local i = 21
	local var k20_unit
	local item crop
	local yes_var k15
	local other_vars k16 k19 k20
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' `other_vars' if `yes_var' == 1 & `item' == `i'
	* Not obvious
	
* 22) Mellon: Not enough observations
* 23) Opium: Only one observation
* 24) Zaghar: Not enough observations
* 25) Saffron: No obs

* 26) Other 1 ( please specify)
	* Hard to tell since it could be many different crops
	
* 27) Other 2 (please specify)
	* Not enough obs
	
drop *_bl *_4w k20_unit ultra_poor a2 flag_outlier*
		