/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Feb 18, 2020
Last udpate on: Feb 18, 2020

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision MDC: drop "flag_outlier" flag vars at teh end of the do-files. Replace "c_a" with "c_a". Replaced enum_id with a2.	

********************************************************************************			

THIS DO FILE: 	Cleans foood consumption from gross outliers

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 1: Food items
********************************************************************************

*use "${consumption_fl1}", clear
	
* Get ultra-poor variable 
	merge m:1 hhid using "${all_HH_interm_rost_nopii_fl1}", assert(3) nogen keepus(ultra_poor a2)

* Get number of HH members
	preserve
		use "${current_roster_fl1}", clear
		keep hhid b3 // former hh_mem
		duplicates drop hhid, force
		tempfile b3
		save	`b3'
	restore
	merge m:1 hhid using `b3', assert(3) nogen
	
* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""
	
* Replace .99 as extended missing .d (don't know)
	count if round(c_a,0.01)==.99
	assert r(N)==44
	replace flag_outlier = 1 if round(c_a,0.01)==.99
	replace flag_outlier_why = ".99 typed instead of -99" if round(c_a,0.01)==.99
	replace c_a=.d if round(c_a,0.01)==.99
	
*--------------------------*
* Graph quantities by item *
*--------------------------*
	/*
		local value_label_item: value label item
		foreach item of numlist 1(1)105 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0, percent name("nup_`item'") title("`l_`item'' - Non-poor") note(N=`r(N)')
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1, percent name("up_`item'")title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		}
	*/
	
*------------------------------------------------------------------------*
* Check big values to identify if they're gross outliers / typing errors *
*------------------------------------------------------------------------*		
		
* 1) Rice (high quality)
	
	local i = 1
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Two clear outliers: We send to missing
		loc check_hhmem "9,10"
		bys b3 ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a) & inlist(b3,`check_hhmem'), d // clearly outliers even comparing to households of the same size
		replace flag_outlier = 1 if item == 1 & inlist(hhid, 5128, 5105)
		replace c_a = .o if item == 1 & hhid == 5128
		replace c_a = .o if item == 1 & hhid == 5105
	
* 2) Rice (low quality)
	
	local i = 2
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		loc check_hhmem "2,4,7,25"
		bys b3 ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a) & inlist(b3,`check_hhmem'), d // clearly outliers even comparing to households of the same size
		replace flag_outlier = 1 if item == 2 & inlist(hhid, 5867, 1062, 5383)	
		replace c_a = .o if item == 2 & hhid == 5867 // 100 Kgs for 2 household members
		replace c_a = .o if item == 2 & hhid == 1062 // 250 Kgs for 4 household members
		replace c_a = .o if item == 2 & hhid == 5383 // 70 Kgs for 7 household members
		* For HHID = 6108, c_a = 120 and b3 = 25, we cannot know if its outlier
	
* 3) Wheat flour
	
	local i = 3
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers

* 4) Naan not made at home
	
	local i = 4
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers

* 5) Barley
	
	local i = 5
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		loc check_hhmem "10,6"
		bys b3 ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a) & inlist(b3,`check_hhmem'), d // clearly outliers even comparing to households of the same size
		replace flag_outlier = 1 if item == 5 & inlist(hhid, 5879, 5471)	
		replace c_a = .o if item == 5 & hhid == 5879 // 350 Kgs for 10 household members
		replace c_a = .o if item == 5 & hhid == 5471 // 500 Kgs for 6 household members
	
* 6) Maize

	local i = 6
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers
	
* 7) Beans

	local i = 7
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 7 & hhid == 1880 
		replace flag_outlier = 3 if item == 7 & c_a == 250 & a2 == 56
		replace flag_outlier_why = "Zuhra Beeg, beans: same value for 6 households" if item == 7 & c_a == 250 & a2 == 56
		
		replace c_a = .o if item == 7 & c_a == 250 & a2 == 56 // 6 surveys by Zuhra Beeg with a value of 250 kgs for households of 3-6 members. Clear outliers
		replace c_a = .o if item == 7 & hhid == 1880 // 300 Kgs for 1 household member
	
* 8) Mung

	local i = 8
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 b3 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing
	replace flag_outlier = 3 if item == 8 & c_a >= 200 & !mi(c_a) & a2 == 56
	replace flag_outlier_why = "Zuhra Beeg, mung: weird values for 10 households" if item == 8 & c_a >= 200 & !mi(c_a) & a2 == 56
	replace flag_outlier = 1 if item == 8 & c_a >= 200 & !mi(c_a) & a2 == 40 
	replace flag_outlier = 1 if item == 8 & c_a >= 100 & !mi(c_a) & a2 == 28 
	replace flag_outlier = 1 if item == 8 & hhid == 1880 
	
	replace c_a = .o if item == 8 & c_a >= 200 & !mi(c_a) & a2 == 56 // 10 surveys by Zuhra Beeg with a value of 200-500 kgs. Clear outliers/made up values
	replace c_a = .o if item == 8 & c_a >= 200 & !mi(c_a) & a2 == 40 // 1 surveys by Noria Neda with a value of 250 kgs for households of 3-6 members. Clear outliers
	replace c_a = .o if item == 8 & c_a >= 100 & !mi(c_a) & a2 == 28 // 2 surveys by Farnosh Amiri with clear outliers
	replace c_a = .o if item == 8 & hhid == 1880 // 300 Kgs for 1 household member
	
* 9) Chickpeas

	local i = 9
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 3 if item == 9 & c_a >= 200 & !mi(c_a) & a2 == 56 
		replace flag_outlier_why = "Zuhra Beeg, chickpeas: weird values for 2 households" if item == 9 & c_a >= 200 & !mi(c_a) & a2 == 56 
		replace flag_outlier = 1 if item == 9 & hhid == 1880 

		replace c_a = .o if item == 9 & c_a >= 200 & !mi(c_a) & a2 == 56 // 2 surveys by Zuhra Beeg with a value of 200/250 kgs for 2 hh members. Clear outliers/made up values
		replace c_a = .o if item == 9 & hhid == 1880 // 300 Kgs for 1 household member	

* 10) Lentils

	local i = 10
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
	
* 11) Pasta

	local i = 11
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 11 & hhid == 1880 
		replace c_a = .o if item == 11 & hhid == 1880 // 200 Kgs for 1 household member	
		
* 12) Other bread and/or cereal

	local i = 12
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
	
* 14) Beef

	local i = 14
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
	
* 15) Veal

	local i = 15
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 15 & hhid == 5643 
		replace flag_outlier_why = "99 typed instead of -99" if item == 15 & hhid == 5643
		replace flag_outlier = 1 if item == 15 & hhid == 1816 

		replace c_a = .d if item == 15 & hhid == 5643 // looks like a -99	
		replace c_a = .o if item == 15 & hhid == 1816 // Clear outlier of 2000
		
* 16) Mutton

	local i = 16
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers
	
* 17) Goat

	local i = 17
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers
	
* 18) Chicken

	local i = 18
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 18 & inlist(hhid, 5574, 6209)
		
		replace c_a = .o if item == 18 & hhid == 5574 // Clear outlier of 600
		replace c_a = .o if item == 18 & hhid == 6209 // Clear outlier of 1000
		
* 19) Liver

	local i = 19
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers	
	
* 20) Dried Meat

	local i = 20
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers		
	
* 21) Fish

	local i = 21
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers		
	
* 22) Other meat and/or fish

	local i = 22
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers		
	
* 24) Milk (fresh)

	local i = 24
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
	* Clear outliers: We send to missing
		loc check_hhmem "9, 7, 12, 8, 10"
		bys b3 ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a) & inlist(b3,`check_hhmem'), d // clearly outliers even comparing to households of the same size
		replace flag_outlier = 1 if item == 24 & inlist(hhid, 1633, 1836, 6006)	

		replace c_a = .o if item == 24 & hhid == 1633 // 150 Kgs for a 7-member household
		replace c_a = .o if item == 24 & hhid == 1836 // 72 Kgs for a 9-member household
		replace c_a = .o if item == 24 & hhid == 6006 // 100 Kgs for a 10-member household
		
* 25) Milk (powdered)

	local i = 25
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers. 			
	
* 26) Yogurt

	local i = 26
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 27) Curd (chaka)

	local i = 27
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 28) Krut (dried)

	local i = 28
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 28 & hhid == 1425
		replace c_a = .o if item == 28 & hhid == 1425 // Clear outlier of 15 (the rest of values are <= .5
	
* 29) Dogh

	local i = 29
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 30) Ghee

	local i = 30
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 30 & inlist(hhid, 1152, 5874)
		replace c_a = .o if item == 30 & hhid == 1152 // Clear outlier of 600 kgs
		replace c_a = .o if item == 30 & hhid == 5874 // Clear outlier of 250 kgs
	
* 31) Butter

	local i = 31
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 32) Cheese

	local i = 32
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.

* 33) Eggs

	local i = 33
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 34) Other dairy products

	local i = 34
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 36) Vegetable oil

	local i = 36
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 36 & hhid == 5643 
		replace flag_outlier_why = "99 typed instead of -99" if item == 36 & hhid == 5643 
		replace c_a = .d if item == 36 & hhid == 5643 // looks like a -99	
	
* 37) Cotton oil or sesame oil

	local i = 37
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 37 & hhid == 1229
		replace flag_outlier_why = "99 typed instead of -99" if item == 37 & hhid == 1229
		replace c_a = .d if item == 37 & hhid == 1229 // looks like a -99	
	
* 38) Animal fat

	local i = 38
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 39) Other oils and fat

	local i = 39
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 41) Potato

	local i = 41
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 41 & hhid == 5643
		replace flag_outlier_why = "99 typed instead of -99" if item == 41 & hhid == 5643
		replace flag_outlier = 1 if item == 41 & hhid == 1614

		replace c_a = .d if item == 41 & hhid == 5643 // looks like a -99	
		replace c_a = .o if item == 41 & hhid == 1614 // clear outlier of 1000 Kgs for a 5-member household
	
* 42) Sweet potato

	local i = 42
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.
	
* 43) Onion

	local i = 43
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 43 & inlist(hhid, 5643, 1458)
		replace flag_outlier_why = "99 typed instead of -99" if item == 43 & inlist(hhid, 5643, 1458)
		replace flag_outlier = 1 if item == 43 & inlist(hhid, 5874, 1614)
		
		replace c_a = .d if item == 43 & hhid == 5643 // looks like a -99	
		replace c_a = .o if item == 43 & hhid == 5874 // clear outlier of 100 Kgs for a 1-member household	
		replace c_a = .d if item == 43 & hhid == 1458 // looks like a -99	
		replace c_a = .o if item == 43 & hhid == 1614 // clear outlier of 4000 Kgs for a 5-member household	

* 44) Tomato

	local i = 44
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 44 & inlist(hhid, 5954, 1503)
		replace flag_outlier_why = "99 typed instead of -99" if item == 44 & inlist(hhid, 5954, 1503)
		replace flag_outlier = 1 if item == 44 & inlist(hhid, 5783, 6177, 1101)
		
		replace c_a = .d if item == 44 & hhid == 5954 // looks like a -99		
		replace c_a = .o if item == 44 & hhid == 5783 // clear outlier of 105 Kgs for a 8-member household	
		replace c_a = .o if item == 44 & hhid == 6177 // clear outlier of 350 Kgs for a 12-member household	
		replace c_a = .d if item == 44 & hhid == 1503 // looks like a -99		
		replace c_a = .o if item == 44 & hhid == 1101 // clear outlier of 200 Kgs for a 4-member household	
		
* 45) Okra

	local i = 45
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 45 & inlist(hhid, 1171, 2131)
		replace flag_outlier_why = "99 typed instead of -99" if item == 45 & inlist(hhid, 1171, 2131)
		replace flag_outlier = 1 if item == 45 & inlist(hhid, 6015, 6209)
		
		replace c_a = .o if item == 45 & hhid == 6015 // clear outlier of 90 Kgs for a 8-member household	
		replace c_a = .o if item == 45 & hhid == 6209 // clear outlier of 1500 Kgs for a 8-member household	
		replace c_a = .d if item == 45 & hhid == 1171 // looks like a -99		
		replace c_a = .d if item == 45 & hhid == 2131 // looks like a -99		
	
* 46) Spinach

	local i = 46
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.	
	
* 47) Cauliflower

	local i = 47
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.	
	
* 48) Eggplant

	local i = 48
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.		

* 49) Carrots

	local i = 49
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 50) Pumpkin, squash

	local i = 50
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 51) Cucumber

	local i = 51
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 51 & hhid == 2131
		replace flag_outlier_why = "99 typed instead of -99" if item == 51 & hhid == 2131
		
		replace c_a = .d if item == 51 & hhid == 2131 // looks like a -99	
	
* 52) Radish

	local i = 52
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 53) Turnip: no one consumed

* 54) Cabbage: no one consumed

* 55) Leek

	local i = 55
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 56) Hot pepper

	local i = 56
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 56 & hhid == 1383
		replace flag_outlier_why = "99 typed instead of -99" if item == 56 & hhid == 1383
		replace c_a = .d if item == 56 & hhid == 1383 // looks like a -99	
		
		replace flag_outlier = 1 if item == 56 & inlist(hhid, 5272, 6150, 1152)
		replace c_a = .o if item == 56 & hhid == 5272 // clear outlier of 100 Kgs for a 9-member household	
		replace c_a = .o if item == 56 & hhid == 6150 // clear outlier of 100 Kgs for a 7-member household	
		replace c_a = .o if item == 56 & hhid == 1152 // clear outlier of 100 Kgs for a 9-member household	
		
		replace flag_outlier = 3 if item == 56 & c_a >= 50 & !mi(c_a) & a2 == 48
		replace flag_outlier_why = "Zahra Amin Husain, hot pepper: 5 surveys with outliers" if item == 56 & c_a >= 50 & !mi(c_a) & a2 == 48
		replace c_a = .o if item == 56 & c_a >= 50 & !mi(c_a) & a2 == 48 // 5 surveys by Zahra Amin Husain who apparenterely misinterpreted the unit

* 57) Wild leafy vegetables

	local i = 57
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 58) Coriander

	local i = 58
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 58 & hhid == 6490 
		replace c_a = .o if item == 58 & hhid == 6490 // clear outlier of 200 Kgs for a 15-member household	
		
* 59) Mint

	local i = 59
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 60) Dried tomatoes

	local i = 60
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			

* 61) Dried vegetables

	local i = 61
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 61 & hhid == 1505 
		replace flag_outlier_why = "99 typed instead of -99" if item == 61 & hhid == 1505 
		
		replace c_a = .d if item == 61 & hhid == 1505 // looks like a -99		
	
* 62) Pickled vegetables

	local i = 62
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 63) Green beans

	local i = 63
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 64) Other vegetables

	local i = 64
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			

* 66) Apple

	local i = 66
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 67) Grapes

	local i = 67
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 67 & hhid == 1503 
		replace flag_outlier_why = "99 typed instead of -99" if item == 67 & hhid == 1503 
		
		replace c_a = .d if item == 67 & hhid == 1503 // looks like a -99	
	
* 68) Melon/watermelon

	local i = 68
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 68 & inlist(hhid, 6174, 6270, 1229) 
		replace flag_outlier_why = "99 typed instead of -99" if item == 68 & inlist(hhid, 6174, 6270, 1229) 
		
		replace c_a = .d if item == 68 & hhid == 6174 // looks like a -99	
		replace c_a = .d if item == 68 & hhid == 6270 // looks like a -99	
		replace c_a = .d if item == 68 & hhid == 1229 // looks like a -99	

* 69) Peach

	local i = 69
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 70) Fresh apricots

	local i = 70
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 71) Dried apricots

	local i = 71
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 72) Orange/citrus

	local i = 72
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 73) Plum

	local i = 73
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 74) Pomegranate

	local i = 74
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 75) Pear

	local i = 75
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 76) Banana

	local i = 76
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 77) Raisins

	local i = 77
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 78) Fresh mulberries: no one consumed
	
* 79) Dried mulberries

	local i = 79
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.			
	
* 80) Mangoes

	local i = 80
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 81) Walnuts

	local i = 81
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 82) Pistachio

	local i = 82
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 83) Almonds

	local i = 83
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 84) Other fruit and/or nuts

	local i = 84
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 86) White sugar

	local i = 86
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 86 & inlist(hhid, 1108, 1229) 
		replace flag_outlier_why = "99 typed instead of -99" if item == 86 & inlist(hhid, 1108, 1229) 
		replace c_a = .d if item == 86 & hhid == 1108 // looks like a -99	
		replace c_a = .d if item == 86 & hhid == 1229 // looks like a -99		
		
		tab a2 if c_a>=80 & !mi(c_a) & item == 86  //56 HHs. they look like issues with the units, we send them to missing
		replace flag_outlier = 2 if c_a>=80 & !mi(c_a) & item == 86 
		replace flag_outlier_why = "Enumerator or respondent misinterpreted the unit of measure" if c_a>=80 & !mi(c_a) & item == 86 
		replace c_a = .o if c_a>=80 & !mi(c_a) & item == 86 
		

* 87) Brown sugar

	local i = 87
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 88) Honey

	local i = 88
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 89) Chocolates

	local i = 89
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 3 if item == 89 & c_a >= 100 & !mi(c_a) & a2 == 51
		replace flag_outlier_why = "Mobina Jahish, chocolates: 4 surveys with outliers" if item == 89 & c_a >= 100 & !mi(c_a) & a2 == 51
		replace c_a = .o if item == 89 & c_a >= 100 & !mi(c_a) & a2 == 51 // 4 surveys by Mobina Jahish who apparenterely misinterpreted the unit
	
		replace flag_outlier = 1 if item == 89 & hhid == 5732
		replace c_a = .o if item == 89 & hhid == 5732 // clear outlier of 200 Kgs for a 4-member household	
	
* 90) Candy, sherinigack

	local i = 90
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
	replace flag_outlier = 1 if item == 90 & hhid == 1627
	replace c_a = .o if item == 90 & hhid == 1627 // clear outlier of 100 Kgs for a 4-member household	
	
* 91) Sweetener

	local i = 91
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 92) Other sweets, specify

	local i = 92
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 94) Black teas

	local i = 94
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing. 30%. 22 out of 72 valid values
		replace flag_outlier = 2 if item == 94 & c_a < 1 & c_a != 0 // it looks like they misinterpreted the unit
		replace flag_outlier_why = "Enumerator or respondent misinterpreted the unit of measure" if item == 94 & c_a < 1 & c_a != 0
		replace c_a = .o if item == 94 & c_a < 1 & c_a != 0
	
* 95) Green teas

	local i = 95
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing. 25% of the valid values
		replace flag_outlier = 2 if item == 95 & c_a < 1 & c_a != 0 // there is a discontinuity here. it looks like they misinterpreted the unit
		replace flag_outlier_why = "Enumerator or respondent misinterpreted the unit of measure" if item == 95 & c_a < 1 & c_a != 0
		replace c_a = .o if item == 95 & c_a < 1 & c_a != 0	
	
* 96) Bottled/canned beverages, Mineral waters

	local i = 96
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
		
	* Clear outliers: We send to missing. 25% of the valid values		
		replace flag_outlier = 1 if item == 96 & inlist(hhid, 6270, 6299) 
		replace flag_outlier_why = "99 typed instead of -99" if item == 96 & inlist(hhid, 6270, 6299) 
		replace c_a = .d if item == 96 & hhid == 6270 // looks like a -99	
		replace c_a = .d if item == 96 & hhid == 6299 // looks like a -99
		
		replace flag_outlier = 1 if item == 96 & c_a >= 150 & !mi(c_a) // implausible values
		replace c_a = .o if item == 96 & c_a >= 150 & !mi(c_a)
		replace flag_outlier = 1 if item == 96 & inlist(hhid, 1498, 1343)
		replace c_a = .o if item == 96 & inlist(hhid, 1498, 1343) // 50 and 60 kgs for 9- and 5-member households
		
* 97) Other beverages

	local i = 97
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if  item == 97 & hhid == 1996
		replace c_a = .o if item == 97 & hhid == 1996 // clear outlier of 100 Liters for a 6-member household	
			
* 99) Salt

	local i = 99
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if  item == 99 & hhid == 5150
		replace c_a = .o if item == 99 & hhid == 5150 // clear outlier of 12,500 grams for a 8-member household		
	
* 100) Black pepper

	local i = 100
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 15% of valid values
		replace flag_outlier = 2 if item == 100 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 100 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 100 & c_a < 1 & c_a > 0 
		
* 101) Ginger and garlic

	local i = 101
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 20% of valid values
		replace flag_outlier = 2 if item == 101 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 101 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 101 & c_a < 1 & c_a > 0
	
* 102) Tomato sauce

	local i = 102
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing: 17% of valid values
		replace flag_outlier = 2 if item == 102 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 102 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 102 & c_a < 1 & c_a > 0
	
* 103) Mixed spices

	local i = 103
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 8% of valid values
		replace flag_outlier = 2 if item == 103 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 103 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 103 & c_a < 1 & c_a > 0	
	
* 104) Other spices

	local i = 104
	bys ultra_poor: sum c_a b3 if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a b3 a2 if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing: 8% of valid values
		replace flag_outlier = 2 if item == 104 & c_a < 1 & c_a > 0
		replace flag_outlier_why = "Values too small to be grams" if item == 104 & c_a < 1 & c_a > 0
		replace c_a = .o if item == 104 & c_a < 1 & c_a > 0		
	
* Graph with cleaned variables
	/*
		local value_label_item: value label item
		foreach item of numlist 1(1)105 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1, percent name("up_`item'", replace)title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		}
	*/
	
* Deleting irrelevant variables
	drop ultra_poor a2 b3 flag_outlier*
	
