 /*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Apr 14, 2020
Last udpate on: Apr 14, 2020

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision MDC: 	"flag_outlier" vars dropped at the end of the do-file.	

********************************************************************************			

THIS DO FILE: 	Cleans livestock own by the household from gross outliers

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/
	
gl livestock_bl	"${TUP_DB}/Baseline/DataSets/Intermediate/k_a_livestock_bl.dta"

preserve

* Prepare baseline info
	use "${livestock_bl}", clear
	rename * *_bl
	rename (hhid_bl livestock_bl) (hhid livestock)
	tempfile baseline
	save	`baseline'

restore

* Merge baseline
	merge 1:1 hhid livestock using `baseline', keep(1 3) nogen
	
* Get ultra-poor variable
	merge m:1 hhid using "${all_HH_interm_rost_nopii_fl1}", assert(3) nogen keepus(ultra_poor k41 k14 a2)


* Quantity owned: we need to complete this variable with info from k7_o
	gen 	lstock_num = k7 
	replace lstock_num = k7_o if k7==11
	replace lstock_num = 0 if k6==0	
	
* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""
	
*-----------------------------------*
* K6: HOW MANY LIVESTOCK DO YOU OWN *
*-----------------------------------*
	/*
		local reps 1/15
		local roster livestock
		local yes_var k6
		local graph_var lstock_num
		
		local value_label_item: value label `roster'
		forvalues item = `reps' {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1, percent name("up_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
		}
	*/
	
* Sheep: This is the only one with big and possible outliers. 
	tab lstock_num if livestock == 6
	tab hhid if livestock == 6 & lstock_num > 3000 & !mi(lstock_num)
	br if inlist(hhid, 5265, 6032) // we cannot asses if this values are true.
		
		* HHID == 5265: owns 1 cow, and 50 goats. We don't have info in baseline (not asked). 
		* 3,500 sheep it's probably a typing error
			replace lstock_num = .o if hhid == 5265
			replace flag_outlier = 1 if hhid == 5265
			
		* HHID == 6032: owns 2 donkeys, and 10 goats. We don't have info in baseline (not asked)
		* 5,500 sheep it's probably a typing error
			replace lstock_num = .o if hhid == 6032
			replace flag_outlier = 1 if hhid == 6032

*-----------------------------------------------*
* k8: EARNINGS IF YOU HAD TO SELL ONE LIVESTOCK *
*-----------------------------------------------*

* Won't be too affected since we used the median in construction. We drop
* implausible values.

	/*
		local reps 1/15
		local roster livestock
		local yes_var k6
		local graph_var k8
		
		local value_label_item: value label `roster'
		forvalues item = `reps' {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
			sum `graph_var'		if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1
			if `r(N)' {
			hist `graph_var' 	if `roster' == `item' & `yes_var' == 1 & ultra_poor == 1, percent name("up_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			}
		}
	*/
	
	* Look at the data to identify potential outliers (NB Asset cost for the program was estimated as 37 000 AFN AFN (2016) ) and included pregnant cow or with calf
	* Transfer equivalence: 1 cow = 3 Sheep = 4 Goats . For chicken, international comparison would be 0.017 cow so 1 cow = 59 chicken 	

	* Values of 0 are pretty unlikely 
		replace k8 = .o if k8 == 0
	
* 1) Cows
	
	* Not very clear
	local i = 1
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'
	sum `var' if `yes_var' == 1 & `item' == `i' & k8 < 100000, d 
	

	* Taking 60000 as an upper limit based on the transfer price, inflation and data distribution - 21 changes, 21 for the NUP 
	replace k8 = .o if livestock == 1 & k8 > 60000 & !mi(k8)	
	
* 2) Bulls

	* No big issues
	local i = 2
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'

* 3) Horses

	* No big issues
	local i = 3
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'

* 4) Donkeys

	* No big issues
	local i = 4
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'

* 5) Goats

	* Some big values, but we cannot assess
	local i = 5
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'
	
	* Taking 20000 as an upper limit based on the transfer price, inflation and data distribution - 2 changes, 2 for the NUP 	
	replace k8 = .o if livestock == 5 & k8 > 20000 & !mi(k8)

* 6) Sheep

	local i = 6
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'

	
	* Taking 15000 as an upper limit based on the transfer price, inflation and data distribution - 9 changes, 7 for the NUP and 2 for UP
	replace k8 = .o if livestock == 6 & k8 > 15000 & !mi(k8)
	

* 7) Chickens

	local i = 7
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'
	sum `var' if `yes_var' == 1 & `item' == `i' & k8 < 1000, d // doesn't change median, we don't change anything
	
	* Taking 1000 as an upper limit based on the transfer price, inflation and data distribution - 7 changes, 4 for the NUP and 3 for UP
	replace k8 = .o if livestock == 7 & k8 > 1000 & !mi(k8)	

* 8) Ducks

	* Not enough obs
	local i = 8
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'

* 9) Turkeys

	* Not enough obs
	local i = 9
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'

* 10) Gooses: No obs
* 11) Rabbits

	* Not enough obs
	local i = 11
	local var k8
	local item livestock
	local yes_var k6
	sum `var' if `yes_var' == 1 & `item' == `i', d
	br `item' ultra_poor `var' if `yes_var' == 1 & `item' == `i'

* 12) Guinea fowl: only 1 obs
* 13) Bee hives: No obs

* 14) Other animal 1 (please specify): Hard to assess since there are many different things
* 15) Other animal 2 (please specify): Hard to assess since there are many different things

* Drop variables
	drop *_bl lstock_num a2 flag_outlier*
