/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	Feb 4, 2020
Last udpate on: Feb 4, 2020

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision MDC: drop "flag_outlier" vars at the end of the do-file. Replace hh_mem with b3. Replace a2 with a2. Remove e1_o and bl_e1_o ("other spec" vars in Dari)

********************************************************************************			

THIS DO FILE: 	Cleans non consumption from gross outliers

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_interm_rost_nopii_fl1 	"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_rost_nopii_fl1.dta"
	gl data_for_analysis_bl				"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	gl nonfood_consumption_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/c_c_nonfoodconsumption_bl.dta" 		
	gl other_assets_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/l_hhassets_fl1.dta"
	gl all_HH_interm_nopii_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_interm_nopii_bl.dta" 
	
			

********************************************************************************
	** Part 1: Non-food items
********************************************************************************
	
* Get ultra-poor variable 
	merge m:1 hhid using "${all_HH_interm_rost_nopii_fl1}", assert(3) nogen keepus(ultra_poor a2)

* Get number of HH members
	preserve
		use "${current_roster_fl1}", clear
		keep hhid b3
		duplicates drop hhid, force
		tempfile b3
		save	`b3'
	restore
	merge m:1 hhid using `b3', assert(3) nogen	

	
* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""	
	
* Replace .99 as extended missing .d (don't know)
	foreach var in c12 c13 {
		count if round(`var',0.01)==.99
			if inlist(`var', c12) {
				assert r(N)==14
			}
			else {
				assert r(N)==144
			}
		replace flag_outlier = 1 if round(`var',0.01)==.99
		replace flag_outlier_why = ".99 typed instead of -99" if round(`var',0.01)==.99				
		replace `var'=.d if round(`var',0.01)==.99
	}
	
*--------------------------------------------------------*
* Check 99 and 98 to identify if they're coding mistakes *
*--------------------------------------------------------*

	tab a2 if inlist(c12, .d, .r) | inlist(c13, .d, .r) // Yalda Mansoury, and Dr. Faruqa Sahab have so many...
	tab a2 if inlist(c12, 99, 98) | inlist(c13, 99, 98) // most of them done by Taibah Nori, Yalda Mansoury, Dr. Faruqa Sahab. We assume they're extended missing
	/*
			   Interviewer ID |      Freq.     Percent        Cum.
		----------------------+-----------------------------------
				  Taibah Nori |         35       39.77       39.77
		 BiBi Qamer Khaleqyar |          1        1.14       40.91
			   Yalda Mansoury |         12       13.64       54.55
			   Nahida Alizada |          2        2.27       56.82
			 Dr. Faruqa Sahab |         28       31.82       88.64
				Freshtah Noor |          1        1.14       89.77
				Muhaya Habibi |          2        2.27       92.05
				   Noria Neda |          2        2.27       94.32
			 Eng Najla Akbari |          5        5.68      100.00
		----------------------+-----------------------------------
						Total |         88      100.00
	*/
	
* We assume these enumerators meant to introduce -99 and -98 
	replace flag_outlier = 1 if c12 == 99 & inlist(a2, 7, 18, 29)
	replace flag_outlier = 1 if c13 == 99 & inlist(a2, 7, 18, 29)
	replace flag_outlier_why = "99 typed instead of -99" if (c12 == 99 | c13 == 99) & inlist(a2, 7, 18, 29)
	replace c12 = .d if c12 == 99 & inlist(a2, 7, 18, 29)
	replace c13 = .d if c13 == 99 & inlist(a2, 7, 18, 29)

	replace flag_outlier = 1 if c12 == 98 & inlist(a2, 7, 18, 29)
	replace flag_outlier = 1 if c13 == 98 & inlist(a2, 7, 18, 29)
	replace flag_outlier_why = "98 typed instead of -98" if (c12 == 98 | c13 == 98) & inlist(a2, 7, 18, 29)	
	replace c12 = .r if c12 == 98 & inlist(a2, 7, 18, 29)
	replace c13 = .r if c13 == 98 & inlist(a2, 7, 18, 29)	
	
* Create one variable for c12 and c13: we're analyzing by item so it doesn't matter c12 is monthly and c13 yearly
	br hhid hhid item c12 c13
	gen 	non_food = c12
	replace non_food = c13 if item >= 21


*------------------------------------*
* Get variables we need for analysis *
*------------------------------------*	
	
*Most important is to check for all the UP first. Let's check their loans, whether they say they have a house, value of food consumption and savings, as well as the bl values for these. 
*It's about 15 HHs but with very high values. Check all above AFG 100K. The median for UP is AFG 7K

	preserve
	
		* HH-level baseline
			use "${all_HH_interm_nopii_bl}", clear
			keep hhid e1 m19 m20 m1_a m5
			rename * bl_*
			rename bl_hhid hhid
			tempfile hh_level_bars_bl
			save	`hh_level_bars_bl'
		
		* HH-level follow-up
			use "${all_HH_interm_rost_nopii_fl1}", clear
			keep hhid e1 m19 m20 m1_a m5
			tempfile hh_level_bars_fl1
			save	`hh_level_bars_fl1'
		
		* Assets
			use "${other_assets_fl1}", clear
			keep if inlist(asset,5,6,7) 
			drop  l2 l3 l4
			gen 	asset_l = "_house_land" if asset == 5
			replace asset_l = "_other_land" if asset == 6
			replace asset_l = "_other_house" if asset == 7
			drop asset
			reshape wide l1 l5, i(hhid) j(asset_l) s
			egen owns_anything = rowtotal(l1_house_land l1_other_house l1_other_land)
			drop l5_*
			tempfile asset_fl1
			save	`asset_fl1'
			
		* Consumption baseline
			use "${data_for_analysis_bl}", clear
			keep hhid exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc_ALCS exp_nf_tot_m_pc_w
			rename * bl_*
			rename bl_hhid hhid
			tempfile consump_bl
			save 	`consump_bl'
			
		* Non-food consumption baseline
			use "${nonfood_consumption_bl}", clear
			rename (c12 c13) (bl_c12 bl_c13)
			tempfile nonfood_bl
			save	`nonfood_bl'
			
	
	restore
	
* Merge
	merge m:1 hhid using `hh_level_bars_bl', keep(1 3) nogen
	merge m:1 hhid using `hh_level_bars_fl1', assert(3) nogen
	merge m:1 hhid using `asset_fl1', assert(3) nogen
	merge m:1 hhid using `consump_bl', keep(1 3) nogen
	merge 1:1 hhid item using `nonfood_bl', keep(1 3) nogen
	
*----------------------------*
* Graph and do summary stats *
*----------------------------*
	/*
		local value_label_item: value label item
		foreach item of numlist 1(1)38 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			count if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 0
			hist non_food if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			count if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 1
			hist non_food if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 1, percent name("up_`item'", replace)title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		}
	*/
*------------------------------------------------------------------------*
* Check big values to identify if they're gross outliers / typing errors *
*------------------------------------------------------------------------*		
		
* 1) Food consumed at home 
	
	* Seems to have some issues, specially in non-poor
	local i = 1
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 20k for ultra-poor
	br item ultra_poor non_food owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=20000 & !mi(non_food) & ultra_poor == 1
		// all of them own at least the house they live in, and have savings or loans. no way to be sure. should be fixed with winsorization
	
* 2) Food consumed outside the home

	* Looks smooth, no big issues
	local i = 2
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	
* 3) Cigarettes

	* Some values seem high, but there is no clear outlier. No way to know.
	* It should be fixed with winsorization
	local i = 3
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 4) Tobacco/snuff

	* Some issues
	* It should be fixed with winsorization
	local i = 4
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	

* 5) Matches

	* Some issues. Values above 100 seem high
	* It should be fixed with winsorization
	local i = 5
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 6) Laundry powder/detergents, cleaning supplies

	* Some issues, specially in non-poor. Values above 1000 seem high
	* It should be fixed with winsorization
	local i = 6
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 7) Soap (hand, toiletry)

	* Some issues. Values above 300 seem high
	* It should be fixed with winsorization
	local i = 7
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 8) Shampoo

	* Some issues in non-poor. Values above 1000 seem high
	* It should be fixed with winsorization
	local i = 8
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 9) Toothpaste

	* Seems smooth
	local i = 9
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
* 10) Personal grooming (haircuts, etc.) for males

	* Some issues in ultra-poor.
	* It should be fixed with winsorization
	local i = 10
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 11) Fee for public bath
	
	* N = 34 for non-poor and N = 9 for poor.
	* Winsorization does not do anything but there are some big values. Not so important.
	local i = 11
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 12) Laundry charges

	* N = 34 for non-poor and N = 10 for poor.
	* Winsorization does not do anything but there are some big values. Not so important.
	local i = 12
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 13) Fee for baking bread

	* N = 96 for non-poor and N = 65 for poor.
	* Winsorization does not do anything but there are some big values
	local i = 13
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 14) Fixed phone line and use (including PCO booths)

	* N = 5 for non-poor and N = 6 for poor.
	* Winsorization does not do anything.
	local i = 14
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* One clear outlier: HHID 5393. We send to missing
	replace flag_outlier = 1 if item == 14 & hhid == 5393
	replace c12		 = .o if item == 14 & hhid == 5393
	replace non_food = .o if item == 14 & hhid == 5393

* 15) Mobile phone charges (minutes and prepaid)

	local i = 15
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* One clear outlier: HHID 1816. We send to missing
	replace flag_outlier = 1 if item == 15 & hhid == 1816
	replace c12 	 = .o if item == 15 & hhid == 1816
	replace non_food = .o if item == 15 & hhid == 1816
	*hist non_food if item == 15 & non_food>0 & !mi(non_food) & ultra_poor == 1, percent
	
* 16) Internet service/Internet café, fax, mail

	* No big issues
	local i = 16
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 17) Transportation fare - bus and taxis

	local i = 17
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* Check values above 10k 
	br item ultra_poor non_food bl_c12 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=10000 & !mi(non_food) 
		// values could be plausible. they have debt	

* 18) Fuel for car/motor bike (do not include business vehicles)

	local i = 18
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* Check values above 15k 
	br item ultra_poor non_food bl_c12 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=15000 & !mi(non_food) 
		
	* Two households with no loans or savings in bl or fl1.
	replace flag_outlier = 4 if item == 18 & inlist(hhid, 6494, 5020)
	replace flag_outlier_why = "School uniforms. No loans or savings" if item == 18 & inlist(hhid, 6494, 5020)
	replace c12 		= .o if item == 18 & inlist(hhid, 6494, 5020)
	replace non_food 	= .o if item == 18 & inlist(hhid, 6494, 5020)

* 19) Taxes (formal and informal)

	* Seems ok
	local i = 19
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

* 20) Other miscellaneous expenses in last month

	local i = 20
	bys ultra_poor: sum c12 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
		
	* Check values above 5k, where there's a discontinuity
	bys hhid: egen max_c12 = max(c12)
	gen flag = 1 if c12 == max_c12
	br item ultra_poor non_food flag bl_c12 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=5000 & !mi(non_food) 
	
	* Most households with no loans or savings in bl or fl1.
	sort bl_m5 m5
	replace m5 = .d if m5 == -99
	egen number_loan_savings =  rownonmiss(bl_m5 m5 bl_m19 m19 bl_m20 m20)
	replace flag_outlier = 4 if item == 20 & number_loan_savings == 0 & non_food>=5000 & !mi(non_food) 
	replace flag_outlier_why = "School uniforms. No loans or savings" if item == 20 & number_loan_savings == 0 & non_food>=5000 & !mi(non_food) 
	replace c12 		= .o if item == 20 & number_loan_savings == 0 & non_food>=5000 & !mi(non_food) 
	replace non_food 	= .o if item == 20 & number_loan_savings == 0 & non_food>=5000 & !mi(non_food) 
	
	drop max_c12 flag number_loan_savings
	
* 21) House construction and repair (materials and labor)

	local i = 21
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 100k for ultra-poor
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=100000 & !mi(non_food) & ultra_poor == 1	
	
	* Flag the ones who don't own the house and any land
	gen flag_house = 1 if !inlist(e1, 1, 2, 5) & !inlist(bl_e1, 1, 2, 5) & owns_anything == 0
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == 21 & non_food>=100000 & !mi(non_food) & ultra_poor == 1 & flag_house == 1  
	drop flag_house
		// both of these two households had loans in bl and fl1. Values could be plausible
	
* 22) Education fees (tuition for school, college, university)

	local i = 22
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* Check values above 5k for ultra-poor
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=5000 & !mi(non_food) & ultra_poor == 1	
		// loans and saving in bl and fl1 could explain it. Values could be plausible
	
* 23) School uniforms

	local i = 23
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues in UP, worth reviwing values above 7K in non-UP (up to 64K)
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=7000 & !mi(non_food)

	* Two households with no loans or savings in bl or fl1.
	replace flag_outlier = 4 if item == 23 & inlist(hhid, 6618, 5726)
	replace flag_outlier_why = "School uniforms. No loans or savings" if item == 23 & inlist(hhid, 6618, 5726)
	replace c13 = .o if item == 23 & inlist(hhid, 6618, 5726)
	replace non_food = .o if item == 23 & inlist(hhid, 6618, 5726)
	
* 24) Textbooks

	local i = 24
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealth with the winsorization.

* 25) Pens, pencils and notebooks (school supplies)

	local i = 25
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealth with the winsorization.

* 26) Other stationery

	local i = 26
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealth with the winsorization.

* 27) Repair, maintenance and tires for motor vehicles

	local i = 27
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 10k for ultra-poor
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=10000 & !mi(non_food) & ultra_poor == 1	

	* One household with no loans or savings in bl or fl1.
	replace flag_outlier = 4 if item == 27 & inlist(hhid, 1360)
	replace flag_outlier_why = "Repair for motor vehicles. No loans or savings" if item == 27 & inlist(hhid, 1360)
	replace c13 = .o if item == 27 & inlist(hhid, 1360)
	replace non_food = .o if item == 27 & inlist(hhid, 1360)
	
* 28) Airfares

	local i = 28
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>0 & !mi(non_food)
		// big values could be explained by loans

* 29) Men's clothing (excluding shoes)

	local i = 29
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealth with the winsorization.

* 30) Women's clothing (excluding shoes)

	local i = 30
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* Check values above 10k 
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=10000 & !mi(non_food) & ultra_poor == 1	
		// could be explain by loans or savings
		
* 31) Children's clothing (excluding shoes and school uniforms)

	local i = 31
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* Check values above 10k 
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=10000 & !mi(non_food) & ultra_poor == 1	
		// could be explain by loans or savings
	
	* One household with no loans or savings in bl or fl1.
	replace flag_outlier = 4 if item == 31 & inlist(hhid, 1042)
	replace flag_outlier_why = "Children's clothing. No loans or savings" if item == 31 & inlist(hhid, 1042)
	replace c13 = .o if item == 31 & inlist(hhid, 1042)
	replace non_food = .o if item == 31 & inlist(hhid, 1042)

* 32) Men's shoes

	local i = 32
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealth with the winsorization.

* 33) Women's shoes

	local i = 33
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* No important issues and the ones are dealth with the winsorization.
	
* 34) Children's shoes

	local i = 34
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* No important issues and the ones are dealth with the winsorization.

* 35) Fines

	local i = 35
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* weird value of 150k
	replace flag_outlier = 1 if item == 35 & inlist(hhid, 5976)
	replace c13 = .o if item == 35 & inlist(hhid, 5976)
	replace non_food = .o if item == 35 & inlist(hhid, 5976)
	
* 36) Weddings and funerals, haj

	local i = 36
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)

	* weird value of 6 million
	replace flag_outlier = 1 if item == 36 & inlist(hhid, 1413)
	replace c13 = .o if item == 36 & inlist(hhid, 1413)
	replace non_food = .o if item == 36 & inlist(hhid, 1413)
	
* 37) Annual celebrations and charitable donations (khair-o-khairat)

	local i = 37
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>0 & !mi(non_food)
		// household with big value have loans in baseline and follow-up
		
* 38) Health services

	local i = 38
	bys ultra_poor: sum c13 if item == `i' & non_food>0 & !mi(non_food), d
	sort item ultra_poor non_food
	br item ultra_poor non_food if item == `i' & non_food>0 & !mi(non_food)
	
	* Check values above 300k 
	br item ultra_poor non_food bl_c13 bl_exp_nf_tot_m_pc_w owns_anything bl_e1 e1 bl_m5 m5 bl_m19 m19 bl_m20 m20 if item == `i' & non_food>=300000 & !mi(non_food) & ultra_poor == 1	
		// all of them have either loans or savings. and it's consistent with expenditure in health services in baseline
	
* Drop variables
	drop ultra_poor a2 b3 non_food bl_e1 bl_m1_a bl_m5 bl_m19 bl_m20 e1 m1_a m5 m19 m20 l1_house_land l1_other_house l1_other_land owns_anything bl_exp_nf_tot_m_pc_w bl_exp_nf_tot_m_pc_ALCS bl_exp_f_tot_m_pc bl_exp_tot_m_pc bl_c12 bl_c13 flag_outlier*
	
