/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Feb 15, 2018
Last udpate on: Feb 15, 2018

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans and prepares cortisol results


CONTENT:		

INPUTS:     	

OUTPUTS:     	

Notes 10/2020:

- Input data changed to clean files in Microdata folder 
- Two results files are saved: LHH and MHHH reparately (these are then merged on to the surveys in the Cleaning do-file)


*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Follow-up 1 survey data appended and merged
		gl all_HH_interm_nopii_fl1 "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_nopii_fl1.dta"

	* Labs results
		gl batch1and2 	"${TUP_DB}/Followup_1/DataSets/Raw/Saliva_Collection/Results_24Sep2018.xlsx"
		gl batch3 		"${TUP_DB}/Followup_1/DataSets/Raw/Saliva_Collection/Results_thirdbatch.xlsx"
		gl batch4 		"${TUP_DB}/Followup_1/DataSets/Raw/Saliva_Collection/Results_fourthbatch.xlsx"

	* Valid barcodes
		gl valid_barcodes "${TUP_DB}/Followup_1/Questionnaire/PreloadData/barcodes_list.csv"

* Outputs
	
	*if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
		gl cortisol_results_fl1 "${TUP_DB}/Followup_1/DataSets/Intermediate/cortisol_results_fl1.dta"

	 *}
	*	if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub
	*	gl cortisol_results_fl1 "${fl1_dt}/Intermediate/cortisol_results_fl1.dta"
	*	}	
		
********************************************************************************
	** Part 1: Import cortisol results 
********************************************************************************

* Import list of valid barcodes
	import delimited "${valid_barcodes}", encoding(ISO-8859-1) clear
	rename barcode_key barcode
	tempfile barcode_list
	save	`barcode_list'


* First and second batch - 24Aug2018
*-----------------------------------

	import excel "${batch1and2}", sheet("Interne ID-Liste") firstrow clear
	drop if mi(externalID)
	rename externalID barcode
	
	* Fix a couple that didn't export
		replace barcode="100490E" if internalID==801
		replace barcode="100286H" if internalID==756
		
	* Fix the ones that were inconsistent: confirmed by DIME and Lab (by email)
	* See file here: TUP_Afghanistan/Data Collection/Follow-up/Saliva_Collection/Results/Verification barcodes first and second batch - Abobaker Kabul barcodes_unmatched_withlabresults_01Oct2018.xlsx
		replace barcode="100638I" if internalID==34
		replace barcode="100639J" if internalID==329
		replace barcode="100369J" if internalID==468
		replace barcode="100904E" if barcode=="100964E"
		replace barcode="100658K" if barcode=="100653K"
		replace barcode="100698O" if barcode=="1006980"
		replace barcode="100819J" if barcode=="100919J"
		replace barcode="100738J" if barcode=="100738I"
		replace barcode="1000214" if barcode=="100214"
		replace barcode="102407E" if barcode=="102407A"
		replace barcode="100166E" if barcode=="100166F"
		replace barcode="100887O" if barcode=="1008870"

	* Replace unreadable
	* File here: "TUP_Afghanistan/Data Collection/Follow-up/Saliva_Collection/Results/Verification_barcodes_12Nov2018_afterverif.xlsx"
	* sheet "unreadable barcodes"
		replace barcode="100584I" if internalID==953
		replace barcode="100927J" if internalID==954
		replace barcode="100938L" if internalID==958
		replace barcode="100516D" if internalID==959
		replace barcode="100626F" if internalID==960
		replace barcode="100880H" if internalID==961
		replace barcode="100557I" if internalID==962
		replace barcode="100882J" if internalID==963
		replace barcode="100672G" if internalID==964
		replace barcode="100156D" if internalID==965
		replace barcode="1000337" if internalID==968
		replace barcode="100256E" if internalID==969
		replace barcode="100681G" if internalID==971
		replace barcode="100257F" if internalID==972
		replace barcode="1000225" if internalID==973
		replace barcode="100857L" if internalID==974
		replace barcode="100849M" if internalID==975
		replace barcode="100127B" if internalID==977
		replace barcode="100646H" if internalID==978
		replace barcode="100990J" if internalID==979
		replace barcode="100866L" if internalID==980
		replace barcode="1000315" if internalID==981
		replace barcode="100933G" if internalID==984
		replace barcode="100592H" if internalID==986
		replace barcode="100863I" if internalID==987
		replace barcode="100482F" if internalID==990
		replace barcode="100799Q" if internalID==991
		replace barcode="100762G" if internalID==992
		replace barcode="1004308" if internalID==993
		replace barcode="100734F" if internalID==994
		replace barcode="100540A" if internalID==995
		replace barcode="100787N" if internalID==996
		replace barcode="100789P" if internalID==997
		replace barcode="100690G" if internalID==998
		
	* Check duplicates
		drop if barcode=="unreadable"
		duplicates tag barcode, gen(dup)
		replace Shipment="First" if mi(Shipment)
		replace Shipment="Second" if Shipment=="28.08.18"
		count if dup>0
		isid barcode
		
	* Format and save
		format barcode %15s
		gen barcode_lab=barcode
		drop F G
		tempfile results_firstandsecond_batch
		save	`results_firstandsecond_batch'

* Third batch - 06Oct2018
*-----------------------------------

	import excel "${batch3}", firstrow clear
	drop if mi(externalID)
	rename externalID barcode
			
	* Fix a couple with spaces
		replace barcode="101479M" if internalID==1
		replace barcode="101433C" if internalID==2
		
	* Check duplicates
		duplicates tag barcode, gen(dup)
		isid barcode
		drop dup
		
	* Format
		format barcode %15s
		gen barcode_lab=barcode
		tempfile results_third_batch
		save	`results_third_batch'
		
* Fourth batch - 06Oct2018
*-----------------------------------

	import excel "${batch4}", firstrow clear
	drop if mi(externalID)
	rename externalID barcode
			
	* Fix a couple with spaces
		replace barcode="102810C" if internalID==48
		
	* Check duplicates
		duplicates tag barcode, gen(dup)
		isid barcode
		drop dup
		
	* Format
		format barcode %15s
		gen barcode_lab=barcode		
		

* Append with other results
*--------------------------

	append using `results_firstandsecond_batch'
	append using `results_third_batch'
	format barcode %15s
	
* Correct some barcodes
	* File here: "TUP_Afghanistan/Data Collection/Follow-up/Saliva_Collection/Results/Verification_barcodes_12Nov2018_afterverif.xlsx"

	* sheet "unmatched barcodes"
		replace barcode="103024A" if barcode=="103024E"
		replace barcode="101094F" if barcode=="101064F"
		replace barcode="103063D" if barcode=="103068D"
		replace barcode="101397L" if barcode=="101397J"
		replace barcode="102498O" if barcode=="1024980"	
	
	drop if barcode=="nicht lesbar"
	tempfile lab_results
	save	`lab_results'
	
	merge 1:1 barcode using `barcode_list', assert(2 3) nogen //all barcodes are part of official list

********************************************************************************
	** Part 2: Create list of barcodes used
********************************************************************************
********************************************************************************
	** Part 2: Create list of barcodes used
********************************************************************************
	
use "${all_HH_interm_nopii_fl1}", clear	
	
* Drop targeting survey
	drop if ultra_poor==0
	
* Keep relevant variables	
	keep hhid a12 a12_saliva sample_barcode barcode_miss key ///
		 barcode_text1 barcode_text2 barcode_pic a12_m a12_saliva_m ///
		 sample_barcode_m barcode_miss_m barcode_text1_m barcode_text2_m barcode_pic_m key_m
	
* Rename for reshaping
	rename (a12 a12_saliva sample_barcode barcode_miss ///
		 barcode_text1 barcode_text2 barcode_pic key) (a12_l a12_saliva_l ///
		 sample_barcode_l barcode_miss_l barcode_text1_l barcode_text2_l barcode_pic_l key_l)
		 
* Reshape
	reshape long a12_ a12_saliva_ sample_barcode_ barcode_miss_ ///
				 barcode_text1_ barcode_text2_ barcode_pic_ key_, i(hhid) j(member) s
				 
* Keep relevant obs
	rename *_ *

* Ones who consented
	keep if a12_saliva==1
	
* Generate barcode variable
	br hhid member sample_barcode barcode_text1 barcode_text2
	gen 	barcode = sample_barcode
	replace barcode = barcode_text1 if mi(sample_barcode)
	replace barcode = strupper(barcode) 
	
* Duplicates
	duplicates tag barcode, gen(dup)
	br hhid member barcode if dup > 0
	sort barcode
	preserve
		keep if dup>0
		replace barcode="Duplicate: " + barcode
		tempfile barcode_dup
		save	`barcode_dup'
	restore
	
* Correct barcodes incorrectly entred
	preserve
	drop if dup>0
	
* Merge data with list of valid barcodes. Only one is not valid
	merge 1:1 barcode using `barcode_list',  keepus(barcode) keep(1 3)
	/*
    Result                           # of obs.
    -----------------------------------------
    not matched                             1
        from master                         1  (_merge==1)
        from using                          0  (_merge==2)

    matched                             1,655  (_merge==3)
    -----------------------------------------
	*/
	restore
	
********************************************************************************
	** Part 3: Merge lab results to data
********************************************************************************
	
	drop if dup>0
	isid barcode
	merge 1:1 barcode using `lab_results'
	format barcode %20s
	drop if _merge==2

	/*
		Result                           # of obs.
		-----------------------------------------
		not matched                           120
			from master                        49	(_merge==1)
			from using                         71	(_merge==2)

		matched                             1,607	(_merge==3)
		-----------------------------------------
		I (Camila) checked the pics of some of the 49 that don't merge and barcodes seem correct.
	*/
	
	* Append 8 dropped because they're duplicates
		append using `barcode_dup'
		tab member _merge, m
	
	* Cleaning
		rename _merge matched_labresults
		recode matched_labresults (1=0) (3=1)
		replace matched_labresults = 2 if mi(matched_labresults)
		lab drop _merge
		lab def matched_labresults_l 0 "Not matched" 1 "Matched" 2 "Barcode duplicated" 4 "Matched but empty"
		lab val matched_labresults matched_labresults_l
	
		* Some samples were empty
			bys member: mdesc Cortisolnmoll if matched_labresults==1
			replace matched_labresults=4 if mi(Cortisolnmoll) & matched_labresults==1 & notes=="empty"
			tab matched_labresults member
		/*
		Camila (28Mar2019): There are 1664 consented samples. 
							8 of these has duplicated barcodes
							We're able to match 1,607 to the lab's results (1592+15)
							From the matched, 15 were empty
							We couldn't match 49 samples
							This is at the individual level, not household level
							
						   |        member
		matched_labresults |         l          m |     Total
		-------------------+----------------------+----------
			   Not matched |        25         24 |        49 
				   Matched |     1,008        584 |     1,592 
		Barcode duplicated |         7          1 |         8 
					 Empty |        11          4 |        15 
		-------------------+----------------------+----------
					 Total |     1,051        613 |     1,664 


		*/
		
		
		
	* Reshape
		keep hhid member a12_saliva barcode Cortisolnmoll notes matched_labresults
		rename (barcode a12_saliva notes Cortisolnmoll matched_labresults) (barcode_ a12_saliva_ cortisol_notes_ cortisol_result_ matched_labresults_)
		reshape wide barcode_ a12_saliva_ cortisol_notes_ cortisol_result_ matched_labresults_, i(hhid) j(member) s
		rename (barcode_l a12_saliva_l cortisol_result_l cortisol_notes_l matched_labresults_l) (barcode a12_saliva cortisol_result cortisol_notes matched_labresults)
		lab var barcode "Saliva sample's barcode"
		lab var cortisol_result "Cortisol result"
		lab var cortisol_notes "Notes on cortisol result"
		lab var barcode_m "Saliva sample's barcode"
		lab var cortisol_result_m "Cortisol result"
		lab var cortisol_notes_m "Notes on cortisol result"
		lab var matched_labresults "Sample was matched with lab results"
		lab var matched_labresults_m "Sample was matched with lab results"
		format barcode barcode_m %15s
		/*
		There're 1,086 household where at least one of the members consented to the saliva sample.
		These're the ones we're going to merge.
		
			. tab a12_saliva_m a12_saliva, m

					 m |
			consent_sa |   l a12_saliva_
				 liva_ |       Yes          . |     Total
			-----------+----------------------+----------
				   Yes |       578         35 |       613 
					 . |       473          0 |       473 
			-----------+----------------------+----------
				 Total |     1,051         35 |     1,086 

		*/

	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${cortisol_results_fl1}", replace v(13)
		}
		else {
			save "${cortisol_results_fl1}", replace
		}	
