/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Nov 13, 2018
Last udpate on: Nov 27, 2018

Written by:  	Rebecca de Guttry and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

1. Ranaming roster datasets for MDC submission

2. Moving all construction out of the cleaning do-file, specifically: 
	a. Roster of baseline members who left: rename SCTO variable hh_mem_left_ to b17 to match the survey
	b. Roster of current household members: move generation of HHsize to "roster_fl1.do" in Construct; include b11 in the roster 
	c. Combine k5_1 with productive activities 
	d. Combine:
					7. Livelihoods - TUP received livestock
					8. Livelihoods - TUP sick livestock
					9. Livelihoods - TUP sold livestock
					10. Livelihoods - TUP dead livestock
	e. 

IMPORTANT : THis do-file can only be runned from LHH_MHHH_Targ_clean_fl1, if you run it directly it will not work.  	
	
********************************************************************************			

THIS DO FILE: 	Prepares and cleans the different datasets of the rosters in the 
				follow-up data collection

CONTENT:		Module 1: Household Roster (B)
					1. Roster of member who left 
					2. Roster of current household members
				Module 2: Productive Activities and Assets (K), and Livelihoods (R) 
					1. Crops
					2. Businesses
					3. Productive activities module - All questions
					4. Productive activities module - Question k5_1
					5. Livestock
					6. Animal products
					7. Livelihoods - TUP received livestock
					8. Livelihoods - TUP sick livestock
					9. Livelihoods - TUP sold livestock
					10. Livelihoods - TUP dead livestock
					11. Livelihoods - TUP animal products
				Module 4: Housing Characteristics (E) and Other Asset Ownership (L)
					1. Other Asset ownership
				Module 11: Credit and Savings (M)
					1. Loans roster
				Module 12: Transfers and Safety Nets (D), and Shocks (G)
					1. Transfers given
					2. Transfers received
					3. Shocks
				Module 13: Mobile Phone Usage (V)
					1. Mobile phone numbers
				Module 3: Consumption (C)
					1. Food consumption module
					2. Non-food consumption
					
INPUTS:     	* Follow-up 1 survey data appended and merged
					all_HH_interm_rost_nopii_fl1 "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_nopii_fl1_roster.dta"

OUTPUTS:		* Roster for HH members who left the HH
					"${TUP_DB}/Followup_1/DataSets/Intermediate/members_who_left_fl1.dta"
				* Current household roster
					"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1.dta"
				* Crops
					"${TUP_DB}/Followup_1/DataSets/Intermediate/crops_fl1.dta"
				* Businesses	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/businesses_fl1.dta"
				* Productive activities
					"${TUP_DB}/Followup_1/DataSets/Intermediate/productive_act_fl1.dta"
				* Question k5_1	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/k5_1_fl1.dta"
				* Livestock own by the household	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_fl1.dta"
				* Animal products 	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/animal_products_fl1.dta"
				* TUP livestock received
					"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_livestock_fl1.dta"
				* TUP sick livestock	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_sick_livestock_fl1.dta"
				* TUP sold livestock	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_sold_livestock_fl1.dta"
				* TUP dead livestock 	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_dead_livestock_fl1.dta"
				* TUP animal products	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_animal_products_fl1.dta"
				* Consumption	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/consumption_fl1.dta"
				* Other assets	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/other_assets_fl1.dta"
				* Loans	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/loans_fl1.dta"
				* Given transfers	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/given_transfers_fl1.dta"
				* Received transfers	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/received_transfers_fl1.dta"
				* Shocks	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/shocks_fl1.dta"
				* Mobile phone	
					"${TUP_DB}/Followup_1/DataSets/Intermediate/mobile_phone_fl1.dta"     	

*******************************************************************************/
	
********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Follow-up 1 survey data appended and merged		

		* MDC data (with roster vars)
		global all_HH_interm_rost_nopii_fl1 "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_rost_nopii_fl1.dta"
		global MHHH_nopii_fl1		 		"${TUP_DB}/Followup_1/DataSets/Intermediate/MHHH_nopii_fl1.dta"

		
* Outputs
		gl current_roster_fl1	 	"${TUP_DB}/Followup_1/DataSets/Intermediate/br_hhmemcurrent_fl1.dta"
		gl members_who_left_fl1 	"${TUP_DB}/Followup_1/DataSets/Intermediate/b_hhmemleftsincebl_fl1.dta" 		
		gl crops_fl1		 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_c_crops_fl1.dta"
		gl businesses_fl1	 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_d_nonagbiz_fl1.dta"
		gl productive_act_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_e_timeuse_fl1.dta"
		gl livestock_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/k_a_livestock_fl1.dta"
		gl animal_products_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_b_animalproduct_fl1.dta"
		gl TUP_animal_products_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/r_b_animalproduct_tup_fl1.dta"
		gl consumption_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/c_a_foodconsumption_fl1.dta"
		gl nonfood_consumption_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/c_c_nonfoodconsumption_fl1.dta"
		gl other_assets_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/l_hhassets_fl1.dta"
		gl loans_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/m_b_loans_fl1.dta"
		gl given_transfers_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/d_a_transfergiven_fl1.dta"
		gl received_transfers_fl1 	"${TUP_DB}/Followup_1/DataSets/Intermediate/d_b_transferrecd_fl1.dta"
		gl shocks_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/g_shocks_fl1.dta"
		gl mobile_phone_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/v_mobile_fl1.dta"
		gl productive_act_m_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_b_timeuse_pm_fl1.dta" // combined with productive_act_fl1, intermediate dataset


		
********************************************************************************
	** Module 1: Household Roster (B)
********************************************************************************
 	
*------------------------------*
* 1. Roster of member who left *
*------------------------------*
	
	use "${all_HH_interm_rost_nopii_fl1}", clear

	
	* Keep relevant variables
		keep hhid hh_mem_left_* b20* 
			 	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	hh_mem_left_ b20_ , ///
						i(hhid) j(member_bl)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "Member #1" "[HH member #]", all 			
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Drop if we didn't use baselien roster
			drop if mi(hh_mem_left)
		
		* Others
			destring hh_mem_left, replace
			rename hh_mem_left b17 // this is effectively b17
			label val b17 yesno
			order b17, before(b20)
			
		* Labels
			lab var hhid "Household ID"
			lab var member_bl "Order of household member in baseline"
			lab var b17 "Which of the following people are still members of the household?"
	
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${members_who_left_fl1}", replace v(13)
		}
		else {
			save "${members_who_left_fl1}", replace
		}
		
*----------------------------------------*
* 2. Roster of current household members *
*----------------------------------------*
	
	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid b5_* b5_ladyhh_* b6_*  b8_year* ///
			 b26_* b27_1_* b27_2_* b27_3_* b27_4_* b27_5_* b27__97_* b28_* b12_* b16_* b11* b15a_* b18_* b19_* b15_b_* b3
			 
	* Drop variables that interfere with reshape
		rename b8_year_* b8_*
			 
	* Global for select_multiple variables
		loc b27_mult "b27_1_ b27_2_ b27_3_ b27_4_ b27_5_ b27__97_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	b5_ b5_ladyhh_ b6_ b8_ ///
						b26_  `b27_mult' b28_ b12_ b16_ b11_ b15a_ b18_ b19_ b15_b_, ///
						i(hhid) j(member)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "[mem 1]" "[HH member #]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Drop non-existent member
			drop if mi(b6)
			
	* Others
			destring b3 b8 b27_1 b27_2 b27_3 b27_4 b27_5 b27__97, replace
	
		* Extended missings: we do it one by one, because in some cases -98 is none
			foreach var in b5 b5_ladyhh b8 b12 b16 b15a b15_b b19 {
				replace `var' = .d if `var' == -99 
				replace `var' = .r if `var' == -98
			}

		* Labels
			lab var hhid "Household ID"
			lab var member "Order of household member in follow-up"
			lab var b27_1 "Reason to be out of village: Work"
			lab var b27_2 "Reason to be out of village: School"
			lab var b27_3 "Reason to be out of village: Security reasons"
			lab var b27_4 "Reason to be out of village: Other economic reason"
			lab var b27_5 "Reason to be out of village: Other family reason"
			lab var b27__97 "Reason to be out of village: Other, please specify"
			lab var b8 "How old is [HH member #] in years?"
			label var b3 "Number of household members"			
	
		* Save data
			if	`c(stata_version)'>=14	{
				saveold "${current_roster_fl1}", replace v(13)
			}
			else {
				save "${current_roster_fl1}", replace
			}	
		
*----------------------------------------------------------------------*
* 3. Other variables with roster people - to merge with Current Roster *
*----------------------------------------------------------------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid r13 r14* r1 r2* r3 r4* r9 r10* r11 r12* 
	
	* Drop variables that interfere with reshape
		drop  r25* r26* r27* r28* r20* r21 r22 r23 r24 r41* r43* r44* r45* r46* r47* r40* r48* ///
			r14_? r4_? r2_? r12_1 r12_2 r12_3
		
		rename *__97 *_97
		rename *_ch* *_*
		rename *__* *_*

	* Keep the ones who "most"
		preserve
			keep hhid r14a 
			keep if !mi(r14a)
			rename r14a member
			gen r14a = 1
			tempfile r14a
			save	`r14a'
		restore
		preserve
			keep hhid r2a 
			keep if !mi(r2a)
			rename r2a member
			gen r2a = 1
			tempfile r2a
			save	`r2a'
		restore
		preserve
			keep hhid r4a 
			keep if !mi(r4a)
			rename r4a member
			gen r4a = 1
			tempfile r4a
			save	`r4a'
		restore		
		
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		keep hhid r13 r14* r1 r2* r3 r4* r9 r10* r11 r12* 
		drop r14a r2a r4a r14 r2 r4 r10 r12
		
		reshape long 	 r14_ r2_ r4_ r10_ r12_, ///
						i(hhid) j(member)
		
		merge 1:1 hhid member using  `r14a', assert(1 3) nogen
		merge 1:1 hhid member using  `r2a', assert(1 3) nogen
		merge 1:1 hhid member using  `r4a', assert(1 3) nogen

	* Paste labels
		rename *_ *
		order hhid member r13 r14 r14a r1 r2 r2a r3 r4 r4a
		lab var member "Household member"
		label var r1 "Did any household member receive animal rearing training?"
		lab var r14 "Which members of your HH have been taking care of the livestock received from CHA?"
		lab var r14a "Who has been mostly taking care of the livestock?"
		lab var r2 "Which members of your HH attended the animal rearing training?"
		lab var r2a "Which member of your HH attended the animal rearing training most frequently?"
		lab var r4 "which members of your HH received the stipend?"
		lab var r4a "Which member of your HH received the majority of the stipends?"
		lab var r10 "which members of your HH attended the health and hygiene training?"
		lab var r12 "which members of your HH attended the training for Saving and Livelihood?"
	
	* Drop members that don't exist
		merge 1:1 hhid member using "${current_roster_fl1}", assert(1 3) keep(3) nogen
	
		order r13 - r12, after(b15_b)
		label drop asset_l
		
	* Save Current Roster
		save "${current_roster_fl1}", replace 
		

********************************************************************************
	** Module 2: Productive Activities and Assets (K), and Livelihoods (R) 
********************************************************************************

*----------*
* 1. Crops *
*----------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid k15* k16* k17* k19* k20* k21* k40*
		drop k15
			 			 	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	k15_ k16_ k17_ k19_ k20_ k21_ k40_, ///
						i(hhid) j(crop)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
		local l_`var'_1 : subinstr local l_`var'_1 ": Wheat" ": [crop]", all 
		lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Recode -98 and -99
			recode crop (99=-99)
					
		* Labels
			lab var hhid "Household ID"
			lab var crop "Crop"
			lab var k15 "Has your household cultivated any of the following crops in the past twelve months:"

		* Label define
			lab def crop_l 	1 "Wheat" 2 "Vetch" 3 "Maize" 4 "Barley" 5 "Rice" ///
							6 "Weed" 7 "Sesame" 8 "Clover" 9 "Millet" 10 "Sharsham" ///
							11 "Sugarcane" 12 "Cotton" 13 "Caraway-seed" 14 "Potato" ///
							15 "Cereal" 16 "Eggplant" 17 "Tomato" 18 "Onion" 19 "Okra" ///
							20 "Fruits from a tree" 21 "Grape" 22 "Mellon" 23 "Opium" ///
							24 "Zaghar" 25 "Saffron" 26 "Other 1 ( please specify)" ///
							27 "Other 2 (please specify)" 0 "None" -99 "Don’t know"
			lab val crop crop_l
			
		egen k15miss = total(k15), by(hhid) missing 
		replace k15 = 0 if k15 ==. & inlist(crop,-99,0) & k15miss!=.
		drop k15miss
		
		*Fix hhid 1974 (responded both .d and None)
		replace k15 = 0 if crop == -99 & hhid == 1974
		replace k15 = 1 if crop == 0 & hhid == 1974
		
		
	* Looking at outliers
		qui do "${fl1_do}/Cleaning/crop_outliers_fl1.do"		
		
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${crops_fl1}", replace v(13)
		}
		else {
			save "${crops_fl1}", replace
		}		

*---------------*
* 2. Businesses *
*---------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid k23_a* k24* k42* k26_y*  k27* k28* k29* k31* k32* k33* k43* k34* k35* k25*
		replace k23_a_0 = 0 if k23_a_0 == . & !mi(k23_a)
		replace k23_a_99 = 0 if k23_a_99 == . & !mi(k23_a)
		
		* 1068 should be a .d
		replace k23_a_99 = 1 if hhid == 1068
		
		
		
		
	* Global for select_multiple variables				   
		loc k24_mult "k24_3_ k24_2_ k24_1_ k24_0_"	   
				   
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	k23_a_ `k24_mult' k42_ k26_y_ k27_ k28_ k29_ k31_ ///
						k32_ k33_ k43_ k34_ k35_ k25_, ///
						i(hhid) j(business)
	
	* Paste labels
		drop k23_a k24_1 - k24_15
		rename *_ *
		
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "[business 1]" "[business #]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Recode -98 and -99
			recode business (99=-99)
			
		* Labels
			lab var hhid "Household ID"
			lab var business "Business"
			lab var k23_a "Does anyone in your household fully, or partly, own and operate any of these businesses?"
			lab var k24_3 "Role in business includes: Owner"
			lab var k24_2 "Role in business includes: Manager"
			lab var k24_1 "Role in business includes: Worker"
			lab var k24_0 "Role in business includes: Do not participate"
			lab var k26_y "When did the ${business_name} business first start? (Years)"
			
			
		* Label define
			lab def business_l 	1 "Selling crafts (baskets, pots, etc.)" 2 "Repairing bicycles" ///
								3 "Selling prepared foods/run restaurant" ///
								4 "Selling raw produce (that is NOT cultivated by respondent but purchased elsewhere)" ///
								5 "Providing transportation" 6 "Making bricks" ///
								7 "Butchering" 8 "Doing carpentry" 9 "Selling clothes and sheets" ///
								10 "Building thatch or iron sheet roofs"  ///
								11 "Constructing houses/buildings" ///
								12 "Drilling boreholes/building latrines" ///
								13 "Collecting and selling firewood" ///
								14 "Other 1 (please specify)"  15 "Other 2 (please specify)" ///
								0 "None" -99 "Don’t know"
			lab val business business_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item business
		loc yesno k23_a
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		drop temp dk
		tab `yesno' if `item' == 1, m 
		
		/*egen k23miss = total(k23_a), by(hhid) missing 
		replace k23_a = 0 if k23_a ==. & inlist(business,-99,0) & k23miss!=.
		drop k23miss*/
		
	* Looking at outliers
		qui do "${fl1_do}/Cleaning/business_outliers_fl1.do"		
		
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${businesses_fl1}", replace v(13)
		}
		else {
			save "${businesses_fl1}", replace
		}	

*-------------------------------------------------*
* 3. Productive activities module - All questions *
*-------------------------------------------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Structure: question_member_activity
	* Reshape para activities: repeat activities_2_repeat
		local k30_3_ "k30_3_1_ k30_3_2_ k30_3_3_ k30_3_4_ k30_3_5_ k30_3_6_ k30_3_7_ k30_3_8_ k30_3_9_ k30_3_10_ k30_3_11_ k30_3_12_ k30_3_13_ k30_3_14_ k30_3_15_ k30_3_16_ k30_3_17_ k30_3_18_ k30_3_19_ k30_3_20_ k30_3_21_ k30_3_22_ k30_3_23_ k30_3_24_ k30_3_25_ k30_3_26_ k30_3_27_ k30_3_28_ k30_3_29_ k30_3_30_ k30_3_31_ k30_3_32_ k30_3_33_"
		local k30_3_hr_ "k30_3_hr_1_ k30_3_hr_2_ k30_3_hr_3_ k30_3_hr_4_ k30_3_hr_5_ k30_3_hr_6_ k30_3_hr_7_ k30_3_hr_8_ k30_3_hr_9_ k30_3_hr_10_ k30_3_hr_11_ k30_3_hr_12_ k30_3_hr_13_ k30_3_hr_14_ k30_3_hr_15_ k30_3_hr_16_ k30_3_hr_17_ k30_3_hr_18_ k30_3_hr_19_ k30_3_hr_20_ k30_3_hr_21_ k30_3_hr_22_ k30_3_hr_23_ k30_3_hr_24_ k30_3_hr_25_ k30_3_hr_26_ k30_3_hr_27_ k30_3_hr_28_ k30_3_hr_29_ k30_3_hr_30_ k30_3_hr_31_ k30_3_hr_32_ k30_3_hr_33_"
		local k30_1_ "k30_1_1_ k30_1_2_ k30_1_3_ k30_1_4_ k30_1_5_ k30_1_6_ k30_1_7_ k30_1_8_ k30_1_9_ k30_1_10_ k30_1_11_ k30_1_12_ k30_1_13_ k30_1_14_ k30_1_15_ k30_1_16_ k30_1_17_ k30_1_18_ k30_1_19_ k30_1_20_ k30_1_21_ k30_1_22_ k30_1_23_ k30_1_24_ k30_1_25_ k30_1_26_ k30_1_27_ k30_1_28_ k30_1_29_ k30_1_30_ k30_1_31_ k30_1_32_ k30_1_33_"
		local k30_2_ "k30_2_1_ k30_2_2_ k30_2_3_ k30_2_4_ k30_2_5_ k30_2_6_ k30_2_7_ k30_2_8_ k30_2_9_ k30_2_10_ k30_2_11_ k30_2_12_ k30_2_13_ k30_2_14_ k30_2_15_ k30_2_16_ k30_2_17_ k30_2_18_ k30_2_19_ k30_2_20_ k30_2_21_ k30_2_22_ k30_2_23_ k30_2_24_ k30_2_25_ k30_2_26_ k30_2_27_ k30_2_28_ k30_2_29_ k30_2_30_ k30_2_31_ k30_2_32_ k30_2_33_"

		preserve
			keep hhid k30_3_*_1 k30_3_*_2 k30_3_*_3 k30_3_*_4 k30_3_*_5 k30_3_*_6 k30_3_*_7 k30_3_*_8 k30_3_*_9 ///
					  k30_1_*_1 k30_1_*_2 k30_1_*_3* k30_1_*_4 k30_1_*_5 k30_1_*_6 k30_1_*_7 k30_1_*_8 k30_1_*_9 ///
					  k30_2_*_1 k30_2_*_2 k30_2_*_3* k30_2_*_4 k30_2_*_5 k30_2_*_6 k30_2_*_7 k30_2_*_8 k30_2_*_9

			* Save labels
				foreach var of varlist * {
					local l_`var' : variable label `var'
					local val_`var': value label `var'
				}
					  
			* Reshape		  
				reshape long `k30_3_' `k30_3_hr_' `k30_1_' `k30_2_', i(hhid) j(activity)
				rename *_ *
				reshape long k30_3_ k30_3_hr_ k30_1_ k30_2_, i(hhid activity) j(member)
			
			* Paste labels
				foreach var of varlist * {
					lab var `var' "`l_`var'1_1'"
					cap confirm numeric var `var'
					if _rc == 0 {
						lab val `var' `val_`var'1_1'
						tab `var'
					}
				}
				
			tempfile roster_activities
			save	`roster_activities'
		restore

	* Reshape for k5_1 and k30_
		keep hhid k5_1_? k5_1_?? k30_? k30_1? k30_2? k30_3? k30_?_? k30_?_?? k30__??_? k30__??_??
			
		* Save labels
			foreach var of varlist * {
				local l_`var' : variable label `var'
				local val_`var': value label `var'
			}
			
		* Prepare for reshape 
			tostring k30_??, replace 
		
		* Reshape
			reshape long k30_ k5_1_ k30_0_ k30_1_ k30_2_ k30_3_ k30_4_ k30_5_ k30_6_ k30_7_ k30_8_ k30_9_ k30__98_ k30__99_, i(hhid) j(member)
		
		* Paste labels
			foreach var of varlist * {
				lab var `var' "`l_`var'1_1'"
				cap confirm numeric var `var'
				if _rc == 0 {
					lab val `var' `val_`var'1_1'
					tab `var'
				}
			}
			
	* Split k30_ given that it was not complete before (due to error in naming variables)
		replace k30_ = " " + k30_ + " "
		forv choice = 0(1)9 {
			gen k30_ch_`choice' = (regexm(k30_," `choice' "))
		}
			gen k30_ch_98 = (regexm(k30_," -98 "))
			gen k30_ch_99 = (regexm(k30_," -99 "))
			
	* Reshape to have a dataset hhid-member-activity
		drop k30_ k30_?_ k30__??_ 
		rename *_ch_* *_*
		reshape long k30_, i(hhid member) j(activity)
		
	* Merge roster of activities
		merge 1:1 hhid activity member using `roster_activities', nogen assert(1 3) //-- YB: removing the assert here because there are instances where _m == 2; they are dropped in line "drop if k5_1 == ."
		
	* Cleaning
		
		* Rename
		rename *_ *
		
		* Drop member who are missing (not enough members or younger than 6 years old)
			* Keep obs with systems missing k5_1 for the following 11 UP HHs for which we have k1_1 vars for member 1, but 
			* systems missing for member 1 in k5_1 (if we keep missing info for member 1, we can merge on k1_1 variables that are for member 1 easily)
			* inlist(hhid,1088,1130,1302,1339,1522,1700,1787,1961,2070,2101,2103) & member == 1 

		keep if (k5_1 != . | inlist(hhid,1088,1130,1302,1339,1522,1700,1787,1961,2070,2101,2103) & member == 1)
			
		* Order and sort
			order k5_1, after(member)
			sort hhid member activity
			
		* Labels
			lab var hhid "Household ID"
			lab var member "Order of household member in follow-up"
			lab var activity "Productive activity"
			lab var k30 "Did [HH member #] do any of these activities in the last 4 weeks?"
			lab var k5_1 "Did [HH member #] try to find work outside the home in the past 2 weeks?"
			lab var k30_3 "In the past 7 days, on how many different days did [HH member #]: [activity #]?"
			lab var k30_3_hr "Hrs worked by [HH member #] on [activity #] (last time)"
			lab var k30_1 "How much did [HH member #] earn to [activity #] in the last 4 weeks?"
			
		* label activities
			recode activity (98 = -98) (99= -99)
			lab def activity_l  1 "1: Tend any animals owned or leased by the household" ///
								2 "2: Farm land owned or sharecropped by the household" ///
								3 "3: Work on business owned by household other than farm/animals (e.g. shop, crafts)" ///
								4 "4: Work as an agricultural laborer outside household" ///
								5 "5: Do housework in someone else's home" ///
								6 "6: Work as a non-agricultural laborer outside the household (other than housework)" ///
								7 "7: Work in salaried/formal employment" ///
								8 "8: Do any other work for pay  (money or in-kind)" ///
								9 "9: Work on household chores (e.g. collecting water, cooking, cleaning) in your household" ///
								0 "0: None" ///
								-98 "-98: Don't answer" ///
								-99 "-99: Don't know"
			lab val activity activity_l

		*Replace all the in kind payment in the payment variable and drop them then
		replace k30_1 = k30_2 if inlist(k30_1,-97,.n)		
		drop k30_2
		
		*Cleaning k30_1 before looking at outliers 
/* 
Main issues identified: In earnings, need to replace with the values of in kind 
There are a few 0.99, 99 and 98 that are likely to be -99 and -98 as they are not round numbers while all the others are 
*/ 		
		replace k30_1 = .d if inlist(k30_1, 97,99) //Likely to be data entry mistakes
		replace k30_1 = .d if k30_1 > 0.99 & k30_1 < 1 
			
		*Looking at outliers in the time_activities_outliers_fl1 do file		
		qui do "${fl1_do}/Cleaning/time_activities_outliers_fl1.do"
		
		
			* Replace to extended missing when they reply "Don't know"
				loc item activity
				loc yesno k30
				tab `item' if `yesno' == 1, m
				gen temp = 1 if `item' == -99 & `yesno' == 1
				bys hhid member: egen dk = max(temp)
				replace `yesno' = .d if dk == 1	& `item' != -99
				tab `yesno' if `item' == 1, m
				drop temp dk
				
			* Replace to extended missing when they reply "Don't answer"
				tab `item' if `yesno' == 1, m
				gen temp = 1 if `item' == -98 & `yesno' == 1
				bys hhid member: egen da = max(temp)
				replace `yesno' = .r if da == 1	& `item' != -98
				tab `yesno' if `item' == 1, m
				drop temp da		
			
			* Save data
				save "${productive_act_fl1}", replace
		
				
*--------------*
* 5. Livestock *
*--------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear // this uses modules replaced with MHH data 
	
	* Keep relevant variables
		keep hhid k6* k7* k8* k14 k41
						 	   
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
		
	* Reshape
		reshape long 	k6_ k7_ k7_o_ k8_, ///
						i(hhid) j(livestock)
	
	* Paste labels
		drop k6
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "Cows" "[animal]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning			
		* Recode -98 and -99
			recode livestock (99=-99)
		
		* Labels
			lab var hhid "Household ID"
			lab var livestock "Livestock"
			lab var k6 "Does your household own any of the following livestock?"
			label var k7_o "Please enter the number of livestock your household own"
			label var k41 "How much did you invest to acquire livestock and produce products (4 weeks)?"
			label var k14 "How much was spent on inputs for livestock and produce products (4 weeks)?"
			
	* for k8, recoding 99 as a mistake and as a "don't know" (ie -99)
	replace k8 = .d if k8 == 99			
			
		* Label define
			lab def livestock_l 1 "Cows" 2 "Bulls" 3 "Horses" 4 "Donkeys" 5 "Goats" ///
								6 "Sheep" 7 "Chickens" 8 "Ducks" 9 "Turkeys" ///
								10 "Gooses" 11 "Rabbits" 12 "Guinea fowl" 13 "Bee hives" ///
								14 "Other animal 1 (please specify)" ///
								15 "Other animal 2 (please specify)" 0 "None" ///
								-99 "Don’t Know"
			lab val livestock livestock_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item livestock
		loc yesno k6
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		drop temp dk
		tab `yesno' if `item' == 1, m

	* Looking at outliers
		qui do "${fl1_do}/Cleaning/livestock_outliers_fl1.do"		
		
		drop ultra_poor 
		
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${livestock_fl1}", replace v(13)
		}
		else {
			save "${livestock_fl1}", replace
		}		
		
*--------------------*
* 6. Animal products *
*--------------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid k9* k10* k12* k13*	
			 	   
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	k9_ k10_ k12_ k13_, ///
						i(hhid) j(product)
	
	* Paste labels
		drop k9
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "of Milk" "[animal product]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning			
		* Recode -98 and -99
			recode product (99=-99)
		
		* Labels
			lab var hhid "Household ID"
			lab var product "Animal product"
			lab var k9 "In the past four weeks has your household produced any of these animal products?"
			
		* Label define
			lab def product_l 	1 "Milk" 2 "Egg" 3 "Honey" 4 "Butter" 5 "Yogurt" ///
								6 "Meat" 7 "Other 1 (please specify)" ///
								8 "Other 2 (please specify)" 0 "None" ///
								-99 "Don’t know "
			lab val product product_l
		
	* Replace to extended missing when they reply "Don't know"
		loc item product
		loc yesno k9
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		drop temp dk
		tab `yesno' if `item' == 1, m		
		
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${animal_products_fl1}", replace v(13)
		}
		else {
			save "${animal_products_fl1}", replace
		}			
		
*---------------------------------------*
* 11. Livelihoods - TUP animal products *
*---------------------------------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant sample (HHs that said yes to question r81 and r13 (received livestock)
		keep if r81==1 & r13 == 1

	* Keep relevant variables
		keep hhid r73* r74* r75* r76* // tot_cows_now cows_now tot_goats_now goats_now tot_sheep_now sheep_now
			 
	* Drop variables that interfere with reshape
		drop r74_year r74a r74b r74c
			 	   
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	r73_ r74_ r75_ r76_, ///
						i(hhid) j(product)
	
	* Drop empty products (we don't ask them because aren't related to TUP livestock. Eg. eggs)
		drop if inlist(product, 2, 3)
	
	* Paste labels
		drop r73
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 ": Milk" " [animal product]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning			
		* Recode -98 and -99
			recode product (99=-99)
			
		* Labels
			lab var hhid "Household ID"
			lab var product "Animal product"
			lab var r73 "In the past four weeks has your household produced any of these animal products with the livestock received through TUP?"
			
		* Label define
			lab def product_l 	1 "Milk" 2 "Egg" 3 "Honey" 4 "Butter" 5 "Yogurt" ///
								6 "Meat" 7 "Other 1 (please specify)" ///
								8 "Other 2 (please specify)" 0 "None" ///
								-99 "Don’t know"
			lab val product product_l
		
		* Drop empty fields 
			drop if mi(product)
			
	* Replace to extended missing when they reply "Don't know"
		loc item product
		loc yesno r73
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk			
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${TUP_animal_products_fl1}", replace v(13)
		}
		else {
			save "${TUP_animal_products_fl1}", replace
		}		
				
		

		
********************************************************************************
	** Module 4: Housing Characteristics (E) and Other Asset Ownership (L)
********************************************************************************

*-----------------------*
* Other Asset ownership *
*-----------------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
				
	* Keep relevant variables
		keep hhid l1* l2* l3* l4* l5*
		rename (l1__98 l1__99) (l1_98 l1_99)
		
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
			
	* Reshape
		reshape long l1_ l2_ l3_ l4_ l5_ , i(hhid) j(asset)
		
	* Paste labels
		drop l1
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
			
	* Cleaning
		* Recode
			recode asset (98=-98) (99=-99)
		
		* Labels
			lab var asset "Assets"
			lab var hhid "Household ID"
			lab var l1 "Please tell me whether you or any HH member owns any of the following assets:"
			lab var l2 "How many [asset] does your HH own?"
			lab var l3 "What is the total size of [asset]?"
			lab var l4  "Owner of [asset]"
			lab var l5 "Value if [asset] were sold today"
	
		* Label define
			lab def asset_l 1 "Radios/CDs/Cassettes" 2 "Televisions" 3 "Dish Antenna" ///
							4 "VCRs/DVD players" 5 "Land on which your home is built" ///
							6 "Other land(s) (excluding land on which your home is built)" ///
							7 "Other houses/buildings" 8 "Refrigerators " ///
							9 "Generators" 10 "Mattresses" 11 "Cell (mobile) phones" ///
							12 "Non-mobile phones" 13 "Clothes irons" 14 "Bed frames" ///
							15 "Pieces of jewelry (gold, silver, etc.)" ///
							16 "Mosquito nets" 17 "Mosquito-repellant candles" ///
							18 "Fans" 19 "Cameras" 20 "Other (please specify)" ///
							0 "None" -98 "Don't answer" -99 "Don't know", replace
			lab val asset asset_l
	
	* Replace to extended missing when they reply "Don't know"
		loc item asset
		loc yesno l1
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da
	
	* Save
		if	`c(stata_version)'>=14	{
			saveold "${other_assets_fl1}", replace v(13)
		}
		else {
			save "${other_assets_fl1}", replace
		}	
		
********************************************************************************
	** Module 11: Credit and Savings (M)
********************************************************************************

*--------------*
* Loans roster *
*--------------*
	
	use "${all_HH_interm_rost_nopii_fl1}", clear

	* Keep relevant variables
		keep hhid m1 m1_a m2_* m2_roster_* m3_* m4_* 
	
	* Keep only households who have loans
		keep if m1==1 //  1,085 obs at this point 
	
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'			
			local valuel_`var': value label `var'

		}

	* Global for select_multiple variables
		local m2_roster_ "m2_roster_1_ m2_roster_2_ m2_roster_3_ m2_roster_4_ m2_roster_5_ m2_roster_6_ m2_roster_7_ m2_roster_8_ m2_roster_9_ m2_roster_10_ m2_roster_11_ m2_roster_12_ m2_roster_13_ m2_roster_14_ m2_roster_15_ m2_roster_16_ m2_roster_17_ m2_roster_18_ m2_roster_19_ m2_roster_20_ m2_roster_21_ m2_roster_22_ m2_roster_23_ m2_roster_24_ m2_roster_25_ m2_roster_26_ m2_roster_27_ m2_roster_28_ m2_roster_29_ m2_roster_30_ m2_roster_31_ m2_roster_32_ m2_roster_33_ m2_roster_34_ m2_roster_35_ m2_roster__98_ m2_roster__99_"
		local m3_ "m3_1_ m3_2_ m3_3_ m3_4_ m3_5_ m3_6_ m3_7_ m3_8_ m3_9_ m3__98_ m3__97_"
	    
		tostring m2_roster_5 m2_roster_6 m2_roster_7 m2_roster_8 m2_roster_9 m2_roster_10, replace 
		
	* Reshape
		tostring m3_? m3_??, replace 
		reshape long m2_ `m2_roster_' `m3_' m4_ m3_ m2_roster_, i(hhid) j(loan_number)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1: subinstr local l_`var'_1 "loan 1" "loan #", all			
			lab var `var' "`l_`var'_1'"
	
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning

		* Drop empty observations (no loan)
			drop if m2 == . // YB 10/15: this needs to be equal to system missing, do not want to drop extended here
			drop m1

		* Labels
			lab var hhid "Household ID"
			lab var m1_a "How many outstanding loans does your household have?"
			lab var loan_number "Loan number"
			lab var m2_roster "HH member who took out the loan"
			lab var m3 	 "Loan's intended purpose"
			lab var m3_1 "Loan's intended purpose includes: For health emergency"
			lab var m3_2 "Loan's intended purpose includes: To purchase food or other essential items for the household"
			lab var m3_3 "Loan's intended purpose includes: To purchase durable good"
			lab var m3_4 "Loan's intended purpose includes: To buy seeds/fertilizer or other farm inputs"
			lab var m3_5 "Loan's intended purpose includes: To start a business"
			lab var m3_6 "Loan's intended purpose includes: To invest in current business"
			lab var m3_7 "Loan's intended purpose includes: To provide working capital for current business"
			lab var m3_8 "Loan's intended purpose includes: To pay for wedding/religious celebration"
			lab var m3_9 "Loan's intended purpose includes: To pay dowry"
			lab var m3__97 "Loan's intended purpose includes: Other"
			lab var m3__98 "Loan's intended purpose includes: Dont answer"
			
			order m2_roster, before(m2_roster_1)
			order m3, before(m3_1)
	
		*Looking at outliers in the loan_outliers_fl1 do file
		qui do "${fl1_do}/Cleaning/loan_outliers_fl1.do"
			
		* Save
			if	`c(stata_version)'>=14	{
				saveold "${loans_fl1}", replace v(13)
			}
			else {
				save "${loans_fl1}", replace
			}
********************************************************************************
	** Module 12: Transfers and Safety Nets (D), and Shocks (G)
********************************************************************************
	
*--------------------*
* 1. Transfers given *
*--------------------*
	
	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid d1* d2* d3*
			 
	* Drop variables that interfere with reshape
		drop d10* d13*
		rename (d1__99 d1__98) (d1_99 d1_98)
			 
	* Global for select_multiple variables
		loc d3_mult "d3_1_ d3_2_ d3_3_ d3_4_ d3_5_ d3_6_ d3_7_ d3_8_ d3_9_ d3_10_ d3_11_ d3_12_ d3_13_ d3_14_ d3_15_ d3_16_ d3_17_ d3_18_ d3_19_ d3_20_ d3_21_ d3__97_ d3__98_ d3__99_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	d1_ d2_1_ d2_ `d3_mult' , ///
						i(hhid) j(item)
	
	* Paste labels
		drop d1 d3_? 
		rename *_ *
		
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Recode -98 and -99
			recode item (98=-98) (99=-99)
		
		* Labels
			lab var hhid "Household ID"
			lab var item "Item given"
			lab var d1 "Which of these items has your HH given to non-HH members in the last 12 months?"
			lab var d3_1 "Gift was given to: Spouse"
			lab var d3_2 "Gift was given to: Son/daughter"
			lab var d3_3 "Gift was given to: Stepson/stepdaughter/adopted/foster"
			lab var d3_4 "Gift was given to: Son-in-law/daughter-in-law"
			lab var d3_5 "Gift was given to: Grandchild"
			lab var d3_6 "Gift was given to: Brother/sister"
			lab var d3_7 "Gift was given to: Brother-in-law/sister-in-law"
			lab var d3_8 "Gift was given to: Father/mother"
			lab var d3_9 "Gift was given to: Father-in-law/mother-in-law"
			lab var d3_10 "Gift was given to: Grandparent"
			lab var d3_11 "Gift was given to: Great-grandchild"
			lab var d3_12 "Gift was given to: Cousin"
			lab var d3_13 "Gift was given to: Nephew/niece"
			lab var d3_14 "Gift was given to: Co-wife"
			lab var d3_15 "Gift was given to: Aunt/uncle"
			lab var d3_16 "Gift was given to: Other relative"
			lab var d3_17 "Gift was given to: Worker/household help"
			lab var d3_18 "Gift was given to: Co-worker"
			lab var d3_19 "Gift was given to: Friend"
			lab var d3_20 "Gift was given to: Lodger"
			lab var d3_21 "Gift was given to: Neighbor"
			lab var d3__97 "Gift was given to: Other unrelated (please specify)"
			lab var d3__98 "Gift was given to: Don't answer"
			lab var d3__99 "Gift was given to: Don't know"

		* Label define
			lab def item_l 	1 "Money" 2 "Clothes, pots, pans, pails, etc." ///
							3 "Uncooked produce" 4 "Meals" 5 "Work materials" ///
							6 "Dowry/bride price" 7 "Wedding gift" 8 "Livestock" ///
							9 "Land" 10 "Other (please specify)" -99 "Don’t know" ///
							-98 "Don't answer" 0 "None"
			lab val item item_l
		
	* Replace to extended missing when they reply "Don't know"
		loc item item
		loc yesno d1
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da
		
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${given_transfers_fl1}", replace v(13)
		}
		else {
			save "${given_transfers_fl1}", replace
		}		

*-----------------------*
* 2. Transfers received *
*-----------------------*
	
	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid d8* d9* d10*
		rename (d8__99 d8__98) (d8_99 d8_98)
			 			 
	* Global for select_multiple variables
		loc d10_mult "d10_1_ d10_2_ d10_3_ d10_4_ d10_5_ d10_6_ d10_7_ d10_8_ d10_9_ d10_10_ d10_11_ d10_12_ d10__97_ d10__98_ d10__99_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	d8_ d9_1_ d9_ `d10_mult' , ///
						i(hhid) j(item)
	
	* Paste labels

		drop d10_?

		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "[mem 1]" "[HH member #]", all 
			local l_`var'_1 : subinstr local l_`var'_1 "[activity 1]" "[activity #]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Recode -98 and -99
			recode item (98=-98) (99=-99)
	
		* Labels
			lab var hhid "Household ID"
			lab var item "Item given"
			lab var d8 "Which of these items has your HH received from non-HH members in the last 12 months?"
			lab var d10_1 "Gift was recieved from: Government"
			lab var d10_2 "Gift was recieved from: World Food Program"
			lab var d10_3 "Gift was recieved from: Other Development Agency (e.g. UN, World Bank, USAID)"
			lab var d10_4 "Gift was recieved from: NGO"
			lab var d10_5 "Gift was recieved from: Religious institution (i.e., church, mosque)"
			lab var d10_6 "Gift was recieved from: Community"
			lab var d10_7 "Gift was recieved from: Relatives in the village"
			lab var d10_8 "Gift was recieved from: Relatives in another village within Afghanistan"
			lab var d10_9 "Gift was recieved from: Relatives abroad"
			lab var d10_10 "Gift was recieved from: Friends or neighbors in the village"
			lab var d10_11 "Gift was recieved from: Friends in another village within Afghanistan"
			lab var d10_12 "Gift was recieved from: Friends abroad"
			lab var d10__97 "Gift was recieved from: Other (please specify)"
			lab var d10__98 "Gift was recieved from: Don't answer"
			lab var d10__99 "Gift was recieved from: Don't know"
			lab var d9_1 "How many times over the past 12 months did you receive [gift] from a non-HH member?"

		* Label define
			lab def item_l 	1 "Money" 2 "Clothes, pots, pans, pails, etc." ///
							3 "Uncooked produce" 4 "Meals" 5 "Work materials" ///
							6 "Dowry/bride price" 7 "Wedding gift" 8 "Livestock" ///
							9 "Land" 10 "Construction/building material"  ///
							11 "Water and/or sanitation"  ///
							12 "Agricultural input assistance (tools, seeds, fertilizer, etc.)"  ///
							13 "Training and technical assistance in improved agricultural/livestock practices" ///
							14 "Fish ponds" 15 "Veterinary services" 16 "For education (e.g. school materials)" /// 
							17 "Medical services" 18 "Pension payment" 19 "Other (please specify)" ///
							-99 "Don’t know" -98 "Don't answer" 0 "None"
			lab val item item_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item item
		loc yesno d8
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da			
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${received_transfers_fl1}", replace v(13)
		}
		else {
			save "${received_transfers_fl1}", replace
		}	
		
*-----------*
* 3. Shocks *
*-----------*
	
	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid g1* g2* 
		rename (g1__99 g1__98) (g1_99 g1_98)
				
	* Global for select_multiple variables
		loc g2_mult "g2_0_ g2_1_ g2_2_ g2_3_ g2_4_ g2_5_ g2_6_ g2_7_ g2_8_ g2_9_ g2_10_ g2_11_ g2_12_ g2_13_ g2_14_ g2_15_ g2_16_ g2_17_ g2_18_ g2__97_ g2__99_ g2__98_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	g1_ g2_ `g2_mult' g2a_, ///
						i(hhid) j(shock)
	
	* Paste labels
		rename *_ *
		drop g2
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Recode -98 and -99
			recode shock (98=-98) (99=-99)

		* Labels
			lab var hhid "Household ID"
			lab var shock "Shock"
			lab var g1 "Please tell me if any of these happened to your household in the past 12 months."
			lab var g2_0 "What did the household do to cope: Nothing"
			lab var g2_1 "What did the household do to cope: Did not need to do anything to compensate"
			lab var g2_2 "What did the household do to cope: Reduced quantity or quality of diet"
			lab var g2_3 "What did the household do to cope: Decreased expenditures"
			lab var g2_4 "What did the household do to cope: Purchased food on credit from traders"
			lab var g2_5 "What did the household do to cope: Took out any other loans"
			lab var g2_6 "What did the household do to cope: Received help from others in the community"
			lab var g2_7 "What did the household do to cope: Rented out or mortgaged land"
			lab var g2_8 "What did the household do to cope: Sold house, land or female reproductive livestock"
			lab var g2_9 "What did the household do to cope: Sold any other assets"
			lab var g2_10 "What did the household do to cope: Worked on relief programmes"
			lab var g2_11 "What did the household do to cope: Joined military"
			lab var g2_12 "What did the household do to cope: Dropped children from school"
			lab var g2_13 "What did the household do to cope: Increased child labor"
			lab var g2_14 "What did the household do to cope: Used daughter's dowry as bride"
			lab var g2_15 "What did the household do to cope: Started begging"
			lab var g2_16 "What did the household do to cope: Used savings"
			lab var g2_17 "What did the household do to cope: Sent children to other household"
			lab var g2_18 "What did the household do to cope: Sent non-working adult member to work"
			lab var g2__97 "What did the household do to cope: Other (please specify)"
			lab var g2__99 "What did the household do to cope: Don't know"
			lab var g2__98 "What did the household do to cope: Don't answer"

		* Label values
			lab def shock_l 1 "Reduced drinking water quantity" 2 "Reduced drinking water quality" ///
							3 "Reduced agricultural water quality or quantity" ///
							4 "Unusually high level of crop pests or diseases" ///
							5 "Opium eradication" 6 "Unusually high livestock diseases" ///
							7 "Reduced availability of grazing areas" ///
							8 "Reduced availability of Kuchi migration routes" ///
							9 "Earthquakes" 10 "Landslides and avalanches" ///
							11 "Flooding" 12 "Late damaging frosts" 13 "Heavy rains preventing work" ///
							14 "Severe winter conditions" 15 "Hailstorms" ///
							16 "Unusually high level of human disease" ///
							17 "Large influx of returnee households" ///
							18 "Unusually high increases in food prices" ///
							19 "Unusual decrease in farm gate prices" ///
							20 "Loss of employment by a household member" ///
							21 "Reduced salary of a household member" ///
							22 "Bankruptcy of family business" ///
							23 "Serious illness or accident of working household member" ///
							24 "Death of a working household member" ///
							25 "Death or serious illness of other household member" ///
							26 "Theft" 27 "Involuntary loss of house or land" ///
							28 "Loss of livestock" 29 "Droughts" 0 "None" ///
							-99 "Don't know" -98 "Don't answer"
			lab val shock shock_l
			
	* Replace to extended missing when they reply "Don't know"
		loc item shock
		loc yesno g1
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
		
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da			
			
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${shocks_fl1}", replace v(13)
		}
		else {
			save "${shocks_fl1}", replace
		}		
		
********************************************************************************/
	** Module 13: Mobile Phone Usage (V)
********************************************************************************
	
*----------------------*
* Mobile phone numbers *
*----------------------*
	
	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	* Keep relevant variables
		keep hhid v* a12_mobile
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}

	* Reshape
		reshape long 	v3_ v4_ v5_, ///
						i(hhid) j(mobile_phone)
	
	* Paste labels
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "number 1" "number #", all
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning
		* Drop empty observations (no phone line)
			drop if mi(v3)
					
		* Labels
			lab var hhid "Household ID"
			label var a12_mobile "Consented to mobile module"
			lab var mobile_phone "Mobile phone"
			lab var v1 "In total, how many mobile phones does your household currently use?"
			drop v1

	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${mobile_phone_fl1}", replace v(13)
		}
		else {
			save "${mobile_phone_fl1}", replace
		}				

********************************************************************************
	** Module 3: Consumption (C)
********************************************************************************/

*-------------------------*
* Food consumption module *
*-------------------------*

	use "${all_HH_interm_rost_nopii_fl1}", clear
	
	local c3_type "Bread"
	local c4_type "Meat"
	local c5_type "Dairy"
	local c6_type "Oils"
	local c7_type "Vegetables"
	local c8_type "Fruits"
	local c9_type "Sweets"
	local c10_type "Beverages"
	local c11_type "Spices"
	
	* Reshape
	* Since each group is a different roster, we do the reshape separately 
		foreach item_type in c3 c4 c5 c6 c7 c8 c9 c10 c11 {
			preserve
			keep hhid `item_type'*
			
			rename `item_type'__100 `item_type'_100
			reshape long `item_type'_ `item_type'_i_ `item_type'_a_ `item_type'_s_, i(hhid) j(item)
			//drop `item_type'
		
			rename  (`item_type'_ `item_type'_i_ `item_type'_a_ `item_type'_s_) ///
					(c c_i c_a c_s) // consumed consumed_other consumed_days consumed_qty consumed_source consumed_source_other
			gen item_type = "``item_type'_type'"
		
		* We have to recode the items in order to get only one data for all
			if "``item_type'_type'" == "Bread" {
				recode item (100 = 13)
				}

			if "``item_type'_type'" == "Meat" {
				recode item (1=14) (2=15) (3=16) (4=17) (5=18) (6=19) (7=20) (8=21) (9=22) (100=23)
				}
				
			if "``item_type'_type'" == "Dairy" {
				recode item (1=24) (2=25) (3=26) (4=27) (5=28) (6=29) (7=30) (8=31) (9=32) (10=33) (11=34) (100=35)
				}
			
			if "``item_type'_type'" == "Oils" {
				recode item (1=36) (2=37) (3=38) (4=39) (100=40)
				}
				
			if "``item_type'_type'" == "Vegetables" {
				recode item (1=41) (2=42) (3=43) (4=44) (5=45) (6=46) (7=47) (8=48) (9=49) (10=50) ///
							(11=51) (12=52) (13=53) (14=54) (15=55) (16=56) (17=57) (18=58) (19=59) (20=60) ///
							(21=61) (22=62) (23=63) (24=64) (100=65)
				}
			
			if "``item_type'_type'" == "Fruits" {
				recode item (1=66) (2=67) (3=68) (4=69) (5=70) (6=71) (7=72) (8=73) (9=74) (10=75) ///
							(11=76) (12=77) (13=78) (14=79) (15=80) (16=81) (17=82) (18=83) (19=84) (100=85)
				}
				
			if "``item_type'_type'" == "Sweets" {
				recode item (1=86) (2=87) (3=88) (4=89) (5=90) (6=91) (7=92) (100=93)
				}
			
			if "``item_type'_type'" == "Beverages" {
				recode item (1=94) (2=95) (3=96) (4=97) (100=98)
				}

			if "``item_type'_type'" == "Spices" {
				recode item (1=99) (2=100) (3=101) (4=102) (5=103) (6=104) (100=105)
				}
	
		tempfile ``item_type'_type'
		save	```item_type'_type''
		restore
	}
	
	* Append all datasets
		use `Bread'
		append using `Meat'
		append using `Dairy'
		append using `Oils'
		append using `Vegetables'
		append using `Fruits'
		append using `Sweets'
		append using `Beverages'
		append using `Spices'
		
	* Labels
	lab def item_l 	1 "Rice (high quality)" 2 "Rice (low quality)" 3 "Wheat flour" ///
					4 "Naan not made at home" 5 "Barley" 6 "Maize" 7 "Beans" 8 "Mung" ///
					9 "Chickpeas" 10 "Lentils" 11 "Pasta" 12 "Other bread and/or cereal" ///
					13 "None" 14 "Beef" 15 "Veal" 16 "Mutton" 17 "Goat" 18 "Chicken" 19 "Liver" ///
					20 "Dried Meat" 21 "Fish" 22 "Other meat and/or fish" 23 "None" 24 "Milk (fresh)" ///
					25 "Milk (powdered)" 26 "Yogurt" 27 "Curd (chaka)" 28 "Krut (dried)" ///
					29 "Dogh" 30 "Ghee" 31 "Butter" 32 "Cheese" 33 "Eggs" 34 "Other dairy products" ///
					35 "None" 36 "Vegetable oil" 37 "Cotton oil or sesame oil" 38 "Animal fat" ///
					39 "Other oils and fat" 40 "None" 41 "Potato" 42 "Sweet potato" 43 "Onion" ///
					44 "Tomato" 45 "Okra" 46 "Spinach" 47 "Cauliflower" 48 "Eggplant" 49 "Carrots" ///
					50 "Pumpkin, squash" 51 "Cucumber" 52 "Radish" 53 "Turnip" 54 "Cabbage" ///
					55 "Leek" 56 "Hot pepper" 57 "Wild leafy vegetables" 58 "Coriander" 59 "Mint" ///
					60 "Dried tomatoes" 61 "Dried vegetables" 62 "Pickled vegetables" ///
					63 "Green beans" 64 "Other vegetables" 65 "None" 66 "Apple" 67 "Grapes" ///
					68 "Melon/watermelon" 69 "Peach" 70 "Fresh apricots" 71 "Dried apricots" ///
					72 "Orange/citrus" 73 "Plum" 74 "Pomegranate" 75 "Pear" 76 "Banana" ///
					77 "Raisins" 78 "Fresh mulberries" 79 "Dried mulberries" 80 "Mangoes" ///
					81 "Walnuts" 82 "Pistachio" 83 "Almonds" 84 "Other fruit and/or nuts" ///
					85 "None" 86 "White sugar" 87 "Brown sugar" 88 "Honey" 89 "Chocolates" ///
					90 "Candy, sherinigack" 91 "Sweetener" 92 "Other sweets, specify" 93 "None" ///
					94 "Black teas" 95 "Green teas" 96 "Bottled/canned beverages, Mineral waters" ///
					97 "Other beverages" 98 "None" 99 "Salt" 100 "Black pepper" 101 "Ginger and garlic" ///
					102 "Tomato sauce" 103 "Mixed spices" 104 "Other spices" 105 "None"
	lab val item item_l
	
	* Order variables
		sort hhid item
		order hhid item_type item, first
		
		
	* Label main source
		lab def source_l 1 "Purchase" 2 "Own production" 3 "Bartered/payment in kind" ///
						4 "Borrowed/taken on credit" 5 "Received as gift from friends or family" ///
						6 "Food aid from organization" -97 "Other"
		lab val c_s source_l

	* Label 
		lab var c "Item was consumed in the last 7 days"
		lab var c_i "Days item was consumed in the last 7 days"
		lab var c_a "Quantity consumed"
		lab var c_s "Main source of item"
		lab var item "Item"
		lab var item_type "Item type"		
	
		
	* For an error in translation, we change ghee to the oils group
	* Mohammad: "On ghee consumption, I looked at the Dari instrument and followed 
	*			up with a surveyor in Afghanistan. Ghee is translated as "cooking oil".
	* 			On NRVA's classification, it seems to me that NARVA has translated ghee 
	*			into  a word the equivalent of which is "butter". In that case, it can 
	*			be categorized as a diary product. We used the word "butter" for that 
	*			in our instrument. 
		replace item_type = "Oils" if item==30
		
	* Looking at outliers in food items
	qui do "${fl1_do}/Cleaning/food_consumption_outliers_fl1.do"
		
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${consumption_fl1}", replace v(13)
		}
		else {
			save "${consumption_fl1}", replace
		}

*-----------------------------------*
* Non-food consumption - last month *
*-----------------------------------*
		
	use "${all_HH_interm_rost_nopii_fl1}", clear	
	
	* Keep relevant variables
		keep hhid c12_*
			
	* Reshape
		reshape long c12_, i(hhid) j(item)
		rename c12_ c12
		
	* Lab var
		lab var c12 "What did your household spend in the last month on [item] (value in Afghanis):"
		lab var item "Item"
		
	* Save
		tempfile nonfood_month
		save	`nonfood_month'
		
*----------------------------------*
* Non-food consumption - last year *
*----------------------------------*
		
	use "${all_HH_interm_rost_nopii_fl1}", clear	
	
	* Keep relevant variables
		keep hhid c13_*
			
	* Reshape
		reshape long c13_, i(hhid) j(item)
		rename c13_ c13
		
	* Lab var
		lab var c13 "What did your household spend in the last 12 month on [item] (value in Afghanis):"
		lab var item "Item"
		replace item = item+20
		
	* Append monthly
		append using `nonfood_month'
			
	* Lab def
		lab def item_l 	1 "Food consumed at home" 2 "Food consumed outside the home" ///
						3 "Cigarettes" 4 "Tobacco/snuff" 5 "Matches" ///
						6 "Laundry powder/detergents, cleaning supplies" ///
						7 "Soap (hand, toiletry)" 8 "Shampoo" 9 "Toothpaste" ///
						10 "Personal grooming (haircuts, etc.) for males" ///
						11 "Fee for public bath" 12 "Laundry charges"  ///
						13 "Fee for baking bread" 14 "Fixed phone line and use (including PCO booths)"  ///
						15 "Mobile phone charges (minutes and prepaid)" ///
						16 "Internet service/Internet café, fax, mail"  ///
						17 "Transportation fare - bus and taxis" ///
						18 "Fuel for car/motor bike (do not include business vehicles)" ///
						19 "Taxes (formal and informal)"  ///
						20 "Other miscellaneous expenses in last month" ///
						21 "House construction and repair (materials and labor)" ///
						22 "Education fees (tuition for school, college, university)" ///
						23 "School uniforms" 24 "Textbooks" 25 "Pens, pencils and notebooks (school supplies)" ///
						26 "Other stationery" 27 "Repair, maintenance and tires for motor vehicles" ///
						28 "Airfares" 29 "Men's clothing (excluding shoes)"  ///
						30 "Women's clothing (excluding shoes)" ///
						31 "Children's clothing (excluding shoes and school uniforms)" ///
						32 "Men's shoes" 33 "Women's shoes" 34 "Children's shoes" ///
						35 "Fines" 36 "Weddings and funerals, haj"  ///
						37 "Annual celebrations and charitable donations (khair-o-khairat)" ///
						38 "Health services"
		lab val item item_l
				
	order hhid item c12 c13
	sort hhid item
		
	* Looking at outliers in non-food items
	do "${fl1_do}/Cleaning/nonfood_consumption_outliers_fl1.do"
				
	* Save
		if	`c(stata_version)'>=14	{
			saveold "${nonfood_consumption_fl1}", replace v(13)
		}
		else {
			save "${nonfood_consumption_fl1}", replace
		}			
				

********************************************************************************
	** MHHH - Module 2: Productive Activities and Assets (K), and Livelihoods (R) 
********************************************************************************
		
*-------------------------------------------------*
* 3. Productive activities module - All questions *
*-------------------------------------------------*
	
	use "${MHHH_nopii_fl1}", clear

		merge 1:1 hhid using "${all_HH_interm_rost_nopii_fl1}", keepusing(hhh_name2) keep(3) nogen
		rename hhh_name2 member // for merge on member
	
	* Keep relevant variables
		keep hhid k1_1_* k2_1_* k3_1_* k4_1_* k5_m k2_1_hr* member 
		rename *_m *
		
		rename (k1_1__99 k1_1__98) (k1_1_99 k1_1_98)
	
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long 	k1_1_ k2_1_ k2_1_hr_ k3_1_ k4_1_, ///
						i(hhid) j(activity)
	
	* Paste labels
		drop k1_1
		rename *_ *
		foreach var of varlist * {
			local l_`var'_1 : subinstr local l_`var'_1 "[mem 1]" "[HH member #]", all 
			local l_`var'_1 : subinstr local l_`var'_1 "[activity 1]" "[activity #]", all 
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
			}
		}
	
		ds , not(varlabel)
		foreach var of varlist `r(varlist)' {
				lab var `var' "`l_`var''"
			}

	* Cleaning
		* Recode -98 and -99
			recode activity (98=-98) (99=-99)
			
		* Drop empty observation
			drop if mi(k1_1)
	
		* Labels
			lab var hhid "Household ID"
			lab var activity "Productive activity"
			lab var k1_1 "Did you do any of these activities in the last 4 weeks?"
			lab var k3_1 "How much did you earn to [activity] in the last 4 weeks?"
			lab var k4_1 "Approximate value in Afghanis of in-kind payment"

		* Label values
			lab def activity_l 1 "1: Tend any animals owned or leased by the household" ///
								2 "2: Farm land owned or sharecropped by the household" ///
								3 "3: Work on business owned by household other than farm/animals (e.g. shop, crafts)" ///
								4 "4: Work as an agricultural laborer outside household" ///
								5 "5: Do housework in someone else's home" ///
								6 "6: Work as a non-agricultural laborer outside the household (other than housework)" ///
								7 "7: Work in salaried/formal employment" ///
								8 "8: Do any other work for pay  (money or in-kind)" ///
								9 "9: Work on household chores (e.g. collecting water, cooking, cleaning) in your household" ///
								0 "0: None" ///
								-98 "-98: Don't answer" ///
								-99 "-99: Don't know"
			lab val activity activity_l
			
	* Looking at outliers in the time_activities_outliers_fl1 do file
		qui do "${fl1_do}/Cleaning/time_activities_outliers_m_fl1.do"
		
	* Replace to extended missing when they reply "Don't know"
		loc item activity
		loc yesno k1_1
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -99 & `yesno' == 1
		bys hhid: egen dk = max(temp)
		replace `yesno' = .d if dk == 1	& `item' != -99
		tab `yesno' if `item' == 1, m
		drop temp dk
				
	* Replace to extended missing when they reply "Don't answer"
		tab `item' if `yesno' == 1, m
		gen temp = 1 if `item' == -98 & `yesno' == 1
		bys hhid: egen da = max(temp)
		replace `yesno' = .r if da == 1	& `item' != -98
		tab `yesno' if `item' == 1, m
		drop temp da	
		
	* Add "_m" suffix back
		rename * *_m
		rename (hhid_m activity_m member_m) (hhid activity member)
		replace member = 1 if mi(member)
		gen member_m = member
		
	* Save data
		save "${productive_act_m_fl1}", replace

	* Merge productive_act_m_fl1 with productive_act_fl1 and save 
		use "${productive_act_fl1}", clear 
			merge 1:1 hhid activity member using "${productive_act_m_fl1}", keep(1 3) // with merge by member, hhid 1982 is missing HHH position, so it does not merge - ASSUME THAT HH HEAD IS MEMBER 1 (LINE 1794, "replace member = 1 if mi(member)"); hhid: 1088,1130,1302,1339,1522,1700,1787,1961,2070,2101,2103 NOW MERGE 
			
			assert _merge != 2
			drop _merge
			
			*label var merge_mhhh "MHHH data on time use is available for this HH"
			order hhid ultra_poor member b6 activity, first
			drop member_m
			
		* Save data
		if	`c(stata_version)'>=14	{
			saveold "${productive_act_fl1}", replace v(13)
		}
		else {
			save "${productive_act_fl1}", replace
		}		
		
