/*******************************************************************************	  
  
Project:  		AFG-TUP  
Created on:  	Feb 10, 2020  
  
Written by:  	Thomas Escande			  
  
Revision MDC: 	drop "flag_outlier" variables at the end of the do-file.	  
  
********************************************************************************	  
  
THIS DO FILE: 	Looks at outliers in the time use roster using consistency checks, replacing as .o all potential outliers  
  
  
CONTENT:		Part 1 - Looking at unusual data like type of missing and negative values for all variables  
				Part 2 - Identify potential outliers  
  
						  
OUTPUTS:     	  
				  
  
Note: 			This do file does not call or save any dataset, it is exclusively used within the "preparing_and_cleaning_rosters" do files.   
  
*******************************************************************************/  
  
  
*********************************************************************************************  
** Part 1: Looking at unusual data like type of missing and negative values for all variables  
*********************************************************************************************  
  
	ds hhid member, not //Having all the variables but hhid  
  
	foreach var of varlist `r(varlist)' {  
	tab `var' , nol m //looking at missing    
	}  
  
/*  
Main issues identified: In earnings, need to replace with the values of in kind  
There are a few 0.99, 99 and 98 that are likely to be -99 and -98 as they are not round numbers while all the others are  
*/  
	replace k30_1 = .d 	if k30_1 == 99 | (k30_1 > 0.989 & k30_1<0.999) //The 0.99 is rounded so it won't work if we do =0.99  
	  
	//Because of wrong coding of 97 instead of -97, question on the inkind was not asked, need to modify to don't know   
	replace k30_1 = -97 if k30_1 == 97 	  
	  
   
	  
********************************************************************************  
** Part 2: Identify potential outliers  
********************************************************************************  
  
/*   
Not much scope for outliers as entry mistakes or misunderstanding with units  
Potential issues with variables that requires entering number:  
1) k30_3 	: In the past 7 days, on how many different days did member i do activity j?  
2) k30_3_hr : For how many hours did did member i do activity j the last time he/she did it?   
3) k30_1 	: How much did member i earn in the last 4 weeks  
4) k30_2 	: How much is the value in Afghanis of in kind gifts?   
*/  
  
  
  
  
* k30_3 	: In the past 7 days, on how many different days did member i do activity j?  
*Checking there are no values greater than 7  
	sum k30_3  
	if `r(max)' > 7 {  
	disp "incorrect maximum value"  
	x  
	}  
*No issues in this variable  
  
  
* k30_3_hr : For how many hours did did member i do activity j the last time he/she did it?   
*Checking there are no values greater than 12 hours a day  
	sum k30_3_hr  
	if `r(max)' > 12 {  
	disp "incorrect maximum value"  
	  
	}  
*No issues in this variable  
  
*Merging to get the gender   
merge m:1 hhid member using "${current_roster_fl1}", keepusing(b6) keep(1 3) nogen  
merge m:1 hhid  using "${all_HH_interm_rost_nopii_fl1}", keepusing(ultra_poor) keep(1 3) nogen  
  
*******************************************	  
*k30_1 	: How much did member i earn in the last 4 weeks  
*Checking the high / low values and look for consistencies with time spent doing the activity  
	sum k30_1  
	tab k30_1,m  
	*hist k30_1 if k30_1 != -97 & k30_1 !=0 , freq  
	  
	*temporarily looking at total time working for consistency   
	gen tot_hr_4weeks = k30_3 * k30_3_hr * 4  
	gen wage = k30_1 / tot_hr_4weeks  
	sort tot_hr_4weeks  
  
	local tot_tot     = 0  
	local tot_outlier = 0  
	  
	forvalues i = 4/8 {	  
		forvalues gender = 1/2 {  
			forvalues	 up = 0/1 	{  
	*Computing mean and standard deviation of each hourly wage  
	quietly sum wage if activity == `i' & k30 == 1 & !mi(k30_1) & k30_1 > 0 & b6 == `gender' &  ultra_poor == `up'   
	local tot = `r(N)'  
	local mean= `r(mean)'  
	*Computing mean and standard deviation of each hourly wage without its maximum. It is useful when the sample is small with a high outlier, the standard deviation will be so high that it will miss the outlier most of the time.   
	quietly sum wage if activity == `i' & k30 == 1 & !mi(k30_1) & k30_1 > 0 & b6 == `gender' &  ultra_poor == `up' & wage != `r(max)'  
	  
	quietly gen dist_mean = (wage-`mean')/`r(sd)'  
	*Outliers if wage is more than 4 standard deviations away from mean. If wages follow a binomial distribution, values after that threshold are extremly unlikely   
	 count 			   if activity == `i'  & k30 == 1  & !mi(k30_1) & k30_1 >  0 & b6 == `gender' &  ultra_poor == `up' & dist_mean > 4 & !mi(dist_mean)	  
	 replace k30_1 = .o if activity == `i'  & k30 == 1  & !mi(k30_1) & k30_1 >  0 & b6 == `gender' &  ultra_poor == `up' & dist_mean > 4 & !mi(dist_mean)  
	local percent : disp %9.2fc `r(N)'/`tot'*100  
	*Checking the percentage of observations changed to outlier  
	disp "Activity `i': `r(N)' or `percent'% sent to missing as outliers, gender == `gender', up == `up'"  
	local tot_tot = `tot_tot' + `tot'  
	local tot_outlier = `tot_outlier' + `r(N)'	  
	drop dist_mean  
			}  
		}  
	}	  
	*Total number of observations changed to outlier  
	local percent_f : disp %9.2fc `tot_outlier'/`tot_tot'*100  
	disp "Total changed `tot_outlier' or `percent_f'%"	  
	
	*From looking at the graphs, two extrem outliers are still present:   
	quietly replace k30_1 = .o if activity == 8  & k30 == 1  & !mi(k30_1)   & k30_1 >  40000 & b6 == 1   
	quietly replace k30_1 = .o if activity == 4  & k30 == 1  & !mi(k30_1)   & k30_1 >  40000 & b6 == 1     
	  
	*Looking at the graph of time spent working vs money earned for each activity and by gender and up for final chck	  
	forvalues i = 4/8 {	  
		forvalues gender = 1/2 {  
			forvalues	 up = 0/1 	{  
				*twoway scatter tot_hr_4weeks k30_1 if k30_1 != -97 & k30_1 !=0 & activity == `i' & k30 == 1 & b6 == `gender' &  ultra_poor == `up',name(activity_`i'_`gender'_`up') || lfit tot_hr_4weeks k30_1 if k30_1 != -97 & k30_1 !=0 & activity == `i' & k30 == 1 & b6 == `gender' &  ultra_poor == `up'  
			}  
		}  
	}	  
	  
  
**********************************************  
*k30_2 	: How much is the value in Afghanis of in kind gifts?   
*Checking the high / low values and look for consistencies with time spent doing the activity  
* Very few values so just looking with a tab  
  

  
*Dropping all variables and graphs - to comment if want to look precisely at outliers  
drop tot_hr_4weeks wage 
graph drop _all  
*********************************************end of do file***********************************  
