/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	Feb 10, 2020

Written by:  	Thomas Escande			

Revision MDC: 	drop "flag_outlier" variables at the end of the do-file.

********************************************************************************	

THIS DO FILE: 	Looks at outliers in the time use roster (only for MALE HEAD of the HOUSEHOLD) using consistency checks, replacing as .o all potential outliers


CONTENT:		Part 1 - Looking at unusual data like type of missing and negative values for all variables
				Part 2 - Identify potential outliers

						
OUTPUTS:     	
				

Note: 			This do file does not call or save any dataset, it is exclusively used within the "preparing_and_cleaning_rosters" do files. 


*******************************************************************************/


*********************************************************************************************
** Part 1: Looking at unusual data like type of missing and negative values for all variables
*********************************************************************************************

	ds hhid , not //Having all the variables but hhid

	foreach var of varlist `r(varlist)' {
	tab `var' , nol m //looking at missing  
	}

/*
Main issues identified: 
There is one 0.98 which is likely to be -98 as it is not a round numbers while all the others are
*/
	replace k3_1 = .r 	if (k3_1 >= 0.98 & k3_1<0.981)

	
********************************************************************************
** Part 2: Identify potential outliers
********************************************************************************

/* 
Not much scope for outliers as entry mistakes or misunderstanding with units
Potential issues with variables that requires entering number:
1) k2_1	: In the past 7 days, on how many different days did member i do activity j?
2) k2_1_hr : For how many hours did did member i do activity j the last time he/she did it? 
3) k3_1 	: How much did member i earn in the last 4 weeks
4) k4_2 	: How much is the value in Afghanis of in kind gifts? 
*/




* k2_1 	: In the past 7 days, on how many different days did member i do activity j?
*Checking there are no values greater than 7
	sum k2_1
	if `r(max)' > 7 {
	disp "incorrect maximum value"
	x
	}
*No issues in this variable


* k2_1_hr : For how many hours did did member i do activity j the last time he/she did it? 
*Checking there are no values greater than 12 hours a day
	sum k2_1_hr
	if `r(max)' > 12 {
	disp "incorrect maximum value"
	x
	}
*No issues in this variable

*******************************************	
*Keep the outliers for later
	gen k3_1_with_outliers = k3_1
*k3_1 	: How much did member i earn in the last 4 weeks
*Checking the high / low values and look for consistencies with time spent doing the activity
	sum k3_1
	tab k3_1
	hist k3_1 if k3_1 != -97 & k3_1 !=0 , freq
	
	*temporarily looking at total time working for consistency 
	gen tot_hr_4weeks = k2_1 * k2_1_hr * 4
	sort tot_hr_4weeks

	*Looking at the graph of time spent working vs money earned for each activity	
	forvalues i = 4/9 {
	*twoway scatter tot_hr_4weeks k3_1 if k3_1 != -97 & k3_1 !=0 & activity == `i' & k1_1 == 1,name(activity_`i') || lfit tot_hr_4weeks k3_1 if k3_1 != -97 & k3_1 !=0 & activity == `i' & k1_1 == 1
	}
	
/*Outliers identified in graphs: 
activity 4: One values which is close to 25000 looks like outlier */ 
	replace k3_1 = .o if activity == 4 & k1_1 == 1 & k3_1 >= 20000 & !mi(k3_1)
	
*activity 5: No obvious mistake/outlier*/ 

*activity 6: One extrem outlier, around 40000 */ 
	replace k3_1 = .o if activity == 6 & k1_1 == 1 & k3_1 >= 40000 & !mi(k3_1)
	
*activity 7: No obvious mistake/outlier*/ 
	
*activity 8:  No obvious mistake/outlier*/  

*Total of 2 observations changed out of 393 non missing values (0.5%)


**********************************************
*k4_2 	: How much is the value in Afghanis of in kind gifts? 
*Only missing values


label var k3_1_with_outliers "k3_1 including gross outliers"

*Dropping all variables and graphs - to comment if want to look precisely at outliers
drop tot_hr_4weeks k3_1_with_outliers
graph drop _all
*********************************************end of do file***********************************
