/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	August 8, 2023
Last udpate on: 

Written by:  	Yulia Belyakova

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates psych well-being variables at baseline for the midline sample 
					to be used as covariates (due to imbalance)

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

* Inputs 
	global all_HH_nopii_fl1 	"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta" // this is merged/appended MDC data WITHOUT roster variables
	global psy_bl 			    "${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta"

* Outputs 
	global psy_bl_flsample		"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl_flsample.dta"

	
use "${psy_bl}", clear 

* Drop existing indices 
	drop *_score_z* psy_5index_z_f psy_5index_z_m

* Merging fl1 sample indicators
preserve 
	use "${all_HH_nopii_fl1}", clear 
	keep hhid merge_mhhh
	rename merge_mhhh merge_mhhh_fl1
	
	tempfile fl1_sample
	save `fl1_sample'
	 
restore 

merge 1:1 hhid using "`fl1_sample'", keepusing(merge_mhhh_fl1) keep(1 3)

* Merge on follow-up data to compute the indices for the follow-up sample only
gen follow_up = (_merge==3)
drop _merge

* Standardization based on control SD for the Follow-up sample 
preserve
	keep if treatment != .
	* For Primary Women
	keep if follow_up == 1 
	
		foreach x in satisf_score hap_score cesd_score  rses_score cohen_score  {
			foreach j in _f {
				egen `x'_z`j' = weightave(`x'`j'), normby(control)
				lab var `x'_z`j' "Standardized score (control)"
		}
		}

	* Overall Index
			global all5_f satisf_score_z_f cesd_score_z_f rses_score_z_f hap_score_z_f cohen_score_z_f
			
			foreach j in _f {
				egen psy_index_z`j' = weightave(${all5`j'}), normby(control)
			}
			
			keep hhid satisf_score_z_? cesd_score_z_? rses_score_z_? hap_score_z_? cohen_score_z_? psy_index_z_?
			tempfile psyc_index_f
			save	`psyc_index_f'
restore 

	merge 1:1 hhid using `psyc_index_f', assert(1 3) nogen
	
	* For Primary Men 
preserve 
	keep if treatment != .
	* For Primary Men [670]
	keep if merge_mhhh_fl1 == 3 
	
	keep if follow_up == 1 

		foreach x in satisf_score hap_score cesd_score  rses_score cohen_score  {
			foreach j in _m {
				egen `x'_z`j' = weightave(`x'`j'), normby(control)
				lab var `x'_z`j' "Standardized score (control)"
		}
		}

	* Overall Index
			global all5_m satisf_score_z_m cesd_score_z_m rses_score_z_m hap_score_z_m cohen_score_z_m
			
			foreach j in _m {
				egen psy_index_z`j' = weightave(${all5`j'}), normby(control)
			}
			
			keep hhid satisf_score_z_? cesd_score_z_? rses_score_z_? hap_score_z_? cohen_score_z_? psy_index_z_?
			tempfile psyc_index_m
			save	`psyc_index_m'
restore
			
	merge 1:1 hhid using `psyc_index_m', assert(1 3) nogen
			
		lab var psy_index_z_f "PW Psychological Well-being Index"
		lab var psy_index_z_m "PM Psychological Well-being Index"
	
	global psy_balance treatment hhid ultra_poor satisf_score_z_f cesd_score_z_f rses_score_z_f hap_score_z_f cohen_score_z_f ///
		satisf_score_z_m cesd_score_z_m rses_score_z_m hap_score_z_m cohen_score_z_m psy_index_z_f psy_index_z_m
	global index_raw satisf_score_f satisf_score_m  hap_score_f hap_score_m trust_score_f trust_score_m cesd_score_f cesd_score_m rses_score_f rses_score_m cohen_score_f cohen_score_m  lotr_score_f lotr_score_m cesd_f_md cesd_m_md cesd_f_ts cesd_m_ts
	keep $psy_balance  $index_raw cesd_m_md cesd_score_m happy_i27_f happy_i27_m i27_f i27_m
	
	rename (psy_index_z_f psy_index_z_m) (psy_5index_z_f psy_5index_z_m)
	
	
	*Save dataset for ultra poors
	if	`c(stata_version)'>=14	{
		saveold "${psy_bl_flsample}", replace v(13)
	}
	else {
		save "${psy_bl_flsample}", replace
	}
	