/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 13, 2019
Last udpate on: Mar 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Merges the constructed variables to the household dataset and creates the dataset for data analysis.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off
set maxvar 20000
* Inputs
	gl all_HH_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl profile_info 					"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl total_expenditure_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/total_expenditure_fl1.dta"
	gl foodsecurity_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/food_security_index_fl1.dta"
	gl finance_index_up 				"${TUP_DB}/Followup_1/DataSets/Intermediate/finance_index_up_fl1.dta"
	gl time_activities_up 				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
	gl wellbeing_index_up 				"${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_up_fl1.dta"
	gl asset_index_up 					"${TUP_DB}/Followup_1/DataSets/Intermediate/asset_index_up_fl1.dta"
	gl livestock_revenue_index_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_revenue_index_fl1.dta"
	gl crop_production_index_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/crop_production_index_fl1.dta"
	gl business_revenue_earnings_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/business_revenue_earnings_fl1.dta"
	gl total_expenditure_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/total_expenditure_bl.dta"
	gl livestock_assets_index_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_assets_index_fl1.dta"
	gl empowerment_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/female_empowerment_index_fl1.dta"
	gl polinvolvement_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/political_involvement_index_fl1.dta"
	gl codebook_data_fl1				"${TUP_DC}/Followup_1/Dofiles/Construct/codebook_data_for_analysis.xlsx"
	gl time_activities_up 				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
	gl health_fl1						"${TUP_DB}/Followup_1/DataSets/Intermediate/health_fl1.dta"
	gl all_HH_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl data_for_analysis_bl				"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	gl f_empowerment_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta"
	gl entrepreneur_index_up 			"${TUP_DB}/Followup_1/DataSets/Intermediate/entrepreneur_index_up_fl1.dta"
	gl entrepreneur_index_up_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/entrepreneur_index_up_bl.dta"	
	gl time_activities_hh 				"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_hh_fl1.dta"
	gl current_roster_fl1	 			"${TUP_DB}/Followup_1/DataSets/Intermediate/br_hhmemcurrent_fl1.dta"
	gl time_activities_ses  			"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"

* Outputs

	* Data for analysis: Follow-up 1
		gl data_for_analysis_fl1	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

	* Data for analysis: IE Main paper
		gl data_for_analysis_fl1_IEpaper	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1_IEpaper.dta"
	
********************************************************************************
	** Part 1: Merge dataset with indices
********************************************************************************


*----------------------------*
* Prepare baseline for merge *
*----------------------------*

	use "${data_for_analysis_bl}", clear

	keep 	hhid exp_tot_m_pc exp_tot_m_pc_ppp hhhead_female  age_pf age_pm /// child_in_schooling_age
			literacy_pf literacy_pm schoolyear_pf schoolyear_pm  diarrhea_yes tot_lstock_value tot_lstock_value_med property_score  wealth_score  psy_5index_z_f did_livestock ///
			index_sdC_f_empowerment_3c
	
	rename * *_bl
	rename hhid_bl hhid
	tempfile baseline
	save 	`baseline'

*---------------*
* Merge indices *
*---------------*
use "${current_roster_fl1}", clear 
	keep hhid r13 r1 r3 r9 r11
	duplicates drop
	
	tempfile r13
	save `r13'

use "${all_HH_nopii_fl1}", clear
		merge 1:1 hhid using "`r13'", keepusing(r13 r1 r3 r9 r11) assert(3) nogen

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) keep(1 3) nogen

* Consumption
	loc consumption_vars "exp_tot_m_pc exp_tot_m_pc_w exp_f_tot_m_pc_c exp_tot_m_pc_c exp_tot_m_pc_ALCS exp_tot_m_pc_c_ALCS exp_f_tot_m_pc exp_nf_tot_m_pc below_pov_af below_pov_af_ALCS exp_nf_tot_m_pc_ALCS exp_durable_m_pc exp_rent_m_pc exp_nf_tot_m_pc_c exp_f_m_pc_* exp_f_outhouse_m_pc"
	merge 1:1 hhid using "${total_expenditure_fl1}", keepus(`consumption_vars') assert(3) nogen	

* Adding entrepreneur_index
	* Follow up
	loc entrep_fl1 "impuls_index_sdC_fl1 passion_work_index_sdC_fl1 tenacity_index_sdC_fl1 polychronicity_index_sdC_fl1 locus_control_index_sdC_fl1 achievement_index_sdC_fl1 power_motivation_index_sdC_fl1  work_central_index_sdC_fl1 organized_index_sdC_fl1 entrep_index_pca_fl1 entrep_index_sdC_fl1"
	merge 1:1 hhid using "${entrepreneur_index_up}", keepus(`entrep_fl1') assert(1 3) nogen
	
	* Baseline
	loc entrep_bl "impuls_index_sdC_bl passion_work_index_sdC_bl tenacity_index_sdC_bl polychronicity_index_sdC_bl locus_control_index_sdC_bl achievement_index_sdC_bl power_motivation_index_sdC_bl  work_central_index_sdC_bl organized_index_sdC_bl entrep_index_pca_bl entrep_index_sdC_bl"
	merge 1:1 hhid using "${entrepreneur_index_up_bl}", keepus(`entrep_bl') keep(1 3)  nogen	
	
* Food Security
	loc foodsec_vars "c14_7 c14_3_ac c14_5_ac c14_1_ac index_sdC_food_sec index_sdC_food_sec2 index_sdUP_food_sec index_sdUP_food_sec2"
	merge 1:1 hhid using "${foodsecurity_fl1}", keepus(`foodsec_vars') assert(3) nogen
	
* Finance
	loc fin_vars "fin_index_sdC_fl1 fin_knowledge saving_account access_credit save_4wdummy saving_4w saving_4w_win saving saving_win fin_index_sdC_fl1 loan_dummy loan loan_win consumption_loan formal_loan_dummy woman_loan_amount productive_loan source1_loan source2_loan source3_loan source4_loan source5_loan source6_loan source7_loan source8_loan source9_loan source10_loan purpose1_loan purpose2_loan purpose3_loan purpose4_loan purpose5_loan purpose6_loan purpose7_loan purpose8_loan purpose9_loan"
	merge 1:1 hhid using "${finance_index_up}", keepus(`fin_vars') assert(1 3) nogen
		
* Psy well being
	loc wellbeing_vars "satisf_z_sdC_fl1 satisf_score_fl1 i5 cesd_z_sdC_fl1 cesd_ts cesd_md i7_origin i10_origin i11_origin i12_origin i16_origin  i23_origin i25_origin trust_z_sdC_fl1 trust_score_fl1 i26_origin hap_z_sdC_fl1 hap_score_fl1 i27_origin lotr_z_sdC_fl1 lotr_score_fl1 i28_a_origin i28_c i28_d_origin i28_g i28_i i28_j_origin i28_a_origin i28_b i28_c i28_d i28_e i28_f i28_g i28_h i28_i i28_j_origin rses_z_sdC_fl1 rses_score_fl1 i34_origin i35_origin i37_origin i38 i39_origin i43 cohen_z_sdC_fl1 cohen_score_fl1 oldi44 oldi45 oldi46 oldi47 lcortisol_clean lcortisol lcortisol_clean_w  lcortisol_w psy_indexC_sdC_fl1 lcortisol_clean lcortisol_clean_inv satisf_z_sdC_fl1 hap_z_sdC_fl1 cesd_z_sdC_fl1 rses_z_sdC_fl1 cohen_z_sdC_fl1 trust_z_sdC_fl1 lotr_z_sdC_fl1 psy_indexC_sdC_m_fl1 lcortisol_clean_m lcortisol_clean_m_inv lcortisol_clean_inv satisf_z_sdC_m_fl1 hap_z_sdC_m_fl1 cesd_z_sdC_m_fl1 rses_z_sdC_m_fl1 cohen_z_sdC_m_fl1  cohen_score_m_fl1 hap_score_m_fl1 satisf_score_m_fl1 trust_score_m_fl1 lotr_score_m_fl1 rses_score_m_fl1 cesd_score_m_fl1	 trust_z_sdC_m_fl1 lotr_z_sdC_m_fl1 cesd_score_fl1 cesd_score_m_fl1"
	merge 1:1 hhid using "${wellbeing_index_up}", keepus(`wellbeing_vars') assert(1 3) nogen

* Household assets
	loc hhassets_vars "wealth_score wealth_score_sdC property_score num_radio_CD num_TV num_DishTV num_VCR_DVD  num_fridge num_generator num_matress num_mobile_phone num_non_mobilephone num_iron num_bedframe num_jewelry num_mosquitonet num_mosq_repel_candle num_fan num_camera own_dwelling own_house_Land own_nonHouse_Land own_othHouse"
	merge 1:1 hhid using "${asset_index_up}", keepus(`hhassets_vars') assert(1 3) nogen
	
* Female empowerment
	loc empowerment_vars "index_sdC_all_decisions index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert h1_ac h2_ac h3_ac h4_ac h5_ac h6_ac h7_ac h8_ac h9_ac h10_ac h11_ac h12_ac h13_ac h14_ac h28_ac h31_ac h24_ac h30 mobile_yes_pf loan_yes_pf index_sdC_role_prod_act index_sdC_work index_sdC_inputs did_labor_pf owner_manager_pf index_sdC_social_norms_dau index_sdC_educ index_sdC_marriage ed_level_d ed_level_s ed_help_d age_marriage_d index_sdC_social_capital index_sdC_tazkira index_sdC_political index_sdC_community s21 s10 n1 n2 index_sdC_f_emp_3c index_sdC_f_emp_3c_r index_sdC_role_prod_act index_sdC_social_capital index_sdC_all_decisions_m index_sdC_foodexp_m index_sdC_homeexp_m index_sdC_homefin_m index_sdC_chischool_m index_sdC_chihealth_m index_sdC_chimarr_m index_sdC_homesale_m index_sdC_otherexp_m index_sdC_fert_m index_sdC_role_prod_act_m index_sdC_social_norms_m index_sdC_social_capital_m index_sdC_f_emp_3c_m index_sdC_work_m index_sdC_inputs_m index_sdC_tazkira_m index_sdC_political_m index_sdC_community_m index_sdC_educ_m index_sdC_marriage_m index_sdC_all_decisions_w index_sdC_foodexp_w index_sdC_homeexp_w index_sdC_homefin_w index_sdC_chischool_w index_sdC_chihealth_w index_sdC_chimarr_w index_sdC_homesale_w index_sdC_otherexp_w index_sdC_fert_w index_sdC_role_prod_act_w index_sdC_social_norms_w index_sdC_social_capital_w index_sdC_f_emp_3c_w index_sdC_work_w index_sdC_inputs_w index_sdC_tazkira_w index_sdC_political_w index_sdC_community_w index_sdC_educ_w index_sdC_marriage_w index_Z_all_decisions index_Z_role_prod_act index_Z_social_capital index_Z_decisions_eco index_Z_f_emp_3c voted index_sdC_h28 index_sdC_h28_m index_sdC_h28_w index_sdC_h31 index_sdC_h31_m index_sdC_h31_w index_sdC_h24 index_sdC_h24_m index_sdC_h24_w occupation_d" 

	merge 1:1 hhid using "${f_empowerment_fl1}", keepus(`empowerment_vars') assert(1 3) nogen	
	
* Political involvement
	loc polinvolvement_vars "s21 s10 n1 n2 index_sdC_pol_involv index_sdUP_pol_involv" //index_sdC_pol_involv_village index_sdUP_pol_involv_village
	merge 1:1 hhid using "${polinvolvement_fl1}", keepus(`polinvolvement_vars') assert(3) nogen	
	
* Value of assets
	loc assets_vars "lstock_yes tot_lstock_value tot_lstock_value_med lstock_value_cow lstock_value_bull lstock_value_horse lstock_value_donkey lstock_value_goat lstock_value_sheep lstock_value_chicken lstock_value_duck lstock_value_turkey lstock_value_goose lstock_value_rabbit tot_lstock_value_goat tot_lstock_value_med_goat  lstock_value_goat_cow lstock_value_goat_bull lstock_value_goat_goat lstock_value_goat_sheep tot_lstock_w_value lstock_value_w_cow lstock_value_w_bull lstock_value_w_goat lstock_value_w_sheep lstock_yes_cow lstock_yes_bull lstock_yes_horse lstock_yes_donkey lstock_yes_goat lstock_yes_sheep lstock_yes_chicken lstock_yes_duck lstock_yes_turkey lstock_yes_goose lstock_yes_rabbit lstock_yes_guineafowl lstock_yes_beehive  lstock_num_cow lstock_num_bull lstock_num_horse lstock_num_donkey lstock_num_goat lstock_num_sheep lstock_num_chicken lstock_num_duck lstock_num_turkey lstock_num_goose lstock_num_rabbit lstock_num_guineafowl lstock_num_beehive lstock_value_goat_cow lstock_value_goat_bull lstock_value_goat_horse lstock_value_goat_donkey lstock_value_goat lstock_value_goat_goat lstock_value_goat_sheep lstock_value_goat_chicken lstock_value_goat_duck lstock_value_goat_turkey lstock_value_goat_goose lstock_value_goat_rabbit lstock_value_goat_guineafowl lstock_value_goat_beehive  tot_lstock_value_goat lstock_value_other lstock_value_goat_other"
	merge 1:1 hhid using "${livestock_assets_index_fl1}", keepus(`assets_vars') assert(1 3) nogen	

* Health	
	loc health_vars "diarrhea_yes fever_yes birth_yes diarrhea_advice fever_advice birth_advice vaccines_card vaccines_card_checked f4_1 f4_2 f4_3 f4_4 f4__97 f4_dkda"
	merge 1:1 hhid using "${health_fl1}", assert(3) nogen keepus(`health_vars')
	
* Revenues
	merge 1:1 hhid using "${livestock_revenue_index_fl1}", assert(1 3) nogen
	merge 1:1 hhid using "${crop_production_index_fl1}", assert(1 3) nogen
	merge 1:1 hhid using "${business_revenue_earnings_fl1}", assert(1 3) nogen

* Time use
	merge 1:1 hhid using "${time_activities_hh}", assert(1 3) nogen
					
*-------------------------*
* Additional construction *
*-------------------------*

* Merge baseline
	merge 1:1 hhid using `baseline', keep(1 3) gen(merge_bl)

* Create winsorization	

	foreach var in tot_lstock_value tot_lstock_revenue fin_index_sdC_fl1 {
		winsor2 `var' if `var'>0, by(ultra_poor) cuts(0 95)
		replace `var'_w = `var' if mi(`var'_w)
		local l_`var' : variable label `var'
		lab var `var'_w "`l_`var'' - Winsorized"

	}

	foreach var in tot_lstock_earn {
		winsor2 `var', by(ultra_poor) cuts(0 95)
		replace `var'_w = `var' if mi(`var'_w)
		local l_`var' : variable label `var'
		lab var `var'_w "`l_`var'' - Winsorized"
	}

* Create total HH income
	egen tot_hh_income = rowtotal(tot_hh_pay tot_lstock_revenue tot_crop_revenue tot_biz_revenue), missing

* Primary Man Participates in Market Work	
preserve 	
	use "${time_activities_ses}", clear
	* Keep only primary female
		keep if hhh_name2 == member & b6 == 1
		isid hhid
		keep hhid did_labor_nohh
		rename did_labor_nohh did_labor_pm
		lab var did_labor_pm "Primary Man Participates in Market Work"
		tempfile engaged_prod_activities_pm
		save `engaged_prod_activities_pm'
restore 		

preserve 	
	use "${time_activities_ses}", clear
	* Keep only primary female
		keep if lady_hh2 == member & b6 == 2
		isid hhid
		keep hhid did_labor_nohh ultra_poor
		rename did_labor_nohh did_labor_pf
		lab var did_labor_pf "Primary Woman Participates in Market Work"
		tempfile engaged_prod_activities_pf
		save `engaged_prod_activities_pf'
restore 	

	merge 1:1 hhid using "`engaged_prod_activities_pm'", assert(1 3) nogen
	merge 1:1 hhid using "`engaged_prod_activities_pf'", nogen update replace 
	
* Create thirds for heterogeneous analysis
	loc consump_var "exp_tot_m_pc_bl"
	loc consump_ppp_var "exp_tot_m_pc_ppp_bl"
	loc asset_var "wealth_score_bl"
	loc psych_var "psy_5index_z_f_bl"
	loc entrep_var "entrep_index_sdC_bl"
	loc entreppca_var 		"entrep_index_pca_bl"
	loc entreporg_var 		"organized_index_sdC_bl"
	loc entrepwork_var 		"work_central_index_sdC_bl"
	loc entreppower_var 	"power_motivation_index_sdC_bl"
	loc entrepachiev_var 	"achievement_index_sdC_bl"
	loc entreplocus_var 	"locus_control_index_sdC_bl"
	loc entreppoly_var 		"polychronicity_index_sdC_bl"
	loc entreptenac_var 	"tenacity_index_sdC_bl"
	loc entreppassion_var 	"passion_work_index_sdC_bl"
	loc entrepimpuls_var 	"impuls_index_sdC_bl"
	loc empower_var 		"index_sdC_f_empowerment_3c_bl"
	loc consump_l "Consumption"
	loc consump_ppp_l "Consumption PPP"
	loc assets_l "Asset levels (PCA)"
	loc psych_l "Psych Well-being"
	loc entrep_l "Entrepreneurial Index (Standardized)"
	loc entreppca_l 		"Entrepreneurial Index (PCA)"
	loc entreporg_l 		"Organized Index"
	loc entrepwork_l 		"Work Centrality Index"
	loc entreppower_l 		"Power Motivation Index"
	loc entrepachiev_l 		"Achievment Index"
	loc entreplocus_l 		"Locus of Control Index"
	loc entreppoly_l 		"Polychronicity Index "
	loc entreptenac_l 		"Tenacity Index"
	loc entreppassion_l 	"Passion for Work Index"
	loc entrepimpuls_l 		"Impulsiveness Index"   
	loc empower_l			"Women's Empowerment Index"
						   
	
	foreach var in consump consump_ppp asset psych entrep entreppca entreppower  entrepachiev entreplocus entreppoly entrepimpuls entreptenac empower { //
		xtile bl_`var'_thirds = ``var'_var', nq(3)
		
if 	"`var'" == "entreppoly" {
* Two are really unbalanced, because the variables are categorical, and quantiles are computed from the higher to the lower value.
*I'll correct it manually, allowing the first tercile to have a bit less value to increase balance
* It works with polychronicity_index_sdC_bl but impossible with impuls_index_sdC_bl because 500 observations have the same value
	replace bl_entreppoly_thirds = 2 if polychronicity_index_sdC_bl < -.3004264 & polychronicity_index_sdC_bl > -.3004266		
}		

		tab bl_`var'_thirds, gen(bl_`var'_)
		lab var bl_`var'_1 "Bottom third - Baseline ``var'_l'"
		lab var bl_`var'_2 "Middle third - Baseline ``var'_l'"
		lab var bl_`var'_3 "Top third - Baseline ``var'_l'"
		
		foreach third in 1 2 3 {
			local l_`third' : variable label bl_`var'_`third'
			gen treatXbl_`var'_`third' = treatment*bl_`var'_`third'
			lab var treatXbl_`var'_`third' "Treatment X `l_`third''"
		}
	}
	
foreach var in consump consump_ppp asset psych entrep entreppca entreppower  entrepachiev entreplocus entreppoly entrepimpuls entreptenac empower { 
	tab bl_`var'_thirds	
	}


	
* PPP variables
	foreach var in exp_tot_m_pc_c exp_tot_m_pc exp_tot_m_pc_c_ALCS exp_tot_m_pc_ALCS tot_lstock_value tot_lstock_value_med saving saving_win saving_4w saving_4w_win loan loan_win woman_loan_amount tot_hh_income tot_lstock_revenue tot_crop_revenue tot_biz_revenue tot_hh_pay lstock_rev_sales prod_revenue_yogurt  prod_revenue_milk prod_revenue_egg prod_revenue_butter exp_tot_m_pc_w tot_lstock_revenue_w tot_lstock_earn_w exp_f_tot_m_pc_c exp_f_tot_m_pc exp_nf_tot_m_pc_c exp_nf_tot_m_pc {
		local l_`var' : variable label `var'
		gen `var'_ppp = `var' / $ppp_2018
		lab var `var'_ppp "`l_`var''"
	}
				

* Winsorize value of livestock at 99th pct by treatment to be consistent with endline  
	foreach var in tot_lstock_value { 
		winsor2 `var', by(treatment) cuts(0 99) suff(_w99t) 
		replace `var'_w99t = `var' if mi(`var'_w99t) 
		local l_`var' : variable label `var' 
		lab var `var'_w99t "`l_`var'' - Treatment Winsorized (99%)" 
	}			 
	
* Rename winsorized variables because the names are too long  
	rename tot_lstock_value_w99t tot_lstock_val_w99t   
 
* Nominal USD conversion
	foreach var in exp_tot_m_pc tot_hh_income tot_lstock_value saving loan tot_lstock_val_w99t {
		local `var'l : var lab `var'
		local `var'l: subinstr local `var'l "(AFN)" "(USD)", all
		gen `var'_usd = `var' / $exchange_rate_2018
		lab var `var'_usd "``var'l'"
	} 				
				
* Order dataset
	order 	exp_tot_m_pc tot_lstock_value tot_lstock_value_med wealth_score wealth_score_sdC fin_index_sdC_fl1 psy_indexC_sdC_fl1 psy_indexC_sdC_m_fl1 ///
			 index_sdC_f_emp_3c lstock_yes lstock_yes_cow ///
			lstock_yes_goat lstock_yes_chicken crop_yes biz_yes exp_tot_m_pc_c below_pov_af_ALCS index_sdC_food_sec ///
			tot_lstock_value wealth_score fin_index_sdC_fl1 access_credit saving saving_win saving_4w saving_4w_win loan loan_win tot_hh_income tot_lstock_revenue tot_crop_revenue ///
			tot_biz_revenue tot_hh_pay psy_indexC_sdC_fl1 psy_indexC_sdC_m_fl1 index_sdC_all_decisions ///
			index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr ///
			index_sdC_homesale index_sdC_otherexp index_sdC_fert  ///
			index_sdC_role_prod_act index_sdC_social_norms_dau index_sdC_social_capital ///
			index_sdC_f_emp_3c  ///
			diarrhea_yes vaccines_card_checked, after(hhid)
		
*------------*
* iecodebook *
*------------*

		
	foreach x in pc {	
			lab var exp_f_m_`x'_beverage "Beverages"
			lab var exp_f_m_`x'_grain  "Grains/legumes/breads"
			lab var exp_f_m_`x'_dairy "Dairy products"
			lab var exp_f_m_`x'_fruit  "Fruits and nuts"
			lab var exp_f_m_`x'_meat_fish  "Meat and fish"
			lab var exp_f_m_`x'_oil  "Oils and fats"
			lab var exp_f_m_`x'_spice "Spices"
			lab var exp_f_m_`x'_sugar "Sugars"
			lab var exp_f_m_`x'_veg "Vegetables"
		}
		
	lab var exp_f_outhouse_m_pc "Food outside the house"
	lab var exp_f_tot_m_pc "Total food consumption"
	lab var exp_nf_tot_m_pc "Total non-food consumption"
		lab var exp_tot_m_pc_w "Per Capita Consumption - Winsorized"

		
	foreach livestock in horse donkey chicken duck turkey goose rabbit {
		lab var lstock_value_`livestock' "Total value of `livestock's"
		local l_`livestock' : variable label lstock_value_`livestock'
		lab var lstock_value_goat_`livestock' "`l_`livestock''"
	}	

	lab var index_sdC_all_decisions "Women's Decision-Making Index"
	lab var index_sdC_foodexp "Major Say in Food Expenditures and What to Cook"
	lab var index_sdC_homeexp "Major Say in Home Improvements/Repairs"
	lab var index_sdC_homefin "Major Say in Managing Household Finances"
	lab var index_sdC_chischool "Major Say in Children's School Attendance"
	lab var index_sdC_chihealth "Major Say in Children's Health Seeking"
	lab var index_sdC_chimarr "Major Say in Children's Marriage"
	lab var index_sdC_homesale "Major Say in Buying or Selling Land or Property"
	lab var index_sdC_otherexp "Major Say in Clothing and Other Non-food Expenditures"
	lab var index_sdC_fert "Major Say in Her Fertility"
	lab var index_sdC_h24 "Her Opening a Business"
	lab var index_sdC_h28 "Her Taking a Loan" 
	lab var index_sdC_h31 "Her Working Outside of Home" 
	lab var index_sdC_work "Participation in Market Work and Running a Business"
	lab var index_sdC_inputs "Access to Resources and Inputs"
	lab var index_sdC_tazkira "National ID Ownership"
	lab var index_sdC_political "Political Participation"
	lab var index_sdC_community "Community Participation"
	lab var index_sdC_educ "Daughters' Education"
	lab var index_sdC_marriage "Daughter's Marriage in Adulthood"
	lab var index_sdC_role_prod_act "Economic Opportunities Index"
	lab var index_sdC_social_norms_dau "Aspirations for Daughters Index (for HH With Daughters $\le$ 12 Years Old)"
	lab var index_sdC_social_capital "Political and Social Involvement Index"
	lab var index_sdC_f_emp_3c "Women's Empowerment Index (3 Components)"

	lab var index_sdC_all_decisions_m "Women's Decision-Making"
	lab var index_sdC_foodexp_m "Major Say in Food Expenditures and What to Cook"
	lab var index_sdC_homeexp_m "Major Say in Home Improvements/Repairs"
	lab var index_sdC_homefin_m "Major Say in Managing Household Finances"
	lab var index_sdC_chischool_m "Major Say in Children's School Attendance"
	lab var index_sdC_chihealth_m "Major Say in Children's Health Seeking"
	lab var index_sdC_chimarr_m "Major Say in Children's Marriage"
	lab var index_sdC_homesale_m "Major Say in Buying or Selling Land or Property"
	lab var index_sdC_otherexp_m "Major Say in Clothing and Other Non-food Expenditures"
	lab var index_sdC_fert_m "Major Say in Her Fertility"
	lab var index_sdC_h24_m "Her Opening a Business"
	lab var index_sdC_h28_m "Her Taking a Loan" 
	lab var index_sdC_h31_m "Her Working Outside of Home" 
	lab var index_sdC_work_m "Participation in Market Work and Running a Business"
	lab var index_sdC_inputs_m "Access to Resources and Inputs"
	lab var index_sdC_tazkira_m "National ID Ownership"
	lab var index_sdC_political_m "Political Participation"
	lab var index_sdC_community_m "Community Participation"
	lab var index_sdC_educ_m "Daughters' Education"
	lab var index_sdC_marriage_m "Daughter's Marriage in Adulthood"
	lab var index_sdC_role_prod_act_m "Economic Opportunities Index"
	lab var index_sdC_social_norms_m "Aspirations for Daughters Index"
	lab var index_sdC_social_capital_m  "Political and Social Involvement Index"
	lab var index_sdC_f_emp_3c_m "Women's Empowerment Index"
	
	lab var index_sdC_all_decisions_w "Women's Decision-making"
	lab var index_sdC_foodexp_w "Major Say in Food Expenditures and What to Cook"
	lab var index_sdC_homeexp_w "Major Say in Home Improvements/Repairs"
	lab var index_sdC_homefin_w "Major Say in Managing Household Finances"
	lab var index_sdC_chischool_w "Major Say in Children's School Attendance"
	lab var index_sdC_chihealth_w "Major Say in Children's Health Seeking"
	lab var index_sdC_chimarr_w "Major Say in Children's Marriage"
	lab var index_sdC_homesale_w "Major Say in Buying or Selling Land or Property"
	lab var index_sdC_otherexp_w "Major Say in Clothing and Other Non-food Expenditures"
	lab var index_sdC_fert_w "Major Say in Her Fertility"
	lab var index_sdC_h24_w "Her Opening a Business"
	lab var index_sdC_h28_w "Her Taking a Loan" 
	lab var index_sdC_h31_w "Her Working Outside of Home" 
	lab var index_sdC_work_w "Participation in Market Work and Running a Business"
	lab var index_sdC_inputs_w "Access to Resources and Inputs"
	lab var index_sdC_tazkira_w "National ID Ownership"
	lab var index_sdC_political_w "Political Participation"
	lab var index_sdC_community_w "Community Participation"
	lab var index_sdC_educ_w "Daughters' Education"
	lab var index_sdC_marriage_w "Daughter's Marriage in Adulthood"
	lab var index_sdC_role_prod_act_w "Economic Opportunities Index"
	lab var index_sdC_social_norms_w "Aspirations for Daughters Index"
	lab var index_sdC_social_capital_w  "Political and Social Involvement Index"
	lab var index_sdC_f_emp_3c_w "Women's Empowerment Index"
	
	lab var below_pov_af "Household Is Below Poverty Line AFN 2,064 (US\textdollar 30.41) pc/Month"
	lab var lstock_yes_cow "Household Owns Cows"
	lab var lstock_yes_goat "Household Owns Goats"
	lab var lstock_yes_chicken "Household Owns Chickens"
	lab var employment_pf "Primary Woman Participates in Income-generating Activities"
	lab var below_pov_af_ALCS "Household Is Below National Poverty Line"
	lab var exp_tot_m_pc "Per Capita Consumption"
	lab var index_sdC_food_sec "Food Security Index "
	label var wealth_score "HH Asset Ownership Index (PCA)"
	lab var wealth_score_sdC "HH Asset Ownership Index"
	label var property_score "Land \& Dwelling Ownership Index (PCA)" 
	lab var access_credit "Can Access Formal Credit if Needed"

	label var tot_hh_income "Total Household Income and Revenues (AFN)"
	label var tot_lstock_revenue 	"Livestock Revenue (AFN)"
	label var tot_crop_revenue  	"Agricultural Revenue (AFN)"
	label var tot_biz_revenue  		"Non-Agricultural Business Revenue (AFN)"
	label var tot_hh_income_ppp "Total Income and Revenues (US\textdollar)"
	label var tot_lstock_revenue_ppp 	"Own Livestock Revenue (US\textdollar)"
	label var tot_crop_revenue_ppp  	"Own Agriculture Revenue (US\textdollar)"
	label var tot_biz_revenue_ppp  		"Own Non-Agricultural Revenue (US\textdollar)"
	label var tot_lstock_revenue_w_ppp "HH Livestock Revenue (US\textdollar)" 	
	label var tot_hh_pay "Paid Labor Income (AFN)"
	label var tot_hh_pay_ppp "Paid Labor Income (US\textdollar)"
	
	lab var psy_indexC_sdC_fl1 "Primary Woman Index"
	lab var psy_indexC_sdC_m_fl1 "Primary Man Index"		
	lab var diarrhea_yes "Diarrhea Rate, Past 2 Weeks"
	lab var vaccines_card_checked "Has Vaccination Card"
	lab var biz_yes "Household Has Other Non-Agricultural Business"
	lab var crop_yes "Household Has an Agriculture Activity"		
	lab var lstock_yes "Household Owns Any Livestock"
	lab var exp_tot_m_pc "Consumption per Capita (AFN), Month"
	lab var exp_tot_m_pc_ppp "Consumption per Capita (US\textdollar), Month"
	lab var exp_tot_m_pc_c_ppp "Consumption per Capita (US\textdollar), Month (Item Winsorization)"
	lab var tot_lstock_value "Value of Livestock (AFN)"
	lab var tot_lstock_value_med "Value of Livestock (AFN) - median based"
	label var tot_lstock_value_ppp "Value of Livestock (US\textdollar)"
	label var tot_lstock_value_med_ppp "Value of Livestock (US\textdollar) - median based"
	
	
	lab var saving_4w 			"HH Savings (AFN), Past 4 Weeks"
	lab var saving_4w_win 		"HH Savings (AFN), Past 4 Weeks - Winsorized"
	lab var saving_4w_ppp 		"HH Savings (US\textdollar), Past 4 Weeks"
	lab var saving_4w_win_ppp 	"HH Savings (US\textdollar), Past 4 Weeks - Winsorized"
	lab var loan	 			"HH Total Outstanding Cash Loans (AFN)"
	lab var loan_win 			"HH Total Outstanding Cash Loans (AFN) - Winsorized"
	lab var loan_ppp 			"HH Outstanding Cash Loans (US\textdollar)"
	lab var loan_win_ppp		"HH Total Outstanding Cash Loans (US\textdollar) - Winsorized"
	lab var saving 				"HH Total Savings (AFN)"
	lab var saving_win 			"HH Total Savings (AFN) - Winsorized"
	lab var saving_ppp 			"HH Total Savings (US\textdollar)"
	lab var saving_win_ppp 		"HH Total Savings (US\textdollar) - Winsorized"
	lab var access_credit 		"HH Members Can Access Formal Credit if Needed"
	lab var fin_index_sdC_fl1 	"Financial Inclusion Index"
	
	lab var fin_knowledge "Primary Woman Knows Different Places to Save"
	lab var saving_account "Anyone in the HH Has Formal Savings Account"
	lab var save_4wdummy "HH Has Saved in the Past 4 Weeks"
	lab var fin_index_sdC_fl1 "Financial Inclusion Index"

	lab var loan_dummy "HH Has Any Kind of Outstanding Loan"
	lab var consumption_loan "HH Has Taken Out a Loan for Consumption Purposes"
	lab var productive_loan "HH Has Taken Out a Loan for Productive Purposes"
	lab var formal_loan_dummy "HH Has an Outstanding Loan From a Formal Institution"	
	
*hr_livestock_4w hr_ownFarming_4w hr_ownBiz_4w hr_oFarm_4w hr_maid_4w hr_outWork_4w hr_salEmp_4w hr_oPaidWork_4w hr_selfemploy_4w
	
	
	foreach group in pf pm {

		label var hr_labor_nohh_4w_`group'  	"Total Time Spent Working"
		label var hr_livestock_4w_`group' 		"Time Spent Working, HH Livestock"
		label var hr_ownFarming_4w_`group'  	"Time Spent Working, HH Agriculture"
		label var hr_ownBiz_4w_`group'  		"Time Spent Working, Own Non-Agriculture Business"
		label var hr_oFarm_4w_`group'  			"Time Spent Working, Agriculture Outside the HH"
		label var hr_maid_4w_`group' 			"Time Spent Working, Maid Services"
		label var hr_outWork_4w_`group' 		"Time Spent Working, Non-Agriculture Outside the HH"
		label var hr_salEmp_4w_`group' 			"Time Spent Working, Salaried or Formal Employment"
		label var hr_oPaidWork_4w_`group'  		"Time Spent Working, Other Paid Work"
		label var labor_particip_`group' 		"Labor Participation"	
		
		label var hr_labor_nohh_4w_`group'  	"Total"
		label var hr_livestock_4w_`group' 		"HH Livestock"
		label var hr_ownFarming_4w_`group'  	"HH Agriculture"
		label var hr_ownBiz_4w_`group'  		"HH Non-Agricultural Business"
		label var hr_oFarm_4w_`group'  			"Casual Labor: Agricultural"
		label var hr_maid_4w_`group' 			"Casual Labor: Maid Services"
		label var hr_outWork_4w_`group' 		"Casual Labor: Non-Agricultural"
		label var hr_salEmp_4w_`group' 			"Salaried or Formal Employment"
		label var hr_oPaidWork_4w_`group'  		"Other Paid Work"
		label var labor_particip_`group' 		"Labor Participation"	
	
	}



	rename  (psy_indexC_sdC_m_fl1 lcortisol_clean_m lcortisol_clean_m_inv satisf_z_sdC_m_fl1 hap_z_sdC_m_fl1 cesd_z_sdC_m_fl1 rses_z_sdC_m_fl1 cohen_z_sdC_m_fl1 trust_z_sdC_m_fl1 lotr_z_sdC_m_fl1) ///
			(psy_indexC_sdC_fl1_m lcortisol_clean_m lcortisol_clean_inv_m satisf_z_sdC_fl1_m hap_z_sdC_fl1_m cesd_z_sdC_fl1_m rses_z_sdC_fl1_m cohen_z_sdC_fl1_m trust_z_sdC_fl1_m lotr_z_sdC_fl1_m)

			
	lab var psy_indexC_sdC_fl1 "Psychological Well-Being Index"
	lab var lcortisol_clean "Log Cortisol (with Controls)"
	lab var satisf_z_sdC_fl1 "Life Satisfaction (WVS) Index"
	lab var hap_z_sdC_fl1 "Happiness (WVS) Index"
	lab var cesd_z_sdC_fl1 "Depression (CESD) Index (Negatively Coded)"
	lab var rses_z_sdC_fl1 "Self-esteem (Rosenberg) Index"
	lab var cohen_z_sdC_fl1  "Stress (Cohen) Index (Negatively Coded)"	
	lab var trust_z_sdC_fl1 "Trust (WVS) Index"
	lab var lotr_z_sdC_fl1 "Life Orientation Test (LOT-R) Index"
		
	lab var psy_indexC_sdC_fl1_m "Psychological Well-Being Index"
	lab var lcortisol_clean_m "Log Cortisol (with Controls)"
	lab var satisf_z_sdC_fl1_m "Life Satisfaction (WVS) Index"
	lab var hap_z_sdC_fl1_m "Happiness (WVS) Index"
	lab var cesd_z_sdC_fl1_m "Depression (CESD) Index (Negatively Coded)"
	lab var rses_z_sdC_fl1_m "Self-esteem (Rosenberg) Index"
	lab var cohen_z_sdC_fl1_m  "Stress (Cohen) Index (Negatively Coded)"	
	lab var trust_z_sdC_fl1_m "Trust (WVS) Index"
	lab var lotr_z_sdC_fl1_m "Life Orientation Test (LOT-R) Index"
	
	label var c14_7 "Everyone in the Household Regularly Eats at Least Two Meals a Day"
	label var c14_3_ac "No Adult Skips or Cuts the Size of Meals"
	label var c14_5_ac "No Child Skips or Cuts the Size of Meals"
	
	
	lab var lstock_rev_sales_ppp "Revenues from Sales of Livestock (US\textdollar)"
	lab var prod_revenue_yogurt_ppp "Revenues from Yogurt Production (US\textdollar)" 
	lab var prod_revenue_milk_ppp "Revenues from Milk Production (US\textdollar)"
	lab var prod_revenue_egg_ppp "Revenues from Egg Production (US\textdollar)"
	lab var prod_revenue_butter_ppp "Revenues from Butter Production (US\textdollar)"
	
	
	lab var exp_tot_m_pc_w_ppp 		 "Consumption per Capita (US\textdollar), Month" 
	
	lab var h1_ac "What to Cook on a Daily Basis"
	lab var h2_ac "Buying Groceries"
	lab var h3_ac "Buying Clothing"
	lab var h4_ac "Buying Expensive Items (i.e., Carpet, Jewelry)"
	lab var h5_ac "Buying Small Items (i.e., Detergent, Soap)"
	lab var h6_ac "Buying or Selling Land or Property"
	lab var h7_ac "Managing Household Finances"
	lab var h8_ac "Making Home Improvements/Repairs"
	
	lab var h9_ac "Whether Your Daughter Should Attend School"
	lab var h10_ac "Whether Your Son Should Attend School"
	lab var h11_ac "Marriage of Daughters"
	lab var h12_ac "Marriage of Sons"
	lab var h13_ac "Consulting a Doctor When Your Child Is Ill"
	
	lab var h14_ac "How Many Children to Have"
	lab var h28_ac "If Primary Woman Wanted to Take out a Loan"
	lab var h31_ac "If Primary Woman Wanted to Pursue a Job outside the Home"
	lab var h24_ac "If Primary Woman Wanted to Open a New Business"
	lab var h30 "Primary Woman Has Financial Assets in Her Name and Separate from Other HH Members"
	lab var mobile_yes_pf "Primary Woman Has a Mobile Phone"
	lab var loan_yes_pf "Primary Woman Has a Loan"
	
	*lab var did_paidwork "Primary Woman Did Any Type of Paid Work in the Past 7 Days"
	*lab var employment "Primary Woman Is in Paid Employment or Self Employment"
	lab var did_labor_pf "Primary Woman Participates in Market Work"
	lab var owner_manager_pf "Primary Woman Is Owner or Manager of an HH Non-Agricultural Business"
	
	lab var s21 "Primary Woman Has a Tazkira ID Card"
	lab var s10 "Primary Woman Belongs to a Political Party"
	lab var n1 "Primary Woman Attended Any CDC/Village Leaders Meetings, Past 12 Months"
	lab var n2 "Primary Woman Approached the Village Leader about Her Needs or Village Issues"
	lab var voted "Primary Woman voted in the last election (presidential or provincial council)"
	lab var lstock_yes_sheep "Household Owns Sheep"
	lab var hr_oWork_4w_pf "Other Work" 
	lab var hr_oWork_4w_pm "Other Work" 
	
	lab var psy_indexC_sdC_fl1 		"PW Psychological Well-Being Index"
	lab var psy_indexC_sdC_fl1_m 	"PM Psychological Well-Being Index"
	lab var hr_labor_nohh_4w_pf 	"PW Total Time Spent Working"
	lab var hr_labor_nohh_4w_pm 	"PM Total Time Spent Working "
	
	
	* Fix labels and correct denominator
	loc element_vars "r80 r81 r13 r54 r1 r3 r9 r11 r16 r24"
	
	loc r80_l "Aware of the CHA TUP project"
	loc r81_l "Received any of the project's benefits"
	loc r13_l "Received livestock"
	loc r54_l "Received food supplement"
	loc r1_l "Received the animal rearing training"
	loc r3_l "Received the monthly stipend support"
	loc r9_l "Attended the health and hygiene training"
	loc r11_l "Attended the training for Saving and Livelihood"
	loc r16_l "Visited by CHA project staff"
	loc r24_l "Received support to enroll children in school"
	
	foreach var of local element_vars {
		lab var `var' "``var'_l'"
		if !inlist("`var'", "r81") { // This is only valid if r80 == 1
			di "`var' this works"
			replace `var'=0 if mi(`var')
		}
	}	
	
lab var employment_pf "Primary Woman Participates in Market Work"
	
* Save dataset will all the vars
	if	`c(stata_version)'>=14	{
		saveold "${data_for_analysis_fl1}", replace v(13)
	}
	else {
		save "${data_for_analysis_fl1}", replace
	}
	
* Save dataset with vars used for the IE Main paper
	* Drop unnecesary variables
		keep hhid ultra_poor treatment PRA_lottery pweight pweight_CWR WealthRankingCategory_v	*_bl ///
		`consumption_vars' `entrep_fl1' `entrep_bl' `foodsec_vars' `fin_vars' ///
		`hhassets_vars' `empowerment_vars' `polinvolvement_vars' tot_hh_pay ///
		`assets_vars' `health_vars' tot_lstock_revenue tot_lstock_earn tot_crop_revenue ///
		tot_biz_revenue tot_biz_earn *_w tot_hh_income bl_*_thirds bl_*_1 bl_*_2 ///
		bl_*_3 *_ppp psy_indexC_sdC_fl1_m lcortisol_clean_m lcortisol_clean_inv_m ///
		satisf_z_sdC_fl1_m hap_z_sdC_fl1_m cesd_z_sdC_fl1_m rses_z_sdC_fl1_m ///
		cohen_z_sdC_fl1_m trust_z_sdC_fl1_m lotr_z_sdC_fl1_m satisf_z_sdC_fl1 ///
		satisf_score_fl1 i5 cesd_z_sdC_fl1 cesd_ts cesd_md i7_origin i10_origin ///
		i11_origin i12_origin i16_origin  i23_origin i25_origin trust_z_sdC_fl1 ///
		trust_score_fl1 i26_origin hap_z_sdC_fl1 hap_score_fl1 i27_origin ///
		lotr_z_sdC_fl1 lotr_score_fl1 i28_a_origin i28_c i28_d_origin i28_g ///
		i28_i i28_j_origin i28_a_origin i28_b i28_c i28_d i28_e i28_f i28_g ///
		i28_h i28_i i28_j_origin rses_z_sdC_fl1 rses_score_fl1 i34_origin ///
		i35_origin i37_origin i38 i39_origin i43 cohen_z_sdC_fl1 cohen_score_fl1 ///
		oldi44 oldi45 oldi46 oldi47 lcortisol_clean lcortisol lcortisol_clean_w ///
		lcortisol_w psy_indexC_sdC_fl1 lcortisol_clean lcortisol_clean_inv ///
		satisf_z_sdC_fl1 hap_z_sdC_fl1 cesd_z_sdC_fl1 rses_z_sdC_fl1 ///
		cohen_z_sdC_fl1 trust_z_sdC_fl1 lotr_z_sdC_fl1 hr_*_4w_* labor_particip_* ///
		employment_* crop_yes biz_yes r80 r81 r13 r54 r1 r3 r9 r11 r16 r24 ///
		hh_head_gender lstock_rev_sales  prod_revenue_yogurt prod_revenue_milk ///
		prod_revenue_egg prod_revenue_butter did_labor_pm hr_oWork_4w_pf hr_oWork_4w_pm


	if	`c(stata_version)'>=14	{
		saveold "${data_for_analysis_fl1_IEpaper}", replace v(13)
	}
	else {
		save "${data_for_analysis_fl1_IEpaper}", replace
	}

	
