/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	August 8, 2023
Last udpate on: 

Written by:  	Yulia Belyakova

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates psych well-being variables

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

* Inputs 
	gl all_HH_nopii_fl1 					"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"	
	gl all_HH_nopii_bl 						"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	gl f_empowerment_all_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_all_bl.dta"          // all indicators, intermediate 

* Outputs 	
	gl f_empowerment_bl_flsample  			"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl_flsample.dta" // follow-up sample 
	gl f_empowerment_pashto_bl_flsample		"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_pashto_bl_flsample.dta" // pashto-standardized fl1 sample 
	
	* Select standartization 
	global normvar control // pashto 

	
	use "${f_empowerment_all_bl}", clear 

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) keep(1 3) nogen

* Merge on follow-up data to compute the indices for the follow-up sample only 
	merge 1:1 hhid using "${all_HH_nopii_fl1}", keepusing(ultra_poor) keep(1 3)
	gen follow_up = _merge == 3
	drop _merge
	
* Merge on follow-up indicator for whether the HH had a young daughter at follow-up 	
preserve 	
	use "${all_HH_nopii_fl1}", clear 
		keep hhid i2_d
		gen dau_fl1 = 1 if !mi(i2_d)
		replace dau_fl1 = 0 if mi(dau_fl1)
		
		tempfile dau_fl1
		save `dau_fl1'
restore	
	
	merge 1:1 hhid using "`dau_fl1'", keep(1 3) nogen
	
	tempfile we_indicators
	save `we_indicators'

********************************************************************************
	** Construction of indices for FOLLOW-UP SAMPLE 
********************************************************************************
********************************************************************************
	** Part 1: Household expenses
********************************************************************************
	
/* 1. Major Say in Food Expenditures and What to Cook (2):

	h1: What to cook on a daily basis
	h2: Buying groceries */
	
* Local for survey vars related 
	loc foodexp_survey_vars "h1 h2"
	loc foodexp_vars "h1_ac h2_ac"
	loc foodexp_vars_r "h1_ac_r h2_ac_r"
	tabm `foodexp_survey_vars', m
	
/* 2. Major Say in Home Improvements/Repairs (1):

	h8: Making home improvements/repair
*/
	loc homeexp_survey_vars "h8"
	loc homeexp_vars "h8_ac"
	loc homeexp_vars_r "h8_ac_r"
	tab `homeexp_survey_vars', m

/* 3. Major Say in Managing Household Finances (1):
		
	h7: Managing household finances
*/
	loc homefin_survey_vars "h7"
	loc homefin_vars "h7_ac"
	loc homefin_vars_r "h7_ac_r"
	tab `homefin_survey_vars', m

/* 4. Major Say in Children's School Attendance (2):

	h9: Whether your daughter should attend school
	h10: Whether your son should attend school
*/
	loc chischool_survey_vars "h9 h10"
	loc chischool_vars "h9_ac h10_ac"
	loc chischool_vars_r "h9_ac_r h10_ac_r"
	tabm `chischool_survey_vars', m

/* 5. Major Say in Children's Health Seeking (1):

	h13: Consulting a doctor when your child is ill
*/
	loc chihealth_survey_vars "h13"
	loc chihealth_vars "h13_ac"
	loc chihealth_vars_r "h13_ac_r"	
	tab `chihealth_survey_vars', m

/* 6. Major Say in Children's Marriage (2):

	h11: Marriage of daughters
	h12: Marriage of sons
*/
	loc chimarr_survey_vars "h11 h12"
	loc chimarr_vars "h11_ac h12_ac"
	loc chimarr_vars_r "h11_ac_r h12_ac_r"
	tabm `chimarr_survey_vars', m

/* 7. Major Say in Buying or Selling Land or Property (1):

	h6: Buying or selling land or property
*/
	loc homesale_survey_vars "h6"
	loc homesale_vars "h6_ac"
	loc homesale_vars_r "h6_ac_r"
	tab `homesale_survey_vars', m

/* 8. Major Say in Other Non-food Expenditures (3):

	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
*/
	loc otherexp_survey_vars "h3 h4 h5"
	loc otherexp_vars "h3_ac h4_ac h5_ac"
	loc otherexp_vars_r "h3_ac_r h4_ac_r h5_ac_r"
	tabm `otherexp_survey_vars', m

/* 9. Major Say in Her Fertility (1):

		h14: How many children to have
*/
	loc fert_survey_vars "h14"
	loc fert_vars "h14_ac"
	loc fert_vars_r "h14_ac_r"
	tab `fert_survey_vars', m

/* 10. Major Say in Her Taking a Loan, Opening a Business, and Working Outside of Home (3):

	h28: If you wanted to take out a loan
	h31: If you wanted to pursue a job outside the home
	h24: If you wanted to open a new business
*/	
	loc h24_survey_vars "h24"
	loc h24_vars "h24_ac"
	loc h24_vars_r "h24_ac_r"
	loc h28_survey_vars "h28"
	loc h28_vars "h28_ac"
	loc h28_vars_r "h28_ac_r"
	loc h31_survey_vars "h31"
	loc h31_vars "h31_ac"
	loc h31_vars_r "h31_ac_r"
	
	loc decide_survey_vars `foodexp_survey_vars' `homeexp_survey_vars' `homefin_survey_vars' `homesale_survey_vars' `chischool_survey_vars' `chihealth_survey_vars' `chimarr_survey_vars' `otherexp_survey_vars' `fert_survey_vars' 	`h24_survey_vars' `h28_survey_vars' `h31_survey_vars'
	
********************************************************************************
	** Part 4: Taking advantage of economic opportunities
********************************************************************************

/* Includes:
	Engaged in productive activities
	Engaged in paid productive activities 
	k24: Primary female is owner or manager of a HH non-agricultural bussiness */
	
	loc work_vars owner_manager_pf did_labor_pf
	loc inputs_vars h30
	
********************************************************************************
	** Part 5: Aspirations for daughters / Social norms
********************************************************************************
/* Includes:
	i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
	i2_d: How will this level of education help ${name_youngest_daughter}?
	i4_d: At what age would you like to see ${name_youngest_daughter} marry? 
	School-age girls are enrolled in school */
	
	loc educ_vars ed_level_yr_d ed_help_d
	loc marriage_vars age_marriage_d
	
********************************************************************************
	** Part 6: Social Capital/Voice outside of the HH = Political involvement Index
********************************************************************************

/* Includes:
	s21: Not in Baseline 
	s10: Not in Baseline
	s12: Not in Baseline 
	s13: Not in Baseline
	n1: Attended village meetings 
	n2: Approached village leaders about village issue */

* Local for survey vars related to political involment
	loc community_vars "n1 n2" 
	
** Keep follow-up 1 sample 
	keep if follow_up == 1 

* Decisionmaking
	loc foodexp_l		"Food Expenditures and What to Cook"
	loc homeexp_l 		"Home Improvements/Repairs"
	loc homefin_l 		"Managing Household Finances"
	loc chischool_l 	"Children's School Attendance"
	loc chihealth_l 	"Children's Health Seeking"
	loc chimarr_l 		"Children's Marriage"
	loc homesale_l		"Buying or Selling Land or Property"
	loc otherexp_l 		"Other Non-food Expenditures"
	loc fert_l 			"Her Fertility"
	loc h28_l 			"Her Taking a Loan"
	loc h31_l 			"Her Working Outside of Home"
	loc h24_l 			"Her Opening a Business"
	
	* Econ opp 
	loc work_l "Participation in Market Work and Running a Business"
	loc inputs_l "Access to Resources and Inputs"
	
	* Political and Social Capital
	loc community_l "Community Participation"
	
	* Aspirations 
	loc educ_l "Daughters' Education"
	loc marriage_l "Daughter's Marriage in Adulthood"

	gl all 		"foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31  work inputs community"
	gl all_dau 	"foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31  work inputs community educ marriage"
	
	keep if ultra_poor == 1

	* Drop if there is no LHH in the household
	drop if  respondent_gender == 1
	
	* Generate indices for the overall control group 
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index' "``index'_l' Index sd(${normvar})"	
		}	
	
	* Decisionmaking index
		loc decide_index "index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert index_sdC_h24 index_sdC_h28 index_sdC_h31"
		egen index_sdC_all_decisions = weightave(`decide_index'), normby(${normvar})
		lab var index_sdC_all_decisions "Decision-making Index sd(${normvar})"
		
	* Econ Opp Index
		loc econ_opp_index "index_sdC_work index_sdC_inputs"
		egen index_sdC_role_prod_act = weightave(`econ_opp_index'), normby(${normvar})
		lab var index_sdC_role_prod_act "Economic Opportunities Index sd(${normvar})"
		
	* Social Capital Index
		loc soc_cap_index "index_sdC_community"
		gen index_sdC_social_capital = index_sdC_community
		lab var index_sdC_social_capital "Social Involvement Index sd(${normvar})"		
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital)
		loc all_index_3 "index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital"
		egen index_sdC_f_empowerment_3c = weightave(`all_index_3'), normby(${normvar})
		lab var index_sdC_f_empowerment_3c "Women's Empowerment Index sd(${normvar}) (3 dimensions)"
			
**************** Create index Z score to be comparable with Banerjee et al. We take the full index although it does not necessarily has the same variables as in Banerjee ***************** 
*Start directly from the single variables, same as Banerjee 
	loc decide_index 		"h1_ac h2_ac h8_ac h7_ac h9_ac h10_ac h13_ac h11_ac h12_ac h6_ac h3_ac h4_ac h5_ac h14_ac h24_ac h28_ac h31_ac"
	loc econ_opp_index 		"owner_manager_pf did_labor_pf h30"
	loc soc_cap_index 		"n1 n2"
	loc soc_norms_index 	"n1 n2"
			
	* For these, computing index similarly as in Banerjee et al. (2015) science paper. Simple Z score
			foreach var in `decide_index' `econ_opp_index' `soc_cap_index' {
gen `var'_Z = .
			 sum `var' if treatment==0 
			if `r(N)' > 0 {
				replace `var'_Z = (`var' - `r(mean)') / `r(sd)' 
	}
}

	loc decide_index_Z  		"h1_ac_Z  h2_ac_Z  h8_ac_Z  h7_ac_Z  h9_ac_Z  h10_ac_Z  h13_ac_Z  h11_ac_Z  h12_ac_Z  h6_ac_Z  h3_ac_Z  h4_ac_Z  h5_ac_Z  h14_ac_Z  h24_ac_Z  h28_ac_Z  h31_ac_Z "
	loc econ_opp_index_Z 		"owner_manager_pf_Z did_labor_pf_Z h30_Z"
	loc soc_cap_index_Z 		"n1_Z n2_Z"

* Decisionmaking index
	egen index_Z_all_decisions = rowmean(`decide_index_Z')
	lab var index_Z_all_decisions "Women's Decisionmaking Index (Z score)"
	
* Econ Opp Index
	egen index_Z_role_prod_act = rowmean(`econ_opp_index_Z')
	lab var index_Z_role_prod_act "Economic Opportunities Index (Z score)"
	

* Social Capital Index
	egen index_Z_social_capital = rowmean(`soc_cap_index_Z')
	lab var index_Z_social_capital "Social Capital Index (Z score)"
	

	*Standardization
	foreach var in index_Z_all_decisions index_Z_role_prod_act index_Z_social_capital {
			 sum `var' if treatment==0 
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
	}
}	
	
*  Decisionmaking index +  Econ Opp Index
	egen index_Z_decisions_eco = rowmean(index_Z_all_decisions index_Z_role_prod_act)
	lab var index_Z_decisions_eco "Decision + Economic Opportunities Index (Z score)"


*  Decisionmaking index +  Econ Opp Index + Social Capital Index
	egen index_Z_f_emp_3c = rowmean(index_Z_all_decisions index_Z_role_prod_act index_Z_social_capital)
	lab var index_Z_f_emp_3c "Women's Empowerment Index (Z score) (3 dimensions)"	
	
	
*Standardization	
foreach var in index_Z_decisions_eco index_Z_f_emp_3c  {
			 sum `var' if treatment==0 
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
		}
	}

*******************************************************************************
* Men-headed HHs 	
*******************************************************************************

preserve 
	keep if hh_head_gender == 2 // keep men-headed HHs only 
	
	foreach index in $all_dau {
		display "`index'"
		des ``index'_vars'
		egen index_sdC_`index'_m = weightave(``index'_vars'), normby(${normvar})
		lab var index_sdC_`index'_m "``index'_l' Index sd(${normvar}) - Men-headed HH"	
	}	
		
* Decisionmaking index
	loc decide_index_m "index_sdC_foodexp_m index_sdC_homeexp_m index_sdC_homefin_m index_sdC_chischool_m index_sdC_chihealth_m index_sdC_chimarr_m index_sdC_homesale_m index_sdC_otherexp_m index_sdC_fert_m index_sdC_h24_m index_sdC_h28_m index_sdC_h31_m"
	egen index_sdC_all_decisions_m = weightave(`decide_index_m'), normby(${normvar})
	lab var index_sdC_all_decisions_m "Women's Decisionmaking Index sd(${normvar}) - Men-headed HH"			
	
* Econ Opp Index
	loc econ_opp_index_m "index_sdC_work_m index_sdC_inputs_m"
	egen index_sdC_role_prod_act_m = weightave(`econ_opp_index_m'), normby(${normvar})
	lab var index_sdC_role_prod_act_m "Economic Opportunities Index sd(${normvar}) - Men-headed HH"
	
* Social Capital Index
	loc soc_cap_index_m "index_sdC_community_m"
	egen index_sdC_social_capital_m = weightave(`soc_cap_index_m'), normby(${normvar})
	lab var index_sdC_social_capital_m "Social Involvement Index sd(${normvar}) - Men-headed HH"	

* Social Norms Index
	loc soc_norms_index_m "index_sdC_educ_m index_sdC_marriage_m"
	egen index_sdC_social_norms_m = weightave(`soc_norms_index_m'), normby(${normvar})
	lab var index_sdC_social_norms_m "Aspirations for Daughters Index sd(${normvar}) - Men-headed HH"
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital) //Social Norm only to be added for a subsample
	loc all_index3_m "index_sdC_all_decisions_m index_sdC_role_prod_act_m index_sdC_social_capital_m"
	egen index_sdC_f_empowerment_3c_m = weightave(`all_index3_m'), normby(${normvar})
	lab var index_sdC_f_empowerment_3c_m "Women's Empowerment Index sd(${normvar}) (3 dimensions) - Men-headed HH"		
		
		tempfile malehead
		save	`malehead'
restore
	
	merge 1:1 hhid using `malehead', assert(1 3) nogen		
	
		
	* Merging treatment and PRA
		merge m:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) assert(2 3) keep(1 3) nogen		
	
	
	
* Save data	
if "$normvar" == "pashto" {
	if	`c(stata_version)'>=14	{
			saveold "${f_empowerment_pashto_bl_flsample}", replace v(13) 
		}
		else {
			save "${f_empowerment_pashto_bl_flsample}", replace
		}
} 	
	
if "$normvar" == "control" {
		if	`c(stata_version)'>=14	{
			saveold "${f_empowerment_bl_flsample}", replace v(13) 
		}
		else {
			save "${f_empowerment_bl_flsample}", replace
		}		
}							

	* Generate indices for each individual ethnicity standardizing by the control group for that ethnicity
	local i = 1
	
	foreach ethnicity in pashto dari uzbek turkmen arabic other {
		foreach index in $all {
			
			if "$normvar" == "pashto" {
				use "${f_empowerment_pashto_bl_flsample}", clear 
			}
	
			if "$normvar" == "control" {
				use  "${f_empowerment_bl_flsample}", clear 
			}
																																						
			* Keep the ethnicity for which we are estimating the index
			keep if `ethnicity' == 1 
			
			* Define the variable by which we normalize
			global normvar_ethnic `ethnicity'_control
			
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_`i' = weightave(``index'_vars'), normby(${normvar_ethnic})
			lab var index_sdC_`index'_`i' "``index'_l' Index sd(${normvar_ethnic})"
			
			keep hhid index_sdC_`index'_`i' 
			tempfile index_sdC_`index'_`i'
			save	`index_sdC_`index'_`i''
		}
			local i = `i' + 1 
	}	
	
			if "$normvar" == "pashto" {
				use "${f_empowerment_pashto_bl_flsample}", clear 
			}
	
			if "$normvar" == "control" {
				use  "${f_empowerment_bl_flsample}", clear 
			}
			
			foreach index in $all {
				forval i = 1/6 {
				merge 1:1 hhid using "`index_sdC_`index'_`i''", assert(1 3) nogen
				}
			}
	
	local i = 1
	
	foreach ethnicity in pashto dari uzbek turkmen arabic other {

		* Define the variable by which we normalize
		global normvar_ethnic `ethnicity'_control
			
	* Decisionmaking index
		loc decide_index "index_sdC_foodexp_`i' index_sdC_homeexp_`i' index_sdC_homefin_`i' index_sdC_chischool_`i' index_sdC_chihealth_`i' index_sdC_chimarr_`i' index_sdC_homesale_`i' index_sdC_otherexp_`i' index_sdC_fert_`i' index_sdC_h24_`i' index_sdC_h28_`i' index_sdC_h31_`i'"
		egen index_sdC_all_decisions_`i' = weightave(`decide_index'), normby(${normvar_ethnic})
		lab var index_sdC_all_decisions_`i' "Women's Decisionmaking Index sd(${normvar_ethnic})"
		
	* Econ Opp Index -- all ethnicities 
	if "`ethnicity'" != "arabic" {
		loc econ_opp_index "index_sdC_work_`i' index_sdC_inputs_`i'"
		egen index_sdC_role_prod_act_`i' = weightave(`econ_opp_index'), normby(${normvar_ethnic})
		lab var index_sdC_role_prod_act_`i' "Economic Opportunities Index sd(${normvar_ethnic})"
	}
	
	* Econ Opp Index -- Arabic ONLY	
	if "`ethnicity'" == "arabic" {
		gen index_sdC_role_prod_act_`i' = index_sdC_work_`i'
		lab var index_sdC_role_prod_act_`i' "Economic Opportunities Index sd(${normvar_ethnic})"
	}
		
	* Social Capital Index
		loc soc_cap_index "index_sdC_community_`i'"
		gen index_sdC_social_capital_`i' = index_sdC_community_`i'
		lab var index_sdC_social_capital_`i' "Social Involvement Index sd(${normvar_ethnic})"
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital)
		loc all_index_3c "index_sdC_all_decisions_`i' index_sdC_role_prod_act_`i' index_sdC_social_capital_`i'"
		egen index_sdC_f_empowerment_3c_`i' = weightave(`all_index_3c'), normby(${normvar_ethnic})
		lab var index_sdC_f_empowerment_3c_`i' "Women's Empowerment Index sd(${normvar_ethnic}) (3 dimensions))"
			
		local i = `i' + 1 
	}
	
* Create pooled versions (i.e., all ethnicities in one variable) of the index to gain power (as in Banerjee et al.)
	* Create indices
		foreach index in $all all_decisions role_prod_act social_capital f_empowerment_3c {
			local index_sdC_`index'_lab : var lab index_sdC_`index'_1
			local index_sdC_`index'_lab : subinstr local index_sdC_`index'_lab " sd(pashto_control)" "", all

			* Use ", m" egen option so that the index goes to missing if all components are missing 
			egen index_sdC_`index'_p = rowtotal(index_sdC_`index'_1 index_sdC_`index'_2 index_sdC_`index'_3 index_sdC_`index'_4 index_sdC_`index'_5), m	
			lab var index_sdC_`index'_p "`index_sdC_`index'_lab' - pooled"	
		}	
		
* Save data	
if "$normvar" == "pashto" {
	if	`c(stata_version)'>=14	{
			saveold "${f_empowerment_pashto_bl_flsample}", replace v(13) 
		}
		else {
			save "${f_empowerment_pashto_bl_flsample}", replace
		}
}
if "$normvar" == "control" {
	if	`c(stata_version)'>=14	{
			saveold "${f_empowerment_bl_flsample}", replace v(13) 
		}
		else {
			save "${f_empowerment_bl_flsample}", replace
		}
}	

	
********************************************************************************
	** Construction of indices for FOLLOW-UP SAMPLE
	**** those that had a daughter at follow-up 
********************************************************************************
	use "`we_indicators'", clear 
	
	keep if ultra_poor == 1 & dau_fl1 == 1

	* Drop if there is no LHH in the household
	drop if  respondent_gender == 1
	
	* Generate indices for the overall control group 
		foreach index in $all_dau {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_dau = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_dau "``index'_l' Index sd(${normvar}) - HH with daughters"	
		}	
		
	* Decisionmaking index
		loc decide_index_dau "index_sdC_foodexp_dau index_sdC_homeexp_dau index_sdC_homefin_dau index_sdC_chischool_dau index_sdC_chihealth_dau index_sdC_chimarr_dau index_sdC_homesale_dau index_sdC_otherexp_dau index_sdC_fert_dau index_sdC_h24_dau index_sdC_h28_dau index_sdC_h31_dau"
		egen index_sdC_all_decisions_dau = weightave(`decide_index_dau'), normby(${normvar})
		lab var index_sdC_all_decisions_dau "Decision-making Index sd(${normvar})"
		
	* Econ Opp Index
		loc econ_opp_index_dau "index_sdC_work_dau index_sdC_inputs_dau"
		egen index_sdC_role_prod_act_dau = weightave(`econ_opp_index_dau'), normby(${normvar})
		lab var index_sdC_role_prod_act_dau "Economic Opportunities Index sd(${normvar})"
		
	* Social Capital Index
		loc soc_cap_index_dau "index_sdC_community_dau"
		gen index_sdC_social_capital_dau = index_sdC_community_dau
		lab var index_sdC_social_capital_dau "Social Involvement Index sd(${normvar})"
		
	* Social Norms Index
		loc soc_norms_index_dau "index_sdC_educ_dau index_sdC_marriage_dau"
		egen index_sdC_social_norms_dau = weightave(`soc_norms_index_dau'), normby(${normvar})
		lab var index_sdC_social_norms_dau "Aspirations for Daughters Index sd(${normvar})"	
					
	* Total index (3 dimensions: decisionmaking, econ opp, social capital)
		loc all_index_3_dau "index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_capital_dau"
		egen index_sdC_f_emp_dau_3c = weightave(`all_index_3_dau'), normby(${normvar})
		lab var index_sdC_f_emp_dau_3c "Women's Empowerment Index sd(${normvar}) (3 dimensions)"

	* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
		loc all_index_dau "index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_capital_dau index_sdC_social_norms_dau"
		egen index_sdC_f_emp_dau = weightave(`all_index_dau'), normby(${normvar})
		lab var index_sdC_f_emp_dau "Women's Empowerment Index sd(${normvar}) (4 dimensions)"			
		
	* Merging treatment and PRA
		merge m:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) assert(2 3) keep(1 3) nogen	
		
		lab var index_sdC_all_decisions_dau "Decision-Making Index"
		lab var index_sdC_role_prod_act_dau "Economic Opportunities Index"
		lab var index_sdC_social_norms_dau "Aspirations for Daughters Index"
		lab var index_sdC_social_capital_dau "Social Involvement Index"
		lab var index_sdC_f_emp_dau_3c "Women's Empowerment Index (3 dimensions)"
		lab var index_sdC_f_emp_dau "Women's Empowerment Index (4 dimensions)"
		
		keep hhid 	*dau* 
		
	tempfile we_aspiration_daughter_fl1
	save `we_aspiration_daughter_fl1'

	if "$normvar" == "pashto" {
		use "${f_empowerment_pashto_bl_flsample}", clear 
		
		merge 1:1 hhid using `we_aspiration_daughter_fl1', assert(1 3) nogen 
	}

	if "$normvar" == "control" {
		use  "${f_empowerment_bl_flsample}", clear 
	
		merge 1:1 hhid using `we_aspiration_daughter_fl1', assert(1 3) nogen 
	}
		
* Save data	
if "$normvar" == "pashto" {
	if	`c(stata_version)'>=14	{			
			saveold "${f_empowerment_pashto_bl_flsample}", replace v(13) 
		}
		else {
			save "${f_empowerment_pashto_bl_flsample}", replace
		}
} 	
	
if "$normvar" == "control" {
		if	`c(stata_version)'>=14	{			
			saveold "${f_empowerment_bl_flsample}", replace v(13) 
		}
		else {
			save "${f_empowerment_bl_flsample}", replace
		}		
}	