/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Apr 23, 2019
Last udpate on: Apr 23, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates female empowerment index based on discussion with Lupe and 
				in the following file: TUP_Afghanistan/Data Analysis/Others/Empowerment/female_empowerment_indicators_23Apr2019_adjusted2available.xlsx

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl profile_info					"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl mobile_phone_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/v_mobile_fl1.dta"
	gl loans_fl1 					"${TUP_DB}/Followup_1/DataSets/Intermediate/m_b_loans_fl1.dta"
	gl schooling_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"
	gl time_activities_ses 			"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
	gl businesses_fl1	 			"${TUP_DB}/Followup_1/DataSets/Intermediate/k_d_nonagbiz_fl1.dta"
	gl f_empowerment_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta"
	gl f_empowerment_bl_flsample  	"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl_flsample.dta" // follow-up sample 
	gl data_for_analysis_bl			"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	
* Outputs
	gl f_empowerment_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta"

********************************************************************************
	** Part 0: Prepare dataset
********************************************************************************

use "${all_HH_nopii_fl1}", clear

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) assert(2 3) keep(3) nogen
	/*
	   
	    Result                           # of obs.
		-----------------------------------------
		not matched                           404
			from master                         0  (_merge==1)
			from using                        404  (_merge==2) // HHs for which we didn't collect follow-up (mostly targeting households i.e. treatment == .)

		matched                             2,495  (_merge==3)
		-----------------------------------------
	*/

* Control dummy
	gen 	control = treatment==0
	replace control = 0 if mi(treatment)
	lab var control "HH is part of control group"
	
* Indicator for each ethnicity to standardize by	
	* Pashto dummy
		gen 	pashto = a10 == 2
		lab var pashto "HH is Pashto speaking"

	* Dari dummy
		gen 	dari = a10 == 1
		lab var dari "HH is Dari speaking"	
		
	* Uzbek dummy
		gen 	uzbek = a10 == 3
		lab var uzbek "HH is Uzbek speaking"	
		
	* Turkmen dummy
		gen 	turkmen = a10 == 4
		lab var turkmen "HH is Turkmen speaking"
		
	* Arabic dummy [N=78]	
		gen 	arabic = a10 == .n & !inlist(a10_o,"هزاره گی")
		lab var arabic "HH is Arabic speaking"
		
	* Hazar dummy [do not estimate the index since the only hazar HH is NUP]
		gen 	hazar = inlist(a10_o,"هزاره گی")
		lab var hazar "HH is Hazar speaking"

* Create an indicator for the control HHs for each ethnicity 	
	foreach ethnicity in pashto dari uzbek turkmen arabic hazar {
		gen `ethnicity'_control = (`ethnicity' == 1 & control == 1)
		lab var `ethnicity'_control "`ethnicity' control group"
	}	

********************************************************************************
	** Part 1: Household expenses
********************************************************************************
	
/* 1. Major Say in Food Expenditures and What to Cook (2):

	h1: What to cook on a daily basis
	h2: Buying groceries */
	
* Local for survey vars related 
	loc foodexp_survey_vars "h1 h2"
	loc foodexp_vars "h1_ac h2_ac"
	loc foodexp_vars_r "h1_ac_r h2_ac_r"
	tabm `foodexp_survey_vars', m
	
/* 2. Major Say in Home Improvements/Repairs (1):

	h8: Making home improvements/repair
*/
	loc homeexp_survey_vars "h8"
	loc homeexp_vars "h8_ac"
	loc homeexp_vars_r "h8_ac_r"
	tab `homeexp_survey_vars', m

/* 3. Major Say in Managing Household Finances (1):
		
	h7: Managing household finances
*/
	loc homefin_survey_vars "h7"
	loc homefin_vars "h7_ac"
	loc homefin_vars_r "h7_ac_r"
	tab `homefin_survey_vars', m

/* 4. Major Say in Children's School Attendance (2):

	h9: Whether your daughter should attend school
	h10: Whether your son should attend school
*/
	loc chischool_survey_vars "h9 h10"
	loc chischool_vars "h9_ac h10_ac"
	loc chischool_vars_r "h9_ac_r h10_ac_r"
	tabm `chischool_survey_vars', m

/* 5. Major Say in Children's Health Seeking (1):

	h13: Consulting a doctor when your child is ill
*/
	loc chihealth_survey_vars "h13"
	loc chihealth_vars "h13_ac"
	loc chihealth_vars_r "h13_ac_r"	
	tab `chihealth_survey_vars', m

/* 6. Major Say in Children's Marriage (2):

	h11: Marriage of daughters
	h12: Marriage of sons
*/
	loc chimarr_survey_vars "h11 h12"
	loc chimarr_vars "h11_ac h12_ac"
	loc chimarr_vars_r "h11_ac_r h12_ac_r"
	tabm `chimarr_survey_vars', m

/* 7. Major Say in Buying or Selling Land or Property (1):

	h6: Buying or selling land or property
*/
	loc homesale_survey_vars "h6"
	loc homesale_vars "h6_ac"
	loc homesale_vars_r "h6_ac_r"
	tab `homesale_survey_vars', m

/* 8. Major Say in Clothing and Other Non-food Expenditures (3):

	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
*/
	loc otherexp_survey_vars "h3 h4 h5"
	loc otherexp_vars "h3_ac h4_ac h5_ac"
	loc otherexp_vars_r "h3_ac_r h4_ac_r h5_ac_r"
	tabm `otherexp_survey_vars', m

/* 9. Major Say in Her Fertility (1):

		h14: How many children to have
*/
	loc fert_survey_vars "h14"
	loc fert_vars "h14_ac"
	loc fert_vars_r "h14_ac_r"
	tab `fert_survey_vars', m

/* 10. Major Say in Her Taking a Loan, Opening a Business, and Working Outside of Home (3):

	h28: If you wanted to take out a loan
	h31: If you wanted to pursue a job outside the home
	h24: If you wanted to open a new business
*/

	loc h24_survey_vars "h24"
	loc h24_vars "h24_ac"
	loc h24_vars_r "h24_ac_r"
	loc h28_survey_vars "h28"
	loc h28_vars "h28_ac"
	loc h28_vars_r "h28_ac_r"
	loc h31_survey_vars "h31"
	loc h31_vars "h31_ac"
	loc h31_vars_r "h31_ac_r"

	loc decide_survey_vars `foodexp_survey_vars' `homeexp_survey_vars' `homefin_survey_vars' `homesale_survey_vars' ///
		`chischool_survey_vars' `chihealth_survey_vars' `chimarr_survey_vars' `otherexp_survey_vars' `fert_survey_vars' ///
		`h24_survey_vars' `h28_survey_vars' `h31_survey_vars'
	
* Generate variables for index. = 1 if always consulted or always consulted and followed decision
	foreach var of local decide_survey_vars {
		local 	`var'_ac_l : variable label `var'
		gen 	`var'_ac = 1 if `var' == 3 | `var' == 4
		replace `var'_ac = 0 if `var'_ac != 1
		replace `var'_ac = . if mi(`var')
		lab var `var'_ac "``var'_ac_l'"
	}
	
* Generate variables for Robustness Checks. = 1 if always consulted AND followed decision
	foreach var of local decide_survey_vars {
		local 	`var'_ac_r_l : variable label `var'
		gen 	`var'_ac_r = 1 if `var' ==  4
		replace `var'_ac_r = 0 if `var'_ac_r != 1
		replace `var'_ac_r = . if mi(`var')
		lab var `var'_ac_r "``var'_ac_r_l'"
	}	

	* Labels
		lab var h28_ac "If you wanted to take out a loan"
		lab var h31_ac "If you wanted to pursue a job outside the home"
		lab var h24_ac "If you wanted to open a new business"
		lab var h30    "Have savings/loans/other financial assets in your own name and separate from other household members"	
		
********************************************************************************
	** Part 4: Taking advantage of economic opportunities
********************************************************************************
	
/* Includes:
	
	Primary female has a mobile phone account 
	h30: Primary female has savings/loans/other financial assets in your own name and separate from other 
	Engaged in productive activities
	k24: Primary female is owner or manager of a HH non-agricultural bussiness */
	
	*-------------------------------------------*
	* Primary female has a mobile phone account *
	*-------------------------------------------*	
	
	preserve
	
	* Open phone roster
		use "${mobile_phone_fl1}", clear
	
	* Merge lady of the HH variable
		merge m:1 hhid using "${all_HH_nopii_fl1}", keepus(lady_hh2 a12_mobile v1) assert(2 3) nogen
		destring lady_hh2, replace
		/*
			Result                           # of obs.
			-----------------------------------------
			not matched                           399
				from master                         0  (_merge==1)
				from using                        399  (_merge==2)

			matched                             2,926  (_merge==3)
			-----------------------------------------

			399 with _merge == 2 because:
				1. 113 who didn't consent (a12_mobile == 0)
				2. 266 who has no mobile phones (v1 == 0)
				3. 20 who didn't know or didn't answer (v1 == .d or v1 == .r)
		*/
		
		
	* Gen dummy for primary female has mobile phone
		gen 	mobile_yes_pf = 1 if v3 == lady_hh2
		replace mobile_yes_pf = 0 if v3 != lady_hh2
		replace mobile_yes_pf = . if a12_mobile == 0 // 113 HHs
		replace mobile_yes_pf = . if lady_hh2 == . // 3 HHs without LHH (5 in total)
		replace mobile_yes_pf = .d if v1 == .d // 19 HHs
		replace mobile_yes_pf = .r if v1 == .r // 1 HH
		
		collapse (max) mobile_yes_pf, by(hhid)
		lab var mobile_yes_pf "Primary Woman has a mobile phone"
		tempfile mobile_yes_pf
		save 	`mobile_yes_pf'
	
	*---------------------------------------*
	* Primary female has a loan in her name *
	*---------------------------------------*	
		
	* Open loan roster
		use "${loans_fl1}", clear
		
	* Merge lady of the HH variable
		*drop m1_a
		merge m:1 hhid using "${all_HH_nopii_fl1}", keepus(lady_hh2 m1) assert(2 3) nogen
		*keep hhid loan_number m2_roster* lady_hh2 m1 m1_a
		/*
		    Result                           # of obs.
			-----------------------------------------
			not matched                         1,420
				from master                         0  
				from using                      1,420  

			matched                             1,783  
			-----------------------------------------
		
			1,420 with merge == 2 because:
				1. 1,369 HH with no outstanding loans (m1 == 0)
				2. 32 HH who said don't know to outstandin loans (m1 == -99)
				3. 9 HH who said don't answer to outstandin loans (m1 == -98)
		*/		

	* Create dummy for primary female has a loan
		replace m2_roster = " " + m2_roster + " " 
		tostring lady_hh2, replace 
		replace lady_hh2 = " " + lady_hh2 + " " 
		gen 	loan_yes_pf = (regexm(m2_roster, lady_hh2))
		replace loan_yes_pf = 0 if m1 == 0
		replace loan_yes_pf = .d if inlist(m2_roster__99, 1, .d)
		replace loan_yes_pf = .r if inlist(m2_roster__98, 1, .r)
		
		collapse (max) loan_yes_pf m1 m1_a, by(hhid)
		replace loan_yes_pf = .d if inlist(m1, -99, .d) 
		replace loan_yes_pf = .r if inlist(m1, -98, .r)
		replace loan_yes_pf = .d if inlist(m1_a, -99, .d) 
		replace loan_yes_pf = .r if inlist(m1_a, -98, .r)	
		
		replace loan_yes_pf = .r if inlist(hhid,1084,2025)
		
		lab var loan_yes_pf "Primary woman has a loan"
		tempfile loan_yes_pf
		save	`loan_yes_pf'
		
		br if hhid == 1677 // 0 .d 1 
	restore
	
	merge 1:1 hhid using `mobile_yes_pf', assert(3) nogen
	merge 1:1 hhid using `loan_yes_pf', assert(3) nogen
  
	*--------------------------------------------------------------------*
	* Engaged in productive activities and in paid productive activities *
	*--------------------------------------------------------------------*	

	preserve
	
	* Open dataset for productive activities 	
		use "${time_activities_ses}", clear
	* Keep only primary female
		keep if lady_hh2 == member & b6 == 2
		isid hhid
		keep hhid did_labor_nohh
		rename did_labor_nohh did_labor_pf
		lab var did_labor_pf "Primary Woman Participates in Market Work"
		tempfile engaged_prod_activities_pf
		save `engaged_prod_activities_pf'
		
	*----------------------------------------------------------------------------*
	* k24: Primary female is owner or manager of a HH non-agricultural bussiness * 
	*----------------------------------------------------------------------------*	

	* Open businesses roster
		use "${businesses_fl1}", clear
		
	* Create variable if primary female is owner or manager in one of the bussiness
		gen 	owner_manager_pf = 1 if k24_3 == 1 | k24_2 == 1
		replace owner_manager_pf = 0 if k24_3 == 0 & k24_2 == 0
		replace owner_manager_pf = 0 if k23_a == 0
		
		* Get hhs with no business (none or don't know)
		*br hhid business k23_a owner_manager_pf
		gen no_biz = 1 if business == 0 & k23_a == 1
		gen dk_biz = 1 if business == -99 & k23_a == 1
		bys hhid: egen biz_no = max(no_biz)
		bys hhid: egen biz_dk = max(dk_biz)
		bys hhid: egen max_owner_manager_pf = max(owner_manager_pf)
		replace max_owner_manager_pf = 0 if biz_no == 1
		replace max_owner_manager_pf = .d if biz_dk == 1
		drop owner_manager_pf biz_no no_biz dk_biz biz_dk
		rename max_owner_manager_pf owner_manager_pf
		duplicates drop hhid, force
		lab var owner_manager_pf "PW Is Owner or Manager of a HH Non-Agricultural Business"
		tempfile owner_manager_pf
		save	`owner_manager_pf'
		
	restore
	
	*---------------------------------------------------*
	* Index: Taking advantage of economic opportunities *
	*---------------------------------------------------*
	
	merge 1:1 hhid using `engaged_prod_activities_pf', assert(1 3) nogen	
	merge 1:1 hhid using `owner_manager_pf', assert(3) nogen
	
	loc work_vars owner_manager_pf did_labor_pf
	loc inputs_vars h30 mobile_yes_pf
	
********************************************************************************
	** Part 5: Aspirations for daughters / Social norms
********************************************************************************
	
/* Includes:
	i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
	i2_d: How will this level of education help ${name_youngest_daughter}?
	i4_d: At what age would you like to see ${name_youngest_daughter} marry? 
	School-age girls are enrolled in school */
	
	
* i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
* Bachelor or above 
	foreach x in d s {
		gen 	ed_level_`x' = 1 if inlist(i1_`x',14,15) // 14 = BA, 15 = MA 
		replace ed_level_`x' = 0 if !inlist(i1_`x',14,15) & !mi(i1_`x')
		replace ed_level_`x' = .  if i1_`x' == -97 // other is missing
		replace ed_level_`x' = .  if i1_`x' == 17 // whatever is already completed
		replace ed_level_`x' = .d if i1_`x'==.d
		replace ed_level_`x' = .n if i1_`x'==.n
		replace ed_level_`x' = .r if i1_`x'==.r
	}

* i2_d: How will this level of education help ${name_youngest_daughter}? -> 1 if get job/earn money, make him/her wiser
	foreach x in d s {
		gen 	ed_help_`x' = 0 if !mi(i2_`x'_1)
		replace ed_help_`x' = 1 if i2_`x'_1 == 1
		replace ed_help_`x' = 1 if i2_`x'_2 == 1
		replace ed_help_`x' = .d if i2_`x'__99 == 1
		replace ed_help_`x' = .r if i2_`x'__98 == 1
	}
	
* i4_d: At what age would you like to see ${name_youngest_daughter} marry? */
	foreach x in d s {
		gen 	age_marriage_`x' = 1 if i4_`x'>18 & !mi(i4_`x')
		replace age_marriage_`x' = 0 if i4_`x'<=18 & !mi(i4_`x')
		replace age_marriage_`x' = .d if i4_`x'==.d
		replace age_marriage_`x' = .r if i4_`x'==.r
		replace age_marriage_`x' = .o if i4_`x'==100 // implausible value (outlier)
	}
	
* i3_d: Desired Occupation: Doctor, Engineer, Anything She Wishes. */
	foreach x in d s {
		gen 	occupation_`x' = 1 if inlist(i3_`x',2,6,8) & !mi(i3_`x')
		replace occupation_`x' = 0 if !inlist(i3_`x',2,6,8)  & !mi(i3_`x')
		replace occupation_`x' = .d if i3_`x'==.d
		replace occupation_`x' = .n if i3_`x'==.n
		replace occupation_`x' = .r if i3_`x'==.r
	}	
	
* In years
	foreach x in d s {
		gen 	ed_level_yr_`x' = i1_`x' 
		replace ed_level_yr_`x' = ed_level_yr_`x' -1 if i1_`x'>0 & i1_`x'<=13
		replace ed_level_yr_`x' = .  if i1_`x' == -97 // other is missing
		replace ed_level_yr_`x' = .  if i1_`x' == 17 // whatever is already completed
		replace ed_level_yr_`x' = 16 if i1_`x' == 14 // bachelor
		replace ed_level_yr_`x' = 18  if i1_`x' == 15 // masters
		replace ed_level_yr_`x' = 0  if i1_`x' == 18 // no education
		replace ed_level_yr_`x' = 12  if i1_`x' == 16 // technical	
	}		
	
	lab var ed_level_d 		"Highest Education Level Desired (Bachelor or Above)"
	lab var ed_help_d 		"Education Level Desired Will Help to Get a Better Job and Make Her Wiser"
	lab var age_marriage_d 	"Desired Age for Marriage Is Older Than 18"
	lab var occupation_d 	"Desired Occupation: Doctor, Engineer, Anything She Wishes"
	
	loc educ_vars ed_level_yr_d ed_help_d
	loc marriage_vars age_marriage_d
	
********************************************************************************
	** Part 6: Social Capital/Voice outside of the HH = Political involvement Index
********************************************************************************

/* Includes:
	s21: Has a Tazkira (Afghan national identification card)
	s10: Is a member of a political party
	n1: Attended village meetings 
	n2: Approached village leaders about village issue */

* Combine two voting variables 
	gen voted = .
		replace voted = 1 if (s12 == 1	| s13 == 1)
		replace voted = 0 if (s12 == 0 | s13 == 0) & mi(voted)
		replace voted = .r if (s12 == .r | s13 == .r) & mi(voted)
	
* Labels
	lab var voted "PW Voted in an Election (Presidential or Provincial)"
	lab var s21 "PW Has a Tazkira (Afghan National ID Card)"
	lab var s10 "PW Is a Member of a Political Party"
	lab var n1 "PW Attended Village Meetings"
	lab var n2 "PW Approached Village Leaders About Village Issue"
	
* Local for survey vars related to political involment
	loc tazkira_vars s21
	loc political_vars s10 voted
	loc community_vars n1 n2
	
********************************************************************************
	** Part 7: Construction of indices
********************************************************************************

	* Decisionmaking
	loc foodexp_l		"Food Expenditures and What to Cook"
	loc homeexp_l 		"Home Improvements/Repairs"
	loc homefin_l 		"Managing Household Finances"
	loc chischool_l 	"Children's School Attendance"
	loc chihealth_l 	"Children's Health Seeking"
	loc chimarr_l 		"Children's Marriage"
	loc homesale_l		"Buying or Selling Land or Property"
	loc otherexp_l 		"Other Non-food Expenditures"
	loc fert_l 			"Her Fertility"
	loc h28_l 		"Her Taking a Loan"
	loc h31_l 		"Her Working Outside of Home"
	loc h24_l 		"Her Opening a Business"

	* Econ opp 
	loc work_l "Participation in Market Work and Running a Business"
	loc inputs_l "Access to Resources and Inputs"
	
	* Political and Social Capital
	loc tazkira_l	"National ID Ownership"
	loc political_l "Political Participation"
	loc community_l "Community Participation"
	
	* Aspirations 
	loc educ_l 		"Daughters' Education"
	loc marriage_l 	"Daughter's Marriage in Adulthood"

	gl all "foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31 work inputs tazkira political community educ marriage" 
	
	keep if ultra_poor == 1
	
	* There are 3 households with no LHH, so we have to drop those HHs 
	drop if respondent_gender == 1

	* Define a variable with which to standardize the index	
		* Overall control first 
	global normvar control
	
	* Create indices for each of the sub sub components
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index' "``index'_l' Index sd(${normvar})"	
		}	
		
* Decisionmaking index
	loc decide_index "index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert index_sdC_h24 index_sdC_h28 index_sdC_h31"
	egen index_sdC_all_decisions = weightave(`decide_index'), normby(${normvar})
	lab var index_sdC_all_decisions "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index
	loc econ_opp_index "index_sdC_work index_sdC_inputs"
	egen index_sdC_role_prod_act = weightave(`econ_opp_index'), normby(${normvar})
	lab var index_sdC_role_prod_act "Economic Opportunities Index sd(${normvar})"
	

* Social Capital Index
	loc soc_cap_index "index_sdC_tazkira index_sdC_political index_sdC_community"
	egen index_sdC_social_capital = weightave(`soc_cap_index'), normby(${normvar})
	lab var index_sdC_social_capital "Social Capital Index sd(${normvar})"
	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	loc all_index3 "index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital"
	egen index_sdC_f_emp_3c = weightave(`all_index3'), normby(${normvar})
	lab var index_sdC_f_emp_3c "Women's Empowerment Index sd(${normvar}) (3 dimensions)"
	
	
**************** Create index Z score to be comparable with Banerjee et al. We take the full index although it does not necessarily has the same variables as in Banerjee ***************** 
*Start directly from the single variables, same as Banerjee 
	loc decide_index 		"h1_ac h2_ac h8_ac h7_ac h9_ac h10_ac h13_ac h11_ac h12_ac h6_ac h3_ac h4_ac h5_ac h14_ac h24_ac h28_ac h31_ac"
	loc econ_opp_index 		"owner_manager_pf did_labor_pf h30 mobile_yes_pf"
	loc soc_cap_index 		"s21 s10 voted n1 n2"
			
	* For these, computing index similarly as in Banerjee et al. (2015) science paper. Simple Z score
			foreach var in `decide_index' `econ_opp_index' `soc_cap_index' {
gen `var'_Z = .
			 sum `var' if treatment==0 
			if `r(N)' > 0 {
				replace `var'_Z = (`var' - `r(mean)') / `r(sd)' 
	}
}

	loc decide_index_Z  		"h1_ac_Z  h2_ac_Z  h8_ac_Z  h7_ac_Z  h9_ac_Z  h10_ac_Z  h13_ac_Z  h11_ac_Z  h12_ac_Z  h6_ac_Z  h3_ac_Z  h4_ac_Z  h5_ac_Z  h14_ac_Z  h24_ac_Z  h28_ac_Z  h31_ac_Z "
	loc econ_opp_index_Z 		"owner_manager_pf_Z did_labor_pf_Z h30_Z mobile_yes_pf_Z"
	loc soc_cap_index_Z 		"s21_Z s10_Z voted_Z n1_Z n2_Z"
	
	
* Decisionmaking index
	egen index_Z_all_decisions = rowmean(`decide_index_Z')
	lab var index_Z_all_decisions "Women's Decisionmaking Index (Z score)"
	
* Econ Opp Index
	egen index_Z_role_prod_act = rowmean(`econ_opp_index_Z')
	lab var index_Z_role_prod_act "Economic Opportunities Index (Z score)"
	

* Social Capital Index
	egen index_Z_social_capital = rowmean(`soc_cap_index_Z')
	lab var index_Z_social_capital "Social Capital Index (Z score)"
	

	*Standardization
	foreach var in index_Z_all_decisions index_Z_role_prod_act index_Z_social_capital {
			 sum `var' if treatment==0 
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
	}
}	
	
*  Decisionmaking index +  Econ Opp Index
	egen index_Z_decisions_eco = rowmean(index_Z_all_decisions index_Z_role_prod_act)
	lab var index_Z_decisions_eco "Decision + Economic Opportunities Index (Z score)"


*  Decisionmaking index +  Econ Opp Index + Social Capital Index
	egen index_Z_f_emp_3c = rowmean(index_Z_all_decisions index_Z_role_prod_act index_Z_social_capital)
	lab var index_Z_f_emp_3c "Women's Empowerment Index (Z score) (3 dimensions)"	
	
	
*Standardization	
foreach var in index_Z_decisions_eco index_Z_f_emp_3c  {
			 sum `var' if treatment==0 
			if `r(N)' > 0 {
				replace `var' = (`var' - `r(mean)') / `r(sd)' 
		}
	}
		

******************* Computing the indices only for household with daughters younger than 12 *****************************
preserve 

keep if !mi(i2_d) //Choosing this variable as it still has the -97 coded as it is a multiple answer raw question, so it was asked to all households with a daughter younger than 12 

	* Create indices
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_dau = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_dau  "``index'_l' Index sd(${normvar} - HH with daughters)"	
		}	

* Decisionmaking index
	loc decide_index_dau "index_sdC_foodexp_dau index_sdC_homeexp_dau index_sdC_homefin_dau index_sdC_chischool_dau index_sdC_chihealth_dau index_sdC_chimarr_dau index_sdC_homesale_dau index_sdC_otherexp_dau index_sdC_fert_dau index_sdC_h24_dau index_sdC_h28_dau index_sdC_h31_dau"
	egen index_sdC_all_decisions_dau = weightave(`decide_index_dau'), normby(${normvar})
	lab var index_sdC_all_decisions_dau "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index
	loc econ_opp_index_dau "index_sdC_work_dau index_sdC_inputs_dau"
	egen index_sdC_role_prod_act_dau = weightave(`econ_opp_index_dau'), normby(${normvar})
	lab var index_sdC_role_prod_act_dau "Economic Opportunities Index sd(${normvar})"
	
* Social Capital Index
	loc soc_cap_index_dau "index_sdC_tazkira_dau index_sdC_political_dau index_sdC_community_dau"
	egen index_sdC_social_capital_dau = weightave(`soc_cap_index_dau'), normby(${normvar})
	lab var index_sdC_social_capital_dau "Social Capital Index sd(${normvar})"

* Social Norms Index
	loc soc_norms_index_dau "index_sdC_educ_dau index_sdC_marriage_dau"
	egen index_sdC_social_norms_dau = weightave(`soc_norms_index_dau'), normby(${normvar})
	lab var index_sdC_social_norms_dau "Aspirations for Daughters Index sd(${normvar})"

* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	loc all_index_dau "index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_capital_dau index_sdC_social_norms_dau" 
	egen index_sdC_f_emp_dau = weightave(`all_index_dau'), normby(${normvar})
	lab var index_sdC_f_emp_dau "Women's Empowerment Index sd(${normvar}) (4 dimensions)"	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	loc all_index3_dau "index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_capital_dau"
	egen index_sdC_f_emp_dau_3c = weightave(`all_index3_dau'), normby(${normvar})
	lab var index_sdC_f_emp_dau_3c "Women's Empowerment Index sd(${normvar}) (3 dimensions)"	
	
keep hhid 	index_sdC_social_norms_dau index_sdC_f_emp_dau index_sdC_f_emp_dau_3c index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_capital_dau
	
tempfile we_aspiration_daughter
save `we_aspiration_daughter'
restore
 
merge 1:1 hhid using `we_aspiration_daughter', assert(1 3) nogen 

	
********************************************************************************
	** Part 8: Robustness Checks 
********************************************************************************	
* Creating indices including the robustness variables instead 
		
	loc work_vars_r   	 	`work_vars'
	loc inputs_vars_r    	`inputs_vars'
	loc educ_vars_r     	`educ_vars'
	loc marriage_vars_r     `marriage_vars'
	loc tazkira_vars_r   	`tazkira_vars'
	loc political_vars_r   	`political_vars'
	loc community_vars_r   	`community_vars'
	
	foreach index in $all {
		display "`index'"
		des ``index'_vars_r'
		egen index_sdC_`index'_r = weightave(``index'_vars_r'), normby(${normvar})
		lab var index_sdC_`index'_r "``index'_l' Index sd(${normvar}) Robustness"	
	}	
		         	 
* Decisionmaking index (10 components)
	loc decide_index_r "index_sdC_foodexp_r index_sdC_homeexp_r index_sdC_homefin_r index_sdC_chischool_r index_sdC_chihealth_r index_sdC_chimarr_r index_sdC_homesale_r index_sdC_otherexp_r index_sdC_fert_r index_sdC_h24_r index_sdC_h28_r index_sdC_h31_r"
	egen index_sdC_all_decisions_r = weightave(`decide_index_r'), normby(${normvar})
	lab var index_sdC_all_decisions_r "Women's Deciosionmaking Index sd(${normvar}) Robustness"	
		
* Econ Opp Index
	loc econ_opp_index_r "index_sdC_work_r index_sdC_inputs_r"
	egen index_sdC_role_prod_act_r = weightave(`econ_opp_index_r'), normby(${normvar})
	lab var index_sdC_role_prod_act_r "Economic Opportunities Index sd(${normvar}) Robustness"
	
* Social Norms Index
	loc soc_norms_index_r "index_sdC_educ_r index_sdC_marriage_r"
	egen index_sdC_social_norms_r = weightave(`soc_norms_index_r'), normby(${normvar})
	lab var index_sdC_social_norms_r "Aspirations for Daughters Index sd(${normvar}) Robustness"

* Social Capital Index
	loc soc_cap_index_r "index_sdC_tazkira_r index_sdC_political_r index_sdC_community_r"
	egen index_sdC_social_capital_r = weightave(`soc_cap_index_r'), normby(${normvar})
	lab var index_sdC_social_capital_r "Social Capital Index sd(${normvar}) Robustness"		
		
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	loc all_index3_r "index_sdC_all_decisions_r index_sdC_role_prod_act_r index_sdC_social_capital_r"
	egen index_sdC_f_emp_3c_r = weightave(`all_index3_r'), normby(${normvar})
	lab var index_sdC_f_emp_3c_r "Women's Empowerment Index sd(${normvar}) (3 dimensions) Robustness"		
	

	
********************************************************************************
	** Part 9: Men-headed households
********************************************************************************

	preserve
		keep if hh_head_gender == 1
		
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_m = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_m "``index'_l' Index sd(${normvar}) - Men-headed HH"	
		}	
		
* Decisionmaking index
	loc decide_index_m "index_sdC_foodexp_m index_sdC_homeexp_m index_sdC_homefin_m index_sdC_chischool_m index_sdC_chihealth_m index_sdC_chimarr_m index_sdC_homesale_m index_sdC_otherexp_m index_sdC_fert_m index_sdC_h24_m index_sdC_h28_m index_sdC_h31_m"
	egen index_sdC_all_decisions_m = weightave(`decide_index_m'), normby(${normvar})
	lab var index_sdC_all_decisions_m "Women's Decisionmaking Index sd(${normvar}) - Men-headed HH"			
	
* Econ Opp Index
	loc econ_opp_index_m "index_sdC_work_m index_sdC_inputs_m"
	egen index_sdC_role_prod_act_m = weightave(`econ_opp_index_m'), normby(${normvar})
	lab var index_sdC_role_prod_act_m "Economic Opportunities Index sd(${normvar}) - Men-headed HH"
	
* Social Norms Index
	loc soc_norms_index_m "index_sdC_educ_m index_sdC_marriage_m"
	egen index_sdC_social_norms_m = weightave(`soc_norms_index_m'), normby(${normvar})
	lab var index_sdC_social_norms_m "Aspirations for Daughters Index sd(${normvar}) - Men-headed HH"

* Social Capital Index
	loc soc_cap_index_m "index_sdC_tazkira_m index_sdC_political_m index_sdC_community_m"
	egen index_sdC_social_capital_m = weightave(`soc_cap_index_m'), normby(${normvar})
	lab var index_sdC_social_capital_m "Social Capital Index sd(${normvar}) - Men-headed HH"	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	loc all_index3_m "index_sdC_all_decisions_m index_sdC_role_prod_act_m index_sdC_social_capital_m"
	egen index_sdC_f_emp_3c_m = weightave(`all_index3_m'), normby(${normvar})
	lab var index_sdC_f_emp_3c_m "Women's Empowerment Index sd(${normvar}) (3 dimensions)- Men-headed HH"	
		
	
		tempfile malehead
		save	`malehead'
	restore
	
	merge 1:1 hhid using `malehead', assert(1 3) nogen
	
	
********************************************************************************
	** Part 10: Women-headed households
********************************************************************************

	preserve
		keep if hh_head_gender == 2
		
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_w = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_w "``index'_l' Index sd(${normvar}) - Women-headed HH"	
		}	
		
* Decisionmaking index
	loc decide_index_w "index_sdC_foodexp_w index_sdC_homeexp_w index_sdC_homefin_w index_sdC_chischool_w index_sdC_chihealth_w index_sdC_chimarr_w index_sdC_homesale_w index_sdC_otherexp_w index_sdC_fert_w index_sdC_h24_w index_sdC_h28_w index_sdC_h31_w"
	egen index_sdC_all_decisions_w = weightave(`decide_index_w'), normby(${normvar})
	lab var index_sdC_all_decisions_w "Women's Decisionmaking Index sd(${normvar}) - Women-headed HH"			
	
* Econ Opp Index
	loc econ_opp_index_w "index_sdC_work_w index_sdC_inputs_w"
	egen index_sdC_role_prod_act_w = weightave(`econ_opp_index_w'), normby(${normvar})
	lab var index_sdC_role_prod_act_w "Economic Opportunities Index sd(${normvar}) - Women-headed HH"
	
* Social Norms Index
	loc soc_norms_index_w "index_sdC_educ_w index_sdC_marriage_w"
	egen index_sdC_social_norms_w = weightave(`soc_norms_index_w'), normby(${normvar})
	lab var index_sdC_social_norms_w "Aspirations for Daughters Index sd(${normvar}) - Women-headed HH"

* Social Capital Index
	loc soc_cap_index_w "index_sdC_tazkira_w index_sdC_political_w index_sdC_community_w"
	egen index_sdC_social_capital_w = weightave(`soc_cap_index_w'), normby(${normvar})
	lab var index_sdC_social_capital_w "Social Capital Index sd(${normvar}) - Women-headed HH"	
	
* Total index (3 dimensions: decisionmaking, econ opp, social capital)
	loc all_index3_w "index_sdC_all_decisions_w index_sdC_role_prod_act_w index_sdC_social_capital_w"
	egen index_sdC_f_emp_3c_w = weightave(`all_index3_w'), normby(${normvar})
	lab var index_sdC_f_emp_3c_w "Women's Empowerment Index sd(${normvar}) (3 dimensions)- Women-headed HH"		
	
		tempfile womanhead
		save	`womanhead'
	restore
	
	merge 1:1 hhid using `womanhead', assert(1 3) nogen
		
* Save data
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_fl1}", replace v(13) 
	}
	else {
		save "${f_empowerment_fl1}", replace
	}		
	
********************************************************************************
** 	Generate indices for each individual ethnicity standardizing by the control
*   group for that ethnicity
********************************************************************************

    	* Generate indices for each individual ethnicity standardizing by the control group for that ethnicity
	local i = 1
	
	foreach ethnicity in pashto dari uzbek turkmen arabic {
		foreach index in $all {
			
			use "${f_empowerment_fl1}", clear 
																																						
			* Keep the ethnicity for which we are estimating the index
			keep if `ethnicity' == 1 
			
			* Define the variable by which we normalize
			global normvar `ethnicity'_control
			
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_`i' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_`i' "``index'_l' Index sd(${normvar})"
			
			keep hhid index_sdC_`index'_`i' 
			tempfile index_sdC_`index'_`i'
			save	`index_sdC_`index'_`i''
		}
			local i = `i' + 1 
	}	
	
		use "${f_empowerment_fl1}", clear 
			foreach index in $all {
				forval i = 1/5 {
				merge 1:1 hhid using "`index_sdC_`index'_`i''", assert(1 3) nogen
				}
			}
			
	local i = 1
	
	foreach ethnicity in pashto dari uzbek turkmen arabic {

		* Define the variable by which we normalize
		global normvar `ethnicity'_control
			
		* Decisionmaking index
			loc decide_index "index_sdC_foodexp_`i' index_sdC_homeexp_`i' index_sdC_homefin_`i' index_sdC_chischool_`i' index_sdC_chihealth_`i' index_sdC_chimarr_`i' index_sdC_homesale_`i' index_sdC_otherexp_`i' index_sdC_fert_`i' index_sdC_h24_`i' index_sdC_h28_`i' index_sdC_h31_`i'"
			egen index_sdC_all_decisions_`i' = weightave(`decide_index'), normby(${normvar})
			lab var index_sdC_all_decisions_`i' "Women's Decisionmaking Index sd(${normvar})"
			
		* Econ Opp Index
			loc econ_opp_index "index_sdC_work_`i' index_sdC_inputs_`i'"
			egen index_sdC_role_prod_act_`i' = weightave(`econ_opp_index'), normby(${normvar})
			lab var index_sdC_role_prod_act_`i' "Economic Opportunities Index sd(${normvar})"
			
		* Social Norms Index
			loc soc_norms_index "index_sdC_educ_`i' index_sdC_marriage_`i'"
			egen index_sdC_social_norms_`i' = weightave(`soc_norms_index'), normby(${normvar})
			lab var index_sdC_social_norms_`i' "Aspirations for Daughters Index sd(${normvar})"

		* Social Capital Index
			loc soc_cap_index "index_sdC_tazkira_`i' index_sdC_political_`i' index_sdC_community_`i'"
			egen index_sdC_social_capital_`i' = weightave(`soc_cap_index'), normby(${normvar})
			lab var index_sdC_social_capital_`i' "Social Capital Index sd(${normvar})"
			
		* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
			loc all_index "index_sdC_all_decisions_`i' index_sdC_role_prod_act_`i' index_sdC_social_capital_`i' index_sdC_social_norms_`i'"
			egen index_sdC_f_empowerment_`i' = weightave(`all_index'), normby(${normvar})
			lab var index_sdC_f_empowerment_`i' "Women's Empowerment Index sd(${normvar})"	
		
		* Total index (3 dimensions: decisionmaking, econ opp, social capital)
			loc all_index_3c "index_sdC_all_decisions_`i' index_sdC_role_prod_act_`i' index_sdC_social_capital_`i'"
			egen index_sdC_f_empowerment_3c_`i' = weightave(`all_index_3c'), normby(${normvar})
			lab var index_sdC_f_empowerment_3c_`i' "Women's Empowerment Index sd(${normvar}) - 3 components"
			
			local i = `i' + 1 
	}
	
	* Create pooled versions (i.e., all ethnicities in one variable) of the index to gain power (as in Banerjee et al.)
	* Create indices
		foreach index in $all all_decisions role_prod_act social_norms social_capital f_empowerment f_empowerment_3c {
			local index_sdC_`index'_lab : var lab index_sdC_`index'_1
			local index_sdC_`index'_lab : subinstr local index_sdC_`index'_lab " sd(pashto_control)" "", all
			
			* Use ", m" egen option so that the index goes to missing if all components are missing 
			egen index_sdC_`index'_p = rowtotal(index_sdC_`index'_1 index_sdC_`index'_2 index_sdC_`index'_3 index_sdC_`index'_4 index_sdC_`index'_5), m
			lab var index_sdC_`index'_p "`index_sdC_`index'_lab' - pooled"	
		}	
	
	* Reflect new grouping for some of the decision-making variables 
		egen foodexp 	= rowmean(h1_ac h2_ac)	
		egen otherexp 	= rowmean(h3_ac h4_ac h5_ac)
		egen chischool 	= rowmean(h9_ac h10_ac)
		egen chimarr 	= rowmean(h11_ac h12_ac)
		
		lab var foodexp "Food Expenditures and What to Cook"
		lab var h8_ac "Home Improvements/Repairs"
		lab var h7_ac "Managing Household Finances"
		lab var h6_ac "Buying or Selling Land or Property"
		lab var otherexp "Other Non-food Expenditures"
		lab var chischool "Children's School Attendance"
		lab var h13_ac "Children's Health Seeking"
		lab var chimarr "Children's Marriage"
		lab var h14_ac "Her Fertility"
		lab var h28_ac "Her Taking a Loan"
		lab var h24_ac"Her Opening a Business"
		lab var h31_ac "Her Working Outside of Home"
		lab var n2 "PW Approached Village Leaders About Issues"
		lab var did_labor_pf "PW Does Market Work"
		lab var h30 "PW Has Financial Assets in Her Own Name"
		lab var owner_manager_pf "PW is Owner or Manager of a HH Non-Agricultural Business"
		lab var s21 "PW Has a Tazkira (National ID Card)"
		lab var n1 "PW Attended Village Meetings"
		lab var n2 "PW Approached Village Leaders About Issues"
		lab var voted "PW Voted in an Election (Presidential or Provincial)"
		lab var s10 "PW Is a Member of a Political Party"
		lab var mobile_yes_pf "PW Has a Mobile Phone"
		lab var did_labor_pf "PW Does Market Work"
		lab var index_sdC_all_decisions "Decision-Making Index"
		lab var index_sdC_role_prod_act "Economic Opportunities Index"
		lab var index_sdC_social_norms_dau "Aspirations for Daughters Index (Households with daughters <= 12)"
		lab var index_sdC_social_capital "Political and Social Involvement Index"
		lab var index_sdC_f_emp_dau "Women's Empowerment Index (Households with daughters <= 12)"
		lab var index_sdC_f_emp_dau_3c "Women's Empowerment Index (3 dimensions, Households with daughters <= 12"
		lab var index_sdC_f_emp_3c "Women's Empowerment Index (3 dimensions)"
		lab var index_sdC_all_decisions_p "Decision-making Index"
		lab var index_sdC_role_prod_act_p "Economic Opportunities Index"
		lab var index_sdC_social_norms_p "Aspirations for Daughters Index"
		lab var index_sdC_social_capital_p "Political and Social Involvement Index"
		//lab var index_sdC_f_empowerment_p "Women's Empowerment Index"
		lab var index_sdC_f_empowerment_3c_p "Women's Empowerment Index (3 dimensions)"
		
* Prepare and add baseline covariates to the dataset 
preserve	
	use "${f_empowerment_bl_flsample}", clear 
		merge 1:1 hhid using "${data_for_analysis_bl}", keepusing(exp_tot_m_pc_ppp) keep(1 3) nogen
		
	keep hhid  index_sdC_f_emp_dau index_sdC_f_empowerment_3c index_sdC_f_empowerment_3c_m ///
	index_sdC_all_decisions index_sdC_all_decisions_m foodexp h8_ac h7_ac chischool ///
							h13_ac chimarr h6_ac otherexp h14_ac index_sdC_role_prod_act index_sdC_role_prod_act_m owner_manager_pf ///
							did_labor_pf h30 index_sdC_social_capital index_sdC_social_capital_m n1 n2 exp_tot_m_pc_ppp ///
							index_sdC_social_norms_dau index_sdC_social_norms_m ed_level_d ed_help_d age_marriage_d ///
							index_sdC_f_empowerment_3c_p index_sdC_all_decisions_p index_sdC_role_prod_act_p ///
							index_sdC_social_capital_p h24_ac h28_ac h31_ac occupation_d ///
							index_sdC_all_decisions_p index_sdC_role_prod_act_p ///
										index_sdC_social_capital_p *_dau*

	rename * *_bl
	rename hhid_bl hhid
	tempfile covariates
	save `covariates'
restore
		merge 1:1 hhid using "`covariates'", keep(1 3)
	
		rename (index_sdC_f_empowerment_3c_p_bl index_sdC_f_empowerment_3c_m_bl index_sdC_social_capital_dau_bl) (index_sdC_empowerment_3c_p_bl index_sdC_empowerment_3c_m_bl index_sdC_socap_dau_bl)
		
	* Create covariate missingness dummy indicator
foreach var in index_sdC_f_empowerment_3c index_sdC_empowerment_3c_m index_sdC_all_decisions index_sdC_all_decisions_m foodexp h8_ac h7_ac chischool h13_ac chimarr h6_ac otherexp h14_ac index_sdC_role_prod_act index_sdC_role_prod_act_m owner_manager_pf did_labor_pf h30 index_sdC_social_capital index_sdC_social_capital_m n1 n2 exp_tot_m_pc_ppp index_sdC_social_norms_m ed_level_d ed_help_d age_marriage_d index_sdC_empowerment_3c_p index_sdC_all_decisions_p index_sdC_role_prod_act_p index_sdC_social_capital_p h24_ac h28_ac h31_ac occupation_d /*index_sdC_f_empowerment_p*/ index_sdC_all_decisions_dau index_sdC_role_prod_act_dau index_sdC_social_norms_dau index_sdC_socap_dau index_sdC_f_emp_dau index_sdC_f_emp_dau_3c {
			gen `var'_bl_m = (mi(`var'_bl))
			replace `var'_bl = 0 if mi(`var'_bl)
		}		
		
* Save data
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_fl1}", replace v(13) 
	}
	else {
		save "${f_empowerment_fl1}", replace
	}	

			
			
	
