/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Apr 23, 2019
Last udpate on: Apr 23, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates female empowerment index based on discussion with Lupe and 
				in the following file: TUP_Afghanistan/Data Analysis/Others/Empowerment/female_empowerment_indicators_23Apr2019_adjusted2available.xlsx

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl profile_info				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl mobile_phone_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/v_mobile_fl1.dta"
	gl loans_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/m_b_loans_fl1.dta"
	gl schooling_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"
	gl time_activities_ses 		"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
	gl businesses_fl1	 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_d_nonagbiz_fl1.dta"

* Outputs
	gl f_empowerment_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta"
	gl f_empowerment_nupcontrol_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_nupcontrol_fl1.dta"


	gl f_empowerment_nup_eth_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_nup_eth_fl1.dta"
	gl f_empowerment_control_eth_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_control_eth_fl1.dta"

********************************************************************************
	** Part 0: Prepare dataset
********************************************************************************

use "${all_HH_nopii_fl1}", clear

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) assert(2 3) keep(3) nogen
	/*
	   
	    Result                           # of obs.
		-----------------------------------------
		not matched                           404
			from master                         0  (_merge==1)
			from using                        404  (_merge==2) // HHs for which we didn't collect follow-up (mostly targeting households i.e. treatment == .)

		matched                             2,495  (_merge==3)
		-----------------------------------------
	*/

* Control dummy
	gen 	control = treatment==0
	replace control = 0 if mi(treatment)
	lab var control "HH is part of control group"
	
* Pashto dummy
	gen 	pashto = a10 == 2
	lab var pashto "HH is Pashto speaking"
	
* PashtoXControl dummy
	gen 	pashto_control = (control == 1 & pashto == 1)
	lab var pashto_control "HH is part of control group and Pashto speaking"	

********************************************************************************
	** Part 1: Household expenses
********************************************************************************
	
/* 1. Major Say in Food Expenditures and What to Cook (2):

	h1: What to cook on a daily basis
	h2: Buying groceries */
	
* Local for survey vars related 
	loc foodexp_survey_vars "h1 h2"
	loc foodexp_vars "h1_ac h2_ac"
	loc foodexp_vars_r "h1_ac_r h2_ac_r"
	tabm `foodexp_survey_vars', m
	
/* 2. Major Say in Home Improvements/Repairs (1):

	h8: Making home improvements/repair
*/
	loc homeexp_survey_vars "h8"
	loc homeexp_vars "h8_ac"
	loc homeexp_vars_r "h8_ac_r"
	tab `homeexp_survey_vars', m

/* 3. Major Say in Managing Household Finances (1):
		
	h7: Managing household finances
*/
	loc homefin_survey_vars "h7"
	loc homefin_vars "h7_ac"
	loc homefin_vars_r "h7_ac_r"
	tab `homefin_survey_vars', m

/* 4. Major Say in Children's School Attendance (2):

	h9: Whether your daughter should attend school
	h10: Whether your son should attend school
*/
	loc chischool_survey_vars "h9 h10"
	loc chischool_vars "h9_ac h10_ac"
	loc chischool_vars_r "h9_ac_r h10_ac_r"
	tabm `chischool_survey_vars', m

/* 5. Major Say in Children's Health Seeking (1):

	h13: Consulting a doctor when your child is ill
*/
	loc chihealth_survey_vars "h13"
	loc chihealth_vars "h13_ac"
	loc chihealth_vars_r "h13_ac_r"	
	tab `chihealth_survey_vars', m

/* 6. Major Say in Children's Marriage (2):

	h11: Marriage of daughters
	h12: Marriage of sons
*/
	loc chimarr_survey_vars "h11 h12"
	loc chimarr_vars "h11_ac h12_ac"
	loc chimarr_vars_r "h11_ac_r h12_ac_r"
	tabm `chimarr_survey_vars', m

/* 7. Major Say in Buying or Selling Land or Property (1):

	h6: Buying or selling land or property
*/
	loc homesale_survey_vars "h6"
	loc homesale_vars "h6_ac"
	loc homesale_vars_r "h6_ac_r"
	tab `homesale_survey_vars', m

/* 8. Major Say in Clothing and Other Non-food Expenditures (3):

	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
*/
	loc otherexp_survey_vars "h3 h4 h5"
	loc otherexp_vars "h3_ac h4_ac h5_ac"
	loc otherexp_vars_r "h3_ac_r h4_ac_r h5_ac_r"
	tabm `otherexp_survey_vars', m

/* 9. Major Say in Her Fertility (1):

		h14: How many children to have
*/
	loc fert_survey_vars "h14"
	loc fert_vars "h14_ac"
	loc fert_vars_r "h14_ac_r"
	tab `fert_survey_vars', m

/* 10. Major Say in Her Taking a Loan, Opening a Business, and Working Outside of Home (3):

	h28: If you wanted to take out a loan
	h31: If you wanted to pursue a job outside the home
	h24: If you wanted to open a new business
*/	
	loc econdec_survey_vars "h24 h28 h31"
	loc econdec_vars "h24_ac h28_ac h31_ac"
	loc econdec_vars_r "h24_ac_r h28_ac_r h31_ac_r"
	tabm `econdec_survey_vars', m
	
	loc decide_survey_vars `foodexp_survey_vars' `homeexp_survey_vars' `homefin_survey_vars' `homesale_survey_vars' `chischool_survey_vars' `chihealth_survey_vars' `chimarr_survey_vars' `otherexp_survey_vars' `fert_survey_vars' `econdec_survey_vars'
	
* Generate variables for index. = 1 if always consulted or always consulted and followed decision
	foreach var of local decide_survey_vars {
		local 	`var'_ac_l : variable label `var'
		gen 	`var'_ac = 1 if `var' == 3 | `var' == 4
		replace `var'_ac = 0 if `var'_ac != 1
		replace `var'_ac = . if mi(`var')
		lab var `var'_ac "``var'_ac_l'"
	}
	
* Generate variables for Robustness Checks. = 1 if always consulted AND followed decision
	foreach var of local decide_survey_vars {
		local 	`var'_ac_r_l : variable label `var'
		gen 	`var'_ac_r = 1 if `var' ==  4
		replace `var'_ac_r = 0 if `var'_ac_r != 1
		replace `var'_ac_r = . if mi(`var')
		lab var `var'_ac_r "``var'_ac_r_l'"
	}	

	* Labels
		lab var h28_ac "If you wanted to take out a loan"
		lab var h31_ac "If you wanted to pursue a job outside the home"
		lab var h24_ac "If you wanted to open a new business"
		lab var h30 "Have savings/loans/other financial assets in your own name and separate from other household members"	
		
	
********************************************************************************
	** Part 4: Taking advantage of economic opportunities
********************************************************************************
	
/* Includes:
	
	Primary female has a mobile phone account 
	h30: Primary female has savings/loans/other financial assets in your own name and separate from other 
	Engaged in productive activities
	k24: Primary female is owner or manager of a HH non-agricultural bussiness */
	
	*-------------------------------------------*
	* Primary female has a mobile phone account *
	*-------------------------------------------*	
	
	preserve
	
	* Open phone roster
		use "${mobile_phone_fl1}", clear
	
	* Merge lady of the HH variable
		merge m:1 hhid using "${all_HH_nopii_fl1}", keepus(lady_hh2 a12_mobile v1) assert(2 3) nogen
		destring lady_hh2, replace
		/*
			Result                           # of obs.
			-----------------------------------------
			not matched                           399
				from master                         0  (_merge==1)
				from using                        399  (_merge==2)

			matched                             2,926  (_merge==3)
			-----------------------------------------

			399 with _merge == 2 because:
				1. 113 who didn't consent (a12_mobile == 0)
				2. 266 who has no mobile phones (v1 == 0)
				3. 20 who didn't know or didn't answer (v1 == .d or v1 == .r)
		*/
		
		
	* Gen dummy for primary female has mobile phone
		gen 	mobile_yes_pf = 1 if v3 == lady_hh2
		replace mobile_yes_pf = 0 if v3 != lady_hh2
		replace mobile_yes_pf = . if a12_mobile == 0 // 113 HHs
		replace mobile_yes_pf = . if lady_hh2 == . // 3 HHs without LHH (5 in total)
		replace mobile_yes_pf = .d if v1 == .d // 19 HHs
		replace mobile_yes_pf = .r if v1 == .r // 1 HH
		
		collapse (max) mobile_yes_pf, by(hhid)
		lab var mobile_yes_pf "Primary Woman has a mobile phone"
		tempfile mobile_yes_pf
		save 	`mobile_yes_pf'
	
	*---------------------------------------*
	* Primary female has a loan in her name *
	*---------------------------------------*	
		
	* Open loan roster
		use "${loans_fl1}", clear
		
	* Merge lady of the HH variable
		*drop m1_a
		merge m:1 hhid using "${all_HH_nopii_fl1}", keepus(lady_hh2 m1) assert(2 3) nogen
		*keep hhid loan_number m2_roster* lady_hh2 m1 m1_a
		/*
		    Result                           # of obs.
			-----------------------------------------
			not matched                         1,420
				from master                         0  
				from using                      1,420  

			matched                             1,783  
			-----------------------------------------
		
			1,420 with merge == 2 because:
				1. 1,369 HH with no outstanding loans (m1 == 0)
				2. 32 HH who said don't know to outstandin loans (m1 == -99)
				3. 9 HH who said don't answer to outstandin loans (m1 == -98)
		*/		

	* Create dummy for primary female has a loan
		replace m2_roster = " " + m2_roster + " " 
		tostring lady_hh2, replace 
		replace lady_hh2 = " " + lady_hh2 + " " 
		gen 	loan_yes_pf = (regexm(m2_roster, lady_hh2))
		replace loan_yes_pf = 0 if m1 == 0
		replace loan_yes_pf = .d if inlist(m2_roster__99, 1, .d)
		replace loan_yes_pf = .r if inlist(m2_roster__98, 1, .r)
		
		collapse (max) loan_yes_pf m1 m1_a, by(hhid)
		replace loan_yes_pf = .d if inlist(m1, -99, .d) 
		replace loan_yes_pf = .r if inlist(m1, -98, .r)
		replace loan_yes_pf = .d if inlist(m1_a, -99, .d) 
		replace loan_yes_pf = .r if inlist(m1_a, -98, .r)	
		
		replace loan_yes_pf = .r if inlist(hhid,1084,2025)
		
		lab var loan_yes_pf "Primary woman has a loan"
		tempfile loan_yes_pf
		save	`loan_yes_pf'
		
		br if hhid == 1677 // 0 .d 1 
	restore
	
	//merge 1:1 hhid using `mobile_yes_pf', assert(3) nogen
	merge 1:1 hhid using `loan_yes_pf', assert(3) nogen
  
	*--------------------------------------------------------------------*
	* Engaged in productive activities and in paid productive activities *
	*--------------------------------------------------------------------*	

	preserve
	
	* Open dataset for productive activities 	
		use "${time_activities_ses}", clear
	* Keep only primary female
		keep if lady_hh2 == member & b6 == 2
		isid hhid
		keep hhid did_labor_nohh
		rename did_labor_nohh did_labor_pf
		lab var did_labor_pf "Primary Woman Participates in Market Work"
		tempfile engaged_prod_activities_pf
		save `engaged_prod_activities_pf'
		
	*----------------------------------------------------------------------------*
	* k24: Primary female is owner or manager of a HH non-agricultural bussiness * 
	*----------------------------------------------------------------------------*	

	* Open businesses roster
		use "${businesses_fl1}", clear
		
	* Create variable if primary female is owner or manager in one of the bussiness
		gen 	owner_manager_pf = 1 if k24_3 == 1 | k24_2 == 1
		replace owner_manager_pf = 0 if k24_3 == 0 & k24_2 == 0
		replace owner_manager_pf = 0 if k23_a == 0
		
		* Get hhs with no business (none or don't know)
		*br hhid business k23_a owner_manager_pf
		gen no_biz = 1 if business == 0 & k23_a == 1
		gen dk_biz = 1 if business == -99 & k23_a == 1
		bys hhid: egen biz_no = max(no_biz)
		bys hhid: egen biz_dk = max(dk_biz)
		bys hhid: egen max_owner_manager_pf = max(owner_manager_pf)
		replace max_owner_manager_pf = 0 if biz_no == 1
		replace max_owner_manager_pf = .d if biz_dk == 1
		drop owner_manager_pf biz_no no_biz dk_biz biz_dk
		rename max_owner_manager_pf owner_manager_pf
		duplicates drop hhid, force
		lab var owner_manager_pf "Primary Woman is owner or manager of a HH non-agricultural bussiness"
		tempfile owner_manager_pf
		save	`owner_manager_pf'
		
	restore
	
	*---------------------------------------------------*
	* Index: Taking advantage of economic opportunities *
	*---------------------------------------------------*
	
	merge 1:1 hhid using `engaged_prod_activities_pf', assert(1 3) nogen	
	merge 1:1 hhid using `owner_manager_pf', assert(3) nogen
	
	loc work_vars owner_manager_pf did_labor_pf
	loc inputs_vars h30 //mobile_yes_pf
	
********************************************************************************
	** Part 5: Aspirations for daughters / Social norms
********************************************************************************
	
/* Includes:
	i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
	i2_d: How will this level of education help ${name_youngest_daughter}?
	i4_d: At what age would you like to see ${name_youngest_daughter} marry? 
	School-age girls are enrolled in school */
	
	
* i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
	foreach x in d s {
		gen 	ed_level_`x' = i1_`x' 
		replace ed_level_`x' = ed_level_`x' -1 if i1_`x'>0 & i1_`x'<=13
		replace ed_level_`x' = .  if i1_`x' == -97 // other is missing
		replace ed_level_`x' = .  if i1_`x' == 17 // whatever is already completed
		replace ed_level_`x' = 16 if i1_`x' == 14 // bachelor
		replace ed_level_`x' = 18  if i1_`x' == 15 // masters
		replace ed_level_`x' = 0  if i1_`x' == 18 // no education
		replace ed_level_`x' = 12  if i1_`x' == 16 // technical	
	}

* i2_d: How will this level of education help ${name_youngest_daughter}? -> 1 if get job/earn money, make him/her wiser
	foreach x in d s {
		gen 	ed_help_`x' = 0 if !mi(i2_`x'_1)
		replace ed_help_`x' = 1 if i2_`x'_1 == 1
		replace ed_help_`x' = 1 if i2_`x'_2 == 1
		replace ed_help_`x' = .d if i2_`x'__99 == 1
		replace ed_help_`x' = .r if i2_`x'__98 == 1
	}
	
* i4_d: At what age would you like to see ${name_youngest_daughter} marry? */
	foreach x in d s {
		gen 	age_marriage_`x' = 1 if i4_`x'>18 & !mi(i4_`x')
		replace age_marriage_`x' = 0 if i4_`x'<=18 & !mi(i4_`x')
		replace age_marriage_`x' = .d if i4_`x'==.d
		replace age_marriage_`x' = .r if i4_`x'==.r
		replace age_marriage_`x' = .o if i4_`x'==100 // implausible value (outlier)
	}

	lab var ed_level_d "Highest Education Level Desired"
	lab var ed_help_d "Education Level Desired Will Help to Get a Better Job and Make Her Wiser"
	lab var age_marriage_d "Desired Age for Marriage Is Older Than 18"
	
	loc educ_vars ed_level_d ed_help_d
	loc marriage_vars age_marriage_d
	
********************************************************************************
	** Part 6: Social Capital/Voice outside of the HH = Political involvement Index
********************************************************************************

/* Includes:
	s21: Has a Tazkira (Afghan national identification card)
	s10: Is a member of a political party
	n1: Attended village meetings 
	n2: Approached village leaders about village issue */

* Combine two voting variables 
	gen voted = .
		replace voted = 1 if (s12 == 1	| s13 == 1)
		replace voted = 0 if (s12 == 0 | s13 == 0) & mi(voted)
		replace voted = .r if (s12 == .r | s13 == .r) & mi(voted)
	
* Labels
	lab var voted "Voted either in provincial or presidential election"
	lab var s21 "Has a Tazkira (Afghan national identification card)"
	lab var s10 "Is a member of a political party"
	lab var n1 "Attended village meetings"
	lab var n2 "Approached village leaders about village issue"
	
* Local for survey vars related to political involment
	loc tazkira_vars s21
	loc political_vars s10 voted
	loc community_vars n1 n2
	
********************************************************************************
	** Part 7: Construction of indices
********************************************************************************

	* Decisionmaking
	loc foodexp_l		"Major Say in Food Expenditures and What to Cook"
	loc homeexp_l 		"Major Say in Home Improvements/Repairs"
	loc homefin_l 		"Major Say in Managing Household Finances"
	loc chischool_l 	"Major Say in Children's School Attendance"
	loc chihealth_l 	"Major Say in Children's Health Seeking"
	loc chimarr_l 		"Major Say in Children's Marriage"
	loc homesale_l		"Major Say in Buying or Selling Land or Property"
	loc otherexp_l 		"Major Say in Clothing and Other Non-food Expenditures"
	loc fert_l 			"Major Say in Her Fertility"
	loc econdec_l 		"Major Say in Her Taking a Loan, Opening a Business, and Working Outside of Home"
	
	* Econ opp 
	loc work_l "Participation in Market Work and Running a Business"
	loc inputs_l "Access to Resources and Inputs"
	
	* Political and Social Capital
	loc tazkira_l	"National ID Ownership"
	loc political_l "Political Participation"
	loc community_l "Community Participation"
	
	* Aspirations 
	loc educ_l "Daughters' Education"
	loc marriage_l "Daughter's Marriage in Adulthood"
	
	gl all "foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert econdec work inputs" // tazkira political community educ marriage  
	
	//keep if ultra_poor == 1
	//keep if ultra_poor == 0
	keep if control == 1
	
	* There are 3 households with no LHH, so we have to drop those HHs 
		drop if respondent_gender == 1
	* Drop if there is no PM (i.e., HHH is female) - for ethnic heterogeneity analysis only 
		//drop if hh_head_gender == 2
		
	* Define a variable with which to standardize the index	
	global normvar pashto // control  // pashto
	
	* Create indices
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index' "``index'_l' Index sd(${normvar})"	
		}	
	
	/* Create special index to be compared
/* Includes:
	h1: What to cook on a daily basis
	h2: Buying groceries
	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
	h6: Buying or selling land or property
	h7: Managing household finances
	h8: Making home improvements/repair 
	h9: Whether your daughter should attend school
	h10: Whether your son should attend school
	h11: Marriage of daughters
	h12: Marriage of sons
	h13: Consulting a doctor when your child is ill	 
	 Political Involvement
	s21: Has a Tazkira (Afghan national identification card)
	s10: Is a member of a political party
	n1: Attended village meetings 
	n2: Approached village leaders about village issue */
	
	* with Ethipoia, India, Peru 
			local comp_EthiIndPer h1_ac h2_ac h7_ac h8_ac h9_ac h10_ac h13_ac
			egen index_sdC_we_compEthiIndPer = weightave(`comp_EthiIndPer'), normby(${normvar})
			lab var index_sdC_we_compEthiIndPer "Women's Empowerment for comparison with Ethiopia, India, Peru,  sd(${normvar})"	
			
			local comp_pol_Ethi h1_ac h2_ac h7_ac h8_ac h9_ac h10_ac h13_ac s10 n1 n2
			egen index_sdC_we_comp_polEth = weightave(`comp_pol_Ethi'), normby(${normvar})
			lab var index_sdC_we_comp_polEth "Women's Empowerment + Political for comparison with Ethiopia sd(${normvar})"	
			
	 * with Ghana, Honduras	
			local comp_GhanaHond h1_ac h2_ac h7_ac  h9_ac h10_ac h13_ac /*h8 not included in Ghana Honduras*/
			egen index_sdC_we_compGhanaHond = weightave(`comp_GhanaHond'), normby(${normvar})
			lab var index_sdC_we_compGhanaHond "Women's Empowerment for comparison with Ghana, Honduras,  sd(${normvar})"
			
			local comp_pol_Hond h1_ac h2_ac h7_ac  h9_ac h10_ac h13_ac s10 n1 n2 /*h8 not included in Ghana Honduras*/
			egen index_sdC_we_comp_polHond = weightave(`comp_pol_Hond'), normby(${normvar})
			lab var index_sdC_we_comp_polHond "Women's Empowerment + Political for comparison with  Honduras,  sd(${normvar})"
			
	* with Pakistan
			local comp_Pakistan h1_ac h2_ac  h8_ac h9_ac h10_ac h13_ac /*h7 not included in Pakistan*/
			egen index_sdC_we_compPakistan = weightave(`comp_Pakistan'), normby(${normvar})
			lab var index_sdC_we_compPakistan "Women's Empowerment for comparison with Pakistan  sd(${normvar})"	
			
			local comp_pol_Pakistan h1_ac h2_ac  h8_ac h9_ac h10_ac h13_ac s10 n1 n2 /*h7 not included in Pakistan*/
			egen index_sdC_we_comp_polPakistan = weightave(`comp_pol_Pakistan'), normby(${normvar})
			lab var index_sdC_we_comp_polPakistan "Women's Empowerment + Political for comparison with Pakistan  sd(${normvar})"	
			

	* Common Women's Empowerment  - only Z score		
			local comp_we_com   h1_ac h2_ac h9_ac h10_ac h13_ac  /*Adding all decision making + political*/
			
	* Common Women's Empowerment and all political involment - only Z score		
			local comp_we_com_work h1_ac h2_ac h9_ac h10_ac h13_ac `work_vars' `inputs_vars'  /*Adding economic empowerment*/

	* Common Women's Empowerment and all political involment and market awork - only Z score		
			local comp_we_com_work_pol h1_ac h2_ac h9_ac h10_ac h13_ac  `work_vars' `inputs_vars' `tazkira_vars' `political_vars' `community_vars' /*Adding political*/			
			
			
	* For these, computing index similarly as in Banerjee et al. (2015) science paper. Simple Z score
			foreach var in `comp_we_com_work_pol' h7_ac h8_ac {
gen `var'_Z = .
			 sum `var' if treatment==0 
			if `r(N)' > 0 {
				replace `var'_Z = (`var' - `r(mean)') / `r(sd)' 
		}
	}



foreach comp in EthiIndPer GhanaHond Pakistan pol_Ethi pol_Hond pol_Pakistan  we_com we_com_work we_com_work_pol {
local `comp'_Z ""
			foreach var in `comp_`comp'' {
		local `comp'_Z ``comp'_Z' `var'_Z 		
			}
		disp 	"``comp'_Z'"
		egen index_Z_we_comp`comp' = rowmean(``comp'_Z')
	}	


	

foreach comp in EthiIndPer GhanaHond Pakistan  pol_Ethi pol_Hond pol_Pakistan we_com we_com_work we_com_work_pol {
			qui sum index_Z_we_comp`comp' if treatment==0 
			if `r(N)' > 0 {
				disp  "index_Z_we_comp`comp'"
				replace index_Z_we_comp`comp' = (index_Z_we_comp`comp' - `r(mean)')/`r(sd)' 
			}	
		}

lab var index_Z_we_compEthiIndPer 	 "Women's Empowerment for comparison with Ethiopia, India, Peru, Z score"	
lab var index_Z_we_compGhanaHond 	 "Women's Empowerment for comparison with Ghana, Honduras, Z score"
lab var index_Z_we_compPakistan	     "Women's Empowerment for comparison with Pakistan Z score"

lab var index_Z_we_comppol_Ethi	 "Women's Empowerment for comparison with Ethiopia, Z score"	
lab var index_Z_we_comppol_Hond 	 "Women's Empowerment for comparison with Honduras, Z score"
lab var index_Z_we_comppol_Pakistan	     "Women's Empowerment for comparison with Pakistan Z score" */

* Decisionmaking index
	loc decide_index "index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert index_sdC_econdec"
	egen index_sdC_all_decisions = weightave(`decide_index'), normby(${normvar})
	lab var index_sdC_all_decisions "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index
	loc econ_opp_index "index_sdC_work index_sdC_inputs"
	egen index_sdC_role_prod_act = weightave(`econ_opp_index'), normby(${normvar})
	lab var index_sdC_role_prod_act "Economic Opportunities Index sd(${normvar})"
	
/* Social Norms Index
	loc soc_norms_index "index_sdC_educ index_sdC_marriage"
	egen index_sdC_social_norms = weightave(`soc_norms_index'), normby(${normvar})
	lab var index_sdC_social_norms "Aspirations for Daughters Index sd(${normvar})"

* Social Capital Index
	loc soc_cap_index "index_sdC_tazkira index_sdC_political index_sdC_community"
	egen index_sdC_social_capital = weightave(`soc_cap_index'), normby(${normvar})
	lab var index_sdC_social_capital "Social Capital Index sd(${normvar})"*/
	
* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	loc all_index "index_sdC_all_decisions index_sdC_role_prod_act" // index_sdC_social_capital index_sdC_social_norms
	egen index_sdC_f_empowerment = weightave(`all_index'), normby(${normvar})
	lab var index_sdC_f_empowerment "Women's Empowerment Index sd(${normvar})"	
	
/********************************************************************************
	** Part 8: Robustness Checks 
********************************************************************************	
* Creating indices including the robustness variables instead 
		
	loc work_vars_r   	 	`work_vars'
	loc inputs_vars_r    	`inputs_vars'
	loc educ_vars_r     	`educ_vars'
	loc marriage_vars_r     `marriage_vars'
	loc tazkira_vars_r   	`tazkira_vars'
	loc political_vars_r   	`political_vars'
	loc community_vars_r   	`community_vars'

	foreach index in $all {
		display "`index'"
		des ``index'_vars_r'
		egen index_sdC_`index'_r = weightave(``index'_vars_r'), normby(${normvar})
		lab var index_sdC_`index'_r "``index'_l' Index sd(${normvar}) Robustness"	
	}	
		         	 
* Decisionmaking index (10 components)
	loc decide_index_r "index_sdC_foodexp_r index_sdC_homeexp_r index_sdC_homefin_r index_sdC_chischool_r index_sdC_chihealth_r index_sdC_chimarr_r index_sdC_homesale_r index_sdC_otherexp_r index_sdC_fert_r index_sdC_econdec_r"
	egen index_sdC_all_decisions_r = weightave(`decide_index_r'), normby(${normvar})
	lab var index_sdC_all_decisions_r "Women's Deciosionmaking Index sd(${normvar}) Robustness"	
		
* Econ Opp Index
	loc econ_opp_index_r "index_sdC_work_r index_sdC_inputs_r"
	egen index_sdC_role_prod_act_r = weightave(`econ_opp_index_r'), normby(${normvar})
	lab var index_sdC_role_prod_act_r "Economic Opportunities Index sd(${normvar}) Robustness"
	
* Social Norms Index
	loc soc_norms_index_r "index_sdC_educ_r index_sdC_marriage_r"
	egen index_sdC_social_norms_r = weightave(`soc_norms_index_r'), normby(${normvar})
	lab var index_sdC_social_norms_r "Aspirations for Daughters Index sd(${normvar}) Robustness"

* Social Capital Index
	loc soc_cap_index_r "index_sdC_tazkira_r index_sdC_political_r index_sdC_community_r"
	egen index_sdC_social_capital_r = weightave(`soc_cap_index_r'), normby(${normvar})
	lab var index_sdC_social_capital_r "Social Capital Index sd(${normvar}) Robustness"		
		
* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	loc all_index_r "index_sdC_all_decisions_r index_sdC_role_prod_act_r index_sdC_social_norms_r index_sdC_social_capital_r"
	egen index_sdC_f_empowerment_r = weightave(`all_index_r'), normby(${normvar})
	lab var index_sdC_f_empowerment_r "Women's Empowerment Index sd(${normvar}) Robustness"	
	
	
*Z index 
			
foreach var in s10 n1 n2	 {
	gen `var'_r = `var'
}


			foreach var in `comp_pol_Ethi'  {
gen `var'_Z_r = .
			 sum `var'_r if treatment==0 
			if `r(N)' > 0 {
				replace `var'_Z_r = (`var'_r - `r(mean)') / `r(sd)' 
		}
	}



foreach comp in EthiIndPer pol_Ethi {
local `comp'_Z_r ""
			foreach var in `comp_`comp'' {
		local `comp'_Z_r ``comp'_Z_r' `var'_Z_r 		
			}
		egen index_Z_we_comp`comp'_r = rowmean(``comp'_Z_r')
	}	

	
	

foreach comp in EthiIndPer   pol_Ethi  {
			qui sum index_Z_we_comp`comp'_r if treatment==0 
			if `r(N)' > 0 {
				replace index_Z_we_comp`comp'_r = (index_Z_we_comp`comp'_r - `r(mean)')/`r(sd)' 
			}	
		}
			
	
********************************************************************************
	** Part 9: Men-headed households
********************************************************************************

	preserve
		keep if hh_head_gender == 1
		
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_m = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_m "``index'_l' Index sd(${normvar}) - Men-headed HH"	
		}	
		
* Decisionmaking index
	loc decide_index_m "index_sdC_foodexp_m index_sdC_homeexp_m index_sdC_homefin_m index_sdC_chischool_m index_sdC_chihealth_m index_sdC_chimarr_m index_sdC_homesale_m index_sdC_otherexp_m index_sdC_fert_m index_sdC_econdec_m"
	egen index_sdC_all_decisions_m = weightave(`decide_index_m'), normby(${normvar})
	lab var index_sdC_all_decisions_m "Women's Decisionmaking Index sd(${normvar}) - Men-headed HH"			
	
* Econ Opp Index
	loc econ_opp_index_m "index_sdC_work_m index_sdC_inputs_m"
	egen index_sdC_role_prod_act_m = weightave(`econ_opp_index_m'), normby(${normvar})
	lab var index_sdC_role_prod_act_m "Economic Opportunities Index sd(${normvar}) - Men-headed HH"
	
* Social Norms Index
	loc soc_norms_index_m "index_sdC_educ_m index_sdC_marriage_m"
	egen index_sdC_social_norms_m = weightave(`soc_norms_index_m'), normby(${normvar})
	lab var index_sdC_social_norms_m "Aspirations for Daughters Index sd(${normvar}) - Men-headed HH"

* Social Capital Index
	loc soc_cap_index_m "index_sdC_tazkira_m index_sdC_political_m" // index_sdC_community_m
	egen index_sdC_social_capital_m = weightave(`soc_cap_index_m'), normby(${normvar})
	lab var index_sdC_social_capital_m "Social Capital Index sd(${normvar}) - Men-headed HH"	
	
	
* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	loc all_index_m "index_sdC_all_decisions_m index_sdC_role_prod_act_m index_sdC_social_capital_m index_sdC_social_norms_m"
	egen index_sdC_f_empowerment_m = weightave(`all_index_m'), normby(${normvar})
	lab var index_sdC_f_empowerment_m "Women's Empowerment Index sd(${normvar}) - Men-headed HH"		
	
		tempfile malehead
		save	`malehead'
	restore
	
	merge 1:1 hhid using `malehead', assert(1 3) nogen
	
	
********************************************************************************
	** Part 10: Women-headed households
********************************************************************************

	preserve
		keep if hh_head_gender == 2
		
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_w = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_w "``index'_l' Index sd(${normvar}) - Women-headed HH"	
		}	
		
* Decisionmaking index
	loc decide_index_w "index_sdC_foodexp_w index_sdC_homeexp_w index_sdC_homefin_w index_sdC_chischool_w index_sdC_chihealth_w index_sdC_chimarr_w index_sdC_homesale_w index_sdC_otherexp_w index_sdC_fert_w index_sdC_econdec_w"
	egen index_sdC_all_decisions_w = weightave(`decide_index_w'), normby(${normvar})
	lab var index_sdC_all_decisions_w "Women's Decisionmaking Index sd(${normvar}) - Women-headed HH"			
	
* Econ Opp Index
	loc econ_opp_index_w "index_sdC_work_w index_sdC_inputs_w"
	egen index_sdC_role_prod_act_w = weightave(`econ_opp_index_w'), normby(${normvar})
	lab var index_sdC_role_prod_act_w "Economic Opportunities Index sd(${normvar}) - Women-headed HH"
	
* Social Norms Index
	loc soc_norms_index_w "index_sdC_educ_w index_sdC_marriage_w"
	egen index_sdC_social_norms_w = weightave(`soc_norms_index_w'), normby(${normvar})
	lab var index_sdC_social_norms_w "Aspirations for Daughters Index sd(${normvar}) - Women-headed HH"

* Social Capital Index
	loc soc_cap_index_w "index_sdC_tazkira_w index_sdC_political_w index_sdC_community_w"
	egen index_sdC_social_capital_w = weightave(`soc_cap_index_w'), normby(${normvar})
	lab var index_sdC_social_capital_w "Social Capital Index sd(${normvar}) - Women-headed HH"	
	
	
* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	loc all_index_w "index_sdC_all_decisions_w index_sdC_role_prod_act_w index_sdC_social_norms_w index_sdC_social_capital_w"
	egen index_sdC_f_empowerment_w = weightave(`all_index_w'), normby(${normvar})
	lab var index_sdC_f_empowerment_w "Women's Empowerment Index sd(${normvar}) - Women-headed HH"

	
		tempfile womanhead
		save	`womanhead'
	restore
	
	merge 1:1 hhid using `womanhead', assert(1 3) nogen /
	

* Save data
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_fl1}", replace v(13) 
	}
	else {
		save "${f_empowerment_fl1}", replace
	}		
	

 Save data
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_eth_fl1}", replace v(13) 
	}
	else {
		save "${f_empowerment_eth_fl1}", replace
	}	
	*/
	
/* Save data - NUP version
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_nup_eth_fl1}", replace v(13) 
	}
	else {
		save "${f_empowerment_nup_eth_fl1}", replace
	}		
			
			stop*/
* Save data - Control version
	if	`c(stata_version)'>=14	{
		saveold "${f_empowerment_control_eth_fl1}", replace v(13) 
	}
	else {
		save "${f_empowerment_control_eth_fl1}", replace
	}		
					
			
	
