/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 26, 2019
Last udpate on: Mar 26, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates health variables for follow-up

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl profile_info				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl current_roster_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/br_hhmemcurrent_fl1.dta"

* Outputs
	gl health_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/health_fl1.dta"
	
	
********************************************************************************
	** Part 1: Getting information on Under 5 kid, especially gender
********************************************************************************	
use "${current_roster_fl1}", clear
	drop if b8 >5 //only keeping under 5

	gen inv_b8 = - b8
*If two children have the same age (3% of the sample), we take the one which was introduced first in the roster, ie the smallest member number
	bysort hhid (inv_b8 member) : keep if _n == 1	
	
	keep hhid b8 b6
	rename b8 b8_ou5
	rename b6 b6_ou5
	tempfile gender_ou5
	save `gender_ou5'

********************************************************************************
	** Part 2: Under 5 Diarrhea
********************************************************************************

use "${all_HH_nopii_fl1}", clear

* Merging with age and gender of Older Under 5
	merge 1:1 hhid using `gender_ou5', assert(1 3) nogen //Not merging from master is for hh which do not have under 5 children	
	
	
/*
    Result                           # of obs.
    -----------------------------------------
    not matched                           903
        from master                       903  (_merge==1)
        from using                          0  (_merge==2)

    matched                             1,592  (_merge==3)
    -----------------------------------------
*/	
	
	

* Being sick
	clonevar diarrhea_yes = f6
	clonevar fever_yes = f10
	clonevar birth_yes = f17
	lab var diarrhea_yes "Diahrrea in oldest under-5 child (last 2 weeks)"
	lab var fever_yes "Fever in oldest under-5 child (last 2 weeks)"
	lab var birth_yes "Primary woman has given birth in the last 2 years"
	
	foreach var in diarrhea_yes fever_yes {
		gen `var'_f = `var' if b6_ou5 == 2
		gen `var'_m = `var' if b6_ou5 == 1
	}
	
	lab var diarrhea_yes_f 	"Diahrrea in OU5 child, if a girl"
	lab var diarrhea_yes_m 	"Diahrrea in OU5 child, if a boy"
	lab var fever_yes_f 	"Fever in OU5 child , if a girl"
	lab var fever_yes_m 	"Fever in OU5 child , if a boy"
	
	*Generating a dummy for whether the oldest under 5 is male
		gen ou5_m = 2 - b6_ou5
		label def gender2 0 "Girl" 1 "Boy"
		label value ou5_m gender2
		label var ou5_m "Oldest Under 5 (OU5) Child is a Boy"
	
* Sought advice
	clonevar diarrhea_advice = f7
	clonevar fever_advice = f11
	clonevar birth_advice = f18
	lab var diarrhea_advice "Sought advice for diarrhea treatment"
	lab var fever_advice "Sought advice for fever treatment"
	lab var birth_advice "Saw someone for prenatal care (most recent pregnancy)"
	
	foreach var in diarrhea_advice fever_advice {
		gen `var'_f = `var' if b6_ou5 == 2
		gen `var'_m = `var' if b6_ou5 == 1
	}
	
	lab var diarrhea_advice_f 	"Sought advice for diarrhea treatment, if child is a girl"
	lab var diarrhea_advice_m 	"Sought advice for diarrhea treatment, if child is a boy"
	lab var fever_advice_f 		"Sought advice for fever treatment , if child is a girl"
	lab var fever_advice_m 		"Sought advice for fever treatment , if child is a boy"

* Vaccination
	gen 	vaccines_card = f14
	replace vaccines_card = f14_b if f14==0
	lab var vaccines_card "Has vaccination card for at least one of the under-5 children"
	gen 	vaccines_card_checked = f15_a
	replace vaccines_card_checked = 0 if mi(vaccines_card_checked) & !mi(vaccines_card)
	lab var vaccines_card_checked "Vaccination card (checked)"
	
	foreach var in vaccines_card_checked {
		gen `var'_f = `var' if b6_ou5 == 2
		gen `var'_m = `var' if b6_ou5 == 1
	}
	
	lab var vaccines_card_checked_f 	"Vaccination card (checked), if child is a girl"
	lab var vaccines_card_checked_m 	"Vaccination card (checked), if child is a boy"
	
* Causes of diarrhea
	gen 	f4_dkda = f4__98
	replace f4_dkda = f4__99 if f4_dkda==0
	lab var f4_1 "Mosquitoes"
	lab var f4_2 "Drinking contaminated water"
	lab var f4_3 "Too much sunlight"
	lab var f4_4 "Contact with contaminated feces"
	lab var f4__97 "Other (please specify)"
	lab var f4_dkda "Don't know/Don't answer"
	/*
	Options selected: included other
			  a |      Freq.     Percent        Cum.
	------------+-----------------------------------
			  1 |        243       36.05       36.05
			  2 |        254       37.69       73.74
			  3 |        126       18.69       92.43
			  4 |         51        7.57      100.00
	------------+-----------------------------------
		  Total |        674      100.00

	Options selected: without other
			  a |      Freq.     Percent        Cum.
	------------+-----------------------------------
			  0 |         20        2.97        2.97
			  1 |        241       35.76       38.72
			  2 |        241       35.76       74.48
			  3 |        123       18.25       92.73
			  4 |         49        7.27      100.00
	------------+-----------------------------------
		  Total |        674      100.00
	*/

	keep hhid *_yes* *_advice* vaccines_card vaccines_card_checked* f4_1 f4_2 f4_3 f4_4 f4__97 f4_dkda ou5_m

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery ultra_poor) keep(1 3) nogen	
	

* Save
	if	`c(stata_version)'>=14	{
		saveold "${health_fl1}", replace v(13)
	}
	else {
		save "${health_fl1}", replace
	}

