/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Feb 26, 2019
Last udpate on: Feb 26, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Makes imputations in the endline database for Market survey. 


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/


********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Market clean
		gl market_clean_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/market_clean_fl1.dta"

* Outputs
	
	*if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
		gl market_imputed_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"
	/* }
		if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub
			gl market_clean_fl1 	"${fl1_dt}/Intermediate/market_clean_fl1.dta"
		}
	*/


********************************************************************************
	** Part 1: Take medians to replace missings
********************************************************************************

use "${market_clean_fl1}", clear

ds ms*
loc price_vars `r(varlist)'
	
* Calculate medians and replace missings
	foreach price_var of varlist `price_vars' {
		tempvar `price_var'_median
		egen 	``price_var'_median' = median(`price_var')
		replace `price_var' = ``price_var'_median' if mi(`price_var')
	}

* For category "other", we take the median of the products of that category
	foreach category of numlist 1(1)9 {
		egen ms`category'_oth = rowmedian(ms`category'_*)
	}
	
* Renaming so it can be merge with consumption dataset
	* Bread
		rename 	(ms1_a ms1_b ms1_c ms1_d ms1_e ms1_f ms1_g ms1_h ms1_i ms1_j ms1_k ms1_oth) ///
				(ms1_1 ms1_2 ms1_3 ms1_5 ms1_6 ms1_7 ms1_8 ms1_9 ms1_10 ms1_11 ms1_4 ms1_12)
	* Meat
		rename (ms2_a ms2_b ms2_c ms2_d ms2_e ms2_f ms2_g ms2_h ms2_oth) ///
			   (ms2_14 ms2_15 ms2_16 ms2_17 ms2_18 ms2_19 ms2_20 ms2_21 ms2_22)
	* Dairy
		rename (ms3_a ms3_b ms3_c ms3_d ms3_e ms3_f ms3_g ms3_h ms3_i ms3_j ms3_oth) ///
			   (ms3_24 ms3_25 ms3_26 ms3_27 ms3_28 ms3_29 ms3_30 ms3_31 ms3_32 ms3_33 ms3_34)
	* Oils
		rename (ms4_a ms4_c ms4_b ms4_oth) ///
			   (ms4_36 ms4_37 ms4_38 ms4_39)
	* Vegetables
		rename 	(ms5_a ms5_b ms5_c ms5_d ms5_e ms5_f ms5_g ms5_h ms5_i ms5_j ms5_k ms5_l ms5_m ms5_n ms5_o ms5_p ms5_q ms5_r ms5_s ms5_t ms5_u ms5_v ms5_w ms5_oth) ///
				(ms5_41 ms5_42 ms5_43 ms5_44 ms5_45 ms5_46 ms5_47 ms5_48 ms5_49 ms5_50 ms5_51 ms5_52 ms5_53 ms5_54 ms5_55 ms5_56 ms5_57 ms5_58 ms5_59 ms5_60 ms5_61 ms5_62 ms5_63 ms5_64) 
	* Fruits
		rename (ms6_a ms6_b ms6_c ms6_d ms6_e ms6_f ms6_g ms6_h ms6_i ms6_j ms6_k ms6_l ms6_m ms6_n ms6_o ms6_p ms6_q ms6_r ms6_oth) ///
				(ms6_66 ms6_67 ms6_68 ms6_69 ms6_70 ms6_71 ms6_72 ms6_73 ms6_74 ms6_75 ms6_76 ms6_77 ms6_78 ms6_79 ms6_80 ms6_81 ms6_82 ms6_83 ms6_84)
	* Sweets
		rename (ms7_a ms7_b ms7_c ms7_d ms7_e ms7_oth) ///
				(ms7_86 ms7_87 ms7_88 ms7_89 ms7_90 ms7_92)
	* Beverages
		rename (ms9_a ms9_b ms9_c ms9_oth) ///
				(ms9_94 ms9_95 ms9_96 ms9_97)
	* Spices
		rename (ms8_a ms8_b ms8_c ms8_d ms8_e ms8_oth) ///
				(ms8_99 ms8_100 ms8_101 ms8_102 ms8_103 ms8_104)
				
* Reshape
	keep vc3 ms*
	rename vc3 district
	reshape long ms1_ ms2_ ms3_ ms4_ ms5_ ms6_ ms7_ ms8_ ms9_, i(district) j(item)
	rename ms*_ ms*
	reshape long ms, i(district item) j(item_type_s) 
	sort district item_type_s item
	drop if mi(ms)
		
* Adjust variables so it can be merge with consumption dataset
	gen 	item_type = "Bread" if item_type_s == 1
	replace item_type = "Meat" if item_type_s == 2
	replace item_type = "Dairy" if item_type_s == 3
	replace item_type = "Oils" if item_type_s == 4
	replace item_type = "Vegetables" if item_type_s == 5
	replace item_type = "Fruits" if item_type_s == 6
	replace item_type = "Sweets" if item_type_s == 7
	replace item_type = "Beverages" if item_type_s == 9
	replace item_type = "Spices" if item_type_s == 8
	drop item_type_s
		
* Labels
	lab var item "Item"
	rename ms price
	lab var price "Price (Afhganis)"
	lab var item_type "Item type"
	order item_type, after(district)

* District
	lab def district_l  1 "Dowlat Abad District" ///
						2 " Dehdadi District" ///
						3 "Nahre Shahee District" ///
						4 "Khulm District"
	
	
	* Labels
	lab def item_l 	1 "Rice (high quality)" 2 "Rice (low quality)" 3 "Wheat flour" ///
					4 "Naan not made at home" 5 "Barley" 6 "Maize" 7 "Beans" 8 "Mung" ///
					9 "Chickpeas" 10 "Lentils" 11 "Pasta" 12 "Other bread and/or cereal" ///
					13 "None" 14 "Beef" 15 "Veal" 16 "Mutton" 17 "Goat" 18 "Chicken" 19 "Liver" ///
					20 "Dried Meat" 21 "Fish" 22 "Other meat and/or fish" 23 "None" 24 "Milk (fresh)" ///
					25 "Milk (powdered)" 26 "Yogurt" 27 "Curd (chaka)" 28 "Krut (dried)" ///
					29 "Dogh" 30 "Ghee" 31 "Butter" 32 "Cheese" 33 "Eggs" 34 "Other dairy products" ///
					35 "None" 36 "Vegetable oil" 37 "Cotton oil or sesame oil" 38 "Animal fat" ///
					39 "Other oils and fat" 40 "None" 41 "Potato" 42 "Sweet potato" 43 "Onion" ///
					44 "Tomato" 45 "Okra" 46 "Spinach" 47 "Cauliflower" 48 "Eggplant" 49 "Carrots" ///
					50 "Pumpkin, squash" 51 "Cucumber" 52 "Radish" 53 "Turnip" 54 "Cabbage" ///
					55 "Leek" 56 "Hot pepper" 57 "Wild leafy vegetables" 58 "Coriander" 59 "Mint" ///
					60 "Dried tomatoes" 61 "Dried vegetables" 62 "Pickled vegetables" ///
					63 "Green beans" 64 "Other vegetables" 65 "None" 66 "Apple" 67 "Grapes" ///
					68 "Melon/watermelon" 69 "Peach" 70 "Fresh apricots" 71 "Dried apricots" ///
					72 "Orange/citrus" 73 "Plum" 74 "Pomegranate" 75 "Pear" 76 "Banana" ///
					77 "Raisins" 78 "Fresh mulberries" 79 "Dried mulberries" 80 "Mangoes" ///
					81 "Walnuts" 82 "Pistachio" 83 "Almonds" 84 "Other fruit and/or nuts" ///
					85 "None" 86 "White sugar" 87 "Brown sugar" 88 "Honey" 89 "Chocolates" ///
					90 "Candy, sherinigack" 91 "Sweetener" 92 "Other sweets, specify" 93 "None" ///
					94 "Black teas" 95 "Green teas" 96 "Bottled/canned beverages, Mineral waters" ///
					97 "Other beverages" 98 "None" 99 "Salt" 100 "Black pepper" 101 "Ginger and garlic" ///
					102 "Tomato sauce" 103 "Mixed spices" 104 "Other spices" 105 "None"
	lab val item item_l
		
	
* Save

	if	`c(stata_version)'>=14	{
		saveold "${market_imputed_fl1}", replace v(13)
	}
	else {
		save "${market_imputed_fl1}", replace
	}		
