/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Feb 24, 2020


Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates phone ownership roster to use

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************


	clear all
	set more off
	set maxvar 20000


* Inputs
	gl mobile_phone_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/v_mobile_fl1.dta"
	gl roster 							"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"	
	gl all_HH_nopii_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"

	
* Outputs
	global mobile_phone_ownership_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/mobile_phone_ownership_fl1.dta"

********************************************************************************
	** Part 1: Phone
********************************************************************************


	* Open phone roster
		use "${mobile_phone_fl1}", clear
		rename v3 member
		drop a12_mobile
	
	* Merge lady of the HH variable
		merge m:1 hhid member using "${roster}", assert(2 3) nogen   //Many members do not own a phone obviously 


		/*
    Result                           # of obs.
    -----------------------------------------
    not matched                        14,404
        from master                         0  (_merge==1)
        from using                     14,404  (_merge==2)

    matched                             2,926  (_merge==3)
    -----------------------------------------

		*/
		
		merge m:1 hhid using "${all_HH_nopii_fl1}", keepus(a12_mobile v1) assert(3) nogen //Everything should merge because of 
		
		
	* Gen dummy for primary female has mobile phone
		gen 	own_mobile 	  = 0
		replace own_mobile 	  = 1 if  mobile_phone >= 1 & !mi(mobile_phone)
		replace own_mobile 	  = . if a12_mobile == 0 // 113 HHs
		replace own_mobile 	  = .d if v1 == .d // 19 HHs
		replace own_mobile    = .r if v1 == .r // 1 HH
		
		collapse (max) own_mobile , by(hhid member)
		lab var own_mobile "HH Member has at least one mobile phone"
		
		*merging back to have all the other variables
		merge 1:1 hhid member using "${roster}", assert(3) nogen 
* Save
	if	`c(stata_version)'>=14	{
		saveold "${mobile_phone_ownership_fl1}", replace v(13)
	}
	else {
		save "${mobile_phone_ownership_fl1}", replace
	}
