/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 6, 2019
Last udpate on: Mar 6, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates political involvement and food security indices.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl profile_info				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"

* Outputs
	gl polinvolvement	"${TUP_DB}/Followup_1/DataSets/Intermediate/political_involvement_index_fl1.dta"
	gl foodsecurity 	"${TUP_DB}/Followup_1/DataSets/Intermediate/food_security_index_fl1.dta"

********************************************************************************
	** Part 1: Prepare dataset
********************************************************************************

use "${all_HH_nopii_fl1}", clear

* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info}", keepus(treatment PRA_lottery) keep(1 3) nogen

* Control dummy
	gen 	control = treatment==0
	replace control = . if mi(treatment)
	lab var control "HH is part of control group"
	
*-----------------------*
* Political involvement *
*-----------------------*
/*
1. Voted in the last presidential election: s12
2. Voted in the last provincial council election: s13
3. Has a Tazkira (Afghan national identification card): s21
4. Is a member of a political party: s10
5. Attended village meetings: n1
6. Approached village leaders about village issue: n2
*/
	
* Observed tazkira
	gen 	s24_index = 1 if inlist(s24, 1, 2)
	replace s24_index = 0 if inlist(s24, 3, 4)
	loc s24_index_l "Observed registration stamp in any Tazkira"
	
* Local for survey vars related to political involment
	loc pol_involv_vars "s21 s10 n1 n2" // s12
	*loc pol_involv_village_vars "n1 n2"
	
* Labels
	loc s12_l "Voted in the last presidential election"
	loc s13_l "Voted in the last provincial council election"
	loc s21_l "Has a Tazkira (Afghan national identification card)"
	loc s10_l "Is a member of a political party"
	loc n1_l "Attended village meetings"
	loc n2_l "Approached village leaders about village issue"

*---------------*
* Food security *
*---------------*
	
/*
1. Everyone eats at least two meals every day: c14_7
2. No adult skips meal or cut the size of meals: c14_3
3. No child skips meal or cut the size of meals	c14_5
4. No food to eat: c14_1
*/	
	
* Local for survey vars related to political involment that need convertion to positive
	loc foodsec_survey_vars "c14_3 c14_5 c14_1"
	
	foreach var of local foodsec_survey_vars {
		gen 	`var'_ac=1 if `var'==0
		replace `var'_ac=0 if `var'==1
	}
	
* Labels
	loc c14_7_l "Everyone regularly eats at least two meals every day"
	loc c14_3_ac_l "No adult skips or cut the size of meals"
	loc c14_5_ac_l "No child skips or cut the size of meals"
	loc c14_1_ac_l "There was enough food"
	
	loc food_sec_vars "c14_7 c14_3_ac c14_5_ac"
	loc food_sec2_vars "c14_7 c14_3_ac c14_5_ac c14_1_ac"

********************************************************************************
	** Part 2: Construct indices
********************************************************************************
	
	loc pol_involv_l "Political involvement"
	loc food_sec_l "Food security"
	loc food_sec2_l "Food security (with enough food to eat)"
	loc sd_var_l "Control"
	loc sd_var "control"
	
	gl all "pol_involv food_sec food_sec2"
	
	foreach index in $all {
		foreach var of local `index'_vars {
			lab var `var' "``var'_l'"
		}
		preserve
			keep if ultra_poor == 1
			egen index_sdC_`index' = weightave(``index'_vars'), normby(`sd_var')
			lab var index_sdC_`index' "``index'_l' Index sd(`sd_var_l')"
			keep hhid index_sdC_`index' 
			tempfile index_sdC_`index'
			save	`index_sdC_`index''
					
		restore
		
		egen index_sdUP_`index' = weightave(``index'_vars'), normby(ultra_poor)
		lab var index_sdUP_`index' "``index'_l' Index sd(Ultra-Poor)"	
	}

	merge 1:1 hhid using `index_sdC_pol_involv', assert(1 3) nogen
	merge 1:1 hhid using `index_sdC_food_sec', assert(1 3) nogen
	merge 1:1 hhid using `index_sdC_food_sec2', assert(1 3) nogen
	
* Save datasets		
	* Political involvement
		preserve
			keep hhid `pol_involv_vars' `pol_involv_village_vars' index_sdC_pol_involv index_sdUP_pol_involv //index_sdC_pol_involv_village index_sdUP_pol_involv_village
			
			if	`c(stata_version)'>=14	{
				saveold "${polinvolvement}", replace v(13)
			}
			else {
				save "${polinvolvement}", replace
			}
		restore
		
	* Food security
		preserve
			keep hhid `foodsec_survey_vars'  `food_sec_vars' `food_sec2_vars' index_sdC_food_sec index_sdC_food_sec2 index_sdUP_food_sec index_sdUP_food_sec2
			
			if	`c(stata_version)'>=14	{
				saveold "${foodsecurity}", replace v(13)
			}
			else {
				save "${foodsecurity}", replace
			}
		restore		
