/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 11, 2019
Last udpate on: Mar 11, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Constructs the following variables: value of livestock, livestock revenue, agricultural revenue, and non-agricultural business revenue.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl all_HH_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
	gl profile_info_nopii  		"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	gl crops_fl1		 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_c_crops_fl1.dta"
	gl businesses_fl1	 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_d_nonagbiz_fl1.dta"
	gl productive_act_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_e_timeuse_fl1.dta"	
	gl livestock_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/k_a_livestock_fl1.dta"
	gl animal_products_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/k_b_animalproduct_fl1.dta"
	gl livestock_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/k_a_livestock_fl1.dta"

* Outputs
	gl livestock_assets_index_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_assets_index_fl1.dta"
	gl livestock_revenue_index_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_revenue_index_fl1.dta"
	gl crop_production_index_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/crop_production_index_fl1.dta"
	gl business_revenue_earnings_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/business_revenue_earnings_fl1.dta"

********************************************************************************
	** Part 1: Value of Livestock
********************************************************************************

*-----------------*
* Livestock value *
*-----------------*

use "${livestock_fl1}", clear
	merge m:1 hhid using "${profile_info_nopii}", keepus(ultra_poor) keep(1 3) nogen

* Drop if "none" or "don't know"
	tab livestock if k6 == 1, m
	tab livestock if k6 == 1, m nol
	drop if inlist(livestock, -99, 0)

* Drop household without this information (no MHHH survey -- 34 households, 1 hh with "don't know'")
	tab k6 if livestock == 1, m
	tab k6, m
	drop if mi(k6)
	
* Does the household own?
	gen lstock_yes = k6
	
* Quantity owned
	gen 	lstock_num = k7 
	replace lstock_num = k7_o if k7==11
	replace lstock_num = 0 if k6==0

* Value of livestock

	* Taking the self reported value of the asset and replacing with the mean when missing. 
		gen unit_value = k8
		
* Replacing outliers and don't know / don't answer in k8. We will follow what we do elsewhere, replacing with the mean (not including by treatment as too few observations otherwise)
	bys livestock ultra_poor: egen mean_unit_value = mean(k8) if k8 > 0 
	replace unit_value = mean_unit_value if k8 == .o  | k8 == .d | k8 == .r
	drop  mean_unit_value  ultra_poor  	
	
	* Find median unit value
		bys livestock: egen unit_value_median = median(unit_value) if unit_value>0
		bys livestock: egen unit_value_med = max(unit_value_median)
		drop unit_value_median
		
	* Use winsorization in k8 to get another measure with they value they report
		winsor2 unit_value if unit_value>0 & !mi(unit_value), c(1 99) by(livestock)
		
	* Find unit value in terms of goats
		* Median 
		gen value_goat_med = unit_value_med if livestock== 5
		egen value_goat_med_max = max(value_goat_med) 
		gen unit_value_med_goat = unit_value_med/(value_goat_med_max)
		drop value_goat_med value_goat_med_max
		* Actual
		gen value_goat = unit_value if livestock== 5
		egen value_goat_max = max(value_goat) 
		gen unit_value_goat = unit_value/(value_goat_max)
		drop value_goat value_goat_max
		
	* Find livestock value
		* Median
		gen lstock_value_med = unit_value_med*lstock_num
		gen lstock_value_med_goat = unit_value_med_goat*lstock_num
		* Actual 
		gen lstock_value = unit_value*lstock_num
		gen lstock_value_goat = unit_value_goat*lstock_num	
		
		replace lstock_value 			= 0 if lstock_yes==0
		replace lstock_value_med 		= 0 if lstock_yes==0	
		replace lstock_value_goat 		= 0 if lstock_yes==0
		replace lstock_value_med_goat 	= 0 if lstock_yes==0
	
	* Find livestock value winsorized
		gen 	lstock_value_w = unit_value_w*lstock_num
		replace lstock_value_w = 0 if lstock_yes==0

	* Replace with .d and .r for the corresponding missing values for the number of livestock 
		replace lstock_value_w 		= .d if k7 == .d & k6==1
		replace lstock_value   		= .d if k7 == .d & k6==1		
		replace lstock_value_goat 	= .d if k7 == .d & k6==1
		replace lstock_value_med   		= .d if k7 == .d & k6==1		
		replace lstock_value_med_goat 	= .d if k7 == .d & k6==1

	* Generate variables of value conditional on having livestock
		gen lstock_value_yes = lstock_value if k6==1
		gen lstock_value_w_yes = lstock_value_w if k6==1
		
	* Generate total values of livestock by household 
		bys hhid:	egen tot_lstock_value = sum(lstock_value) 
		bys hhid:	egen tot_lstock_value_goat = sum(lstock_value_goat) 
		bys hhid:	egen tot_lstock_w_value = sum(lstock_value_w) 
		
	lab var tot_lstock_value 		"Total livestock value (Afghanis)"
	lab var tot_lstock_w_value 		"Total livestock value - Winsorized (Afghanis)"
	lab var tot_lstock_value_goat 	"Total livestock value (Goats)"
	
	* Reshape
	drop k6 k7 k7_o k8
	rename * *_
	rename (hhid_ livestock_) (hhid livestock)

	reshape wide lstock_yes_ lstock_num_ unit_value_ unit_value_med_ unit_value_w_ unit_value_goat_ unit_value_med_goat_ lstock_value_ lstock_value_med_   lstock_value_yes_ lstock_value_w_ lstock_value_w_yes_ lstock_value_goat_ lstock_value_med_goat_, i(hhid) j(livestock)
	
* Generate total value of livestock
	* Median
	egen tot_lstock_value_med 		= rowtotal(lstock_value_med_1 lstock_value_med_2 lstock_value_med_3 lstock_value_med_4 lstock_value_med_5 		lstock_value_med_6 lstock_value_med_7 lstock_value_med_8 lstock_value_med_9 lstock_value_med_10 lstock_value_med_11 lstock_value_med_12 lstock_value_med_13)
	* Actual
	egen tot_lstock_value 		= rowtotal(lstock_value_1 		lstock_value_2 		lstock_value_3 		lstock_value_4 		lstock_value_5 		lstock_value_6 		lstock_value_7 		lstock_value_8 		lstock_value_9 		lstock_value_10 	 lstock_value_11 		lstock_value_12 		lstock_value_13)
	* Median
	egen tot_lstock_value_med_goat 	= rowtotal(lstock_value_med_goat_1 	lstock_value_med_goat_2 lstock_value_med_goat_3 lstock_value_med_goat_4 lstock_value_med_goat_5 lstock_value_med_goat_6 lstock_value_med_goat_7 lstock_value_med_goat_8 lstock_value_med_goat_9 lstock_value_med_goat_10 lstock_value_med_goat_11 lstock_value_med_goat_12 	lstock_value_med_goat_13)
	* Actual
	egen tot_lstock_value_goat 	= rowtotal(lstock_value_goat_1 	lstock_value_goat_2 lstock_value_goat_3 lstock_value_goat_4 lstock_value_goat_5 lstock_value_goat_6 lstock_value_goat_7 lstock_value_goat_8 lstock_value_goat_9 lstock_value_goat_10 lstock_value_goat_11 	lstock_value_goat_12 	lstock_value_goat_13)

	egen tot_lstock_w_value 	= rowtotal(lstock_value_w_1 	lstock_value_w_2 	lstock_value_w_3 	lstock_value_w_4 	lstock_value_w_5 	lstock_value_w_6 	lstock_value_w_7 	lstock_value_w_8 	lstock_value_w_9 	lstock_value_w_10 	 lstock_value_w_11 		lstock_value_w_12 		lstock_value_w_13)
	lab var tot_lstock_value 			"Total livestock value (Afghanis)"
	lab var tot_lstock_value_med 		"Total livestock value (Afghanis) - median based"
	lab var tot_lstock_w_value 			"Total livestock value - Winsorized (Afghanis)"
	lab var tot_lstock_value_goat 		"Total livestock value (Goats)"
	lab var tot_lstock_value_med_goat 	"Total livestock value (Goats) - median based"

* Including the missings again
	forvalues i=1/13 {
		disp `i'
		replace tot_lstock_value 			= .d if lstock_value_`i' == .d
		replace tot_lstock_value_med 		= .d if lstock_value_`i' == .d
		replace tot_lstock_w_value   		= .d if lstock_value_`i' == .d		
		replace tot_lstock_value_goat 		= .d if lstock_value_`i' == .d
		replace tot_lstock_value_med_goat 	= .d if lstock_value_med_`i' == .d
	}

* Labeling and renaming
	loc	lstock1		cow 
	loc	lstock2		bull
	loc	lstock3		horse
	loc	lstock4		donkey
	loc	lstock5		goat
	loc	lstock6		sheep
	loc	lstock7		chicken
	loc	lstock8		duck
	loc	lstock9		turkey
	loc lstock10	goose
	loc lstock11	rabbit
	loc lstock12	guineafowl
	loc lstock13	beehive
	loc lstock14	othlstock1
	loc lstock15	othlstock2
	
	loc lstock_yes_l 			"HH owns any"
	loc lstock_num_l 			"Number of owned"
	loc unit_value_l 			"Unit value of"
	loc unit_value_med_l 		"Median Unit value of"
	loc unit_value_w_l 			"Unit value (winsorized) of"
	loc unit_value_med_goat_l 	"Median Unit value in goats of"
	loc unit_value_goat_l 		"Unit value in goats of"
	loc lstock_value_l 			"(Afghanis)"
	loc lstock_value_med_l 		"(Afghanis) - median based"
	loc lstock_value_yes_l 		"(Afghanis)"
	loc lstock_value_w_yes_l 	"- Winsorized (Afghanis)"
	loc lstock_value_goat_l 	"(Goats)"
	loc lstock_value_med_goat_l "(Goats) - median based"
	
	loc vars "lstock_yes lstock_num unit_value unit_value_med unit_value_w unit_value_goat unit_value_med_goat lstock_value lstock_value_med lstock_value_yes lstock_value_w lstock_value_w_yes lstock_value_goat lstock_value_med_goat"
	
	foreach var of local vars {
		forval lstocknum=1/15 {
			rename `var'_`lstocknum' `var'_`lstock`lstocknum''
			lab var `var'_`lstock`lstocknum'' "``var'_l' `lstock`lstocknum''"
			if inlist("`var'", "lstock_value", "lstock_value_med", "lstock_value_w", "lstock_value_yes", "lstock_value_w_yes", "lstock_value_goat", "lstock_value_med_goat") {
				lab var `var'_`lstock`lstocknum'' "Total value of `lstock`lstocknum'' ``var'_l'"
				*histogram `var'_`lstock`lstocknum'' if lstock_yes_`lstock`lstocknum''==1, percent name(graph_`var'_`lstocknum', replace)
			}
		}
	}
	
* Group other different than cows, sheep, goats and chicken in the same category	
	* Actual
	egen lstock_value_other = rowtotal(lstock_value_horse lstock_value_donkey lstock_value_duck lstock_value_turkey lstock_value_goose lstock_value_rabbit lstock_value_guineafowl lstock_value_beehive)
	lab var lstock_value_other "Other livestock"
	egen lstock_value_goat_other = rowtotal(lstock_value_goat_horse lstock_value_goat_donkey lstock_value_goat_duck lstock_value_goat_turkey lstock_value_goat_goose lstock_value_goat_rabbit lstock_value_goat_guineafowl lstock_value_goat_beehive)
	lab var lstock_value_goat_other "Other livestock"
	* Median
	egen lstock_value_med_other = rowtotal(lstock_value_med_horse lstock_value_med_donkey lstock_value_med_duck lstock_value_med_turkey lstock_value_med_goose lstock_value_med_rabbit lstock_value_med_guineafowl lstock_value_med_beehive)
	lab var lstock_value_med_other "Other livestock - median based"
	egen lstock_value_med_goat_other = rowtotal(lstock_value_med_goat_horse lstock_value_med_goat_donkey lstock_value_med_goat_duck lstock_value_med_goat_turkey lstock_value_med_goat_goose lstock_value_med_goat_rabbit lstock_value_med_goat_guineafowl lstock_value_med_goat_beehive)
	lab var lstock_value_med_goat_other "Other livestock - median based"

* Generate if has any crop
	egen 	lstock_yes = rowtotal(lstock_yes_cow lstock_yes_bull lstock_yes_horse lstock_yes_donkey lstock_yes_goat lstock_yes_sheep lstock_yes_chicken lstock_yes_duck lstock_yes_turkey lstock_yes_goose lstock_yes_rabbit lstock_yes_guineafowl lstock_yes_beehive lstock_yes_othlstock1 lstock_yes_othlstock2), missing
	replace lstock_yes = 1 if lstock_yes>1	
	lab var lstock_yes "Household Owns Any Livestock"
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_assets_index_fl1}", replace v(13)
	}
	else {
		save "${livestock_assets_index_fl1}", replace
	}		

********************************************************************************
	** Part 2: Livestock revenue
********************************************************************************
	
* 1. Revenues from sales in livestock and costs
*----------------------------------------------
		use "${livestock_fl1}", clear
			merge m:1 hhid using "${all_HH_nopii_fl1}", keepusing(k38) assert(3) nogen

	* Generate variable for livestock sales
		gen 	lstock_rev_sales = k38
		replace lstock_rev_sales = 0 if lstock_rev_sales==.
		
	* Generate variable for costs
		gen 	lstock_cost = k14
		replace	lstock_cost = 0 if lstock_cost==.
		keep hhid lstock_rev_sales lstock_cost
		duplicates drop
		
		tempfile rev_sales
		save	`rev_sales'
	

* 2. Revenues from production
*----------------------------
	use "${animal_products_fl1}", clear
	
	* Drop if "none" or "don't know", and "others"
		tab product if k9 == 1
		tab product if k9 == 1, nol
		drop if inlist(product, -99, 0, 7, 8)
		
	* 917 households without information because didn't produce (no MHHH survey -- 34 households and 883 households with no livestock, 8 with "don't know")
		tab k9 if product == 1, m
		merge m:1 hhid using "${livestock_assets_index_fl1}", assert(1 3) keepus(hhid lstock_yes_* lstock_num_*)
		merge m:1 hhid using "${all_HH_nopii_fl1}", assert(1 3) keepus(ultra_poor) keep(3) nogen
		mdesc k9 if product == 1 & _merge == 1 // the 34 household without info
		drop if mi(k9) & _merge ==1
		drop _merge
	
	* Looking at outliers in the time_activities_outliers_fl1 do file
		qui do "${fl1_do}/Cleaning/animal_products_outliers_fl1.do"		
			
	* Produced product
		replace k9 = 0 if mi(k9)
		gen prod_yes = k9
		
		
	* Quantity sold and produced
		gen 	prod_qty_prod = k10
		replace prod_qty_prod = 0 if prod_yes == 0
		
		gen prod_qty_sold = k12
	
		replace prod_qty_sold=. if flag_milk_yogurt==1 | flag_eggs==1
		
	* Calculate price
		gen 	price_unit = k13/prod_qty_sold
		replace price_unit = . if price_unit == 0
		
	* Get median price to impute to HHs who didn't sell
		bys product: egen median_price = median(price_unit)
		replace price_unit = median_price if mi(price_unit) 
	
	* Revenue of production in the past month = prod_qty_prod x price_unit x 4.3/4
		gen 	prod_revenue = (prod_qty_prod*price_unit)
		replace prod_revenue = 0 if k9==0

		keep hhid product prod_revenue flag_hh
		decode product, gen(product_s)
		replace product_s = lower(product_s)
		replace product_s = "other1" if product ==7
		replace product_s = "other2" if product ==8
		rename * *_
		drop product_
		rename (hhid_ product_s_) (hhid product_s)
		reshape wide prod_revenue_, i(hhid) j(product_s) s
		rename flag_hh_ flag_hh
		
* Merge revenue from sales
	merge 1:1 hhid using `rev_sales', assert(2 3) nogen keep(3)

* Gen total revenue
	egen 	tot_lstock_revenue = rowtotal(prod_revenue_* lstock_rev_sales)
	lab var tot_lstock_revenue "Total livestock revenue (past 4 weeks, Afghanis)"
	replace tot_lstock_revenue = . if flag_hh==1
	
	foreach var of varlist prod_revenue_* {
		replace `var' = . if flag_hh==1
	}
	
* Gen total earning
	gen		tot_lstock_earn = tot_lstock_revenue-lstock_cost
	lab var tot_lstock_earn "Total livestock earnings (past 4 weeks, Afghanis)"
	
* Labels
	lab var prod_revenue_yogurt "Yogurt"
	lab var prod_revenue_milk "Milk"
	lab var prod_revenue_meat "Meat"
	lab var prod_revenue_egg "Eggs" 
	lab var prod_revenue_butter "Butter"
	lab var lstock_rev_sales "Sales of livestock"
	
* Merging treatment and PRA
	merge 1:1 hhid using "${profile_info_nopii}", keepus(treatment PRA_lottery) keep(1 3) nogen
	
	tempfile livestock_revenue
	save	`livestock_revenue'
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_revenue_index_fl1}", replace v(13)
	}
	else {
		save "${livestock_revenue_index_fl1}", replace
	}			
	
********************************************************************************
	** Part 3: Crops
********************************************************************************

use "${crops_fl1}", clear

* Drop if "none" or "don't know"
	tab crop if k15==1
	tab crop if k15==1, nol
	drop if inlist(crop, -99, 0)

* Drop household without this information (no MHHH survey -- 34 households, 12 hhs with don't know)
	tab k15 if crop == 1, m
	drop if mi(k15)
	
* Cultivated the crop
	gen crop_yes = k15

* Quantity sold and produced and earnings from sold
	gen 	crop_prod_qty = k17
	replace crop_prod_qty = 0 if crop_yes==0
	replace crop_prod_qty = . if k17==0 
	
	gen crop_prod_sold = k19
	
* Calculate price
	gen 	price_kg = k20/crop_prod_sold
	replace price_kg = . if price_kg==0

* Get median price to impute to HHs who didn't sell
	bys crop: egen median_price = median(price_kg) if price_kg>0
	replace price_kg = median_price if mi(price_kg) | price_kg==0

		/*
				. tab crop if mi(median_price) & k15==1

							 Crop |      Freq.     Percent        Cum.
		--------------------------+-----------------------------------
							Vetch |          2        8.33        8.33
							Maize |         21       87.50       95.83
						   Potato |          1        4.17      100.00
		--------------------------+-----------------------------------
							Total |         24      100.00
		*/

* Value of production in the last 12 months = crop_prod_qty x price_kg x k16
	gen 	crop_revenue = (crop_prod_qty*price_kg*k16)
	replace crop_revenue = 0 if k15==0
	replace crop_prod_qty = crop_prod_qty*k16 if crop_prod_qty!=0
	
* Reshape
	keep hhid crop crop_yes crop_revenue  
	rename * *_
	rename (hhid_ crop_) (hhid crop)
	reshape wide crop_yes_ crop_revenue_ , i(hhid) j(crop) 
	
* Totals
	egen 	tot_crop_revenue = rowtotal(crop_revenue_1 crop_revenue_2 crop_revenue_3 crop_revenue_4 crop_revenue_5 crop_revenue_6 crop_revenue_7 crop_revenue_8 crop_revenue_9 crop_revenue_10 crop_revenue_11 crop_revenue_12 crop_revenue_13 crop_revenue_14 crop_revenue_15 crop_revenue_16 crop_revenue_17 crop_revenue_18 crop_revenue_19 crop_revenue_20 crop_revenue_21 crop_revenue_22 crop_revenue_23 crop_revenue_24 crop_revenue_25)
	replace tot_crop_revenue = tot_crop_revenue/13 // 52 weeks in a year. divided by 13 to get 4 weeks
	lab var tot_crop_revenue "Total crop revenue (Afghanis, 4 weeks)"
	
* Labeling and renaming
	loc	crop1	wheat
	loc	crop2	vetch
	loc	crop3	maize
	loc	crop4	barley
	loc	crop5	rice
	loc	crop6	weed
	loc	crop7	sesame
	loc	crop8	clover
	loc	crop9	millet
	loc	crop10	sharsham
	loc	crop11	sugarcane
	loc	crop12	cotton
	loc	crop13	caraway
	loc	crop14	potato
	loc	crop15	cereal
	loc	crop16	eggplant
	loc	crop17	tomato
	loc	crop18	onion
	loc	crop19	okra
	loc	crop20	treefruit	
	loc	crop21	grape
	loc	crop22	melon
	loc	crop23	opium
	loc	crop24	zaghar
	loc	crop25	saffron
	loc crop26	othercrop1
	loc	crop27	othercrop2
	
	loc crop_yes_l "HH cultivated"
	loc crop_value_l "Total value of"
	loc agric_income_l "Agricultural income from"
	loc crop_prod_qty_l "Total production of"
	
	loc vars "crop_yes crop_revenue" 
	
	* Labels
	foreach var of local vars {
		forval cropnum=1/27 {
			rename `var'_`cropnum' `var'_`crop`cropnum''
			if inlist("`var'", "crop_prod_qty") {
				lab var `var'_`crop`cropnum'' "``var'_l' `crop`cropnum'' (Kgs, last 12 months)"
			}
			else {
				lab var `var'_`crop`cropnum'' "``var'_l' `crop`cropnum'' (Afghanis, last 12 months)"
			}
		}
	}	
			
* Generate if has any crop
	egen 	crop_yes = rowtotal(crop_yes_wheat crop_yes_vetch crop_yes_maize crop_yes_barley crop_yes_rice crop_yes_weed crop_yes_sesame crop_yes_clover crop_yes_millet crop_yes_sharsham crop_yes_sugarcane crop_yes_cotton crop_yes_caraway crop_yes_potato crop_yes_cereal crop_yes_eggplant crop_yes_tomato crop_yes_onion crop_yes_okra crop_yes_treefruit crop_yes_grape crop_yes_melon crop_yes_opium crop_yes_zaghar crop_yes_saffron crop_yes_othercrop1 crop_yes_othercrop2), missing
	replace crop_yes = 1 if crop_yes > 1
	lab var crop_yes "Household Has Any Crop"
				
* Save
	if	`c(stata_version)'>=14	{
		saveold "${crop_production_index_fl1}", replace v(13)
	}
	else {
		save "${crop_production_index_fl1}", replace
	}	
	
********************************************************************************
	** Part 4: Business
********************************************************************************

use "${businesses_fl1}", clear

* Drop if "none" or "don't know". We keep other as it is important
	tab business if k23_a==1
	tab business if k23_a==1, nol
	drop if inlist(business, -99, 0)

* Drop household without this information (no MHHH survey -- 34 households, and 3 wit "don't answer")
	tab k23_a if business==1, m
	drop if mi(k23_a)
	
* Operate business
	gen biz_yes = k23_a
	
* Revenues in last 4 weeks
	gen 	biz_revenue = k32 
	replace biz_revenue = 0 if biz_yes==0
	
* Operational costs in the last 4 weeks
	gen biz_cost = k34
	
* Rent: asked for past 12 months. We get a measure for 1 month, and then for 4 weeks
	gen 	biz_rent = k43/k25
	replace biz_rent = biz_rent*4/4.3 
	
* Earnings
	gen 	biz_earn = biz_revenue-biz_cost-biz_rent
	replace biz_earn = 0 if biz_yes ==0

* Reshape
	keep hhid business biz_revenue biz_earn biz_yes
	rename * *_
	rename (hhid_ business_) (hhid business)
	reshape wide biz_yes_ biz_revenue_ biz_earn_, i(hhid) j(business)
	
* Totals
	egen 	tot_biz_revenue = rowtotal(biz_revenue_1 	biz_revenue_2 	biz_revenue_3 	biz_revenue_4 	biz_revenue_5 	biz_revenue_6 	biz_revenue_7 	biz_revenue_8 	biz_revenue_9 	biz_revenue_10 	biz_revenue_11 	biz_revenue_12 	biz_revenue_13	biz_revenue_14	biz_revenue_15)
	egen	tot_biz_earn  	= rowtotal(biz_earn_1 		biz_earn_2 		biz_earn_3 		biz_earn_4		biz_earn_5 		biz_earn_6 		biz_earn_7 		biz_earn_8 		biz_earn_9 		biz_earn_10 	biz_earn_11 	biz_earn_12 	biz_earn_13		biz_earn_14		biz_earn_15)
	lab var tot_biz_revenue "Total business revenue (Afghanis, 4 weeks)"
	lab var tot_biz_earn 	"Total business earnings (Afghanis, 4 weeks)"
					
* Generate if has any business
	egen 	biz_yes = rowtotal(biz_yes_1 biz_yes_2 biz_yes_3 biz_yes_4 biz_yes_5 biz_yes_6 biz_yes_7 biz_yes_8 biz_yes_9 biz_yes_10 biz_yes_11 biz_yes_12 biz_yes_13 biz_yes_14 biz_yes_15), missing
	replace biz_yes = 1 if biz_yes > 1
	lab var biz_yes "Household Has Any Business"
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${business_revenue_earnings_fl1}", replace v(13)
	}
	else {
		save "${business_revenue_earnings_fl1}", replace
	}	
	
	
	
