/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	Feb 24, 2020

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Takes the dataset "current roster" and construct some of the variables that will be useful later on


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Basic cleaning and preparing dataset
				Part 2 - 
  

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

	clear all
	set more off
	set maxvar 20000

	* Input files
		global all_HH_interm_nopii_fl1  "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		global roster 					"${TUP_DB}/Followup_1/DataSets/Intermediate/br_hhmemcurrent_fl1.dta"	
		global profile_info 			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
		global mobile_phone_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/v_mobile_fl1.dta"

	*Ouput
		global roster_final             "${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"		

********************************************************************************
** Part 1: Merge to have lady of the household and primary man number
********************************************************************************

	use "$roster", clear
	
	** Move generation of HHsize from "preparing_and_cleaning_rosters_fl1.do" here
	* Gen HHsize - per adult equivaleng
	tempvar weight
	gen 	weight = 1 if b8>=10 & !mi(b8)
	replace weight = 0.5 if b8<10 & !mi(b8)
	replace weight = 1 if mi(b8)
	bys hhid: egen HHsize = sum(weight)
	order HHsize, after(member)
	drop weight
	
	lab var HHsize "HH size per adult equivalent (>=10 years)"

	merge m:1 hhid using "$all_HH_interm_nopii_fl1", keepusing(lady_hh2 hhh_name2) assert(3) nogen
	
	merge m:1 hhid using "$profile_info", keepusing(treatment  PRA_lottery ultra_poor) keep(3) assert(2 3) nogen //Some households from the profile were not part of the follow up. Only keep the ones that merge
	
	destring hhh_name2, replace
	destring lady_hh2, replace
	
	* There is a 2 year old that owns a mobile phone; there is no other roster info for this HH member, so the age is likely a mistake. Set age 
	* to missing. 
	preserve 
		use "${mobile_phone_fl1}", clear
		rename v3 member
		collapse (sum) v4, by(hhid member)
		
		tempfile mobile
		save `mobile'
	restore 
	
	* Merge mobile phone ownership so we can make the replacement 
	merge m:1 hhid member using "`mobile'", nogen keepusing(v4)   //Many members do not own a phone obviously 
	replace b8 = . if b8 == 2 & !mi(v4)
	drop v4 	

********************************************************************************
** Part 2: Specific variables like interactions for analysis later on
********************************************************************************
*Variable indicating if household has only a primary woman (ie no primary man)

*Create variable = 1 if no primary man in household	
	egen pm = total(cond(hhh_name2 == member & b6 == 1),1,0), by(hhid)
	gen hh_only_pf = 1 - pm
	lab var hh_only_pf "Households with only primary women"

*Dummy variable for whether member is primary man (pm) or primary female (pf) (0==woman) (1==man)
	gen     pf_pm = 0 if lady_hh2  == member & b6 == 2 //Is primary female
	replace pf_pm = 1 if hhh_name2 == member & b6 == 1 //Is primary man
	lab var pf_pm "Man"
	
*Interaction
	gen t_pf_pm = treatment * pf_pm
	lab var t_pf_pm "Treatment x Man"
	
*Dummy variable for whether member is male or female other adults (0==woman) (1==male)
	gen     otheradult_m = 0 if b8 > 18 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 2 //Is Other Adult female
	replace otheradult_m = 1 if b8 > 18 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 1 //Is Other Adult male
	lab var otheradult_m "Man"
	
*Interaction
	gen t_otheradult_m = treatment * otheradult_m
	lab var t_otheradult_m "Treatment x Man"

*Dummy variable for whether member is male or female ALL adults (0==woman) (1==male)
	gen     adult_m = 0 if b8 > 18 & !mi(b8) & b6 == 2 //Adult female
	replace adult_m = 1 if b8 > 18 & !mi(b8) & b6 == 1 //Adult male
	lab var adult_m "Man"
	
*Interaction
	gen t_adult_m = treatment * adult_m
	lab var t_adult_m "Treatment x Man"	
	
*Dummy variable for whether member is male or female other adults (0==woman) (1==male)
	gen     otheradult18_m = 0 if b8 > 17 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 2 //Is Other Adult female
	replace otheradult18_m = 1 if b8 > 17 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 1 //Is Other Adult male
	lab var otheradult18_m "Man (incuding 18)"
	
*Interaction
	gen t_otheradult18_m = treatment * otheradult18_m
	lab var t_otheradult18_m "Treatment x Man"	
	
*Dummy variable for whether member is male or female children 6-14 (0==woman 6-14) (1==male 6-14)
	gen     kid_6_14_m = 0 if b8 > 5 & b8 < 15 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 2 //Is children 6-14 female
	replace kid_6_14_m = 1 if b8 > 5 & b8 < 15 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 1 //Is children 6-14 male
	lab var kid_6_14_m "Man"
	
*Interaction
	gen t_kid_6_14_m = treatment * kid_6_14_m
	lab var t_kid_6_14_m "Treatment x Man"
	
*Dummy variable for whether member is male or female children 15-17 (0==woman 15-17) (1==male 15-17 )
	gen     kid_15_17_m = 0 if b8 >= 15 & b8 <= 17 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 2 //Is children 15-17 female
	replace kid_15_17_m = 1 if b8 >= 15 & b8 <= 17 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 1  //Is children 15-17 male
	lab var kid_15_17_m "Man"
	
*Interaction
	gen t_kid_15_17_m = treatment * kid_15_17_m
	lab var t_kid_15_17_m "Treatment x Man"
	
*Dummy variable for whether member is male or female children 15-18 (0==woman 15-18) (1==male 15-18 )
	gen     kid_15_18_m = 0 if b8 >= 15 & b8 <= 18 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 2 //Is children 15-18 female
	replace kid_15_18_m = 1 if b8 >= 15 & b8 <= 18 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 1  //Is children 15-18 male
	lab var kid_15_18_m "Man"
	
*Interaction
	gen t_kid_15_18_m = treatment * kid_15_18_m
	lab var t_kid_15_18_m "Treatment x Man"

*Dummy variable for whether member is male or female children 6-17 (0==woman 6-17) (1==male 6-17 )
	gen     kid_6_17_m = 0 if b8 > 5 & b8 <= 17 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 2 //Is children 6-17 female
	replace kid_6_17_m = 1 if b8 > 5 & b8 <= 17 & !mi(b8) & lady_hh2 != member & hhh_name2 != member & b6 == 1 //Is children 6-17 male
	lab var kid_6_17_m "Man"
	
*Interaction
	gen t_kid_6_17_m = treatment * kid_6_17_m
	lab var t_kid_6_17_m "Treatment x Man"
	
*Dummy variable for whether member is Adult male or female
	gen 	male_adult 		= 0 if pf_pm == 0	| otheradult_m ==0
	replace male_adult 		= 1 if pf_pm == 1	| otheradult_m ==1
	lab var male_adult "Man"
	
*Interaction
	gen t_male_adult 	= male_adult * treatment
	lab var t_male_adult "Treatment x Man"
	
*Dummy variable for whether member is Adult male or female
	gen 	male_adult18 		= 0 if pf_pm == 0	| otheradult18_m ==0
	replace male_adult18 		= 1 if pf_pm == 1	| otheradult18_m ==1
	lab var male_adult18 "Man (including 18)"
	
*Interaction
	gen t_male_adult18 	= male_adult18 * treatment
	lab var t_male_adult18 "Treatment x Man"

*Simple dummy variable for whether belongs or not to a certain categorie - Not use in an interaction 	
	gen oth_f_adult_fl = (b6 == 2 & b8 > 18 & !mi(b8) & lady_hh2 != member & hhh_name2 != member)
	gen oth_m_adult_fl = (b6 == 1 & b8 > 18 & !mi(b8) & hhh_name2 != member & lady_hh2 != member)
	gen oth_f_adult18_fl = (b6 == 2 & b8 > 17 & !mi(b8) & lady_hh2 != member & hhh_name2 != member)
	gen oth_m_adult18_fl = (b6 == 1 & b8 > 17 & !mi(b8) & hhh_name2 != member & lady_hh2 != member)
	gen kidf_6_14_fl 	= (b6 == 2 & b8 > 5 & b8 <15)	
	gen kidm_6_14_fl 	= (b6 == 1 & b8 > 5 & b8 <15)
	gen kidf_15_18_fl 	= (b6 == 2 & b8 >= 15 & b8 <=18)	
	gen kidm_15_18_fl 	= (b6 == 1 & b8 >= 15 & b8 <=18)

	label var oth_f_adult18_fl "Adult Women >=18 yo (except PW)"
	label var oth_m_adult18_fl "Adult Men >=18 yo (except PM)"
	label var oth_f_adult_fl "Adult Women >=19 yo (except PW)"
	label var oth_m_adult_fl "Adult Men >=19 yo (except PM)"
	lab var kidf_6_14_fl 		"Girl Children (6-14)"
	lab var kidm_6_14_fl 		"Boy Children (6-14)"
	lab var kidf_15_18_fl 		"Girl Children (15-18)"
	lab var kidm_15_18_fl		"Boy Children (15-18)"			
	
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${roster_final}", replace v(13)
		}
		else {
			save "${roster_final}", replace
		}	
