/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 26, 2019
Last udpate on: Mar 26, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Constructs school enrollment ans absenteeism variables.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

	clear all
	set more off
	set maxvar 20000

* Inputs
	global profile_info				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
	global roster 					"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"
* Outputs
	global schooling_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"

********************************************************************************
	** Part 1: Schooling variables
********************************************************************************

use "${roster}", clear

* Mohammad: In Balkh, children go to school 6 days a week. 
* We cap the school days missed to 24
	loc max_school_days "24"
	replace b19 = `max_school_days' if b19 > `max_school_days' & !mi(b19)

* Conditions to be considered children: we use the relationship to the head of the household
	loc cond_hh = "!inlist(b5, 1, 8, 9, 10, 14, 17, 18, 19, 20, 21, -97)"
	
* Create variables

	foreach group in hh {
	
		* School age children: between 6 and 18 inclusive
			gen child_in_schooling_age_`group' 	= 1 if inrange(b8,6,18) & `cond_`group''
			gen boy_in_schooling_age_`group' 	= 1 if child_in_schooling_age_`group'==1 & b6==1
			gen girl_in_schooling_age_`group' 	= 1 if child_in_schooling_age_`group'==1 & b6==2

		* Children in school (b15a == 1) among those in schooling age
			gen 	child_inschool_`group' 			= 1 if child_in_schooling_age_`group' == 1   & b15a == 1
			gen 	boy_inschool_`group'			= 1 if boy_in_schooling_age_`group'   == 1   & b15a == 1
			gen 	girl_inschool_`group'			= 1 if girl_in_schooling_age_`group'  == 1   & b15a == 1
		
		* Children not in school (b15a == 0) among those in schooling age
			replace child_inschool_`group' 	= 0 if child_in_schooling_age_`group' == 1 & b15a == 0
			replace boy_inschool_`group'	= 0 if boy_in_schooling_age_`group' == 1 & b15a == 0
			replace girl_inschool_`group'	= 0 if girl_in_schooling_age_`group' == 1 & b15a == 0
			
	
		* Days missed
			gen days_missed_school_`group' = b19/`max_school_days' 				if child_in_schooling_age_`group' == 1
			gen girl_days_missed_school_`group' = days_missed_school_`group' 	if girl_in_schooling_age_`group' == 1 & b6==2 
			gen boy_days_missed_school_`group' = days_missed_school_`group' 	if boy_in_schooling_age_`group' == 1 & b6==1
			
	}
	


* Labels
	foreach group in hh {
		lab var child_in_schooling_age_`group' "Children in schooling age"
		lab var boy_in_schooling_age_`group' "Boy in schooling age"
		lab var girl_in_schooling_age_`group' "Girl in schooling age"
		lab var child_inschool_`group' "Children in schooling age in school"
		lab var boy_inschool_`group' "Boys"
		lab var girl_inschool_`group' "Girls"
		lab var girl_days_missed_school_`group' "Girls"
		lab var boy_days_missed_school_`group' "Boys"
	}
	
	
* HHs with children in schooling age:
	bys hhid: gen count= _n
	bys hhid: egen child = max(child_in_schooling_age_hh)
	tab child if count == 1, m
	drop count child
	/*
		      child |      Freq.     Percent        Cum.
		------------+-----------------------------------
				  1 |      2,033       81.48       81.48
				  . |        462       18.52      100.00
		------------+-----------------------------------
			  Total |      2,495      100.00
	*/
	
	keep if child_in_schooling_age_hh == 1
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${schooling_fl1}", replace v(13)
	}
	else {
		save "${schooling_fl1}", replace
	}
