/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	August 18, 2021
Last udpate on: August 18, 2021

Written by:  	Yulia Belyakova (ybelyakova@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates intermediate datasets with variables related to TUP livestock

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
gl all_HH_interm_nopii_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
gl current_roster_fl1	 		"${TUP_DB}/Followup_1/DataSets/Intermediate/br_hhmemcurrent_fl1.dta"


* Outputs
gl TUP_livestock_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/r_livestockrecd_tup_fl1.dta"
gl TUP_sick_livestock_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/r_livestocksick_tup_fl1.dta"
gl TUP_sold_livestock_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/r_livestocksold_tup_fl1.dta"
gl TUP_dead_livestock_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/r_livestockdead_tup_fl1.dta"

*-----------------------------------------*
* 7. Livelihoods - TUP received livestock *
*-----------------------------------------*

* Even though this module was not programmed as a roster, it can be processed as it was
	use "${current_roster_fl1}", clear 
		keep hhid r13
		duplicates drop
		
		tempfile r13
		save `r13'
		
	use "${all_HH_interm_nopii_fl1}", clear
		merge 1:1 hhid using "`r13'", keepusing(r13) assert(3) nogen
	
	* Keep relevant sample (HHs that said yes to question r81 and r13 (received livestock)
		keep if r81==1 & r13 == 1
	
	* Keep relevant variables
		keep hhid r25* r26* r27* r82* r28* r74*
			 
	* Rename for the reshape
		rename (r25_1 r25_2 r25_3) (r25_a r25_b r25_c)
		rename (r26a r26b r26c r26d r26e r26f) (r26_grown_a r26_baby_a r26_grown_b r26_baby_b r26_grown_c r26_baby_c)
		rename (r27a r27b r27c r27d r27e r27f) (r27_grown_a r27_baby_a r27_grown_b r27_baby_b r27_grown_c r27_baby_c)
		foreach var in r82 r28 r74 {
			rename (`var'a `var'b `var'c) (`var'_a `var'_b `var'_c)
		}
		
	* Reshape
		reshape long r25_ r26_grown_ r26_baby_ r27_grown_ r27_baby_ r82_ r28_ r74_, ///
					 i(hhid) j(type) s

	* Cleaning
		drop r25
		rename *_ *
	
		* Create type of livestock
			gen 	type_livestock = 1 if type=="a"
			replace type_livestock = 2 if type=="b"
			replace type_livestock = 3 if type=="c"
			lab def type_livestock_l 1 "Cow" 2 "Goat" 3 "Sheep"
			lab val type_livestock type_livestock_l
			drop type
			order type_livestock, after(hhid)

		* Labels
			lab var r25 "What type of livestock did your household receive from CHA?"
			lab var type_livestock "Type of livestock received"
			lab var r26_grown "How many livestock did your household receive from CHA? (grown)"
			lab var r26_baby "How many livestock did your household receive from CHA? (baby)"
			lab var r27_grown "Of the livestock received, how many were female? (grown)"
			lab var r27_baby "Of the livestock received, how many were female? (baby)"
			lab var r82 "Is any of your livestock pregnant or breastfeeding?"
			lab var r28 "How many living calves have any of your livestock given birth to?"
			lab var r74 "How many animals does your household still own?"
			
		* Drop empty fields 
			drop if mi(type_livestock)
			
		* Save file	
			save "${TUP_livestock_fl1}", replace
			
*-------------------------------------*
* 8. Livelihoods - TUP sick livestock *
*-------------------------------------*
	
	use "${all_HH_interm_nopii_fl1}", clear
		merge 1:1 hhid using "`r13'", keepusing(r13) assert(3) nogen

	* Keep relevant sample (HHs that said yes to question r81 and r13 (received livestock)
		keep if r81==1 & r13 == 1
	
	* Keep relevant variables
		keep hhid r25* r30 r31* r34* r35* r36* 
		rename (r31a r31b r31c) (r31_1 r31_2 r31_3)
			 	
	* Global for select_multiple variables
		loc r35_mult "r35_1_ r35_2_ r35_3_ r35_4_ r35_5_ r35__97_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		tostring r35_2, replace
		reshape long r25_ r31_ r34_ r35_ `r35_mult' r36_ r36_1_, ///
						i(hhid) j(type_livestock)
	
	* Paste labels
		drop r25
		rename *_ *
		drop r35
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning		
		* Labels
			lab var hhid "Household ID"
			lab var r25 "What type of livestock did your household receive from CHA?"
			lab var type_livestock "Type of livestock received"
			lab var r30 "Has any livestock you received got sick in a way that affected its productivity?"
			lab var r31 "In the last twelve months, how many animals got sick in a way that affected its productivity?"
			lab var r35_1 "Treatment for disease: Sought no treatment"
			lab var r35_2 "Treatment for disease: Received treatment from CHA vet"
			lab var r35_3 "Treatment for disease: Sought treatment by experienced villagers"
			lab var r35_4 "Treatment for disease: Sought treatment by another vet"
			lab var r35_5 "Treatment for disease: Treated on our own"
			lab var r35__97 "Treatment for disease: Other (please specify)"
			
		* Label define
			lab def type_livestock_l 1 "Cow" 2 "Goat" 3 "Sheep"
			lab val type_livestock type_livestock_l
			
	* Save data
			save "${TUP_sick_livestock_fl1}", replace
	
*-------------------------------------*
* 9. Livelihoods - TUP sold livestock *
*-------------------------------------*
	
	use "${all_HH_interm_nopii_fl1}", clear
			merge 1:1 hhid using "`r13'", keepusing(r13) assert(3) nogen

	* Keep relevant sample (HHs that said yes to question r81 and r13 (received livestock)
		keep if r81==1 & r13 == 1
	
	* Keep relevant variables
		keep hhid r25* r37 r38* r39 r40* r41* r43* r44* r45*
		rename (r38a r38b r38c) (r38_1 r38_2 r38_3)
		
	* These vars have all missing values and were set to byte earlier in the cleaning 
		tostring r43_2 r43_3 r44_2 r45_2 r45_3, replace 
			 	
	* Global for select_multiple variables
		loc r41_mult "r41_1_ r41_2_ r41_3_ r41_4_ r41_5_ r41_6_ r41_7_ r41_8_ r41_9_ r41_10_ r41__97_"
	    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long r25_ r38_ r40_ r41_ `r41_mult' r43_ r44_ r45_, ///
						i(hhid) j(type_livestock)
	
	* Paste labels
		drop r25
		rename *_ *
		drop r41
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning	
		* Labels
			lab var hhid "Household ID"
			lab var r25 "What type of livestock did your household receive from CHA?"
			lab var type_livestock "Type of livestock received"
			lab var r37 "Did you sell any of the livestock receive from CHA?"
			lab var r38 "How many livestock did you sell?"
			lab var r39 "How much did you earn in total? (Afghanis)"
			lab var r41_1 "Reason to sell: The livestock was sick"
			lab var r41_2 "Reason to sell: Could not feed the livestock                                  "
			lab var r41_3 "Reason to sell: Needed money for household consumption"
			lab var r41_4 "Reason to sell: Needed money to repay household debt              "
			lab var r41_5 "Reason to sell: Needed money for household emergency expenses (illness, death, travel, wedding, etc.)   "
			lab var r41_6 "Reason to sell: Needed money for medical treatment/expenses"
			lab var r41_7 "Reason to sell: Needed money for educational expenses"
			lab var r41_8 "Reason to sell: Sold to invest in another business"
			lab var r41_9 "Reason to sell: Sold to buy other livestock                                   "
			lab var r41_10 "Reason to sell: Sold to buy household assets  "
			lab var r41__97 "Reason to sell: Other (please specify)"
			
		* Label define
			lab def type_livestock_l 1 "Cow" 2 "Goat" 3 "Sheep"
			lab val type_livestock type_livestock_l
			
		* Drop empty fields 
			drop if mi(type_livestock)
			
	* Save data
		save "${TUP_sold_livestock_fl1}", replace
		
		
*--------------------------------------*
* 10. Livelihoods - TUP dead livestock *
*--------------------------------------*
	
	use "${all_HH_interm_nopii_fl1}", clear
			merge 1:1 hhid using "`r13'", keepusing(r13) assert(3) nogen

	* Keep relevant sample (HHs that said yes to question r81 and r13 (received livestock)
		keep if r81==1 & r13 == 1
	
	* Keep relevant variables
		keep hhid r25* r46 r47* r48*
		rename (r47a r47b r47c) (r47_1 r47_2 r47_3)
			 		    
	* Save labels
		foreach var of varlist * {
			local l_`var' : variable label `var'
			local valuel_`var': value label `var'
		}
		
	* Reshape
		reshape long r25_ r47_ r48_, ///
						i(hhid) j(type_livestock)
	
	* Paste labels
		drop r25
		rename *_ *
		foreach var of varlist * {
			lab var `var' "`l_`var'_1'"
			cap confirm numeric var `var'
			if _rc == 0 {
				lab val `var' `valuel_`var'_1'
				*tab `var'
			}
		}
	
	* Cleaning	
		* Labels
			lab var hhid "Household ID"
			lab var r25 "What type of livestock did your household receive from CHA?"
			lab var type_livestock "Type of livestock received"
			lab var r46 "Did you lose any of the livestock because of death?"
			lab var r47 "How many livestock died?"
			
		* Label define
			lab def type_livestock_l 1 "Cow" 2 "Goat" 3 "Sheep"
			lab val type_livestock type_livestock_l
			
		* Drop empty fields 
			drop if mi(type_livestock)
			
	* Save data
		save "${TUP_dead_livestock_fl1}", replace