   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *                MIDLINE (FOLLOW UP 1)                                 *
   *               MASTER DO_FILE                                         *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      This master do file run all the cleaning and construction do files for the Midline (first follow up) survey was conducted in person from July to October 2018 approximately two years after the asset transfer/ one year after the end of the intervention

       ** OUTLINE:      PART 0: Standardize settings and install packages
                        PART 1: Preparing folder path globals
                        PART 2: Run the master do files for each high level task

       ** IDS VAR:       hhid       //Uniquely identifies households

       ** NOTES:

       ** WRITEN BY:    Camila Ayala (mayalaguerrero@worldbank.org)
						Thomas Escande (tescande@worldbank.org)

       */

*iefolder*0*StandardSettings****************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 0:  INSTALL PACKAGES AND STANDARDIZE SETTINGS
   *
   *           -Install packages needed to run all dofiles called
   *            by this master dofile.
   *           -Use ieboilstart to harmonize settings across users
   *
   * ******************************************************************** *

   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           -Set the global box to point to the project folder
   *            on each collaborators computer.
   *           -Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *


*iefolder*1*FolderGlobals*master************************************************
*iefolder will not work properly if the line above is edited

   global mastData               "$dataWorkFolder/MasterData" 

*iefolder*1*FolderGlobals*rawData***********************************************
*iefolder will not work properly if the line above is edited

   global encryptFolder          "$dataWorkFolder/EncryptedData" 

*iefolder*1*FolderGlobals*Followup_1********************************************
*iefolder will not work properly if the line above is edited

   *Followup_1 folder globals
   global fl1                    "$dataWorkFolder/Followup_1" 
   global fl1_dt                 "$fl1/DataSets" 
   global fl1_do                 "$fl1/Dofiles" 
   global fl1_out                "$fl1/Output" 

   *Encrypted round sub-folder globals
   global fl1_encrypt            "$encryptFolder/Round Followup_1 Encrypted" 
   global fl1_dtRaw              "$fl1_encrypt/Raw Identified Data" 
   global fl1_doImp              "$fl1_encrypt/Dofiles Import" 
   global fl1_HFC                "$fl1_encrypt/High Frequency Checks" 

   *DataSets sub-folder globals
   global fl1_dtInt              "$fl1_dt/Intermediate" 
   global fl1_dtFin              "$fl1_dt/Final" 

   *Dofile sub-folder globals
   global fl1_doCln              "$fl1_do/Cleaning" 
   global fl1_doCon              "$fl1_do/Construct" 
   global fl1_doAnl              "$fl1_do/Analysis" 

   *Output sub-folder globals
   global fl1_outRaw             "$fl1_out/Raw" 
   global fl1_outFin             "$fl1_out/Final" 

   *Questionnaire sub-folder globals
   global fl1_prld               "$fl1_quest/PreloadData" 
   global fl1_doc                "$fl1_quest/Questionnaire Documentation" 

*iefolder*1*End_FolderGlobals***************************************************
*iefolder will not work properly if the line above is edited


*iefolder*2*StandardGlobals*****************************************************
*iefolder will not work properly if the line above is edited

   * Set all non-folder path globals that are constant accross
   * the project. Examples are conversion rates used in unit
   * standardization, differnt set of control variables,
   * ado file paths etc.

   do "$dataWorkFolder/global_setup.do" 


*iefolder*2*End_StandardGlobals*************************************************
*iefolder will not work properly if the line above is edited


*iefolder*3*RunDofiles**********************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 3: - RUN DOFILES CALLED BY THIS MASTER DO FILE
   *
   *           -A task master dofile has been created for each high
   *            level task (cleaning, construct, analyze). By 
   *            running all of them all data work associated with the 
   *            Followup_1 should be replicated, including output of 
   *            tablets, graphs, etc.
   *           -Feel free to add to this list if you have other high
   *            level tasks relevant to your project.
   *
   * ******************************************************************** *

******************************************************************************** 
********************************************************************************
	** FOLLOW-UP DO FILES
********************************************************************************
********************************************************************************

* Questionnaires:
* ${fl1}/Questionnaire/Questionnaire Final

*------------------------------------*
* A. IMPORT AND PREPARE - DO NOT RUN * 
*------------------------------------*

* These do files should be run only once (at the end of data collection) UNLESS 
* something went wrong during the import of the do files or the preparation.

	* 1. Import do files from CSV to Stata.
	*	 Imports LHH, MHHH, Targeting and Market surveys
	*	do "${fl1_do}/Cleaning/import_all_fl1.do"
		
	* 2. Prepare LHH, MHHH, Targeting.
	*	 Makes corrections based on field reports and anonymize data
	*	do "${fl1_do}/Cleaning/LHH_MHHH_Targ_prepare_fl1.do"

/*-------------*
* B. CLEANING * 
*-------------*
   
	*------------------*
	* 1. Market Survey *
	*------------------*
			
		* Main cleaning do file
			do "${fl1_do}/Cleaning/market_survey_clean_fl1.do"
				
		* This do file also runs:
			
			* 1. Import do files
			*	do "${fl1_do}/Cleaning/import_Market_Survey_Followup.do"
			
	*-----------------------*
	* 2. Households Surveys *
	*-----------------------*
			
		* Main cleaning do file
			do "${fl1_do}/Cleaning/LHH_MHHH_Targ_clean_fl1.do"
					
		* This do file also runs:
			
			* 1. Import do files
			*	do "${fl1_do}/Cleaning/import_LHH_Survey_Followup.do"
			*	do "${fl1_do}/Cleaning/import_MHHH_Survey_Followup.do"
			*	do "${fl1_do}/Cleaning}/import_Targeting_Survey_Followup.do"
							
			* 2. Preparing and cleaning cortisol results
			*	do "${fl1_do}/Cleaning/preparing_and_cleaning_cortisol_results_fl1.do"
				
			* 3. Preparing and cleaning rosters
			*	do "${fl1_do}/Cleaning/preparing_and_cleaning_rosters_fl1.do"
			
			* 4. Dropping variables in roster datasets from the main files 
			*	do "${fl1_do}/Cleaning/roster_vars_todrop_fl1.do"
			
			* 5. Psychological well-being
			* do "${fl1_do}/Cleaning/all_wellbeing_clean_fl1.do"
			
			* At this point this will be the MDC published dataset (w/roster variables removed): all_HH_nopii_fl1.dta */
			

*-----------------*
* C. CONSTRUCTION * 
*-----------------*
  
 	*---------------*
	* Market Survey *
	*---------------*
				
		do "${fl1_do}/Construct/market_survey_construct_fl1.do"
		
	*--------*
	* Roster *
	*--------*
		
	* Do file
		do "${fl1_do}/Construct/roster_fl1.do"
		
	* Outputs
		* 1. Current Roster final
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta", clear 
 
	*-------------*
	* Consumption *
	*-------------*

	* Do file
		do "${fl1_do}/Construct/consumption_construct_fl1.do"
		
	* Outputs
		* 1. Total expenditure variables 
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/total_expenditure_fl1.dta", clear

	*-----------------------------------------*
	* Political involvement and food security *
	*-----------------------------------------*
		
	* Do file
		do "${fl1_do}/Construct/polinvolvement_foodsecurity_construct_fl1.do"
		
	* Outputs
		* 1. Political involvement index
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/political_involvement_index_fl1.dta", clear
			
		* 2. Food security index
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/food_security_index_fl1.dta", clear
	
	*-------------------*
	* Productive assets *
	*-------------------*
	
	* Do file
		do "${fl1_do}/Construct/productive_assests_construct_fl1.do"
		
	* Outputs
		* 1. Value of livestock
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_assets_index_fl1.dta", clear
		
		* 2. Revenue from livestock
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/livestock_revenue_index_fl1.dta", clear
		
		* 3. Revenue from crops (agricultural revenue)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/crop_production_index_fl1.dta", clear
		
		* 4. Revenue from non-agricultural businesses
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/business_revenue_earnings_fl1.dta", clear
		
	*--------*
	* Health *
	*--------*

	* Do file
		do "${fl1_do}/Construct/health_construct_fl1.do"

	* Outputs
		* 1. Children's health outcomes
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/health_fl1.dta", clear
	
	*-----------------*
	* Phone ownership *
	*-----------------*
		
	* Do file
		do "${fl1_do}/Construct/phone_ownership_fl1.do"
		
	* Outputs
		* 1. Phone ownership
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/phone_ownership_fl1.dta", clear
		
	*-----------*
	* Schooling *
	*-----------*
		
	* Do file
		do "${fl1_do}/Construct/schooling_construct_fl1.do"
		
	* Outputs
		* 1. Children's schooling outcomes
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta", clear
		
	*---------------------------------------------------*
	*  Baseline Psych well-being for follow-up 1 sample *
	*---------------------------------------------------*
  
	* Do file
		do "${fl1_do}/Construct/LHH_MHHH_Psywellbeing_construct_bl_fl1sample.do"
		
	* Outputs
		* 1. Psych well-being index UP (treatment vs. Control)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_bl_flsample.dta", clear	
		
	*------------------*
	* Psych well-being *
	*------------------*
  
	* Do file
		do "${fl1_do}/Construct/LHH_MHHH_Psywellbeing_construct_fl1.do"
		
	* Outputs
		* 1. Psych well-being index SES (UP vs. Non-UP)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_ses_fl1.dta", clear
		
		* 2. Psych well-being index UP (treatment vs. Control)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_up_fl1.dta", clear

		* 3. Psych well-being index gender (PF vs. PM)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_ses_fl1.dta", clear

	*--------------*
	* Assets index *
	*--------------*
	
	* Do file
		do "${fl1_do}/Construct/asset_index_construct_fl1.do"
		
	* Outputs
		* 1. Assets index SES (UP vs. Non-UP)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/asset_index_ses_fl1.dta", clear
		
		* 2. Assets index UP (treatment vs. Control)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/asset_index_up_fl1.dta", clear	
		
	*------------------------*
	* Entrepreneurship index *
	*------------------------*
	
	* Do file
		do "${fl1_do}/Construct/entrepreneurship_index_fl1.do"
		
	* Outputs
		* 1. Entrepeneurship index UP (treatment vs. Control)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/entrepreneur_index_up_fl1.dta", clear		
		
 	*-----------------*
	* Financial index *
	*-----------------*
	
	* Do file
		do "${fl1_do}/Construct/Financial_index_construct_fl1.do"
		
	* Outputs
		* 1. Financial index SES (UP vs. Non-UP)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/finance_index_ses_fl1.dta", clear
		
		* 2. Financial index UP (treatment vs. Control)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/finance_index_up_fl1.dta", clear
  	
 	*-------------------------------------*
	* Time spend in productive activities *
	*-------------------------------------*
	
	* Do file
		do "${fl1_do}/Construct/time_activities_construct_fl1.do"
		do "${fl1_do}/Construct/time_activities_long_construct_fl1.do"
		
	* Outputs
		* 1. Time spend SES (UP vs. Non-UP)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta", clear
		
		* 2. Time spend UP (treatment vs. Control)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta", clear
  	
		* 2. Time spend HH (total for each household)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_hh_fl1.dta", clear
	
	*----------------------------------------------------*
	* Baseline woman's empowerment for follow-up 1 sample*
	*----------------------------------------------------*

	* Do file
	do "${fl1_do}/Construct/female_empowerment_construct_bl_fl1sample.do"
	
	* Outputs
		* 1. Baseline female empowerment index (6 dimensions) for follow-up 1 sample 
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta", clear
		
				
	*---------------------*
	* Woman's empowerment *
	*---------------------*

	* Do file
		do "${fl1_do}/Construct/female_empowerment_construct_fl1.do"
		
	* Outputs
		* 1. Female empowerment index (6 dimensions)
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/f_empowerment_fl1.dta", clear
		
				
	*-----------------*
	* TUP livestock *
	*-----------------*
		
	* Do file
		do "${fl1_do}/Construct/tup_implementation_fl1.do"
		
	* Outputs
		* 1. TUP livestock ownership
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_livestock_fl1.dta", clear
		* 2. Sick TUP livestock
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_sick_livestock_fl1.dta", clear
		* 3. Sold TUP livestock
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_sold_livestock_fl1.dta", clear
		* 4. Dead TUP livestock
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/TUP_dead_livestock_fl1.dta", clear
	
 	*----------------------------------------*
	* Data for analysis --> COMPILED DATASET *
	*----------------------------------------*
   
	* Do file
		do "${fl1_do}/Construct/data_for_analysis_fl1.do"
		
	* Outputs
		* 1. data_for_analysis_fl1: compiled dataset for analysis
		* use "${TUP_DB}/Followup_1/DataSets/Intermediate/data_for_analysis_fl1.dta", clear


*iefolder*3*End_RunDofiles******************************************************
*iefolder will not work properly if the line above is edited

