set scheme s2mono


* Midline 
use "${data_for_analysis_fl1_phonesvy}", clear

		gen up_control = .
			replace up_control = 1 if treatment == 0
			replace up_control = 0 if ultra_poor == 0
	
	keep hhid tot_hh_income_1_usd_fl1 exp_f_tot_m_pc_ca21_fl1 c14_3_ac_fl1 c14_5_ac_fl1 up_control treatment ultra_poor tot_hh_income_1_usd_s exp_tot_m_pc_noh_ca21_s c14_3_ac_s c14_5_ac_s
	
	rename *_fl1 * 
	
	* Replace with missing observations that are not in the endline sample 
	replace exp_f_tot_m_pc_ca21 = . if exp_tot_m_pc_noh_ca21_s == .
	foreach var in  tot_hh_income_1_usd c14_3_ac c14_5_ac {
	 	replace `var' = . if `var'_s == .
	 }
	 
	gen endline = 0
	
	tempfile midline
	save `midline'
	
* Endline 
use "${data_for_analysis_phonesvy_long}", clear 

	gen up_control = .
		replace up_control = 1 if treatment == 0
		replace up_control = 0 if ultra_poor == 0	
		drop if up_control == .
		
	keep hhid exp_f_tot_m_pc_ca21 c14_3_ac c14_5_ac	up_control treatment ultra_poor	
	
	gen endline = 1 
	
	append using "`midline'"

	collapse (mean) exp_f_tot_m_pc_ca21 c14_3_ac c14_5_ac, by(up_control ultra_poor endline)
	
	local mlabsize "medlarge"
	local size "medium"
	local labsize "medium"
	local leg_size "medium"
	local title_size "medium"
	local leg_pos "position(0) bplacement(north)"
	
	gen endline_l = endline - 0.03
	
	* Food consumption
	gen exp_f_tot_m_pc_ca21_l = exp_f_tot_m_pc_ca21 + 0.04
		
	twoway (line exp_f_tot_m_pc_ca21 endline if up_control == 0) ///
	(line exp_f_tot_m_pc_ca21 endline if up_control == 1) ///
	(scatter exp_f_tot_m_pc_ca21_l endline_l if up_control == 0,  mlabel(exp_f_tot_m_pc_ca21) mlabf(%9.2fc) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(black))  ///
	(scatter exp_f_tot_m_pc_ca21_l endline_l if up_control == 1,  mlabel(exp_f_tot_m_pc_ca21) mlabf(%9.2fc) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(grey)), ///
	ytitle("", size(`size')) ///
	xtitle("") ylab(, nogrid) ///
	xlabel(0.05 "Midline" 0.95  "Endline" , noticks labsize(`labsize')) xscale(range(0(1)1)) ///
	legend(`leg_pos'  row(1) order(2 "UP Control" 1 "Non-UP")  size(`leg_size') region(style(none))) /// 
	graphregion(color(white)) ///
	title("Index of Per Capita Food Consumption Proxy", size(`title_size')) ///
	subtitle("Control UP HHs at Endline = 1, Constant") ///
	xsize(3) ysize(2)	
	
	*graph save "${output_raw_figures}/figure_context_consumption.gph", replace 
	
	*graph export "${output_raw_figures}/figure_context_consumption.png", replace 	 width(2000)	
	
	graph export "${output_figure_overleaf_main}/figure_context_consumption.png", replace  width(2000)		

* Food security - adult	
	replace c14_3_ac = (1 - c14_3_ac) * 100
	
	gen c14_3_ac_s  = string(round(c14_3_ac,1))   
	gen c14_3_ac_l = c14_3_ac + 5
		
	twoway (line c14_3_ac endline if up_control == 0) ///
	(line c14_3_ac endline if up_control == 1) ///
	(scatter c14_3_ac_l endline_l if up_control == 0,  mlabel(c14_3_ac_s) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(black))  ///
	(scatter c14_3_ac_l endline_l if up_control == 1,  mlabel(c14_3_ac_s) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(grey)), ///
	ytitle("", size(`size')) ///
	xtitle("") yscale(range(0 100)) ylab(0(20)100, nogrid) ///
	xlabel(0.05 "Midline" 0.95  "Endline", noticks labsize(`labsize')) xscale(range(0(1)1)) ///
	legend(`leg_pos' row(1) order(2 "UP Control" 1 "Non-UP")  size(`leg_size') region(style(none))) /// 
	graphregion(color(white)) ///
	title("Any Adult Ever Skipped or Cut Size of Meals in Past Month", size(`title_size')) ///
	subtitle("Percentage of Households") ///
	xsize(3) ysize(2)	
	
	*graph save "${output_raw_figures}/figure_context_fs_adult.gph", replace 
	
	*graph export "${output_raw_figures}/figure_context_fs_adult.png", replace 	 width(2000)	
	
	graph export "${output_figure_overleaf_main}/figure_context_fs_adult.png", replace  width(2000)	

* Food security - child c14_5_ac
	replace c14_5_ac = (1-c14_5_ac) * 100
	
	gen c14_5_ac_s  = string(round(c14_5_ac,1))   
	gen c14_5_ac_l = c14_5_ac + 5
		
	twoway (line c14_5_ac endline if up_control == 0) ///
	(line c14_5_ac endline if up_control == 1) ///
	(scatter c14_5_ac_l endline_l if up_control == 0,  mlabel(c14_5_ac_s) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(black))  ///
	(scatter c14_5_ac_l endline_l if up_control == 1,  mlabel(c14_5_ac_s) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(grey)), ///
	ytitle("", size(`size')) ///
	xtitle("") yscale(range(0 100)) ylab(0(20)100, nogrid labsize(`labsize')) ///
	xlabel(0.05 "Midline" 0.95  "Endline", noticks labsize(medlarge)) xscale(range(0(1)1)) ///
	legend(`leg_pos'  row(1) order(2 "UP Control" 1 "Non-UP")  size(`leg_size') region(style(none))) /// 
	graphregion(color(white)) ///
	title("Any Child Ever Skipped or Cut Size of Meals in Past Month", size(`title_size')) ///
	subtitle("Percentage of Households") ///
	xsize(3) ysize(2)	
	
	*graph save "${output_raw_figures}/figure_context_fs_child.gph", replace 
	
	*graph export "${output_raw_figures}/figure_context_fs_child.png", replace 	 width(2000)	
	
	graph export "${output_figure_overleaf_main}/figure_context_fs_child.png", replace  width(2000)	

	* Income 
	use "${data_for_analysis_phonesvy}", clear 

	gen up_control = .
		replace up_control = 1 if treatment == 0
		replace up_control = 0 if ultra_poor == 0	
	
	gen endline = 1 
	
	* Rename for append with midline 
	
	append using "`midline'"
	
	keep hhid tot_hh_income_1_usd	up_control treatment ultra_poor	endline
	
	collapse (mean) tot_hh_income_1_usd, by(up_control ultra_poor endline)

	drop if up_control == .
	replace up_control = 0 if mi(up_control)	
	
	gen tot_hh_income_1_usd_s  = string(round(tot_hh_income_1_usd,1))   
	gen endline_l = endline - 0.03
	gen tot_hh_income_1_usd_l = tot_hh_income_1_usd + 5
	
	twoway (line tot_hh_income_1_usd endline if up_control == 0) ///
		(line tot_hh_income_1_usd endline if up_control == 1) ///
		(scatter tot_hh_income_1_usd_l endline_l if up_control == 0,  mlabel(tot_hh_income_1_usd_s) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(black))  ///
		(scatter tot_hh_income_1_usd_l endline_l if up_control == 1,  mlabel(tot_hh_income_1_usd_s) ms(none) mlabc(black) mlabsize(`mlabsize') lcolor(grey)), ///
		xtitle("") yscale(range(0 100)) ylab(0(20)100, nogrid) ///
		ytitle("", size(`size')) ///
		xlabel(0.05 "Midline" 0.95 "Endline", noticks labsize(`labsize')) xscale(range(0 1.02)) ///
		legend(`leg_pos' row(1) order(2 "UP Control" 1 "Non-UP")  size(`leg_size') region(style(none))) /// 
		graphregion(color(white)) ///
		title("Total Household Income and Revenues Proxy (Nominal USD), Month", size(`title_size')) ///
		xsize(3) ysize(2)
	
	*graph save "${output_raw_figures}/figure_context_income.gph", replace 
	
	*graph export "${output_raw_figures}/figure_context_income.png", replace 	 width(2000)	
	
	graph export "${output_figure_overleaf_main}/figure_context_income.png", replace  width(2000)	