gl sample_indicators_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 	 
gl lstock_transition_cowequiv			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_cowequiv.dta"

global lstock_cowequiv  lstock_unit_cow_0 lstock_unit_cow_1 lstock_unit_cow_2
global controls i.PRA_lottery


* NOTE : there are 5 more obs in the panel regression for endline than in the tables; need to go back and check why this is 

***************************************************************Graph ************************************************************ 

use "${lstock_transition_cowequiv}", clear 

	merge m:1 hhid using "${sample_indicators_phonesvy}", assert(1 3) nogen keepusing(tot_lstock_value_4_usd_s lstock_num_cow_s lstock_num_goat_s lstock_num_sheep_s lstock_num_chicken_s)

	*Keeping impact estimate samples 
	keep if (lstock_num_cow_s == 1 | lstock_num_goat_s == 1 | lstock_num_sheep_s == 1 | lstock_num_chicken_s == 1)

	keep hhid period lstock_unit_cow
	
	*Not including baseline 
	drop if period == "baseline"
	
	gen round = 0 if period == "transfer"
	replace round = 1 if period == "midline"
	
	replace round = 2 if period == "follow_up_r1" // pooled together with R4
	replace round = 2 if period == "follow_up_r4" 

	drop period 
	
	//rename lstock_unit_cow lstock_unit_cow_
	
	//reshape wide lstock_unit_cow_, i(hhid) j(round)

	merge m:1 hhid using "${phone_svy_profile}", keepusing(PRA_lottery treatment) keep(3)
	
	gen counter = 1 if _n == 1 
	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	gen control_mean = .
	gen estim_point = .
	gen se = .
	gen counter_l = .	
	
	
	local i = 1 
	
	foreach var in lstock_unit_cow { // $lstock_cowequiv 
		
	replace counter = `i' if _n ==  `i'
	
	* Get the treatment estimate 	
		estimates clear
		reg `var' treatment $controls if round == 0, r 
		replace estim 	= _b[treatment] if counter == `i'
		gen sample = e(sample)
		
		replace se 	= r(table)[2,1]  if counter == `i' // SE of the treatment estimate 
			
	* Get the control mean
		sum `var' if treatment == 0 & sample == 1
		replace control_mean = `r(mean)' if counter == `i'
		
		drop sample 
		
		local i = `i' + 1 
		}

	foreach var in lstock_unit_cow { // $lstock_cowequiv 
		
	replace counter = `i' if _n ==  `i'
	
	* Get the treatment estimate 	
		estimates clear
		reg `var' treatment $controls if round == 1, r 
		replace estim 	= _b[treatment] if counter == `i'
		gen sample = e(sample)
		
		replace se 	= r(table)[2,1]  if counter == `i' // SE of the treatment estimate 
			
	* Get the control mean
		sum `var' if treatment == 0 & sample == 1
		replace control_mean = `r(mean)' if counter == `i'
		
		drop sample 
		
		local i = `i' + 1 
		}		
foreach var in lstock_unit_cow { // $lstock_cowequiv 
		
	replace counter = `i' if _n ==  `i'
	
	* Get the treatment estimate 	
		estimates clear
		reg `var' treatment ${panel_controls} if round == 2, r 
		replace estim 	= _b[treatment] if counter == `i'
		gen sample = e(sample)
		
		replace se 	= r(table)[2,1]  if counter == `i' // SE of the treatment estimate 
			
	* Get the control mean
		sum `var' if treatment == 0 & sample == 1
		replace control_mean = `r(mean)' if counter == `i'
		
		drop sample 
		
		local i = `i' + 1 
		}				
	
		format %3.2fc estim_point
		format %3.2fc control_mean
		
		replace estim_point 	= control_mean + estim 
		
		*Computes confidence interval by testing the significance of the sum of the coefficient and using the usual OLS CI formula
		replace CI_l 	= (estim - 1.96 * se) + control_mean
		replace CI_h 	= (estim + 1.96 * se) + control_mean
		
		replace counter_l = counter + 0.1
		
		gen date = .
			replace date = date("15jul2016","DMY") if counter == 1 // transfer 
			replace date = date("12aug2018","DMY") if counter == 2 // midline
			replace date = date("02june2021","DMY") if counter == 3 // R4
		
		gen date_l = date + 10

		gen estim_point_l = estim_point - 0.01
		gen control_mean_l = control_mean - 0.01

	local title "Number of Livestock Owned"
	local subtitle "In Cow Equivalents"
	local 	ytitle 	"ytitle("")"
	local 	ylabel 	"ylabel(0(0.4)2, format(%9.1f) labsize(small) angle(0))"

	*Main graph
	twoway  connected estim_point date, msymbol(smcircle) msize(small) lpattern(solid) lcolor(eltblue) mfcolor(eltblue) mlcolor(none) || ///
				connected control_mean date, msymbol(smcircle) msize(small) lpattern(longdash) lcolor(ebblue) mfcolor(ebblue) mlcolor(none) || ///
				scatter estim_point_l date_l, msym(none) mlab(estim_point) mlabpos(12) mlabcolor(black) mlabsize(small) ytitle(" ") xtitle(" ") || ///
				scatter control_mean_l date_l, msym(none) mlab(control_mean) mlabpos(12) mlabcolor(black) mlabsize(small) ytitle(" ") xtitle(" ") ///
				xlabel(20650 "    Transfer" 21408 "Midline" 22433 "Endline", labsize(small) angle(horizontal)) ///
				legend(row(1) order(1 "UP Treatment" 2 "UP Control")  size(small) region(style(none))) ///
				graphregion(color(white)) ylabel(,nogrid)  ///
				`ylabel' /// 
				subtitle("`subtitle'", margin(b=5) size(small)) `ylabel' /// 
				title("`title'", size(medium) color(black)) /// 
				graphregion(color(white))
 
	*graph export "${output_figure_overleaf_main}\figure_dynamic_lstock_cowequiv.png", replace width(1000)	
	graph export "${output_raw}\figure_dynamic_lstock_cowequiv.png", replace width(1000)
	graph save "${output_raw}\figure_dynamic_lstock_cowequiv.gph", replace
	
	* Graph combine with the number of livestock in cow equivalents
	grc1leg "${output_raw}\figure_dynamic_lstock_cowequiv.gph" "${output_raw}\figure_dynamic_lstock_value.gph", graphregion(color(white))
	graph export "${output_figure_overleaf_main}\figure_dynamic_lstock.png", replace // width(10000) height(4000) 
