/*******************************************************************************	
Project:  	AFG-TUP
********************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
global lstock_transition_cowequiv	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_cowequiv.dta"
global sample_indicators_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta"
global output_raw					"${TUP_DB}/IE_Phone_Paper/Output/Final"

global lstock_cowequiv_usd  tot_lstock_value_w99t_usd_1 tot_lstock_value_w99t_usd_2 tot_lstock_value_w99t_usd_3

global controls i.PRA_lottery

***************************************************************Graph ************************************************************ 

use "${lstock_transition_cowequiv}", clear 

merge m:1 hhid using "${sample_indicators_phonesvy}", assert(1 3) nogen keepusing(tot_lstock_value_4_usd_s)

	*Keeping impact estimate samples (N=694 for midline and N=721 for endline)
	keep if tot_lstock_value_4_usd_s == 1 

	keep hhid period tot_lstock_value tot_lstock_value_w99t tot_lstock_value tot_lstock_value_usd tot_lstock_value_w99t_usd 

	*Only including r4 as in r1 we did not collect livestock value and we want to be consistent 
	drop if period == "follow_up_r1" | period == "baseline"
	
	gen round = 1 if period == "transfer"
	replace round = 2 if period == "midline"
	replace round = 3 if period == "follow_up_r4"
	
	drop period 
	
	rename (tot_lstock_value tot_lstock_value_w99t tot_lstock_value_usd tot_lstock_value_w99t_usd) (tot_lstock_value_ tot_lstock_value_w99t_ tot_lstock_value_usd_ tot_lstock_value_w99t_usd_)
	
	reshape wide tot_lstock_value_ tot_lstock_value_w99t_ tot_lstock_value_usd_ tot_lstock_value_w99t_usd_, i(hhid) j(round)
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(PRA_lottery treatment) keep(3)	
	
	gen counter = 3 if _n == 1 
	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	gen control_mean = .
	gen estim_point = .
	gen se = .
	gen counter_l = .	
	
	
	local i = 1 
	
	foreach var in $lstock_cowequiv_usd {
		
	replace counter = `i' if _n ==  `i'
	
	* Get the treatment estimate 	
		estimates clear
		reg `var' treatment $controls, r 
		replace estim 	= _b[treatment] if counter == `i'
		gen sample = e(sample)
		
		replace se 	= r(table)[2,1]  if counter == `i' // SE of the treatment estimate 
			
	* Get the control mean
		sum `var' if treatment == 0 & sample == 1
		replace control_mean = `r(mean)' if counter == `i'
		
		drop sample 
		
		local i = `i' + 1 
		}
	
		* Round 
		format %3.0fc estim_point
		format %3.0fc control_mean
		
		replace estim_point 	= control_mean + estim 
		
		*Computes confidence interval by testing the significance of the sum of the coefficient and using the usual OLS CI formula
		replace CI_l 	= (estim - 1.96 * se) + control_mean
		replace CI_h 	= (estim + 1.96 * se) + control_mean
		
		replace counter_l = counter + 0.1
		
		gen date = .
			replace date = date("15jul2016","DMY") if counter == 1 // transfer 
			replace date = date("12aug2018","DMY") if counter == 2 // midline
			replace date = date("02june2021","DMY") if counter == 3 // R4
					
		
		gen date_l = date + 10

		gen estim_point_l = estim_point - 0.01
		gen control_mean_l = control_mean - 0.01

		
	*Main graph
	local title "Mean Value of Livestock Owned"
	local subtitle "Nominal USD"
	local 	ytitle 	"ytitle("")"
	local 	ylabel 	"ylabel(0(100)600, format(%9.0f) labsize(small) angle(0) noticks)"

	*Main graph
	twoway  connected estim_point date, msymbol(smcircle) msize(small) lpattern(solid) lcolor(eltblue) mfcolor(eltblue) mlcolor(none) || ///
				connected control_mean date, msymbol(smcircle) msize(small) lpattern(longdash) lcolor(ebblue) mfcolor(ebblue) mlcolor(none) || ///
				scatter estim_point_l date_l, msym(none) mlab(estim_point) mlabpos(6) mlabcolor(black) mlabsize(small) ytitle(" ") xtitle(" ") || ///
				scatter control_mean_l date_l, msym(none) mlab(control_mean) mlabpos(12) mlabcolor(black) mlabsize(small) ytitle(" ") xtitle(" ") ///
				xlabel(20650 "Transfer"  21408 "Midline" 22433 "Endline", labsize(small) angle(horizontal)) ///
				legend(row(1) order(1 "UP Treatment" 2 "UP Control")  size(small) region(style(none))) ///
				graphregion(color(white)) ylabel(,nogrid)  ///
				`ylabel' yscale(range(0 600)) /// 
				subtitle("`subtitle'", margin(b=5) size(small)) `ylabel' /// 
				title("`title'", size(medium) color(black)) /// 
				graphregion(color(white))
				
	graph save "${output_raw}\figure_dynamic_lstock_value.gph", replace 
	graph export "${output_raw}\figure_dynamic_lstock_value.png", replace width(1000)		
	*graph export "${output_figure_overleaf_main}\figure_dynamic_lstock_value.pdf", as(pdf) replace 
	