* Overleaf
texdoc init "${output_overleaf_online_appendix}/table_robust_bl_controls.tex", replace hardcode nokeep

/***
\documentclass[crop=false]{standalone}
\usepackage{amssymb,amsmath,amsfonts,eurosym,geometry,graphicx,caption,color,setspace,sectsty,comment,caption,pdflscape,subfigure,array,hyperref}
\usepackage{textcomp}
\usepackage[utf8]{inputenc}
\usepackage{titlesec}
\usepackage[usenames,dvipsnames]{xcolor}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{longtable}
\usepackage{indentfirst}
\usepackage[justification=centering]{caption}
\usepackage[multiple]{footmisc}
***/

*-----------------------------------------------------------*
* Table 1. Impacts on Main Outcomes *
*-----------------------------------------------------------*

/***	
	\begin{document}
	\begin{table}
	\centering
	\footnotesize
	\captionof{table}{Robustness Check: Impacts on Main Outcomes with Baseline Controls}
	\label{table:robust_bl_controls}
	\begin{tabular}{@{\extracolsep{1pt}}p{5cm}ccccc}
	\\[-1.8ex] \hline \\[-1.8ex]
	& \makecell{Control\\Mean (SD)} & \makecell{Level (SE)} & \makecell{p-value} & \makecell{\% Control\\Mean} & \makecell{N} \\     
	& (1) & (2) & (3) & (4) & (5) \\ \hline \\ 
	***/	
	
	texdoc stlog, nolog
	
	tex \\[-1.8ex] \multicolumn{6}{@{} l}{\textbf{Consumption and Food Security}} \\  \\[-1.8ex]
	
	foreach var in $consumption_ca21 index_sdC_food_sec  {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} (${N_`var'}) \\  \\[-1.8ex]
	}
		
	tex \\[-1.8ex] \multicolumn{6}{@{} l}{\textbf{Finance}} \\  \\[-1.8ex]
	
	foreach var in $fin_sum_usd {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} (${N_`var'}) \\  \\[-1.8ex]
		}
		
	tex \\[-1.8ex] \multicolumn{6}{@{} l}{\textbf{Household and Productive Assets}} \\  \\[-1.8ex]
	
	foreach var in $asset_sum {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} (${N_`var'}) \\  \\[-1.8ex]
	}
	
	foreach var in tot_lstock_value_4_w99t_usd {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} \\  \\[-1.8ex]
	}
	
	tex \\[-1.8ex] \multicolumn{6}{@{} l}{\textbf{Labor Participation}} \\  \\[-1.8ex]
	
	foreach var in $labor {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} (${N_`var'}) \\  \\[-1.8ex]
	}
	
foreach var in $revenues_sum_usd  {
	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} \\  \\[-1.8ex]
	}

	tex \\[-1.8ex] \multicolumn{6}{@{} l}{\textbf{Psychological Wellbeing, Education and Women's Empowerment}} \\  \\[-1.8ex]	
	
foreach var in $psy_detail {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} \\  \\[-1.8ex]
	}	
	
foreach var in $enrollment_hh {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} \\  \\[-1.8ex]
	}	
	
	foreach var in $empower  {
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0}) \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \end{tabular} & ${`var'p} & ${`var'imp} & ${Nhh_`var'} \\  \\[-1.8ex]
		}		
	
	tex \hline \\[-1.8ex]\multicolumn{6}{p{14cm}}{${note_table_robust_bl_controls}}\\
	
	texdoc stlog close
	
/***
	\end{tabular}
	\end{table}
	\end{document}
***/