*-------------------------------------------------* 
*  Baseline Balance Test - Main Outcomes * 
*-------------------------------------------------* 

global note_table_balance "\footnotesize{\textit{Notes}. This table reports the baseline balance test for the outcomes of interest. All regressions include 133 randomization PRA controls. Column (1) reports the mean (standard deviation in parentheses) of each outcome for the control group for the five-year follow-up sample. Column (2) reports the treatment assignment estimates (robust standard errors) in levels. Column (3) reports the “naive” p-value in brackets. Column (4) reports the total sample for each treatment estimate. All monetary amounts are in nominal Afghanis. The psychological well-being index is a standardised index including different complementary measures of psychological well-being. Women's empowerment index at baseline excludes: mobile phone ownership, national ID ownership, and voting in elections. Due to a survey error, the PW was not explicitly identified in the baseline roster. To estimate PW's labor outcomes at baseline, we use information such as age, gender, and relationship to the head of the household. HH = household; PCA = principal component analysis; PM = Primary Man; PW = Primary Woman; PRA = participatory rural appraisal; SD = standard deviation.}" 
 
* Balance test  
global ftest_vars exp_tot_m_pc_noh_ca21 index_sdC_food_sec_phone tot_lstock_value wealth_score_sdC_phone saving did_labor_pf psy_indexC_sdC_bl_phone index_sdC_f_emp_3c_phone  

global ftest_test_vars exp_tot_m_pc_noh_ca21 index_sdC_food_sec_phone tot_lstock_value wealth_score_sdC_phone saving did_labor_pf psy_indexC_sdC_bl_phone index_sdC_f_empowerment_3c_phone


 
 * Keep the relevant phone survey sample (based on regression) 

	foreach var in index_sdC_all_decisions $index_sdC_f_emp_3c $cate_outcome_1 $cate_outcome_2 {
		
			use "${data_for_analysis_phonesvy}", clear
				
			qui reg `var' treatment ${controls}, r
		
			gen `var'_s = e(sample) 
			keep if e(sample) == 1  
			keep hhid `var'_s  
			duplicates drop  
			isid hhid  
			
			tempfile `var'_s 
			save ``var'_s'
		 
		}	
		
		foreach var in index_sdC_all_decisions $index_sdC_f_emp_3c $cate_outcome_1 $cate_outcome_2 {
		    merge 1:1 hhid using ``var'_s', nogen
		}
		 
		tempfile phone_sample 
		save `phone_sample' 
	
	use "${data_for_analysis_fl1_phonesvy}", clear
		
		merge 1:1 hhid using "`phone_sample'", keepusing(*_s) nogen 
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(attrition_r* anyround treatment) keep(3) nogen

	* Rename vars to match endline 
	foreach var in index_sdC_f_emp_3c h14_ac h24_ac h31_ac h28_ac did_labor_nohh h30 n1 n2 {
		rename `var'_fl1 `var'_1_fl1 
	}
	rename (z2_fl1 z1_3_fl1) (z2_all_fl1 z1_3_all_fl1)
	rename index_sdC_role_prod_act_fl1 index_sdC_role_prod_1_fl1 // varname too long  
			
	foreach var in $index_sdC_f_emp_3c index_sdC_all_decisions $cate_outcome_1 $cate_outcome_2 {
		global `var'_fl1_lab : variable label `var'_fl1
		global `var'_fl1_lab : subinstr global `var'_fl1_lab " sd(control)" "", all
		
		reg `var'_fl1 treatment ${controls} if `var'_s == 1, r 
		sum `var'_fl1 if treatment == 0 & e(sample) == 1
	
 
	foreach var in $ftest_vars { 
 
		use "${data_for_analysis_bl_phonesvy}", clear 
		  
		
		global `var'_lab : variable label `var' 
		 
		if "`var'" == "exp_tot_m_pc_ca21" {
			global `var'_lab "Total Proxy Consumption Index (Q1 2021 = 1), Month"
		} 
		if "`var'" == "tot_lstock_value_w99" {
			global `var'_lab "Total Value of Livestock (AFN)"
		} 
				 
		* Drop indices standardized to main sample and keep those standardized for phone sample 
		drop psy_indexC_sdC_bl psy_indexC_sdC_m_bl wealth_score wealth_score_sdC property_score index_sdC_food_sec index_sdC_f_empowerment_3c 
		rename *_phone * 
		rename own_mobile own_mobile_phone 
		 		 
		reg `var' treatment ${controls}, r 
		sum `var' if treatment == 0 & e(sample) == 1	 
			 
		if "`var'" == "exp_tot_m_pc_ca18" | "`var'" == "tot_lstock_value_w99" | "`var'" == "saving_win" | "`var'" == "loan_win" {
				coeff_treat `var' treatment 1
			}
		else {
				coeff_treat `var' treatment
			}
		} 
 
 * Schooling	
	* Get an indicator for whether the HH still has school-aged children (6-18) at Phone survey R1
	use "${schooling_phonesvy}", clear
		keep if ultra_poor == 1 
		keep hhid child_in_schooling_age_hh_1
		rename child_in_schooling_age_hh_1 child_in_schooling_age_hh_phone 
		keep if child_in_schooling_age_hh_phone == 1 
		duplicates drop
		isid hhid 
	
	* Merge on baseline schooling data and keep only full merges (i.e., HHs that have a school-aged kid at endline and also had one at baseline)
	merge 1:m hhid using "${schooling_bl}", keep(3) 

	merge m:1 hhid using "${phone_svy_profile}", keepus(attrition_r1_or_r2) keep(3) nogen
	
	tempfile schooling
	save `schooling'
	
	
	foreach var in $schooling {
		
	*R1 OR R2 sample (union)
		use "`schooling'", clear 
		
		global `var'_lab : variable label `var'
	
		reg `var' treatment ${controls} if attrition_r1_or_r2 == 0, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		
		coeff_treat `var' treatment
	}

	
**** F-test	
use "${data_for_analysis_bl_phonesvy}", clear 
	
	reg treatment $ftest_test_vars ${controls}, r 
	*Ftest for all coefficients 
	test $ftest_test_vars
	global f_test_r1_r2   :  di %10.2fc  r(F) 
	global f_test_p_r1_r2 :  di %10.3fc  r(p) 
	 
	* Start the Latex document 
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_balance.do"	 