global note_table_balance_any "\footnotesize{\textit{Notes}. This table reports the baseline balance test for the outcomes of interest and other indicators. All regressions include 133 randomization PRA controls. Includes household that were surveyed in at least one of the four endline rounds. Column (1) reports the mean (standard deviation in parentheses) of each outcome for the control group for the endline sample. Column (2) reports the treatment assignment estimates (robust standard errors) in levels. Column (3) reports the “naive” p-value in [brackets]. Column (4) reports the total sample for each indicator. All monetary amounts are in nominal USD. Total value of livestock is winsorized at the 99th percentile, by treatment and control groups. The psychological well-being index is a standardised index including different complementary measures of psychological well-being. Women's empowerment index at baseline excludes: mobile phone ownership, national ID ownership, and voting in elections. Due to a survey error, the PW was not explicitly identified in the baseline roster. To estimate PW's labor outcomes at baseline, we use information such as age, gender, and relationship to the head of the household. All monetary amounts are in nominal USD. ER for 2016 of 68.87 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (annual average). HH = household; PCA = principal component analysis; PM = Primary Man; PW = Primary Woman; PRA = participatory rural appraisal; SD = standard deviation; ER = exchnage rate.}" 
 
* Balance test  
global ftest_vars exp_tot_m_pc_noh_ca21 index_sdC_food_sec_phone tot_lstock_value_4_w99t_usd wealth_score_sdC_phone saving_usd did_labor_pf psy_indexC_sdC_bl_phone index_sdC_f_emp_3c_phone   

global balance_vars b3 hhhead_female illiteracy_pf property_score own_mobile_phone loan_usd did_livestock /*did_ownFarming*/ did_ownBiz did_mkt_outhh psy_indexC_sdC_m_bl_phone diarrhea_yes vaccinecard_yes
global schooling child_inschool_hh

global ftest_test_vars exp_tot_m_pc_noh_ca21 index_sdC_food_sec_phone tot_lstock_value_4_w99t_usd wealth_score_sdC_phone saving_usd did_labor_pf psy_indexC_sdC_bl_phone index_sdC_f_emp_3c_phone

*-------------------------------------------------* 
*  Baseline Balance Test - Main Outcomes * 
*-------------------------------------------------* 
 
	foreach var in $ftest_vars $balance_vars { 

		use "${data_for_analysis_bl_phonesvy}", clear 
	
		keep if anyround == 1 
		 
		global `var'_lab : variable label `var' 
		 		 
		if "`var'" == "exp_tot_m_pc_noh_ca21" {
			global `var'_lab "Consumption Index Proxy (Endline Control = 1), Month"
		}	 
		
		if "`var'" == "psy_indexC_sdC_bl_phone" {
			global `var'_lab "PW Psychological Well-being Index (3 components) "
		}	  
			
		if "`var'" == "tot_lstock_value_4_w99t_usd" {
			global `var'_lab "Total Value of Livestock (USD)"
		}	  
			
		if "`var'" == "saving_usd" {
			global `var'_lab "HH Total Savings (USD)"
		}			
		
		if "`var'" == "loan_usd" {
			global `var'_lab "HH Total Outstanding Cash Loans (USD)"
		}	
							 
		reg `var' treatment ${controls}, r 
		sum `var' if treatment == 0 & e(sample) == 1	 
			 
		if regexm("`var'","tot_lstock_value") | regexm("`var'","saving") | regexm("`var'","loan") {
				coeff_treat `var' treatment 1
			}
		else {
				coeff_treat `var' treatment
			}
		} 
 
 * Schooling	
	* Get an indicator for whether the HH still has school-aged children (6-18) at Phone survey R1
	use "${schooling_bl_phonesvy}", clear

	keep if anyround == 1 
	
	foreach var in $schooling {
		
		global `var'_lab : variable label `var'
		
		if "`var'" == "child_inschool_hh" {
			global `var'_lab "School Enrollment (Children Ages 6 to 18 Years)"
		}	
		
		reg `var' treatment ${controls} if anyround == 1, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		
		coeff_treat `var' treatment
	}

	
**** F-test	
use "${data_for_analysis_bl_phonesvy}", clear 
		 
	keep if anyround == 1 
 
	reg treatment $ftest_test_vars ${controls}, r 
	*Ftest for all coefficients 
	test $ftest_test_vars
	global f_test_r1_r2   :  di %10.2fc  r(F) 
	global f_test_p_r1_r2 :  di %10.3fc  r(p) 
	 
	* Start the Latex document 
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_balance_anyround.do"	 