/* CBA inputs 
	
This do-file calculates total inflated costs and discounted benefits for the CBA analysis.

For reference, the original Excel workbook this is based on can be foud here:
	Dropbox/DataWork/Phone_Survey/Output/Final/Cost benefit analysis table.xlsx
	
*/	
	
	global roster_final_phonesvy 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/current_roster_final_phonesvy.dta"		
	global roster_final_fl1						"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"	
		
		
	global data_for_analysis_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy.dta"
	global data_for_analysis_phonesvy_long 		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy_long.dta"
	global data_for_analysis_fl1_phonesvy		"${TUP_DB}/Followup_1_Phone/DataSets/Final/data_for_analysis_fl1_phonesvy.dta"
	global data_for_analysis_fl1  				"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

	global controls i.PRA_lottery
	global panel_controls i.PRA_lottery ib(4).round

	* Social discount rate 
	global disc_rate 1.05
	
	//putexcel set "${TUP_DB}/Phone_Survey/Output/Final/Cost benefit analysis table.xlsx", modify sheet(CBA inputs_April2023)	 
	


********************************************************************************
* HH sise
********************************************************************************

* Midline -- for the Endline sample 
use "${roster_final_fl1}", clear 
	merge m:1 hhid using "${data_for_analysis_fl1_phonesvy}", keepusing(exp_tot_m_pc_noh_ca21_s) keep(1 3) nogen 

	keep hhid b3 ultra_poor exp_tot_m_pc_noh_ca21_s
	duplicates drop hhid ultra_poor, force

	sum b3 if ultra_poor == 1 & exp_tot_m_pc_noh_ca21_s == 1 
	
	global hhsize_mid `r(mean)'
	

* Endline 
use "${roster_final_phonesvy}", clear 

	keep hhid hh_mem round ultra_poor
	duplicates drop hhid round ultra_poor, force

	sum hh_mem if ultra_poor == 1
	
	global hhsize_end `r(mean)'


********************************************************************************
* full consumption indicator
********************************************************************************

* Midline [487]
use "${data_for_analysis_fl1}", clear 

reg exp_tot_m_pc treatment ${controls}

* In nominal USD
global fullcons_mid = (_b[treatment]/$exchange_rate_2018)
di $fullcons_mid

********************************************************************************
* proxy consumption 
********************************************************************************

* Midline - Midline sample [316], N = 1,147
use "${data_for_analysis_fl1_phonesvy}", clear 

reg exp_tot_m_pc_noh_ca18_fl1 treatment ${controls}

* In nominal USD
global proxycons_mid = (_b[treatment]/$exchange_rate_2018) 
di $proxycons_mid

* Midline - Endline sample [236], N = 839
use "${data_for_analysis_fl1_phonesvy}", clear 

reg exp_tot_m_pc_noh_ca18_fl1 treatment ${controls} if exp_tot_m_pc_noh_ca21_s == 1

global proxycons_mid_endsamp = (_b[treatment]/$exchange_rate_2018) 
di $proxycons_mid_endsamp

* Endline [142]
use "${data_for_analysis_phonesvy_long}", clear

reg exp_tot_m_pc_noh treatment ${panel_controls} treatment

* In nominal USD
global proxycons_end = (_b[treatment]/$exchange_rate_2021)
di $proxycons_end

********************************************************************************
* Upscaling ratio to full consumption
********************************************************************************

global upscale_ratio $fullcons_mid / $proxycons_mid
di $upscale_ratio

********************************************************************************
* Annual household consumption return [cons x updscale ratio x HH size x 12]
********************************************************************************

* Midline
global ann_cons_mid = ($proxycons_mid_endsamp * $upscale_ratio * $hhsize_mid * 12)
di $ann_cons_mid

* Endline
global ann_cons_end = ($proxycons_end * $upscale_ratio * $hhsize_end * 12)
di $ann_cons_end

********************************************************************************
* Livestock sell-off at endline (year 5) [322 USD]
********************************************************************************
use "${data_for_analysis_phonesvy}", clear 
	
reg tot_lstock_value_4_usd treatment ${controls}

global lstock_end _b[treatment]
di $lstock_end

********************************************************************************
* Inter- and extrapolations for consumption impact
********************************************************************************

* Slope (nominal USD 46)
global slope = ($ann_cons_mid - $ann_cons_end)/3 
di $slope

* Linear projection, assuming constant diminishing slope (nominal USD)
clear 
input year
	1
	2
	3 
	4
	5
	6
	7
	8
	9
end
	gen cons = cond(_n == 1, $ann_cons_mid + $slope, cond(_n == 2, $ann_cons_mid, cond(_n == 3, $ann_cons_mid - $slope, cond(_n == 4, $ann_cons_mid - 2*$slope, cond(_n == 5, $ann_cons_end, cond(_n == 6, $ann_cons_end - $slope, cond(_n == 7, $ann_cons_end - 2*$slope, cond(_n == 8, $ann_cons_end - 3*$slope, cond(_n == 9, $ann_cons_end - 4*$slope,.)))))))))
	gen cons_lstock = cond(_n == 1, $ann_cons_mid + $slope, cond(_n == 2, $ann_cons_mid, cond(_n == 3, $ann_cons_mid - $slope, cond(_n == 4, $ann_cons_mid - 2*$slope, cond(_n == 5, $ann_cons_end + $lstock_end, cond(_n == 6, 0, cond(_n == 7, 0, cond(_n == 8, 0, cond(_n == 9, 0,.)))))))))

* Discount to year 2 (2018 USD)
gen cons_discount = .
	replace cons_discount = cons if year == 1 | year == 2 
	forval year= 3/9 {
		replace cons_discount = cons / ($disc_rate^(`year'-2)) if year == `year'
	}
	
gen cons_lstock_discount = .
	replace cons_lstock_discount = cons_lstock if year == 1 | year == 2 
	forval year= 3/9 {
		replace cons_lstock_discount = cons_lstock / ($disc_rate^(`year'-2)) if year == `year'
	}	

rename * *_
rename year_ year 
gen n = 1 
reshape wide cons_ cons_lstock_ cons_discount_ cons_lstock_discount_, j(year) i(n)
drop n
	
********************************************************************************
* Summing up the benefits
********************************************************************************

* Year 3 to Year 5
egen cons_3to5 = rowtotal(cons_discount_3 cons_discount_4 cons_discount_5) 
egen cons_lstock_3to5 = rowtotal(cons_lstock_discount_3 cons_lstock_discount_4 cons_lstock_discount_5)

* Year 6 to Year 9
egen cons_6to9 = rowtotal(cons_discount_6 cons_discount_7 cons_discount_8 cons_discount_9) 
egen cons_lstock_6to9 = rowtotal(cons_lstock_discount_6 cons_lstock_discount_7 cons_lstock_discount_8 cons_lstock_discount_9)

* Total benefits
gen cons_total = cons_discount_1 + cons_discount_2 + cons_3to5 + cons_6to9
gen cons_lstock_total = cons_lstock_discount_1 + cons_lstock_discount_2 + cons_lstock_3to5 + cons_lstock_6to9

* Excess Livestock in Year 5 for line 9
gen lstock_diff = cons_lstock_3to5 - cons_3to5

********************************************************************************
* Sum up cost inputs and inflate to Year 2 

/* (1) Direct Transfer Costs $831
Asset Cost $608
Food Stipend $181
Health Voucher $42
(2) Total Supervision Costs $687
Salaries of Implementing Organization Staff $402
Materials $55
Training $44
Travel Costs $7
Other Supervision Expenses $180
(3) Total Direct Costs $1,518
Start-up Expenses $4
Indirect Costs $152
(4) Total Costs, Calculated as if All Incurred Immediately at Be-
ginning of Year 0
$1,675
(5) Total Costs, In
ated to Year 2 at 5% Annual Discount
Rate
$1,847 */

********************************************************************************
gen tot_cost = 608 + 181 + 42 + 402 + 55 + 44 + 7 + 180 + 4 + 152
gen tot_cost_discounted = tot_cost*($disc_rate^2)

********************************************************************************
* Break even point - EDIT THIS 
********************************************************************************

* Total discounted costs local
sum tot_cost_discounted
local tot_cost_discounted `r(mean)' 

* Sum up costs year by year - consumption only 
	local y3 = cons_1 + cons_2 + (cons_2 - $slope)/$disc_rate
	di `y3'
	local y4 = `y3' + (cons_3 - $slope)/$disc_rate^2
	di `y4'
	local y5 = `y4' + (cons_4 - $slope)/$disc_rate^3
	di `y5'
	local y6 = `y5' + (cons_5 - $slope)/$disc_rate^4
	di `y6'
	local y7 = `y6' + (cons_6 - $slope)/$disc_rate^5
	di `y7'
	local y8 = `y7' + (cons_7 - $slope)/$disc_rate^6
	di `y8'
	local y9 = `y8' + (cons_8 - $slope)/$disc_rate^7
	di `y9'

forval x = 3/9 {
	di "Consumption only. Difference up to year `x':" `y`x'' - `tot_cost_discounted' // 39$ short of breaking even in year 6
	
	if (`y`x'' - `tot_cost_discounted')>-50 { // if it's less than $50, we "round up"
		di "Breakeven year is year `x'" 
		global break_cons "`x' years"
		continue, break
		
	}
	
}

* Sum up costs year by year - plus livestock
	local y3 = cons_1 + cons_2 + (cons_2 - $slope)/$disc_rate
	di `y3'
	local y4 = `y3' + (cons_3 - $slope)/$disc_rate^2
	di `y4'
	local y5 = `y4' + cons_lstock_discount_5
	di `y5'

forval x = 3/5 {
	di "Constumption and livestock. Difference up to year `x':" `y`x'' - `tot_cost_discounted' // break-even in year 5 
	if (`y`x'' - `tot_cost_discounted')>0 {
		di "Breakeven year is year `x'"
		global break_cons_lstock "`x' years"
		continue, break
	}
}

di "$break_cons"
di "$break_cons_lstock"

********************************************************************************
* Total benefits / total costs ratio
********************************************************************************
gen cons_cbratio = cons_total/tot_cost_discounted
gen cons_lstock_cbratio = cons_lstock_total/tot_cost_discounted

sum cons_cbratio cons_lstock_cbratio

********************************************************************************
* Export into Overleaf 
********************************************************************************

	foreach var in cons_discount_1 cons_discount_2 cons_3to5 cons_lstock_3to5 cons_6to9 cons_total cons_lstock_total tot_cost tot_cost_discounted lstock_diff {
		qui sum `var'
		global `var' : di %10.0fc `r(mean)'
	}

	foreach var in cons_lstock_cbratio cons_cbratio {
		qui sum `var'
		global `var' :  di %10.2fc `r(mean)'
	}

* Putting all numbers in string to have them in math mode in Latex
	foreach var in cons_discount_1 cons_lstock_discount_1 cons_discount_2 cons_lstock_discount_2 cons_3to5 cons_lstock_3to5 cons_6to9 cons_total cons_lstock_total tot_cost tot_cost_discounted cons_lstock_cbratio cons_cbratio lstock_diff {
		global `var' = "$" + "${`var'}" + "$"
	}
	
* Start the Latex document 
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_cost_benefit.do"	 

		
		





