*-----------------------------------------------------------*
* Table X. Impacts on Household and Productive Assets       *
*-----------------------------------------------------------*

global note_table_impacts_assets_fl1 "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects at the two-year follow-up for the five-year follow-up sample. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in SOM 1 of the Appendix. Column (1) reports the mean and the standard deviation of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the total sample size. All monetary amounts are in nominal USD. ER for 2018 of 72.08 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (annual average). TUP livestock includes cows, goats, and sheep. The asset ownership index is constructed using PCA on the number of assets owned, normalized to the unit SD of control HHs, with mean equal to zero. Total value of livestock is winsorized at the 99th percentile, by treatment and control groups. PRA = participatory rural appraisal; SE = standard error; SD = standard deviation.}"

	* Outcome globals 
	global asset_sum			tup_lstock_yes lstock_yes_chicken wealth_score_sdC
	global lstock 				lstock_num_cow lstock_num_goat lstock_num_sheep lstock_num_chicken		
		
********************************************************************************
	* Follow-up 1 	
********************************************************************************	
	
	use "${data_for_analysis_fl1_phonesvy}", clear

	foreach var in $asset_sum $lstock $asset_sum2 {
		
		global `var'_fl1_lab : variable label `var'_fl1
		
		if regexm("`var'","tot_lstock_val") {
			global `var'_l "Total Value of Livestock (2018 USD)"
		}
		
		reg `var'_fl1 treatment ${controls} if `var'_s == 1, r
		sum `var'_fl1 if treatment == 0 & e(sample) == 1
		
		if regexm("`var'","wealth_score_sdC") | regexm("`var'","lstock_yes") | regexm("`var'","lstock_num_cow") | regexm("`var'","lstock_num_goat") | regexm("`var'","lstock_num_sheep") | regexm("`var'","lstock_num_chicken") | regexm("`var'","tup_lstock_yes") | regexm("`var'","lstock_yes_chicken") {		
			coeff_treat `var'_fl1 treatment
		}		
		else {
			coeff_treat `var'_fl1 treatment 1
		}
		
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
	
		if regexm("`var'","wealth_score_sdC") {
			gl `var'_fl1imp " "
			}
		else {
			gl `var'_fl1imp "${`var'_fl1imp1}\%"
		}	
		
	}

	foreach var in tot_lstock_val_w99t_usd {
		
		global `var'_l "Total Value of Livestock (2018 USD)"
		
		reg `var'_fl1 treatment ${controls} if tot_lstock_value_4_usd_s == 1, r
		sum `var'_fl1 if treatment == 0 & e(sample) == 1
		
		if regexm("`var'","wealth_score_sdC") | regexm("`var'","lstock_yes") | regexm("`var'","lstock_num_cow") | regexm("`var'","lstock_num_goat") | regexm("`var'","lstock_num_sheep") | regexm("`var'","lstock_num_chicken") | regexm("`var'","tup_lstock_yes") | regexm("`var'","lstock_yes_chicken") {		
			coeff_treat `var'_fl1 treatment
		}		
		else {
			coeff_treat `var'_fl1 treatment 1
		}
		
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
	
		if regexm("`var'","wealth_score_sdC") {
			gl `var'_fl1imp " "
			}
		else {
			gl `var'_fl1imp "${`var'_fl1imp1}\%"
		}	
		
	}
	
	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_impacts_assets_fl1.do"	


