*-----------------------------------------------------------*
* Table X. Impacts on Consumption and Food Security         *
*-----------------------------------------------------------*

global note_table_impacts_consump_fl1 "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects at the two-year follow-up for the five-year follow-up sample. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in SOM 1 of the Appendix. Column (1) reports the mean and the standard deviation of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the total sample size. Our proxy consumption estimate includes 25 food and 5 non-food items with greatest explanatory power. Consumption in constant 2018 AFN is converted into an index where the five-year follow-up (Q1 2021) consumption for the control group = 1. The food security index combines three variables listed in Table X of the Appendix, normalized to the unit SD of control HHs, with mean equal = 0. Nutritional diversity results report shares of proxy food consumption, by type of food. Meat category includes beef, veal, mutton, goat, and chicken; dairy category includes milk (fresh), yogurt, curd (chaka), dogh (a yogurt drink), and eggs; vegetables category includes potato, tomato, okra, pumpkin, and green pepper; fruits category includes apple, orange, banana, mango, and lettuce. HH = household; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation.}"

	* Outcome globals (pooled)
	global consumption_ca21 	exp_tot_m_pc_noh_ca21
	global index_sdC_food_sec   index_sdC_food_sec
	global item_type 			item_type_share_1 item_type_share_2 item_type_share_3 item_type_share_4 item_type_share_7 item_type_share_9 item_type_share_10 item_type_share_11 item_type_share_12 
	

********************************************************************************
	* Follow-up 1 	
********************************************************************************	
	
	use "${data_for_analysis_fl1_phonesvy}", clear

	foreach var in $consumption_ca21 $index_sdC_food_sec {
		
		global `var'_fl1_lab : variable label `var'_fl1
		
		reg `var'_fl1 treatment ${controls} if `var'_s == 1, r
		sum `var'_fl1 if treatment == 0 & e(sample) == 1
		
		if regexm("`var'","ca21") | regexm("`var'","index_sdC_food_sec") | regexm("`var'","c14_7") | regexm("`var'","c14_3_ac") | regexm("`var'","c14_5_ac") {		
			coeff_treat `var'_fl1 treatment
			gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		}		
		else {
			coeff_treat `var'_fl1 treatment 1
			gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		}
		
		if  regexm("`var'","index_sdC_food_sec") {
		gl `var'_fl1imp " "
		}
		else {
		gl `var'_fl1imp "${`var'_fl1imp1}\%"
		}
	
	}
	
	* Nutrition shares 
	use "${food_consumption_shares_fl1}", clear 
			
	foreach var in $item_type {
		
		global `var'_fl1_lab : variable label `var'_fl1
		
		reg `var'_fl1 treatment ${controls}, r
		sum `var'_fl1 if treatment == 0 & e(sample) == 1
	
		coeff_treat `var'_fl1 treatment
		
		gl `var'_fl1imp "${`var'_fl1imp1}\%"	 
	}	

	
		* AFN 2018 divided by endline control mean 
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_impacts_consump_ca21_fl1.do"

