*-----------------------------------------------------------*
* Table X. Impacts on Diversification                       *
*-----------------------------------------------------------*

global note_table_impacts_divers "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls. For household business ownership indicator the regression also controls for data collection rounds in which the outcome was collected, and the SEs are clustered at the household level. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the total sample size. For the household business ownership indicator, column (5) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). The number of income sources counts the following types of income: primary man paid labor income, primary woman paid labor income, agricultural income, non-agricultural business income, and livestock-related income. Productive assets include assets that could be used for productive activities, such as agricultural tools. HH = household; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation.}" 

* Outcome globals
global diver_outcomes num_inc_source_1 asset_num num_asset_produse num_crop_type
 
********************************************************************************
* Phone Survey  
********************************************************************************	
	
	use "${data_for_analysis_phonesvy}", clear
			
	foreach var in $diver_outcomes {
		
		global `var'_lab : variable label `var'
			
		if "`var'" == "num_inc_source_1" { 
			global `var'_lab "Income Sources (Out of 5)" 
		} 	
		if "`var'" == "asset_num" { 
			global `var'_lab "Non-Livestock Assets Owned" 
		} 		
		if "`var'" == "num_asset_produse" { 
			global `var'_lab "Non-Livestock Assets Owned and Used for Production" 
		} 				
			
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		coeff_treat `var' treatment
		gl `var'p "$[$${`var'p}$]$"
		
		gl `var'imp "${`var'imp1}\%"	
		
		* Number of unique HHs
		global Nhh_`var' ${N_`var'}	
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
		
		* Get NUP means and N 
		sum `var' if ultra_poor == 0
			global `var'm_nup : di %10.3fc `r(mean)'
			global `var's_nup : di %10.3fc `r(sd)'
			
			* Math mode for Latex 
			global `var'm_nup = "$" + "${`var'm_nup}" + "$"
			global `var's_nup = "$" + "${`var's_nup}" + "$"
			
			global N_nup_`var' : di %10.0fc `r(N)'
			global N_nup_`var' = "$" + "${N_nup_`var'}" + "$"
			
			* Number of unique HHs
			unique hhid if !mi(`var') & ultra_poor == 0
			global Nhh_nup_`var' : di %10.0fc `r(sum)'
			global Nhh_nup_`var' = "$" + "${Nhh_nup_`var'}" + "$"
			
	}
	
	* Pooled outcome biz_yes (R1 + R4)
	use "${data_for_analysis_phonesvy_long}", clear
			
	foreach var in biz_yes {

		global `var'_lab "Household Has Any Non-Agricultural Business" 

		reg `var' treatment ${panel_controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1 
		
		coeff_treat `var' treatment
		gl `var'p "$[$${`var'p}$]$"
		
		gl `var'imp "${`var'imp1}\%"	
		
		* Number of unique HHs
		macro drop Nhh_`var'
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
		
		* Number of rounds included - do not count R4 completion
		macro drop Nr_`var'
		unique round if e(sample) == 1
		if `r(N)'/`r(sum)' < 600 { // do not count R4 completion
			local Nr_`var' = `r(sum)' - 1
		}
		else {
		    local Nr_`var' = `r(sum)'
		}
		global Nr_`var' : di %10.0fc `Nr_`var''
		
		* Get NUP means and N 
		sum `var' if ultra_poor == 0
			global `var'm_nup : di %10.3fc `r(mean)'
			global `var's_nup : di %10.3fc `r(sd)'
			
			* Math mode for Latex 
			global `var'm_nup = "$" + "${`var'm_nup}" + "$"
			global `var's_nup = "$" + "${`var's_nup}" + "$"
			
			global N_nup_`var' : di %10.0fc `r(N)'
			global N_nup_`var' = "$" + "${N_nup_`var'}" + "$"
			
			* Number of unique HHs
			unique hhid if !mi(`var') & ultra_poor == 0
			global Nhh_nup_`var' : di %10.0fc `r(sum)'
			global Nhh_nup_`var' = "$" + "${Nhh_nup_`var'}" + "$"
	}		
	
	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_impacts_diversification.do"

