*-----------------------------------------------------------*
* Table 1. Impacts on Finance (Nominal USD)                 *
*-----------------------------------------------------------*

global note_table_impacts_finance_fl1 "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects at the two-year follow-up for the five-year follow-up sample. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in SOM 1 of the Appendix. Column (1) reports the mean and the standard deviation of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the total sample size. All monetary amounts are in nominal USD. ER for 2018 of 72.08 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (annual average). PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; ER = exchange rate.}"

	* Outcome globals 
	global fin_sum_usd 			saving_dummy saving_usd loan_dummy loan_usd		
		
	*prod_loan is in the cross-section dataset since it is only available in R3 (no pooled indicator) 

********************************************************************************
	* Follow-up 1 	
********************************************************************************	
	
	use "${data_for_analysis_fl1_phonesvy}", clear

	foreach var in $fin_sum_ca18 $fin_sum_ca21 $fin_sum_usd prod_loan {
		
		global `var'_fl1_lab : variable label `var'_fl1
		
		reg `var'_fl1 treatment ${controls} if `var'_s == 1, r
		sum `var'_fl1 if treatment == 0 & e(sample) == 1
		
		if regexm("`var'","saving_dummy") | regexm("`var'","loan_dummy") | regexm("`var'","prod_loan") {		
			coeff_treat `var'_fl1 treatment
		}		
		else {
			coeff_treat `var'_fl1 treatment 1
		}
		
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		gl `var'_fl1imp "${`var'_fl1imp1}\%"
		
	}
	
	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_impacts_finance_usd_fl1.do"	
	


