*--------------------------------------------------------------------------------------*
* Table X. Impacts on Household Income and Revenues (Nominal USD), Past 4 Weeks        *
*--------------------------------------------------------------------------------------*

global note_table_impacts_income_fl1 "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects at the two-year follow-up for the five-year follow-up sample. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in SOM 1 of the Appendix. Column (1) reports the mean and the standard deviation of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). All monetary amounts are in nominal USD (2018 for two- and 2021 for five-year follow-up). All monetary amounts are in nominal USD. ER for 2018 of 72.08 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (annual average). PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; ER = exchange rate.}"

	* Outcome globals 
	global revenues_sum_usd	    tot_hh_income_1_usd tot_lstock_rev_1_usd tot_crop_rev_imp_2_usd tot_biz_rev_imp_1_usd tot_hh_pay_imp_1_usd
	
********************************************************************************
	* Follow-up 1 	
********************************************************************************	

	use "${data_for_analysis_fl1_phonesvy}", clear

	foreach var in $revenues_sum_usd {
		
		global `var'_fl1_lab : variable label `var'_fl1
		
		if regexm("`var'","tot_hh_income") {
		    global `var'_fl1_lab "Proxy Total Income and Revenues"
		}
		
		reg `var'_fl1 treatment ${controls} if `var'_s == 1, r
		sum `var'_fl1 if treatment == 0 & e(sample) == 1

		coeff_treat `var'_fl1 treatment 1
		
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		gl `var'_fl1imp "${`var'_fl1imp1}\%"
	}
	

	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_impacts_income_usd_fl1.do"
	


