global note_table_impacts_psy_det_fl1	"\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects at the two-year follow-up for the five-year follow-up sample. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in SOM 1 of the Appendix. Column (1) reports the mean and the standard deviation of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean, except for indices. Column (5) reports the total sample size. The psychological well-being measures include questions on life satisfaction and happiness from the WVS (averages of round 1 and 2 of the five-year follow-up data collection); and scores on the CES-D seven-point scale (negatively coded). Each psychological well-being measure is estimated as a score on the variable's scale, normalized to the unit SD of control HHs, with mean equal to zero. The psychological well-being index is an index of the three previous measures, normalized in the same way. School enrolment is estimated for school-age children (ages 6 to 18 years). The unit of observation is the child for the schooling and health outcomes, hence all SEs are clustered at the household level. PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; CES-D = Center for Epidemiological Studies Depression.}" 
 
 * Outcome globals 
	global psy_detail 			psy_indexC_sdC happy satisf_score cesd_md	
	global enrollment_hh		child_inschool_hh
 
*------------------------------------------------------------*	 
* Table X. Impacts on Psychological Well-Being and Schooling * 
*------------------------------------------------------------* 
	 
******************************************************************************** 
	* Follow-up 1 	 
********************************************************************************	 
	
	use "${data_for_analysis_fl1_phonesvy}", clear
	
	foreach var in $psy_detail { 
		 
		global `var'_fl1_lab : variable label `var'_fl1 
		
		if "`var'" == "cesd_md" {
		    global `var'_fl1_lab "PW is Depressed (7-CESD $\geq$ 8)"
		}
		
		reg `var'_fl1 treatment ${controls} if `var'_s == 1, r 
		sum `var'_fl1 if treatment == 0 & e(sample) == 1 
		 
		coeff_treat `var'_fl1 treatment 
		 
		gl `var'_fl1p "$[$${`var'_fl1p}$]$" 
		
		if regexm("`var'","index") {
			gl `var'_fl1imp " "
			}
		else {
			gl `var'_fl1imp "${`var'_fl1imp1}\%"
		}
		
		* Number of unique HHs
		global Nhh_`var' ${N_`var'}
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
	}	 
		
* Schooling regression at the child-level
	
	use "${schooling_fl1_phonesvy}", clear
		
	foreach var in $enrollment_hh { 
	    
		global `var'_fl1_lab : variable label `var'_fl1 
		 
		reg `var'_fl1 treatment ${controls} if `var'_s == 1, r cluster(hhid) 
		sum `var'_fl1 if treatment == 0 & e(sample) == 1 
		 
		coeff_treat `var'_fl1 treatment 
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		
		if regexm("`var'","index") {
			gl `var'_fl1imp " "
			}
		else {
			gl `var'_fl1imp "${`var'_fl1imp1}\%"
		}
		
		* Number of unique HHs
		global Nhh_`var' ${N_`var'}
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
	} 		
	 
	* Start the Latex document 
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_impacts_psy_detail_fl1.do"	 
