*---------------------------------------------------------------------------------------------*
* Table X: Impacts on Labor Supply and Time Use, Primary Woman and Man, Past 4 Weeks (Pooled) *
*---------------------------------------------------------------------------------------------*

global note_table_impacts_timeuse_fl1	"\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects at the two-year follow-up for the five-year follow-up sample. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in SOM 1 of the Appendix. Column (1) reports the meanand the standard deviation of each outcome for the primary woman (respectively, column (4) for the primary man) of the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses) for the primary woman (respectively, column (5) for the primary man). Column (3) reports the naive p-values [in brackets] for the primary woman (respectively, column (6) for the primary man). Total primary woman (respectively, primary man) sample size for each treatment estimate is reported at the bottom of the panels. Total is the sum of the market activities listed. All estimates are whether the HH member engaged in an activity over the past four weeks. Labor force participation is defined by the ILO as the working-age population that engages actively in the labour market, either by working or looking for work. HH = household; PRA = participatory rural appraisal; SD = standard deviation.}"

* Outcome globals 

	* Pooled
	global labor_particip	labor_particip
	global participation	employment k5_1		
	global time_sum			did_livestock did_ownFarming did_ownBiz did_oWork
	
	/* Not pooled (R3 only) [separate section] - exclude this from the table for now 
	global hours 			tot_k30_out_hrs_4w tot_k30_in_hrs_4w */
	
********************************************************************************
	* Follow-up 1 	
********************************************************************************	
	
	use "${data_for_analysis_fl1_phonesvy}", clear

	foreach var in $labor_particip $participation {
		global `var'_fl1_lab : variable label `var'_pf_fl1
		
		* For female
		reg `var'_pf_fl1 treatment ${controls} if `var'_pf_s == 1, r
		sum `var'_pf_fl1 if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_fl1 treatment

		*For male
		reg `var'_pm_fl1 treatment ${controls} if `var'_pm_s == 1, r
		sum `var'_pm_fl1 if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_pm_fl1 treatment
		
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		gl `var'_pm_fl1p "$[$${`var'_pm_fl1p}$]$"	
	}
	
		
	foreach var in $time_sum {
		global `var'_fl1_lab : variable label `var'_pf_fl1
		
		* For female
		reg `var'_pf_fl1 treatment ${controls} if `var'_pf_s == 1, r
		sum `var'_pf_fl1 if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_fl1 treatment

		*For male
		reg `var'_pm_fl1 treatment ${controls} if `var'_pm_s == 1, r
		sum `var'_pm_fl1 if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_pm_fl1 treatment
		
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		gl `var'_pm_fl1p "$[$${`var'_pm_fl1p}$]$"	
	}	
	
	* Save the smallest N of all variables in the table to display at the bottom 
	local N_min_list_fl1 
	local N_min_list_pm_fl1 
	
	foreach var in $labor_particip $time_sum {
		foreach suff in "" "_pm" {
			local N_`var'`suff'_fl1 : subinstr global N_`var'`suff'_fl1 "$" "", all
			local N_`var'`suff'_fl1 : subinstr local N_`var'`suff'_fl1 "," "", all
			local N_`var'`suff'_fl1 : subinstr local N_`var'`suff'_fl1 "     " ",", all
			local N_`var'`suff'_fl1 : list uniq local N_`var'`suff'_fl1

			local N_min_list`suff'_fl1 `N_min_list`suff'_fl1' `N_`var'`suff'_fl1'
		}
	}

	global N_min_fl1 : di %10.0fc min(`N_min_list_fl1')
	global N_min_fl1 = "$" + "${N_min_fl1}" + "$"

	global N_min_pm_fl1 : di %10.0fc min(`N_min_list_pm_fl1')
	global N_min_pm_fl1 = "$" + "${N_min_pm_fl1}" + "$"
	
	/* Hours 
	foreach var in $hours {
		global `var'_fl1_lab : variable label `var'_pf_fl1
		
		* For female
		reg `var'_pf_fl1 treatment ${controls} if `var'_pf_fl1_s == 1, r
		sum `var'_pf_fl1 if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_fl1 treatment 1

		*For male
		reg `var'_pm_fl1 treatment ${controls} if `var'_pm_fl1_s == 1, r
		sum `var'_pm_fl1 if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_pm_fl1 treatment 1
		
		gl `var'_fl1p "$[$${`var'_fl1p}$]$"
		gl `var'_pm_fl1p "$[$${`var'_pm_fl1p}$]$"	
	}	
	
	* Save the smallest N of all variables in the table to display at the bottom 
	local hrs_N_min_list_fl1 
	local hrs_N_min_list_pm_fl1 
	
	foreach var in $hours {
		foreach suff in "" "_pm" {
			local hrs_N_`var'`suff'_fl1 : subinstr global N_`var'`suff'_fl1 "$" "", all
			local hrs_N_`var'`suff'_fl1 : subinstr local hrs_N_`var'`suff'_fl1 "," "", all
			local hrs_N_`var'`suff'_fl1 : subinstr local hrs_N_`var'`suff'_fl1 "     " ",", all
			local hrs_N_`var'`suff'_fl1 : list uniq local hrs_N_`var'`suff'_fl1

			local hrs_N_min_list`suff'_fl1 `hrs_N_min_list`suff'_fl1' `hrs_N_`var'`suff'_fl1'
			
			di "`hrs_N_min_list`suff'_fl1'"
		}
	}

	global hrs_N_min_fl1 : di %10.0fc min(`hrs_N_min_list_fl1')
	global hrs_N_min_fl1 = "$" + "${hrs_N_min_fl1}" + "$"

	global hrs_N_min_pm_fl1 : di %10.0fc min(`hrs_N_min_list_pm_fl1')
	global hrs_N_min_pm_fl1 = "$" + "${hrs_N_min_pm_fl1}" + "$"	*/
	
	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_impacts_timeuse_fl1.do"	
