*-----------------------------------------------------------*
* Table 1. Impacts on Main Outcomes *
*-----------------------------------------------------------*

global note_table_robust_allrounds "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. The sample includes HHs surveyed in all four of the endline survey rounds. All regressions include 133 randomization PRA controls control control for data collection rounds in which outcomes were collected (for outcomes collected in more than one round). SEs are clustered at the household level for outcomes collected in endline data collection rounds, and for school enrollment, where the unit of observation is a child. Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. Column (1) reports the mean and the standard deviation of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean, except for indices. Column (5) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). Total value of livestock is winsorized at the 99th percentile, by treatment and control groups. All monetary amounts are in nominal USD. ER for 2021 of 77.45 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (average of ER for March, April and May 2021, due to data unavailability in the rest of the months). PRA = participatory rural appraisal; SE = standard error; SD = standard deviation.}"

	* Outcome globals 
	global consumption_ca21_all 	exp_tot_m_pc_noh_ca21_all // pooled 
	global fin_sum_usd_all 			saving_dummy saving_usd loan_dummy loan_usd // pooled		
	global asset_sum_all			tup_lstock_yes wealth_score_sdC_allrounds // pooled
	global labor_all 				labor_particip_pf labor_particip_pm // pooled
	
	global revenues_sum_usd_all	    tot_hh_income_1_usd // single round 
	global psy_detail_all 			psy_indexC_sdC_allr // single round
	global empower_all				index_sdC_f_emp_3c_1_all // single round
	global enrollment_hh_all		child_inschool_hh // single round
		
	* tot_lstock_value_usd - a single round outcome 	
	
********************************************************************************
	* Phone Survey - pooled outcomes 
********************************************************************************		
	use "${data_for_analysis_phonesvy_long}", clear

	assert !mi(all_rounds)
	
	keep if all_rounds == 1
	
	foreach var in $consumption_ca21_all index_sdC_food_sec_all $fin_sum_usd_all $asset_sum_all $labor_all {
		
		global `var'_lab : variable label `var'
		global `var'_lab : subinstr global `var'_lab " (2021 USD)" " (USD)", all 
		
		if regexm("`var'","tup_lstock_yes") {
		    global `var'_lab "HH Owns Any Cows, Goats, or Sheep"
		}
		if regexm("`var'","labor_particip_pf") {
		    global `var'_lab "PW Labor Participation"
		}
		if regexm("`var'","labor_particip_pm") {
		    global `var'_lab "PM Labor Participation"
		}
		if regexm("`var'","exp_tot_m_pc_noh_ca21") {
		    global `var'_lab "Consumption Index Proxy (Endline Control = 1), Month"
		}
		
		reg `var' treatment ${panel_controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","usd") {	
			
			coeff_treat `var' treatment 1 
			gl `var'p "$[$${`var'p}$]$"
		}		
		else {
			coeff_treat `var' treatment 
			gl `var'p "$[$${`var'p}$]$"
		}
		
		if regexm("`var'","index") | regexm("`var'","wealth_score_sdC") {
			gl `var'imp " "	
		}
		else {
		gl `var'imp "${`var'imp1}\%"	
		}
		
		* Number of unique HHs
		macro drop Nhh_`var'
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
	}	
	
********************************************************************************
	* Phone Survey - single round outcomes 
********************************************************************************		
	use "${data_for_analysis_phonesvy}", clear
	
	assert !mi(all_rounds)
	
	keep if all_rounds == 1
			
	foreach var in $revenues_sum_usd_all $psy_detail_all $empower_all tot_lstock_value_4_w99t_usd {
		
		global `var'_lab : variable label `var'
		global `var'_lab : subinstr global `var'_lab " (2021 USD)" " (USD)", all 
				
		if regexm("`var'","tot_hh_income_1_usd") {
		    global `var'_lab "Total HH Income and Revenues Proxy (USD), Month"
		}
		if regexm("`var'","psy_indexC_sdC_all") {
		    global `var'_lab "PW Psychological Well-being Index (3 items)"
		}		
		if regexm("`var'","tot_lstock_value_4") {
		    global `var'_lab "Total Value of Livestock (USD)"
		}
		
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","usd") {	
			coeff_treat `var' treatment 1 
			gl `var'p "$[$${`var'p}$]$"
		}		
		else {
			coeff_treat `var' treatment 
			gl `var'p "$[$${`var'p}$]$"
		}
		
		if regexm("`var'","index") | regexm("`var'","wealth_score") {
			gl `var'imp " "	
		}
		else {
			gl `var'imp "${`var'imp1}\%"	
		}
		
		global Nhh_`var' = "${N_`var'}"
		
	}		
	
* Schooling regression at the child-level  
	use "${schooling_phonesvy}", clear  
	
	assert !mi(all_rounds)
	keep if all_rounds == 1
	
	foreach var in $enrollment_hh_all { 
	   
		global `var'_lab : variable label `var'
		
		if regexm("`var'","child_inschool_hh") {
		    global `var'_lab "School Enrollment (Children Ages 6 to 18 Years)"
		} 
		 
		reg `var' treatment ${controls}, r cluster(hhid) 
		sum `var' if treatment == 0 & e(sample) == 1 
		 
		coeff_treat `var' treatment 
		gl `var'p "$[$${`var'p}$]$" 
		
		if regexm("`var'","index") {
			gl `var'imp " "
		}
		else {
			gl `var'imp "${`var'imp1}\%"
		}
		
		global Nhh_`var' = "${N_`var'}"
	}	 	
 	
	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_robust_allrounds.do"

