*-----------------------------------------------------------*
* Table 1. Impacts on Main Outcomes *
*-----------------------------------------------------------*

global note_table_robust_bl_controls "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls control for endline data collection rounds in which outcomes were collected (for outcomes collected in more than one round). SEs are clustered at the household level for outcomes collected in multiple endline data collection rounds, and for school enrollment, where the unit of observation is a child. All regressions also control for baseline values of outcomes unbalanced at baseline, value of livestock (in nominal USD) and primary women's psychological well-being index. Missing baseline values are imputed with the overall mean if no more than 10\% of the values are missing, and with an arbitrary constant (0) otherwise (following \cite{Green2016}). Regressions include a dummy to indicate baseline covariate missingness, which is never above 10\%. Column (1) reports the mean and the standard deviation of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean, except for indices. Column (5) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. Total value of livestock is winsorized at the 99th percentile, by treatment and control groups. ER for 2021 of 77.45 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (average of ER for March, April and May 2021, due to data unavailability in the rest of the months). PRA = participatory rural appraisal; SE = standard error; SD = standard deviation.}"

	* Outcome globals 
	global consumption_ca21 	exp_tot_m_pc_noh_ca21
	global fin_sum_usd 			saving_dummy saving_usd loan_dummy loan_usd		
	global asset_sum			tup_lstock_yes wealth_score_sdC
	global labor 				labor_particip_pf labor_particip_pm
	
	global revenues_sum_usd	    tot_hh_income_1_usd
	global psy_detail 			psy_indexC_sdC
	global empower				index_sdC_f_emp_3c_1
	global enrollment_hh		child_inschool_hh

	global controls 			i.PRA_lottery
	global bl_controls 		    psy_indexC_sdC_bl psy_indexC_sdC_bl_mi tot_lstock_val_4_w99t_usd_bl tot_lstock_val_4_w99t_usd_bl_mi // w99t livestock value 
	global panel_controls		i.PRA_lottery ib(4).round
	
********************************************************************************
	* Phone Survey - pooled outcomes 
********************************************************************************		
	use "${data_for_analysis_phonesvy_long}", clear

	foreach var in $consumption_ca21 index_sdC_food_sec $fin_sum_usd $asset_sum $labor {
		global `var'_lab : variable label `var'
		global `var'_lab : subinstr global `var'_lab " (2021 USD)" " (USD)", all 

		if regexm("`var'","tup_lstock_yes") {
		    global `var'_lab "HH Owns Any Cows, Goats, or Sheep"
		}
		if regexm("`var'","labor_particip_pf") {
		    global `var'_lab "PW Labor Participation"
		}
		if regexm("`var'","labor_particip_pm") {
		    global `var'_lab "PM Labor Participation"
		}
		if regexm("`var'","exp_tot_m_pc_noh_ca21") {
		    global `var'_lab "Consumption Index Proxy (Endline Control = 1), Month"
		}
		
		reg `var' treatment ${panel_controls} ${bl_controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","usd") {	
			
			coeff_treat `var' treatment 1 
			gl `var'p "$[$${`var'p}$]$"
		}		
		else {
			coeff_treat `var' treatment 
			gl `var'p "$[$${`var'p}$]$"
		}
		
		if regexm("`var'","sdC") {
		gl `var'imp " "	
		}
		else {
		gl `var'imp "${`var'imp1}\%"	
		}
		
		* Number of unique HHs
		macro drop Nhh_`var'
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
	}	
	
* Schooling regression at the child-level  
	use "${schooling_phonesvy}", clear  	
		* Merging on 2 covariates unbalanced at baseline 
		merge m:1 hhid using "${covars_bl_phonesvy}", keep(1 3) nogen // 5264 HHID does not have baseline covariates? It's NUP so not super important, but check this later 
 		 
	foreach var in $enrollment_hh { 		
		if regexm("`var'","child_inschool_hh") {
		    global `var'_lab "School Enrollment (Children Ages 6 to 18 Years)"
		} 
		 
		reg `var' treatment ${controls} ${bl_controls}, vce(cluster hhid) 
		sum `var' if treatment == 0 & e(sample) == 1 
		 
		coeff_treat `var' treatment 
		gl `var'p "$[$${`var'p}$]$" 
		
		gl `var'imp "${`var'imp1}\%"
		
		global Nhh_`var' = "${N_`var'}"
	}	 	
	
********************************************************************************
	* Phone Survey - single round outcomes 
********************************************************************************		
	use "${data_for_analysis_phonesvy}", clear
			
	foreach var in $revenues_sum_usd $psy_detail $empower tot_lstock_value_4_w99t_usd {
		global `var'_lab : variable label `var'
		global `var'_lab : subinstr global `var'_lab " (2021 USD)" " (USD)", all 
		
		if regexm("`var'","tot_hh_income_1_usd") {
		    global `var'_lab "Total HH Income and Revenues Proxy (USD), Month"
		}
		if regexm("`var'","psy_indexC_sdC") {
		    global `var'_lab "PW Psychological Well-being Index (3 items)"
		}
		if regexm("`var'","tot_lstock_value_4") {
		    global `var'_lab "Total Value of Livestock (USD)"
		}
		
		reg `var' treatment ${controls} ${bl_controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","usd") {	
			
			coeff_treat `var' treatment 1 
			gl `var'p "$[$${`var'p}$]$"
		}		
		else {
			coeff_treat `var' treatment 
			gl `var'p "$[$${`var'p}$]$"
		}
		
		if regexm("`var'","sdC") {
		gl `var'imp " "	
		}
		else {
		gl `var'imp "${`var'imp1}\%"	
		}
		
		global Nhh_`var' = "${N_`var'}"
	}		
	
	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_robust_bl_controls.do"

