*-----------------------------------------------------------------------------*
* Table AX: Differences Between Midline and Endline Samples and Indicators    *
*-----------------------------------------------------------------------------* 

global note_table_sample_impact_compare "\footnotesize{\textit{Notes}. This table reports OLS estimates of treatment effects at midline. All regressions include 133 randomization PRA controls. Panel A reports midline impact estimates for select outcomes using indicators collected at midline. Panel B reports midline impact estimates for select outcomes using indicators collected at endline, where some indicators are equivalent to midline indicators (food security index, value of livestock, asset ownership index, total savings, market work participation), and some are reduced proxies (consumption, income and revenues, psychological well-being and women's empowerment). Detailed defenitions of primary outcomes can be found in \autoref{ssec:som_1}. Columns (1)-(4) report estimates for the midline sample (N=1,147), and columns (5)-(8) report estimates for the endline sample (N=839). Columns (1), (5) report the mean and the standard deviation (in parentheses) of each outcome for the control group for the midline and endline samples, respectively. Columns (2), (3), (6), (7) report the treatment estimates in levels with robust standard errors (in parentheses) and naive p-values [in brackets]. Columns (4), (8) reports the treatment estimates as a percentage of the control mean, except for indices. All monetary amounts are in nominal USD. ER for 2018 of 72.08 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (annual average). Total value of livestock is winsorized at the 99th percentile, by treatment and control groups. PW = Primary Woman; HH = household; PRA = participatory rural appraisal; SD = standard deviation; SE = standard error.}" 

* Include exp_tot_m_pc_noh outside of the global

global ftest_vars  exp_tot_m_pc_usd index_sdC_food_sec tot_hh_income_usd tot_lstock_val_w99t_usd wealth_score_sdC saving_usd loan_usd ///
						employment_pf psy_indexC_sdC index_sdC_f_emp_3c 
						
global ftest_vars_phonesvy   exp_tot_m_pc_noh_usd index_sdC_food_sec tot_hh_income_1_usd tot_lstock_val_w99t_usd wealth_score_sdC saving_usd loan_usd ///
						employment_pf psy_indexC_sdC index_sdC_f_emp_3c_1 

********************************************************************************
* Panel A: Midline Indicators
********************************************************************************

********************************************************************************
* Top left panel: Midline sample, midline indicator (N=1147)
********************************************************************************
use "${data_for_analysis_fl1}", clear
	
	foreach var in  $ftest_vars {
		cap noi rename `var'_fl1 `var'
		
		global `var'_lab : variable label `var' 
		
		if regexm("`var'","employment_pf") {
		    global `var'_lab "PW Did Market Work" 
		}
		if regexm("`var'","exp_tot_m_pc") {
		    global `var'_lab "Consumption per Capita (USD), Month" 
		}
		if regexm("`var'","income") {
		    global `var'_lab "Total Household Income and Revenues (USD), Month"
		}
		if regexm("`var'","tot_lstock_val") {
			global `var'_lab "Total Value of Livestock (USD)"
		}
		if regexm("`var'","saving") {
			global `var'_lab "HH Total Savings (USD)"
		}
		if regexm("`var'","loan") {
			global `var'_lab "HH Outstanding Cash Loans (USD)"
		}
		if regexm("`var'","exp_tot_m_pc") | regexm("`var'","tot_lstock_val") | regexm("`var'","saving") | regexm("`var'","income") | regexm("`var'","loan") {		 
			reg `var' treatment ${controls}, r 
			sum `var' if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var' treatment 1 
		} 
		 
		else { 
			reg `var' treatment ${controls}, r 
			sum `var' if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var' treatment 
		}
		
		if regexm("`var'","index_sdC_food_sec") | regexm("`var'","wealth_score_sdC") | regexm("`var'","psy_indexC_sdC") | regexm("`var'", "index_sdC_f_emp_3c") {
			gl `var'imp " "
		}
		else {
			gl `var'imp "${`var'imp1}\%"
		}
	}	 

********************************************************************************	
* Top right panel: Endline sample, midline indicator (N ~ 800)
********************************************************************************
	
	use "${data_for_analysis_fl1_phones}", clear
		
	* Rename endline sample indicators to match midline indicator names 
		rename (exp_tot_m_pc_noh_ca21_s  tot_hh_income_1_usd_s tot_lstock_value_4_usd_s index_sdC_f_emp_3c_1_s) ///
			   (exp_tot_m_pc_usd_s  		 tot_hh_income_usd_s 	   tot_lstock_value_usd_s 		index_sdC_f_emp_3c_s)
			
		rename tot_lstock_value_usd_s tot_lstock_val_w99t_usd_s 
		
	foreach var in $ftest_vars { 
		
		cap noi rename `var'_fl1 `var'
		rename `var' `var'e
		
		if regexm("`var'","exp_tot_m_pc") | regexm("`var'","tot_lstock_val") | regexm("`var'","saving") | regexm("`var'","income") | regexm("`var'","loan") {		 
			reg `var'e treatment ${controls} if `var'_s == 1, r 
			sum `var'e if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var'e treatment 1 
		} 
		 
		else { 
			reg `var'e treatment ${controls} if `var'_s == 1, r 
			sum `var'e if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var'e treatment 
		} 
		
		if regexm("`var'","index_sdC_food_sec") | regexm("`var'","wealth_score_sdC") | regexm("`var'","psy_indexC_sdC") | regexm("`var'", "index_sdC_f_emp_3c") {
			gl `var'eimp " "
		}
		else {
			gl `var'eimp "${`var'eimp1}\%"
		}
	}	 
	
********************************************************************************
* Panel B: Endline (Proxy) Indicators
********************************************************************************
		
********************************************************************************		
* Bottom left panel: Midline sample, endline indicator (N=1147)
********************************************************************************

use "${data_for_analysis_fl1_phone_full}", clear

	* Rename endline sample indicators to match variable names 
	rename exp_tot_m_pc_noh_ca21_s exp_tot_m_pc_noh_s
	
	rename *_usd_s *_s
	rename index_sdC_f_emp_3c_full_fl1 index_sdC_f_emp_3c_1_full_fl1 // move this line 
	
	foreach var in $ftest_vars_phonesvy   { 
		
		cap noi rename `var'_full_fl1 `var'
		cap noi rename `var'_fl1 `var'
		
		rename `var' `var'p // p for proxy
		
		global `var'p_lab : variable label `var'p 
		
		
		if regexm("`var'","employment_pf") {
		    global `var'p_lab "PW Did Market Work" 
		}
		if regexm("`var'","psy_indexC_sdC") {
		    global `var'p_lab "Proxy PW Well-Being Index (3 Components)" 
		}
		if regexm("`var'","tot_hh_income") {
		    global `var'p_lab "Total Household Income and Revenues Proxy (USD), Month" 
		}
		if regexm("`var'","exp_tot_m_pc") {
		    global `var'p_lab "Consumption per Capita Proxy (USD), Month" 
		}
		if regexm("`var'","wealth") {
		     global `var'p_lab "HH Asset Ownership Index"
		}
		if regexm("`var'","tot_lstock_val") {
			global `var'p_lab "Total Value of TUP Livestock (USD)"
		}
		if regexm("`var'","saving_usd") {
			global `var'p_lab "HH Total Savings (USD)"
		}
		if regexm("`var'","loan_usd") {
			global `var'p_lab "HH Outstanding Cash Loans (USD)"
		}
		
		if regexm("`var'","exp_tot_m_pc") | regexm("`var'","tot_lstock_val") | regexm("`var'","saving") | regexm("`var'","income") | regexm("`var'","loan") {		 
			reg `var'p treatment ${controls}, r 
			sum `var'p if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var'p treatment 1 
		} 
		 
		else { 
			reg `var'p treatment ${controls}, r 
			sum `var'p if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var'p treatment 
			 
		} 
		
		if regexm("`var'","index_sdC_food_sec") | regexm("`var'","wealth_score_sdC") | regexm("`var'","psy_indexC_sdC") | regexm("`var'", "index_sdC_f_emp_3c") {
			gl `var'pimp " "
		}
		else {
			gl `var'pimp "${`var'pimp1}\%"
		}	
		rename `var'p `var'
	}	 
	
	cou if ultra_poor == 1 
	global N_full : di %10.0fc `r(N)'

	
********************************************************************************	
* Endline sample, endline indicator (N~800) 
********************************************************************************

use "${data_for_analysis_fl1_phonesvy}", clear 

	* Rename endline sample indicators to match variable names 
	rename exp_tot_m_pc_noh_ca21_s exp_tot_m_pc_noh_usd_s
	
	rename tot_lstock_value_4_usd_s tot_lstock_val_w99t_usd_s 

	foreach var in $ftest_vars_phonesvy { 
		
		cap noi rename `var'_fl1 `var'
		rename `var' `var'pe // p for proxy; e for endline 
		
		if regexm("`var'","exp_tot_m_pc") | regexm("`var'","tot_lstock_val") | regexm("`var'","saving") | regexm("`var'","income")  | regexm("`var'","loan") {		 
			reg `var'pe treatment ${controls} if `var'_s == 1, r 
			sum `var'pe if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var'pe treatment 1 
		} 
		 
		else { 
			reg `var'pe treatment ${controls} if `var'_s == 1, r 
			sum `var'pe if treatment == 0 & e(sample) == 1	 
			 
			coeff_treat `var'pe treatment 
		} 
		
		if regexm("`var'","index_sdC_food_sec") | regexm("`var'","wealth_score_sdC") | regexm("`var'","psy_indexC_sdC") | regexm("`var'", "index_sdC_f_emp_3c") {
			gl `var'peimp " "
		}
		else {
			gl `var'peimp "${`var'peimp1}\%"
		}
	}
	
	* N based on consumption 
	cou if ultra_poor == 1 & exp_tot_m_pc_noh_usd_s == 1 
	global N_endline : di %10.0fc `r(N)'
	
	* Start the Latex document
	texdoc do 	"${online_appendix_dofile_loc}/Latex/tex_table_sample_impact_compare.do"	

