* Appendix Table X. Household Socioeconomic Conditions

global note_table_hhsocioec_chars "\footnotesize{\textit{Notes.} This table is constructed using baseline data and indicators for UP households. The sample includes households surveyed in at least one of the endline data collection rounds with baseline data available. Baseline data is not available for 6\% of households. Baseline total consumption estimate includes food (purchased, produced, and received as a gift), personal and household items, education, health, household repairs, social expenses (weddings, funerals, religious expenses, and other ceremonies), temptation goods, and legal expenses. The national poverty line threshold is AFN 2,064 (US\textdollar\ 30 nominal) per capita per month from the \cite{OCS2018}. This poverty line consumption excludes legal, health, household construction, and repair expenditures, and includes expenses on consumer durables and housing. We use consistent consumption with this figure to classify households with respect to the national poverty line. The psychological well-being measures include the Center for Epidemiologic Studies Depression (CES-D) seven-point scale \citep{Radloff1977} and questions on happiness and life satisfaction from the World Values Survey (WVS). All monetary amounts are in nominal USD. ER for 2016 of 68.87 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (annual average). SD = standard deviation; UP = ultra-poor; ER = exchnage rate.}"

global hh_general_desc1 	b3
global hh_general_desc3 	hhhead_female illiteracy_pf illiteracy_pm 
global enrollment_table1 	child_inschool_hh
global consump				exp_tot_m_pc_USD below_pov_af 
global foodsec				c14_3 c14_5
global assets 				own_Land_yes own_mobile_phone savings_dummy loan_dummy
global psych_bl	 			happy_i27_f satisf_score_f cesd_f_md  
global psych_bl2 			rses_zscore_ses_fC_bl1 		


/**************************************************************************************
				Compute Coefficients - Interviewed at Midline / Follow-up 1 				   
***************************************************************************************/		
	use "${schooling_bl}", clear
	
	* Keep the relevant sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(fl1_sample anyround attrition_r*) keep(3) nogen

	keep if ultra_poor == 1 	
 
	foreach var in $enrollment_table1 {
	    global `var'_lab : variable label `var'
				
		if "`var'" == "child_inschool_hh" {
			global `var'_lab = "School Enrollment (Children Ages 6 to 18 Years)"		
		}		
				
		rename `var' `var'_0		
		sum `var'_0 if fl1_sample == 1
			
		if  "`var'" == "b3" {
			means_desc `var'_0 1 
		}		
		else {
			means_desc `var'_0
		}
		
		rename `var'_0 `var'_1
		sum `var'_1 if anyround == 1
			
		if "`var'" == "b3" {
			means_desc `var'_1 1 
		}		
		else {
			means_desc `var'_1
		}
		
		rename `var'_1 `var'
	}
	
		preserve
			keep hhid $enrollment_table1 anyround
			keep if anyround == 1
			rename anyround group
			recode group (1=0)
			tempfile endlinesample
			save `endlinesample'
		restore 
		
			keep hhid $enrollment_table1 fl1_sample
			keep if fl1_sample == 1 
			rename fl1_sample group 
		
		append using "`endlinesample'"
		
	* T-test of difference between (1 = T) and (3 = NUP)
	foreach var in $enrollment_table1 {
		mvdecode `var', mv(-99=.d \ -98=.r)		
		
		ttest `var', by(group)  
		
		global `var'p_diff :  di %10.3f `r(p)'
		global `var'p_diff 	= "$[$$" + "${`var'p_diff}" + "$]$"
			
		* (3 - 2) or (NUP - T)
		global `var'_diff  :  di %10.3fc `r(mu_1)' - `r(mu_2)' 
	}		
		
	use "${data_for_analysis_bl}", clear
	
* Keep the relevant sample  
	merge m:1 hhid using "${phone_svy_profile}", keepus(fl1_sample anyround attrition_r*) keep(3) nogen	 
	* If using 2018 AFN:
	*merge m:1 hhid using "${total_expenditure_bl_phones}", keepus(exp_tot_m_pc_ca18) keep(3) nogen	 
	
	keep if ultra_poor == 1 

	foreach var in $hh_general_desc1 $hh_general_desc3 $consump $assets $psych_bl {
	    global `var'_lab : variable label `var'
				
		if "`var'" == "exp_tot_m_pc_USD" {
			global `var'_lab "Total Consumption per Capita (USD), Month"
		}	
		if "`var'" == "below_pov_af" {
			global `var'_lab "Household Is Below the National Poverty Line"
		}		
		if "`var'" == "savings_dummy" {
			global `var'_lab "Household Has Any Savings"
		}		
		if "`var'" == "loans_dummy" {
			global `var'_lab "Household Has Any Loans"
		}
	
		rename `var' `var'_0		
		sum `var'_0 if fl1_sample == 1
			
		if "`var'" == "exp_tot_m_pc_USD" {
			means_desc `var'_0 1 
		}		
		else {
			means_desc `var'_0
		}
		
		rename `var'_0 `var'_1
		sum `var'_1 if anyround == 1
			
		if "`var'" == "exp_tot_m_pc_USD" {
			means_desc `var'_1 1 
		}		
		else {
			means_desc `var'_1
		}
		
		rename `var'_1 `var'
	}
	
		preserve
			keep hhid $hh_general_desc1 $hh_general_desc3 $consump $assets $psych_bl anyround
			keep if anyround == 1
			rename anyround group
			recode group (1=0)
			tempfile endlinesample
			save `endlinesample'
		restore 
		
			keep hhid $hh_general_desc1 $hh_general_desc3 $consump $assets $psych_bl fl1_sample
			keep if fl1_sample == 1 
			rename fl1_sample group 
		
		append using "`endlinesample'"
		
	* T-test of difference between (1 = T) and (3 = NUP)
	foreach var in $hh_general_desc1 $hh_general_desc3 $consump $assets $psych_bl {
		mvdecode `var', mv(-99=.d \ -98=.r)		
		
		ttest `var', by(group)  
		
		global `var'p_diff :  di %10.3f `r(p)'
		global `var'p_diff 	= "$[$$" + "${`var'p_diff}" + "$]$"
			
		if "`var'" == "exp_tot_m_pc_USD" {
			* (3 - 2) or (NUP - T)
			global `var'_diff  :  di %10.1fc `r(mu_1)' - `r(mu_2)' 
		}		
		else {
			* (3 - 2) or (NUP - T)
			global `var'_diff  :  di %10.3fc `r(mu_1)' - `r(mu_2)' 
		}
	}					
		
	
	
	* Average PW age 
	use "${roster_bl}", clear 
		
	* Keep the relevant sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(fl1_sample anyround attrition*) keep(3) nogen
	
	lab var b8_bl 
	
	keep if ultra_poor == 1 
	keep if pf == 1

	foreach var in b8_bl {
	    global `var'_lab : variable label `var'
				
		if "`var'" == "b8_bl" {
			global `var'_lab "Primary Woman's Age (Years)"
		}
		
		rename `var' `var'_0		
		sum `var'_0 if fl1_sample == 1
			
		if "`var'" == "b8_bl" {
			means_desc `var'_0 1 
		}		
		else {
			means_desc `var'_0
		}
		
		rename `var'_0 `var'_1
		sum `var'_1 if anyround == 1
			
		if "`var'" == "b8_bl" {
			means_desc `var'_1 1 
		}		
		else {
			means_desc `var'_1
		}
		
		rename `var'_1 `var'
	}
	
		preserve
			keep hhid b8_bl anyround
			keep if anyround == 1
			rename anyround group
			recode group (1=0)
			tempfile endlinesample
			save `endlinesample'
		restore 
		
			keep hhid b8_bl fl1_sample
			keep if fl1_sample == 1 
			rename fl1_sample group 
		
		append using "`endlinesample'"
		
	* T-test of difference between (1 = T) and (3 = NUP)
	foreach var in b8_bl {
		mvdecode `var', mv(-99=.d \ -98=.r)		
		
		ttest `var', by(group)  
		
		global `var'p_diff :  di %10.3f `r(p)'
		global `var'p_diff 	= "$[$$" + "${`var'p_diff}" + "$]$"
			
		* (3 - 2) or (NUP - T)
		global `var'_diff  :  di %10.3fc `r(mu_1)' - `r(mu_2)' 
	}					
		

	* Food security 
	use "${all_HH_nopii_bl}", clear 
 
	* Keep the relevant sample  
	merge m:1 hhid using "${phone_svy_profile}", keepus(fl1_sample attrition_r* anyround) keep(3) nogen 
	
		keep if ultra_poor == 1

	foreach var in $foodsec {
		mvdecode `var', mv(-99=.d \ -98=.r)
	    global `var'_lab : variable label `var'
				
		if ("`var'" == "c14_3") {
			global `var'_lab = "Any Adult Ever Skipped or Cut the Size of Meals, Month"
		}
		if ("`var'" == "c14_5") {
			global `var'_lab = "Any Child Ever Skipped Meals or Cut the Size of Meals, Month"
		}
	
		rename `var' `var'_0		
		sum `var'_0 if fl1_sample == 1
			
		if "`var'" == "exp_tot_m_pc_USD" {
			means_desc `var'_0 1 
		}		
		else {
			means_desc `var'_0
		}
		
		rename `var'_0 `var'_1
		sum `var'_1 if anyround == 1	
			
		if "`var'" == "exp_tot_m_pc_USD" {
			means_desc `var'_1 1 
		}		
		else {
			means_desc `var'_1
		}
		
		rename `var'_1 `var'
	}

		preserve
			keep hhid $foodsec anyround
			keep if anyround == 1
			rename anyround group
			recode group (1=0)
			tempfile endlinesample
			save `endlinesample'
		restore 
		
			keep hhid $foodsec fl1_sample
			keep if fl1_sample == 1 
			rename fl1_sample group 
			
		append using "`endlinesample'"
		
	* T-test of difference between (1 = T) and (3 = NUP)
	foreach var in $foodsec {
		mvdecode `var', mv(-99=.d \ -98=.r)		
		
		ttest `var', by(group)  
		
		global `var'p_diff :  di %10.3f `r(p)'
		global `var'p_diff 	= "$[$$" + "${`var'p_diff}" + "$]$"
			
		* (3 - 2) or (NUP - T)
		global `var'_diff  :  di %10.3fc `r(mu_1)' - `r(mu_2)' 
	}		
		

	* Get the N (missingness would vary a lot depending on outcome)
	gen sample = (group == 0)
	
	forval i = 0/1 {
		unique hhid if sample == `i'
		
		global N_`i' : di %10.0fc `r(N)'
		
	}

	* Start the Latex document
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_hhsocioec_chars.do"	
