*-----------------------------------------------------------*
* Table X. Impacts on Household and Productive Assets       *
*-----------------------------------------------------------*

global note_table_impacts_assets "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls and control for data collection rounds in which outcomes were collected (for outcomes collected in more than one round). SEs are clustered at the household level, except for the total value of TUP livestock, which was collected in only one round. Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). For the total value of livestock (cows, goats, sheep, and chickens), column (5) reports the total sample size. All monetary amounts are in nominal USD. ER for 2021 of 77.45 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (average of ER for March, April and May 2021, due to data unavailability in the rest of the months). The asset ownership index is constructed using PCA on the number of assets owned, normalized to the unit SD of control HHs, with mean equal to zero. Total value of livestock is winsorized at the 99th percentile, by treatment and control groups. HH = household; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; ER = exchange rate.}"

	* Outcome globals 
	global asset_sum			tup_lstock_yes lstock_yes_chicken wealth_score_sdC
	
	global lstock 				lstock_num_cow lstock_num_goat lstock_num_sheep lstock_num_chicken		
	
********************************************************************************
	* Phone Survey - pooled estimates 
********************************************************************************		
	use "${data_for_analysis_phonesvy_long}", clear

	foreach var in $asset_sum $lstock $asset_sum2  {
	    
		local  `var'_lab : variable label `var'
		local `var'_lab: subinstr local `var'_lab "2021 " "", all
		global `var'_lab ``var'_lab'
		
		if "`var'" == "lstock_num_chicken" {
			global `var'_lab "Chickens"
		}
		
		reg `var' treatment ${panel_controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","wealth_score_sdC") | regexm("`var'","lstock_yes") | regexm("`var'","lstock_num_cow") | regexm("`var'","lstock_num_goat") | regexm("`var'","lstock_num_sheep") | regexm("`var'","lstock_num_chicken") | regexm("`var'","tup_lstock_yes") | regexm("`var'","lstock_yes_chicken") {		
			coeff_treat `var' treatment
		}		
		else {
			coeff_treat `var' treatment 1	
		}
		
		gl `var'p "$[$${`var'p}$]$"
	
		if regexm("`var'","wealth_score_sdC") {
			gl `var'imp " "
			}
		else {
			gl `var'imp "${`var'imp1}\%"
		}
		
		* Number of unique HHs
		macro drop Nhh_`var'
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
		
		* Number of rounds included - do not count R4 completion
		macro drop Nr_`var'
		unique round if e(sample) == 1
		if `r(N)'/`r(sum)' < 600 { // do not count R4 completion
			local Nr_`var' = `r(sum)' - 1
		}
		else {
		    local Nr_`var' = `r(sum)'
		}
		global Nr_`var' : di %10.0fc `Nr_`var''
	}	
	
	
	* Livestock value [not pooled]
	use "${data_for_analysis_phonesvy}", clear 
	
	foreach var in tot_lstock_value_4_w99t_usd {
		
		global `var'_lab "Total Value of Livestock (USD)"
		
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","tot_lstock_value") {		
			coeff_treat `var' treatment 1
		}		
		else {
			coeff_treat `var' treatment
			
		}
		
		gl `var'p "$[$${`var'p}$]$"
	
		if regexm("`var'","wealth_score_sdC") {
			gl `var'imp " "
			}
		else {
			gl `var'imp "${`var'imp1}\%"
		}
		
		* Number of unique HHs
		global Nhh_`var' ${N_`var'}
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
	}
	
	* Start the Latex document
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_impacts_assets.do"	


