*-----------------------------------------------------------*
* Table X. Impacts on Consumption and Food Security         *
*-----------------------------------------------------------*

global note_table_impacts_consump "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls and control for data collection rounds in which outcomes were collected. SEs are clustered at the household level. Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). Our consumption proxy estimate includes 25 food and 4 non-food items that best predict total consumption at midline (for details, see \autoref{ssec:som_2}). Consumption is converted into an index where endline consumption for the control group = 1. The food security index combines three food security measures, normalized to the unit SD of control HHs, with mean equal = 0. Nutritional diversity results report shares of proxy food consumption, by type of food. Meat category includes beef, veal, mutton, goat, and chicken; dairy category includes milk (fresh), yogurt, curd (chaka), dogh (a yogurt drink), and eggs; vegetables category includes potato, tomato, okra, pumpkin, and green pepper; fruits category includes apple, orange, banana, mango, and lettuce. HH = household; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation.}"

	* Outcome globals (pooled)
	global consumption_ca21 	exp_tot_m_pc_noh_ca21
	global index_sdC_food_sec   index_sdC_food_sec
	global item_type 			item_type_share_1 item_type_share_2 item_type_share_3 item_type_share_4 item_type_share_7 item_type_share_9 item_type_share_10 item_type_share_11 item_type_share_12 
	

********************************************************************************
	* Phone Survey - pooled estimates 
********************************************************************************		
	use "${data_for_analysis_phonesvy_long}", clear
			
	foreach var in $consumption_ca21 $index_sdC_food_sec {
		
		global `var'_lab : variable label `var'
		
		if regexm("`var'","exp_tot_m_pc_noh_ca21") {
		    global `var'_lab "Consumption Index Proxy (Endline Control = 1), Month"
		}
		
		reg `var' treatment ${panel_controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","ca21") | regexm("`var'","index_sdC_food_sec") | regexm("`var'","c14_7") | regexm("`var'","c14_3") | regexm("`var'","c14_5") {			
		coeff_treat `var' treatment
			gl `var'p "$[$${`var'p}$]$"
		}		
		else {
			coeff_treat `var' treatment 1
			gl `var'p "$[$${`var'p}$]$"
		}
		
		if  regexm("`var'","index_sdC_food_sec") {
		gl `var'imp " "	
		}
		else {
		gl `var'imp "${`var'imp1}\%"	
		}
		
		* Number of unique HHs
		macro drop Nhh_`var'
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
		
		* Number of rounds included - do not count R4 completion
		macro drop Nr_`var'
		unique round if e(sample) == 1
		if `r(N)'/`r(sum)' < 600 { // do not count R4 completion
			local Nr_`var' = `r(sum)' - 1
		}
		else {
		    local Nr_`var' = `r(sum)'
		}
		global Nr_`var' : di %10.0fc `Nr_`var''
		
	}	
	
	* Nutrition shares 
	use "${food_consumption_shares_phonesvy}", clear 
			
	foreach var in $item_type {
		
		global `var'_lab : variable label `var'
		
		reg `var' treatment ${panel_controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1
	
		coeff_treat `var' treatment
		
		gl `var'p "$[$${`var'p}$]$"
		gl `var'imp "${`var'imp1}\%"	 
		
		* Number of unique HHs
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
		
		* Number of rounds included - do not count R4 completion 
		unique round if e(sample) == 1 
		global Nr_`var' : di %10.0fc `r(sum)' 
	}	
	
	* Start the Latex document
	* AFN 2018 divided by endline control mean 
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_impacts_consump_ca21.do"

