*-----------------------------------------------------------*
* Table 1. Impacts on Finance (Nominal USD)                 *
*-----------------------------------------------------------*

global note_table_impacts_finance "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls and control for data collection rounds in which outcomes were collected (for outcomes collected in more than one round). SEs are clustered at the household level, except for whether HH has taken out a loan for productive purposes, which was collected in only one round. Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). All monetary amounts are in nominal USD. ER for 2021 of 77.45 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (average of ER for March, April and May 2021, due to data unavailability in the rest of the months). HH = household; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; ER = exchange rate.}"

	* Outcome globals 
	global fin_sum_usd 			saving_dummy saving_usd loan_dummy loan_usd		
		
	*prod_loan is in the cross-section dataset since it is only available in R3 (no pooled indicator) 
	
********************************************************************************
	* Phone Survey - pooled outcomes
********************************************************************************		
	use "${data_for_analysis_phonesvy_long}", clear

	foreach var in $fin_sum_usd {
	    
		local  `var'_lab : variable label `var'
		local `var'_lab: subinstr local `var'_lab "2021 " "", all
		global `var'_lab ``var'_lab'
		
		reg `var' treatment ${panel_controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","saving_dummy") | regexm("`var'","loan_dummy") {		
			coeff_treat `var' treatment
		}		
		else {
			coeff_treat `var' treatment 1
		}
		
		gl `var'p "$[$${`var'p}$]$"
		gl `var'imp "${`var'imp1}\%"	
		
		* Number of unique HHs
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
		
		* Number of rounds included - do not count R4 completion
		unique round if e(sample) == 1
		if `r(sum)' < 400 { // do not count R4 completion
			local Nr_`var' = `r(sum)' - 1
		}
		global Nr_`var' : di %10.0fc `Nr_`var''
	}	
	
	* Whether a loan is used for a productive purpose 
	use "${data_for_analysis_phonesvy}", clear

	foreach var in prod_loan {
		
		global `var'_lab : variable label `var'
		
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
	
		if regexm("`var'","saving_dummy") | regexm("`var'","loan_dummy") {		
			coeff_treat `var' treatment
		}		
		else {
			coeff_treat `var' treatment	
		}
		
		gl `var'p "$[$${`var'p}$]$"
		gl `var'imp "${`var'imp1}\%"	
		
		* Number of unique HHs
		unique hhid if e(sample) == 1
		global Nhh_`var' : di %10.0fc `r(sum)'
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
	}		
	
	* Start the Latex document
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_impacts_finance_usd.do"	
	


