*--------------------------------------------------------------------------------------*
* Table X. Impacts on Household Income and Revenues (Nominal USD), Past 4 Weeks        *
*--------------------------------------------------------------------------------------*

global note_table_impacts_income "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean. Column (5) reports the total sample size. All monetary amounts are in nominal USD. ER for 2021 of 77.45 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (average of ER for March, April and May 2021, due to data unavailability in the rest of the months). PM = primary man; PW = primary woman; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; ER = exchange rate.}"

	* Outcome globals 
	global revenues_sum_usd	    tot_hh_income_1_usd tot_lstock_rev_1_usd tot_crop_rev_imp_2_usd tot_biz_rev_imp_1_usd tot_hh_pay_imp_1_usd
	
********************************************************************************
	* Phone Survey
********************************************************************************		
	use "${data_for_analysis_phonesvy}", clear
		
	foreach var in $revenues_sum_usd {
		
		global `var'_lab : variable label `var'
		global `var'_lab : subinstr global `var'_lab " (2021 USD)" "", all 
		
		if "`var'" == "tot_hh_income_1_usd" {
			global `var'_lab "Total HH Income and Revenues Proxy"
		}
		
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
	
		coeff_treat `var' treatment 1
			
		gl `var'p "$[$${`var'p}$]$"
		gl `var'imp "${`var'imp1}\%"			
			
				
		* Number of unique HHs
		global Nhh_`var' ${N_`var'}	
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
	}
	
	* Start the Latex document
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_impacts_income_usd.do"
	


