*------------------------------------------------------------*	 
* Table X. Impacts on Psychological Well-Being and Schooling * 
*------------------------------------------------------------* 

global note_table_impacts_psy_detail	"\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each outcome for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the treatment estimates as a percentage of the control mean, except for indices. Column (5) reports the total sample size. Psychological well-being measures include questions on life satisfaction and happiness from the WVS (averages of two data collection rounds); and scores on the CES-D seven-point scale (negatively coded). Indicators were collected across different data collection rounds and, due to attrition between rounds, the sample for psychological well-being outcomes is reduced to households surveyed in all rounds in order to have a complete set of indicators. Each psychological well-being measure is estimated as a score on the variable’s scale, normalized to the unit SD of control HHs, with mean equal to zero. Impacts on the normalized measures can be found in \autoref{table:psy_we_index}. The psychological well-being index is an index of the three previous measures, normalized in the same way. School enrolment is estimated for school-age children (ages 6 to 18 years), with the unit of observation being the child, hence all SEs are clustered at the household level. PW = primary woman; SE = standard error; SD = standard deviation; PRA = participatory rural appraisal; WVS = World Values Survey; CES-D = Center for Epidemiological Studies Depression.}" 

 * Outcome globals 
	global psy_detail 			psy_indexC_sdC happy satisf_score cesd_md	
	global enrollment_hh		child_inschool_hh
			 
******************************************************************************** 
	* Phone Survey 
********************************************************************************		 
	use "${data_for_analysis_phonesvy}", clear 
 
	foreach var in $psy_detail { 
		 
		global `var'_lab : variable label `var'
		 
		if "`var'" == "psy_indexC_sdC" {
			global `var'_lab "PW Psychological Well-being Index (3 items)"  
		}
		
		reg `var' treatment ${controls}, r 
		sum `var' if treatment == 0 & e(sample) == 1 
		 
		coeff_treat `var' treatment 
		 
		gl `var'p "$[$${`var'p}$]$" 
		
		if regexm("`var'","index") {
			gl `var'imp " "
			}
		else {
			gl `var'imp "${`var'imp1}\%"
		}
		
		* Number of unique HHs
		global Nhh_`var' ${N_`var'}
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
	}	 
	
* Schooling regression at the child-level  
	use "${schooling_phonesvy}", clear  	
				 
	foreach var in $enrollment_hh { 
		 
		global `var'_lab "School Enrollment (Children Ages 6 to 18 Years)"
		 
		reg `var' treatment ${controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1 
		 
		coeff_treat `var' treatment 
		gl `var'p "$[$${`var'p}$]$" 
		
		if regexm("`var'","index") {
			gl `var'imp " "
			}
		else {
			gl `var'imp "${`var'imp1}\%"
		}
		
		* Number of unique HHs
		global Nhh_`var' ${N_`var'}
		
		* Number of rounds (1)
		global Nr_`var' : di %10.0fc 1
	}	 	
 
	* Start the Latex document 
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_impacts_psy_detail.do"	 
