/* Impacts on Shocks */

global note_table_shocks_new "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each indicator for the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses). Column (3) reports the naive p-values [in brackets]. Column (4) reports the total sample size. Data on incidence of shocks was collected in two survey rounds (starting in January and June 2021, respectively), with a one year recall and one month recall periods. Incidence of shocks over the past year was collected starting in January 2021 with a screening question that we believe reduced the number of shocks reported, while the question collected starting in June 2021 presented respondents with a full list of options prompted by the enumerator one by one. The list included 16 options of adverse events: lost a job or cannot find work (outside of HH); household livestock got sick or died; household business had to close; household business had a loss; household forced to move; severe illness or injury of a HH member (including accidents); death of a HH member; imprisonment of a HH member; weather or natural disaster shock (e.g., drought, flood, storm, earthquake); theft; destruction of house / other property (due to conflict or accident); HH member had to pay compensation; other violence/crime event; rise in food prices; lower crop yield; loss of household asset. Use of coping strategies was collected only with 12 months recall. Remittance amounts are in nominal USD. ER for 2021 of 77.45 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (average of ER for March, April and May 2021, due to data unavailability in the rest of the months). HH = household; PW = primary woman; PM = primary man; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; ER = exchange rate.}"

global shock anyshock_4wk anyshock_12mo
global coping_12mo g2_2_12mo g2_3_12mo g2_1_12mo g2_6_12mo g2_7_12mo g2_5_12mo g2_4_12mo 
global recovery_cond_12mo recover_cond_12mo

global coping_cond_12mo g2_cond_2_12mo g2_cond_3_12mo g2_cond_1_12mo g2_cond_6_12mo g2_cond_7_12mo g2_cond_5_12mo g2_cond_4_12mo 
global recovery_12mo recover_12mo

********************************************************************************
	* Phone Survey
********************************************************************************		
	use "${data_for_analysis_phonesvy}", clear

	foreach var in $shock $recovery_12mo $coping_12mo $coping_cond_12mo $recovery_cond_12mo {
		global `var'_lab : var lab `var'
		
		if "`var'" == "anyshock_12mo" {
			global `var'_lab "Had Any Shock, Past Year (Jan 2021)"
		}
		if "`var'" == "anyshock_4wk" {
			global `var'_lab "Had Any Shock of 16 Individual Shocks, Past Month (Jun 2021)"
		}		
		if "`var'" == "recover_cond_12mo" {
			global `var'_lab "Have Somewhat, Mostly or Fully Recovered from Any Shock(s), Past Year (Jan 2021)"
		}
		
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if regexm("`var'","trans_value") {
			coeff_treat `var' treatment 1
			gl `var'p "$[$${`var'p}$]$"
		}		
		else {
			coeff_treat `var' treatment
			gl `var'p "$[$${`var'p}$]$"
		}
		
		gl `var'imp "${`var'imp1}\%"
	}	
	
	* Remittances
	
	foreach var in migrant_remittance migrant_remit_amt_afn_usd  {
		
		if "`var'" == "migrant_remittance" {
			global `var'_lab "Received Sometimes or Regularly"
		}
		if "`var'" == "migrant_remit_amt_afn_usd" {
			global `var'_lab "Value Received (USD), Past Month"
		}
			
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if "`var'" == "migrant_remit_amt_afn_usd" {			
			coeff_treat `var' treatment 1
			gl `var'p "$[$${`var'p}$]$"
		}		
		else {
			coeff_treat `var' treatment
			gl `var'p "$[$${`var'p}$]$"
		}
		
		gl `var'imp "${`var'imp1}\%"
		
	}	

	* Start the Latex document
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_impacts_shocks_r4_new.do"
