*---------------------------------------------------------------------------------------------*
* Table X: Impacts on Labor Supply and Time Use, Primary Woman and Man, Past 4 Weeks (Pooled) *
*---------------------------------------------------------------------------------------------*

global note_table_impacts_timeuse	"\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of treatment effects. All regressions include 133 randomization PRA controls and control for data collection rounds in which outcomes were collected. SEs are clustered at the household level. Outcomes are listed on the left and primary outcomes are described in detail in \autoref{ssec:som_1}. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the mean and the standard deviation (in parentheses) of each outcome for the primary woman (respectively, column (4) for the primary man) of the control group. Column (2) reports the treatment estimates in levels with robust standard errors (in parentheses) for the primary woman (respectively, column (5) for the primary man). Column (3) reports the naive p-values [in brackets] for the primary woman (respectively, column (6) for the primary man). Primary woman (respectively, primary man) sample size for each treatment estimate is reported at the bottom of the panels: it lists the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). All market work participation estimates are whether the HH member engaged in an activity over the past month. Labor force participation is defined by the International Labour Organization as the working-age population that engages actively in the labour market, either by working or looking for work. HH = household; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation.}"

* Outcome globals 

	* Pooled
	global labor_particip	labor_particip
	global participation	employment k5_1		
	global time_sum			did_livestock did_ownFarming did_ownBiz did_oWork

********************************************************************************
	* Phone Survey - Pooled Regressions 
********************************************************************************		
	use "${data_for_analysis_phonesvy_long}", clear

	foreach var in $labor_particip $participation {		
		
		global `var'_lab : variable label `var'_pf
		global `var'_lab : subinstr global `var'_lab "PF " "", all 
		global `var'_lab : subinstr global `var'_lab "PM " "", all 
		
		* For female
		reg `var'_pf treatment ${panel_controls}, vce(cluster hhid)
		sum `var'_pf if treatment == 0 & e(sample) == 1
		
		coeff_treat `var' treatment

		*For male
		reg `var'_pm treatment ${panel_controls}, vce(cluster hhid)
		sum `var'_pm if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_pm treatment
		
		gl `var'p "$[$${`var'p}$]$"
		gl `var'_pmp "$[$${`var'_pmp}$]$"	
	}
		
	foreach var in $time_sum {
	    
		global `var'_lab : variable label `var'_pf
		global `var'_lab : subinstr global `var'_lab "PF " "", all 
		global `var'_lab : subinstr global `var'_lab "PM " "", all 
		
		* For female
		reg `var'_pf treatment ${panel_controls}, vce(cluster hhid)
		sum `var'_pf if treatment == 0 & e(sample) == 1
		
		coeff_treat `var' treatment

		*For male
		reg `var'_pm treatment ${panel_controls}, vce(cluster hhid)
		sum `var'_pm if treatment == 0 & e(sample) == 1
		
		coeff_treat `var'_pm treatment 
		
		gl `var'p "$[$${`var'p}$]$"
		gl `var'_pmp "$[$${`var'_pmp}$]$"			
	}	

	* Save the smallest N of all variables in the table to display at the bottom 
	local N_min_list 
	local N_min_list_pm 
	
	foreach var in $labor_particip $time_sum {
		foreach suff in "" "_pm" {
			local N_`var'`suff' : subinstr global N_`var'`suff' "$" "", all
			local N_`var'`suff' : subinstr local N_`var'`suff' "," "", all
			local N_`var'`suff' : subinstr local N_`var'`suff' "     " ",", all
			local N_`var'`suff' : list uniq local N_`var'`suff'

			local N_min_list`suff' `N_min_list`suff'' `N_`var'`suff''
		}
	}

	global N_min : di %10.0fc min(`N_min_list')
	global N_min = "$" + "${N_min}" + "$"

	global N_min_pm : di %10.0fc min(`N_min_list_pm')
	global N_min_pm = "$" + "${N_min_pm}" + "$"
	
	
	* Number of rounds (1, 3 and R4 completion)
	local Nr_min_list_pf
	local Nr_min_list_pm 
	
	foreach var in $labor_particip $time_sum {
		foreach suff in "_pf" "_pm" {
			
		qui reg `var'`suff' treatment ${panel_controls}, vce(cluster hhid)
		
		unique round if e(sample) == 1
		
			if `r(N)'/`r(sum)' < 600 { // do not count R4 completion
				local Nr_`var'`suff' = `r(sum)' - 1
			}
			else {
				local Nr_`var'`suff' = `r(sum)'
			}

			local Nr_min_list`suff' `Nr_min_list`suff'' `Nr_`var'`suff''
			local Nr_min_list`suff' : subinstr local Nr_min_list`suff' " " ",", all
		}
	}
	

	global Nr_min :  di %10.0fc min(`Nr_min_list_pf')
	global Nr_min = "$" + "${Nr_min}" + "$"

	global Nr_min_pm : di %10.0fc min(`Nr_min_list_pm')
	global Nr_min_pm = "$" + "${Nr_min_pm}" + "$"

	
	* Number of unique HHs
	local Nhh_min_list_pf
	local Nhh_min_list_pm 
	
	foreach var in $labor_particip $time_sum {
		foreach suff in "_pf" "_pm" {
			
		qui reg `var'`suff' treatment ${panel_controls}, vce(cluster hhid)
		
		unique hhid if e(sample) == 1
		
	
			local Nhh_min_list`suff' `Nhh_min_list`suff'' `r(sum)'
			local Nhh_min_list`suff' : subinstr local Nhh_min_list`suff' " " ",", all
		}
	}

	global Nhh_min :  di %10.0fc min(`Nhh_min_list_pf')
	global Nhh_min = "$" + "${Nhh_min}" + "$"

	global Nhh_min_pm : di %10.0fc min(`Nhh_min_list_pm')
	global Nhh_min_pm = "$" + "${Nhh_min_pm}" + "$"	
	
	* Start the Latex document
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_impacts_timeuse.do"	
