* Test for difference in coefficient using stacking 

global note_table_nup_compare_gaps "\footnotesize{\textit{Notes.} This table reports Ordinary Least Squares estimates of the adjusted differences (gaps) between non-UP households with control and treatment groups. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in \autoref{ssec:som_1}. (***) (**) (*) denotes significance at (1\%) (5\%) (10\%) level. Column (1) reports the adjusted differences (gaps) over UP control for the NUP with robust standard errors (in parentheses). Column (2) reports the adjusted differences (gaps) over UP treatment for the NUP with robust standard errors (in parentheses). Column (3) reports the naive p-value of the difference between columns (1) and (2) in [brakets]. Column (4) reports the number of unique HHs and the total number of observations across all data collection rounds (in parentheses). All monetary amounts are in nominal USD. ER for 2021 of 77.45 from the \href{https://data.imf.org/regular.aspx?key=61545850}{IMF} (average of ER for March, April and May 2021, due to data unavailability in the rest of the months). Total value of livestock is winsorized at the 99th percentile, by treatment and control groups. PM = primary man; PW = primary woman; PRA = participatory rural appraisal; SE = standard error; SD = standard deviation; ER = exchange rate.}"

global single_round_vars    index_sdC_f_emp_3c_1 index_sdC_f_emp_3c_nomkt tot_hh_income_1_usd tot_lstock_val_w99t_usd psy_indexC_sdC index_sdC_f_emp_3c_1  tot_hh_income_1_usd tot_lstock_rev_1_usd tot_crop_rev_imp_2_usd tot_biz_rev_imp_1_usd tot_hh_pay_imp_1_usd prod_loan 

global mult_round_vars 	  exp_tot_m_pc_noh_ca21 exp_tot_m_pc_noh_ca21  index_sdC_food_sec saving_dummy saving_usd loan_usd employment_pf employment_pm lstock_num_cow lstock_num_goat lstock_num_sheep lstock_num_chicken index_sdC_food_sec biz_yes

global controls i.PRA_lottery
global panel_controls i.PRA_lottery ib(4).round


********************************************************************************
* Schooling
********************************************************************************

use "$schooling_phonesvy", clear  

* Save total N (UP and NUP) before stacking 
cou if !mi(child_inschool_hh)
global child_inschool_hh_N : di %10.0fc `r(N)'
global child_inschool_hh_N = "$" + "${child_inschool_hh_N}" + "$"

global child_inschool_hh_lab "School Enrollment (Children Ages 6 to 18 Years)"

gen control = 1 if treatment == 0 
replace control = 0 if treatment == 1  
 
gen non_ultra_poor = (missing(control)) 

* Estimate NUP-Control gap
rename child_inschool_hh child_inschool_hh_c
reg child_inschool_hh_c non_ultra_poor ${controls} if treatment != 1, cluster(hhid) r // exclude treatment from regression
sum child_inschool_hh_c if non_ultra_poor == 0 & e(sample) == 1 
coeff_treat child_inschool_hh_c non_ultra_poor

rename child_inschool_hh_c child_inschool_hh

gen sf1 = e(sample)
keep if sf1 == 1
tempfile sf1
save `sf1'


* Estimate NUP-Treatment gap
use "$schooling_phonesvy", clear  

gen control = 1 if treatment == 0 
replace control = 0 if treatment == 1  
 
gen non_ultra_poor = (missing(control)) 

rename child_inschool_hh child_inschool_hh_nup
reg child_inschool_hh_nup non_ultra_poor ${controls} if treatment != 0 , cluster(hhid) r // exclude control from regression
sum child_inschool_hh_nup if non_ultra_poor == 0 & e(sample) == 1 
coeff_treat child_inschool_hh_nup non_ultra_poor

rename child_inschool_hh_nup child_inschool_hh

gen sf2 = e(sample)
keep if sf2 == 1

append using "`sf1'"

replace sf1 = 0 if sf1 == .
replace sf2 = 0 if sf2 == .

foreach var in non_ultra_poor PRA_lottery {
	gen `var'_1 = `var'*sf1
	replace `var'_1 = 0 if mi(`var'_1)
} 
foreach var in non_ultra_poor PRA_lottery {
	gen `var'_2 = `var'*sf2
	replace `var'_2 = 0 if mi(`var'_2)
	} 
reg child_inschool_hh non_ultra_poor_1 non_ultra_poor_2 i.PRA_lottery_1 i.PRA_lottery_2 sf1 sf2 , cluster(hhid) 
test non_ultra_poor_1 = non_ultra_poor_2 
* Save p-value from test 
global child_inschool_hh_p : di %10.3f `r(p)'
global child_inschool_hh_p = "$" + "${child_inschool_hh_p}" + "$"
global child_inschool_hh_p "$[$${child_inschool_hh_p}$]$"


********************************************************************************
* Single round outcomes 
********************************************************************************
* Livestock value, income, diversification indicators 

	foreach var in $single_round_vars {
		
		use "$data_for_analysis_phonesvy", clear  
		
		* variable name too long 
		rename tot_lstock_value_4_w99t_usd tot_lstock_val_w99t_usd

		* Save total N (UP and NUP) before stacking 
		cou if !mi(`var')
		global `var'_N : di %10.0fc `r(N)'
		global `var'_N = "$" + "${`var'_N}" + "$"
		
		* For indices need to combine the N since these are different variables 
		if "`var'" == "psy_indexC_sdC" {  
			cou if !mi(psy_indexC_sdC) | !mi(psy_indexC_sdT_NUP)
			global `var'_N : di %10.0fc `r(N)'
			global `var'_N = "$" + "${`var'_N}" + "$"
		}
		
		if "`var'" == "index_sdC_f_emp_3c_1" {  
			cou if !mi(index_sdC_f_emp_3c_1) | !mi(index_sdT_NUP_f_emp_3c_1)
			global `var'_N : di %10.0fc `r(N)'
			global `var'_N = "$" + "${`var'_N}" + "$"
		}
		
		if "`var'" == "index_sdC_f_emp_3c_nomkt" {  
			cou if !mi(index_sdC_f_emp_3c_nomkt) | !mi(index_sdT_NUP_f_emp_3c_nomkt)
			global `var'_N : di %10.0fc `r(N)'
			global `var'_N = "$" + "${`var'_N}" + "$"
		}
		
		global `var'_lab : variable label `var'
		global `var'_lab : subinstr global `var'_lab " (2021 USD)" "", all 
		
		if "`var'" == "tot_hh_income_1_usd" {  
			global `var'_lab "Total HH Income and Revenues Proxy, Month (USD)"
		}		
		if "`var'" == "tot_lstock_val_w99t_usd" {  
			global `var'_lab "Total Value of Livestock (USD)"
		}	
		if "`var'" == "psy_indexC_sdC" {  
			global `var'_lab "PW Psychological Well-being Index (3 items)"
		}	
		if "`var'" == "index_sdC_f_emp_3c_nomkt" {
			global `var'_lab "Excluding PW Market Work Participation"
		} 
		
		gen control = 1 if treatment == 0 
		replace control = 0 if treatment == 1  
		 
		gen non_ultra_poor = (missing(control)) 
	
		
		* Estimate NUP-Control gap
		if "`var'" == "psy_indexC_sdC" | "`var'" == "index_sdC_f_emp_3c_1" | "`var'" == "index_sdC_f_emp_3c_nomkt" {  
			cap drop `var'
			cap noi rename psy_indexC_sdC_NUP psy_indexC_sdC
			cap noi rename index_sdC_NUP_f_emp_3c_1 index_sdC_f_emp_3c_1 
			cap noi rename index_sdC_NUP_f_emp_3c_nomkt index_sdC_f_emp_3c_nomkt
		}
		
		rename `var' `var'_c
		reg `var'_c non_ultra_poor ${controls} if treatment!=1, r // exclude treatment 
		sum `var'_c if non_ultra_poor == 0 & e(sample) == 1
		if inlist("`var'","tot_lstock_val_w99t_usd","tot_hh_income_1_usd","tot_lstock_rev_1_usd","tot_crop_rev_imp_2_usd","tot_biz_rev_imp_1_usd","tot_hh_pay_imp_1_usd") {  
			coeff_treat `var'_c non_ultra_poor 1
		}
		else {
		    coeff_treat `var'_c non_ultra_poor
		}
		
		rename `var'_c `var'
		
		gen sf1 = e(sample)
		keep if sf1 == 1
		tempfile sf1
		save `sf1'
		
		use "$data_for_analysis_phonesvy", clear
		
		* variable name too long 
		rename tot_lstock_value_4_w99t_usd tot_lstock_val_w99t_usd
				
		gen control = 1 if treatment == 0 
		replace control = 0 if treatment == 1  
		 
		gen non_ultra_poor = (missing(control)) 		
				
		* Estimate NUP-Treatment gap	
		if "`var'" == "psy_indexC_sdC" | "`var'" == "index_sdC_f_emp_3c_1" | "`var'" == "index_sdC_f_emp_3c_nomkt" {  
			cap drop `var'
			cap noi rename psy_indexC_sdT_NUP psy_indexC_sdC
			cap noi rename index_sdT_NUP_f_emp_3c_1 index_sdC_f_emp_3c_1 
			cap noi rename index_sdC_NUP_f_emp_3c_nomkt index_sdC_f_emp_3c_nomkt
		}
		
		rename `var' `var'_nup
 		reg `var'_nup non_ultra_poor ${controls} if treatment!=0, r
		sum `var'_nup if non_ultra_poor == 0 & e(sample) == 1
		if inlist("`var'","tot_lstock_val_w99t_usd","tot_hh_income_1_usd","tot_lstock_rev_1_usd","tot_crop_rev_imp_2_usd","tot_biz_rev_imp_1_usd","tot_hh_pay_imp_1_usd") {  
			coeff_treat `var'_nup non_ultra_poor 1
		}
		else {
		    coeff_treat `var'_nup non_ultra_poor
		}
		
		gen sf2 = e(sample)
		keep if sf2 == 1
		
		rename `var'_nup `var'
		
		* Append data 
		append using "`sf1'"
		replace sf1 = 0 if sf1 == .
		replace sf2 = 0 if sf2 == .
		
		foreach i in non_ultra_poor PRA_lottery {
			gen `i'_1 = `i'*sf1
			replace `i'_1 = 0 if mi(`i'_1)
		} 
		foreach j in non_ultra_poor PRA_lottery {
			gen `j'_2 = `j'*sf2
			replace `j'_2 = 0 if mi(`j'_2)
			} 
		reg `var' non_ultra_poor_1 non_ultra_poor_2 i.PRA_lottery_1 i.PRA_lottery_2 sf1 sf2 , cluster(hhid) 
		test non_ultra_poor_1 = non_ultra_poor_2 
		* Save p-value from test 
		global `var'_p : di %10.3f `r(p)'
		global `var'_p = "$" + "${`var'_p}" + "$"
		global `var'_p "$[$${`var'_p}$]$"	
} 


********************************************************************************
* Multiple round outcomes 
********************************************************************************	
* Finance, food sec, comsumption, labor, number of livestock
  
foreach var in $mult_round_vars {
		
		use "$data_for_analysis_phonesvy_long", clear  
		
		* Save total N (UP and NUP)
		unique hhid if !mi(`var')
		global `var'_N : di %10.0fc `r(unique)'
		global `var'_N = "$" + "${`var'_N}" + "$"
		
		* Number of obs 
		cou if !mi(`var')
		global Nr_`var' : di %10.0fc `r(N)'
		global Nr_`var' = "$" + "${Nr_`var'}" + "$"

		if "`var'" == "index_sdC_food_sec" {  
			* Save total N (UP and NUP)
			unique hhid if !mi(index_sdC_food_sec) | !mi(index_sdT_NUP_food_sec)
			global `var'_N : di %10.0fc `r(unique)'
			global `var'_N = "$" + "${`var'_N}" + "$"
			
			* Number of obs 
			cou if !mi(index_sdC_food_sec) | !mi(index_sdT_NUP_food_sec)
			global Nr_`var' : di %10.0fc `r(N)'
			global Nr_`var' = "$" + "${Nr_`var'}" + "$"
		}
		
		global `var'_lab: var label `var'
		
		if "`var'" == "lstock_num_chicken" {  
			global `var'_lab "Chickens"
		}
		if "`var'" == "exp_tot_m_pc_noh_ca21" {  
			global `var'_lab "Consumption Index Proxy (Endline Control = 1)"
		}
		if "`var'" == "loan_usd" {  
			global `var'_lab "HH Outstanding Cash Loans (USD)"
		}
		if "`var'" == "saving_usd" {  
			global `var'_lab "HH Total Savings (USD)"
		}
		if "`var'" == "employment_pf" {  
			global `var'_lab "PW Market Work Participation"
		}
		if "`var'" == "biz_yes" {  
			global `var'_lab "Household Has Any Non-Agricultural Business"
		}
		 
		gen non_ultra_poor = (missing(control)) 
		
		* Estimate NUP-Control gap
		if "`var'" == "index_sdC_food_sec" {  
			cap drop `var'
			cap noi rename index_sdC_NUP_food_sec index_sdC_food_sec 
		}
		
		rename `var' `var'_c
		reg `var'_c non_ultra_poor ${panel_controls} if treatment!=1, vce(cluster hhid) // exclude treatment 
		sum `var'_c if non_ultra_poor == 0 & e(sample) == 1
		if "`var'" == "loan_usd" | "`var'" == "saving_usd" { 
			coeff_treat `var'_c non_ultra_poor 1
		}
		else {
		    coeff_treat `var'_c non_ultra_poor
		}
		
		rename `var'_c `var'
		
		gen sf1 = e(sample)
		keep if sf1 == 1
		tempfile sf1
		save `sf1'
		
		* Estimate NUP-Treatment gap	
		use "$data_for_analysis_phonesvy_long", clear  
		
		gen non_ultra_poor = (missing(control)) 
		
		if "`var'" == "index_sdC_food_sec" {  
			cap drop `var'
			cap noi rename index_sdT_NUP_food_sec index_sdC_food_sec 
		}
		
		rename `var' `var'_nup 
 		reg `var'_nup non_ultra_poor ${panel_controls} if treatment!=0, vce(cluster hhid)
		sum `var'_nup if non_ultra_poor == 0 & e(sample) == 1
		if "`var'" == "loan_usd" | "`var'" == "saving_usd" { 
			coeff_treat `var'_nup non_ultra_poor 1
		}
		else {
		    coeff_treat `var'_nup non_ultra_poor
		}
		
		rename `var'_nup `var'
		
		gen sf2 = e(sample)
		keep if sf2 == 1
		
		append using "`sf1'"
		replace sf1 = 0 if sf1 == .
		replace sf2 = 0 if sf2 == .
		
		foreach i in non_ultra_poor PRA_lottery round {
			gen `i'_1 = `i'*sf1
			replace `i'_1 = 0 if mi(`i'_1)
		} 
		foreach j in non_ultra_poor PRA_lottery round {
			gen `j'_2 = `j'*sf2
			replace `j'_2 = 0 if mi(`j'_2)
			} 
		reg `var' non_ultra_poor_1 non_ultra_poor_2 i.PRA_lottery_1 i.PRA_lottery_2 i.round_1 i.round_2 sf1 sf2, cluster(hhid)
		test non_ultra_poor_1 = non_ultra_poor_2 
		* Save p-value from test 
		global `var'_p : di %10.3f `r(p)'
		global `var'_p = "$" + "${`var'_p}" + "$"
		global `var'_p "$[$${`var'_p}$]$"
		
		
}
	
	* Start the Latex document
	texdoc do 	"${main_table_dofile_loc}/Latex/tex_table_nup_compare_gaps.do"
		