/* This do-file computes in-text numbers used in the endline IE paper 
that are not shown in the tables.


*/

gl lstock_transition_all			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_all.dta"
gl sample_indicators_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta"

/* Page 3

Third, TUP households are 20 percentage points (53%) more likely to have recovered to some extent
from shocks occurred in the previous year compared to control households experiencing similar shocks.*/

use "${data_for_analysis_phonesvy}", clear

	reg recover_cond_12mo treatment ${controls}, r
	sum recover_cond_12mo if treatment == 0 & e(sample) == 1

	gl shock_p3 : di %10.0fc 100*_b[treatment] / `r(mean)'
	
di "Third, TUP households are 20 percentage points ($shock_p3%) more likely to have recovered to some extent from shocks occurred in the previous year compared to control households experiencing similar shocks"
	
/* Page 6

Food consumption among UP control households decreased by 27% between July 2018 and June 2021, */

* Midline (July 2018)
use "${data_for_analysis_fl1_phonesvy}", clear

		gen up_control = .
			replace up_control = 1 if treatment == 0
			replace up_control = 0 if ultra_poor == 0
	
	keep hhid tot_hh_income_1_ca18_fl1 exp_f_tot_m_pc_ca21_fl1  up_control treatment ultra_poor tot_hh_income_1_usd_s exp_tot_m_pc_noh_ca21_s  
	
	rename *_fl1 * 
	
	* Replace with missing observations that are not in the endline sample 
	replace exp_f_tot_m_pc_ca21 = . if exp_tot_m_pc_noh_ca21_s == .
	rename tot_hh_income_1_usd_s tot_hh_income_1_ca18_s
	foreach var in  tot_hh_income_1_ca18  {
	 	replace `var' = . if `var'_s == .
	 }
	 
	gen endline = 0
	
	tempfile midline
	save `midline'
	
* Endline (June 2021)
use "${data_for_analysis_phonesvy_long}", clear 

	gen up_control = .
		replace up_control = 1 if treatment == 0
		replace up_control = 0 if ultra_poor == 0	
		drop if up_control == .
		
	keep hhid exp_f_tot_m_pc_ca21 up_control treatment ultra_poor	
	
	gen endline = 1 
	
	append using "`midline'"

	sum exp_f_tot_m_pc_ca21 if up_control == 1 & endline == 0
	local mean_mid `r(mean)'
	sum exp_f_tot_m_pc_ca21 if up_control == 1 & endline == 1 
	local mean_end `r(mean)'

	gl context_cons_up: di %10.0fc 100*(`mean_mid'-`mean_end')/`mean_mid'
	di "$context_cons_up"

/* while non-UP households faced an even larger reduction of 33%.*/
	
	sum exp_f_tot_m_pc_ca21 if up_control == 0 & endline == 0
	local mean_mid `r(mean)'
	sum exp_f_tot_m_pc_ca21 if up_control == 0 & endline == 1 
	local mean_end `r(mean)'

	gl context_cons_nup: di %10.0fc 100*(`mean_mid'-`mean_end')/`mean_mid'
	di "$context_cons_nup"
	
di "Food consumption among UP control households decreased by $context_cons_up% between July 2018 and June 2021, while non-UP households faced an even larger reduction of $context_cons_nup%"

/*Income and revenues across all sources decreased by 40% for UP control
households and by 43% for non-UP households in real terms.*/

use "${data_for_analysis_phonesvy}", clear 

	gen up_control = .
		replace up_control = 1 if treatment == 0
		replace up_control = 0 if ultra_poor == 0	
	
	gen endline = 1 
	
	append using "`midline'"
	keep hhid tot_hh_income_1_ca18 up_control treatment ultra_poor	endline

	sum tot_hh_income_1_ca18 if up_control == 1 & endline == 0
	local mean_mid `r(mean)'
	sum tot_hh_income_1_ca18 if up_control == 1 & endline == 1 
	local mean_end `r(mean)'

	gl context_inc_up: di %10.0fc 100*(`mean_mid'-`mean_end')/`mean_mid'
	di "$context_inc_up"	
	
	sum tot_hh_income_1_ca18 if up_control == 0 & endline == 0
	local mean_mid `r(mean)'
	sum tot_hh_income_1_ca18 if up_control == 0 & endline == 1 
	local mean_end `r(mean)'

	gl context_inc_nup: di %10.0fc 100*(`mean_mid'-`mean_end')/`mean_mid'
	di "$context_inc_nup"
	
di "Income and revenues across all sources decreased by $context_inc_up% for UP control households and by $context_inc_nup% for non-UP households in real terms."

/* Page 15 

Treatment households interviewed in any of the four survey rounds have 39% lower (p-value = 0.024)
value of livestock at baseline [...]], compared to control */

use "${data_for_analysis_bl_phonesvy}", clear 
	
	keep if anyround == 1 
	
	reg tot_lstock_value_4 treatment ${controls}, r 
	sum tot_lstock_value_4 if treatment == 0 & e(sample) == 1
	
	global lstock_bal: di %10.0fc -100*_b[treatment]/`r(mean)'
		
di "Treatment households interviewed in any of the four survey rounds have $lstock_bal% lower (p-value = 0.024) value of livestock at baseline [...]], compared to control"


/* Page 17

Due to food price increases, food consumption in constant terms decreased by 27% in
the control group between midline (July-October 2018) and endline (January-June 2021)
(Figure IV), while total consumption decreased by 8% during the same period (Table A7).*/

use "${data_for_analysis_fl1_phonesvy}", clear

	reg exp_tot_m_pc_noh_ca21_fl1 treatment ${controls} if exp_tot_m_pc_noh_ca21_s == 1, r
	sum exp_tot_m_pc_noh_ca21_fl1 if treatment == 0 & e(sample) == 1
	local cons_m0_fl1 `r(mean)'
	
use "${data_for_analysis_phonesvy_long}", clear 
	
	reg exp_tot_m_pc_noh_ca21 treatment ${controls}, r
	sum exp_tot_m_pc_noh_ca21 if treatment == 0 & e(sample) == 1
	local cons_m0 `r(mean)'	
	
	gl tot_cons_dec : di %10.0fc 100*(`cons_m0_fl1'-`cons_m0')/`cons_m0_fl1'
	di "$tot_cons_dec"
	
di "Due to food price increases, food consumption in constant terms decreased by $context_cons_up in the control group between midline (July-October 2018) and endline (January-June 2021) (Figure IV), while total consumption decreased by $tot_cons_dec % during the same period (Table A7)."

/* Page 19 
that at baseline and at midline, UP households reported consumption and health shocks as
the main reasons for accessing loans.*/

***************At baseline*******************************************************
*starting from the loan roster 
use		"${TUP_DB}/Baseline/DataSets/Intermediate/m_b_loans_bl.dta", clear 
	gen reason_consum_health = 0 if !mi(m3_1)  //loanfor which there is a reason 
	replace reason_consum_health = 1 if m3_1 == 1 | m3_2 == 1
 
 
 *Merging to have the treatment variable 
merge m:1 hhid using "${phone_svy_profile}", keepusing(treatment PRA_lottery ultra_poor)	assert(2 3) keep(3)

 tab reason_consum_health if ultra_poor == 1 /*78% are for that reason */
 
 tab reason_consum_health if ultra_poor == 1 & treatment == 0 /*79% are for that reason */
 tab reason_consum_health if ultra_poor == 1 & treatment == 1 /*78% are for that reason */
  



***************At midline*******************************************************
*starting from the loan roster 
use		"${TUP_DB}/Followup_1/DataSets/Intermediate/m_b_loans_fl1.dta", clear 
	gen reason_consum_health = 0 if !mi(3) & m3__98 != 1 //loan reasons which are not "don't know"
	replace reason_consum_health = 1 if m3_1 == 1 | m3_2 == 1
 
 tab reason_consum_health if ultra_poor == 1 /*81% are for that reason */
 
 *Merging to have the treatment variable 
merge m:1 hhid using "${phone_svy_profile}", keepusing(treatment PRA_lottery ultra_poor)	assert(2 3) keep(3)

 tab reason_consum_health if ultra_poor == 1 & treatment == 0 /*83% are for that reason */
 tab reason_consum_health if ultra_poor == 1 & treatment == 1 /*76% are for that reason */
  

/* Page 20

treatment households have 4.7 times the number of cows*/
	
use "${data_for_analysis_phonesvy_long}", clear

	reg lstock_num_cow treatment ${panel_controls}, vce(cluster hhid)
	sum lstock_num_cow if treatment == 0 & e(sample) == 1
	global cow_times: di %10.1fc (_b[treatment] + `r(mean)')/`r(mean)'
	di "$cow_times"

/* ...3.1 times the number of goats*/
  
	reg lstock_num_goat treatment ${panel_controls}, vce(cluster hhid)
	sum lstock_num_goat if treatment == 0 & e(sample) == 1
	global goat_times: di %10.1fc (_b[treatment] + `r(mean)')/`r(mean)'
	di "$goat_times"

/* ...7 times more sheep*/

	reg lstock_num_sheep treatment ${panel_controls}, vce(cluster hhid)
	sum lstock_num_sheep if treatment == 0 & e(sample) == 1
	global sheep_times: di %10.0fc (_b[treatment] + `r(mean)')/`r(mean)'
	di "$sheep_times"

/* and 1.4 times more chickens*/

	reg lstock_num_chicken treatment ${panel_controls}, vce(cluster hhid)
	sum lstock_num_chicken if treatment == 0 & e(sample) == 1
	global chicken_times: di %10.1fc (_b[treatment] + `r(mean)')/`r(mean)'
	di "$chicken_times"

/* TUP households report 4.1 times the value of livestock*/
use "${data_for_analysis_phonesvy}", clear 
	reg tot_lstock_value_4_usd treatment ${controls}, r
	sum tot_lstock_value_4_usd if treatment == 0 & e(sample) == 1
	
	global lstockvalue_times: di %10.1fc (_b[treatment] + `r(mean)')/`r(mean)'
	global lstockvalue_per: di %10.1fc (_b[treatment])/`r(mean)' * 100
	di "$lstockvalue_times"
	di "$lstockvalue_per"
	
di "... treatment households have $cow_times times the number of cows (p-value < 0.0005) as their control group counterparts, who own 0.1 cow, on average; $goat_times times the number of goats (p-value = 0.006); $sheep_times times more sheep (p-value = 0.005); and $chicken_times more chickens (p-value = 0.025) than the control group." 

di "Consistent with these results, TUP households report $lstockvalue_times times the value of livestock, or $lstockvalue_per% (p-value < 0.0005) larger than the the control group."

/* The estimated impacts increases by 11 percentage points to 321\% of control (p-value $<$ 0.0005). */

global bl_controls psy_indexC_sdC_bl psy_indexC_sdC_bl_mi tot_lstock_value_4_usd_bl tot_lstock_value_4_usd_bl_mi

use "${data_for_analysis_phonesvy}", clear
			
	reg tot_lstock_value_4_usd treatment ${controls} ${bl_controls}, r
	sum tot_lstock_value_4_usd if treatment == 0 & e(sample) == 1
	
	local lstockvalue = _b[treatment] 
	di _b[treatment] / `r(mean)'
	
	reg tot_lstock_value_4_usd treatment ${controls}, r
	sum tot_lstock_value_4_usd if treatment == 0 & e(sample) == 1
	
	local lstockvalue_controls = _b[treatment]
	di _b[treatment] / `r(mean)'
	
	global lstockvalue_impact_controls: di %10.0fc -(`lstockvalue_controls' - `lstockvalue')
	di "$lstockvalue_impact_controls"
		
di "The estimated impacts increases $lstockvalue_impact_controls percentage points to 321\% of control (p-value $<$ 0.0005)"	

/* Page 24 - Footnote 22

At midline, our proxy accounted for 76% and 67% of the total income and revenues for control and treatment households, respectively, for the endline sample */

use "${data_for_analysis_fl1_phones}", clear
		
	reg tot_hh_income treatment ${controls} if tot_hh_income_1_usd_s== 1, r 
	sum tot_hh_income if treatment == 0 & e(sample) == 1	
	
	loc inc_treat_fl1ind = _b[treatment] + `r(mean)'
	loc inc_control_fl1ind = `r(mean)'
			
use "${data_for_analysis_fl1_phonesvy}", clear 

	reg tot_hh_income_1_fl1 treatment ${controls} if tot_hh_income_1_usd_s== 1, r 
	sum tot_hh_income_1_fl1 if treatment == 0 & e(sample) == 1	
	
	loc inc_treat_endind = _b[treatment] + `r(mean)'
	loc inc_control_endind = `r(mean)'
	
	gl inc_treat_samp: di %10.0fc 100*`inc_treat_endind'/`inc_treat_fl1ind'
	
	gl inc_control_samp: di %10.0fc 100* `inc_control_endind'/`inc_control_fl1ind'

di "At midline, our proxy accounted for $inc_control_samp% and $inc_treat_samp% of the total income and revenues for control and treatment households, respectively, for the endline sample"

/* Page 25 

Although treatment households receive more paid labor income than control
households, the proportion that this income contributes to overall household
income is lower (62% vs. 69% in control).*/
		
use "${data_for_analysis_phonesvy}", clear
	
	* Total income 
	reg tot_hh_income_1_usd treatment ${controls}, r
	sum tot_hh_income_1_usd if treatment == 0 & e(sample) == 1
	local tot_inc_treat = _b[treatment] + `r(mean)'
	local tot_inc_control `r(mean)'
	
	* Paid labor income 
	reg tot_hh_pay_imp_1_usd treatment ${controls}, r
	sum tot_hh_pay_imp_1_usd if treatment == 0 & e(sample) == 1
	local labor_treat = _b[treatment] + `r(mean)'
	local labor_control `r(mean)'
	
	global treat_incshare: di %10.0fc 100*(`labor_treat'/`tot_inc_treat')
	
	global control_incshare: di %10.0fc 100*(`labor_control'/`tot_inc_control')
	
di "Although treatment households receive more paid labor income than control households, the proportion that this income contributes to overall household income is lower ($treat_incshare% vs. $control_incshare% in control)."

/*As mentioned in Section 2, income and revenues decrease
considerably (-41%) for UP control households between midline and endline.*/

use "${data_for_analysis_fl1_phonesvy}", clear

		gen up_control = .
			replace up_control = 1 if treatment == 0
			replace up_control = 0 if ultra_poor == 0
	
	keep hhid tot_hh_income_1_ca18_fl1 exp_f_tot_m_pc_ca21_fl1  up_control treatment ultra_poor tot_hh_income_1_usd_s exp_tot_m_pc_noh_ca21_s  
	
	rename *_fl1 * 
	
	* Replace with missing observations that are not in the endline sample 
	replace exp_f_tot_m_pc_ca21 = . if exp_tot_m_pc_noh_ca21_s == .
	rename tot_hh_income_1_usd_s tot_hh_income_1_ca18_s
	foreach var in  tot_hh_income_1_ca18  {
	 	replace `var' = . if `var'_s == .
	 }
	 
	gen endline = 0
	
	tempfile midline
	save `midline'
	
use "${data_for_analysis_phonesvy}", clear 

	gen up_control = .
		replace up_control = 1 if treatment == 0
		replace up_control = 0 if ultra_poor == 0	
	
	gen endline = 1 
	
	append using "`midline'"
	keep hhid tot_hh_income_1_ca18 up_control treatment ultra_poor	endline

	sum tot_hh_income_1_ca18 if up_control == 1 & endline == 0
	local mean_mid `r(mean)'
	sum tot_hh_income_1_ca18 if up_control == 1 & endline == 1 
	local mean_end `r(mean)'

	gl context_inc_up: di %10.0fc 100*(`mean_mid'-`mean_end')/`mean_mid'
	di "$context_inc_up"	
	
di "As mentioned in Section 2, income and revenues decrease considerably (-$context_inc_up%) for UP control households between midline and endline."

/* Page 27 -- 24%

The impact on our index of psychological well-being increased to 0.27 SD, or 24% more than the originally estimated, when we control for baseline characteristics. */

use "${data_for_analysis_phonesvy}", clear
			
	reg psy_indexC_sdC treatment ${controls} ${bl_controls}, r	
	local psy = _b[treatment] 
	
	reg psy_indexC_sdC treatment ${controls}, r
	local psy_controls = _b[treatment]
	
	global psy_impact_controls: di %10.0fc -100*(`psy_controls' - `psy')/`psy_controls'
	di "$psy_impact_controls"
		
di "The impact on our index of psychological well-being increased to 0.27 SD, or $psy_impact_controls% more than the originally estimated, when we control for baseline characteristics."	

/* Footnote 25 
Further, the impact on mobile phone ownership at the household level at
midline is small and not signficant (1 percentage point decrease, p-value = 0.996).*/

use "${TUP_DB}/Followup_1/DataSets/Intermediate/mobile_phone_ownership_fl1.dta", clear
keep if own_mobile == 1
gen hh_mobile_ownership = 1 //all households in this dataset have at least one phone 
duplicates drop hhid, force 
 
 *Merging to have the treatment variable 
merge 1:1 hhid using "${phone_svy_profile}", keepusing(treatment PRA_lottery ultra_poor)	assert(2 3) 
replace hh_mobile_ownership = 0 if _merge == 2

reg hh_mobile_ownership treatment ${controls}, r

global imp_phone: di %10.0fc 100*_b[treatment]*100
global imp_phone_p: di %10.3fc r(table)[4,1]

disp  "$imp_phone"
disp  "$imp_phone_p"

disp "Further, the impact on mobile phone ownership at the household level at midline is small and not signficant ($imp_phone percentage point decrease, p-value = $imp_phone_p)"

/* Page 28 - more than double is what needs to be checked 

However, the past-month's incidence is more than double that of past-year's incidence: 60% of households in the treatment group report experiencing a shock in the past month (p-value = 0.711), compared to 61% in control group; */

use "${data_for_analysis_phonesvy}", clear

	sum anyshock_4wk if treatment == 0 | treatment == 1
	global shock_4w: di %10.4fc  `r(mean)'
	di "$shock_4w"
	
	sum anyshock_12mo if treatment == 0 | treatment == 1
	global shock_12mo: di %10.4fc `r(mean)'
	di "$shock_12mo"
	
	di $shock_4w/$shock_12mo /*2.18 more than double*/
	
/* 60% of households in the treatment group report experiencing a shock in the
past month (p-value = 0.711), compared to 61% in control group; while the incidence
of a shock for treatment households in the past year is 26% (p-value = 0.225),
compared to 30% in control.*/ 
		
use "${data_for_analysis_phonesvy}", clear
	
	reg anyshock_4wk treatment ${controls}, r
	sum anyshock_4wk if treatment == 0 & e(sample) == 1
	
	global shock_4w_treat: di %10.0fc 100*(_b[treatment] + `r(mean)')
	di "$shock_4w_treat"
	
	reg anyshock_12mo treatment ${controls}, r
	sum anyshock_12mo if treatment == 0 & e(sample) == 1

	global shock_12mo_treat: di %10.0fc 100*(_b[treatment] + `r(mean)')
	di "$shock_12mo_treat"
		
di "$shock_4w_treat% of households in the treatment group report experiencing a shock in the past month (p-value = 0.711), compared to 61% in control group; while the incidence of a shock for treatment households in the past year is $shock_12mo_treat% (p-value = 0.225), compared to 30% in control."	


/* Page 30

As Table 9 shows, treatment households are 19.7 percentage points, or 53% (p-value = 0.025)
more likely to at least somewhat recover from shocks occurred in the past year */

use "${data_for_analysis_phonesvy}", clear
	
	reg recover_cond_12mo treatment ${controls}, r
	sum recover_cond_12mo if treatment == 0 & e(sample) == 1
	
	gl shock_p3 : di %10.0fc 100*_b[treatment] / `r(mean)'
	
di "As Table 9 shows, treatment households are 19.7 percentage points, or $shock_p3% (p-value = 0.025) more likely to at least somewhat recover from shocks occurred in the past year"

/* [...] compared to 21% who had a shock and used loans as a coping mechanism (or 70% of those who had a shock) in control; */

use "${data_for_analysis_phonesvy}", clear
	
	reg g2_cond_2_12mo treatment ${controls}, r
	sum g2_cond_2_12mo if treatment == 0 & e(sample) == 1
	
	global loan_shock : di %10.0fc 100*`r(mean)'
	
di "[...] compared to 21% who had a shock and used loans as a coping mechanism (or $loan_shock% of those who had a shock) in control;"
	
/* [...] and children's labor (-1.1 percentage points, p-value=0.026), compared to 1.1%
in control who had a shock and relied on children's labor to help cope with the shock
(or 3.5% of those who had a shock).*/	

	reg g2_cond_7_12mo treatment ${controls}, r
	sum g2_cond_7_12mo if treatment == 0 & e(sample) == 1
	
	global childwork_shock: di %10.1fc 100*`r(mean)'
	
di "[...] and children's labor (-1.1 percentage points, p-value=0.026), compared to 1.1% in control who had a shock and relied on children's labor to help cope with the shock (or $childwork_shock% of those who had a shock)."	

/* Page 32 

[...] hence the biggest difference between treatment and control households at the time of
the asset transfer in 2016 was on cows ownership: the treatment group held on average 1.5 cows, compared to 0.1 in control as a consequence of the transfer. */

use "${TUP_DB}/Phone_Survey/DataSets/Intermediate/lstock_transition_all.dta", clear

keep if livestock == 1 & period == "transfer"

sum lstock_num if treatment == 1
	global lstock_num_trans_t: di %10.1fc (`r(mean)')
	di "$lstock_num_trans_t"

sum lstock_num if treatment == 0
	global lstock_num_trans_c: di %10.1fc (`r(mean)')
	di "$lstock_num_trans_c"
	
di "[...] the treatment group held on average $lstock_num_trans_t cows, compared to $lstock_num_trans_c in control as a consequence of the transfer."		

/* twice as many types of crops cultivated */
 
use "${data_for_analysis_phonesvy}", clear
			
	reg num_crop_type treatment ${controls}, r
	sum num_crop_type if treatment == 0 & e(sample) == 1
	
	global twice_as_many_crop: di %10.0fc (_b[treatment] + `r(mean)')/`r(mean)'
	di "$twice_as_many_crop"
	
/* Page 33 -- this is computed for the stats on Page 25 

[...] paid labor income, the main component of our proxy for income and revenues,
representing 69% for control households.*/

di "[...] paid labor income, the main component of our proxy for income and revenues, representing $control_incshare% for control households."

/* Page 33 
[...] at the time of the asset transfer in 2016 was on cows ownership:
the treatment group held on average 1.5 cows, compared to 0.1 in control as a
consequence of the transfer (not shown). */

use "${lstock_transition_all}", clear 

	merge m:1 hhid using "${sample_indicators_phonesvy}", assert(1 3) nogen keepusing(tot_lstock_value_4_usd_s) 
 
	* Keep cows at transfer 
	keep if livestock == 1 & period == "transfer" 
	
	*Keeping impact estimate samples (N=694 for midline and N=721for endline) 
	keep if tot_lstock_value_4_usd_s == 1  
		
	tab treatment // N = 672

	sum lstock_num if treatment == 0
	global trans_cow_0 : di %10.1fc `r(mean)'
 	sum lstock_num if treatment == 1
	global trans_cow_1 : di %10.1fc `r(mean)'

di "...at the time of the asset transfer in 2016 was on cows ownership: the treatment group held on average $trans_cow_1 cows, compared to $trans_cow_0 in control as a consequence of the transfer (not shown)."
	
/* page 33 

[...] for TUP households the largest proportion of livestock value (70\%) is in higher-return assets---cows, goats and sheep---while the majority livestock value (70\%) for the control group is in the lowest-return asset, chickens (not shown). */	

* Endline 
global lstocks	lstock_value_cow_4_usd lstock_value_goat_4_usd lstock_value_sheep_4_usd lstock_value_chicken_4_usd
	 
use "${data_for_analysis_phonesvy}", clear  
 
	keep if treatment !=. & !mi(tot_lstock_value_4_usd) // N = 721    
	drop if tot_lstock_value_4_usd !=tot_lstock_value_4_w99t_usd // drop 6 HHs that were winsorized as outliers  
		 
	egen lstock_value_tup = rowtotal(lstock_value_cow_4_usd lstock_value_goat_4_usd lstock_value_sheep_4_usd)
		
	foreach var in lstock_value_tup	{ 
		gen `var'_pct = `var'/tot_lstock_value_4_usd 
	}
	
	sum lstock_value_tup_pct if treatment == 0 
	global lstock_pct_0 : di %10.0fc (1-`r(mean)')*100
	sum lstock_value_tup_pct if treatment == 1 	
	global lstock_pct_1 : di %10.0fc `r(mean)'*100

di "[...] for TUP households the largest proportion of livestock value (${lstock_pct_1}%) is in higher-return assets---cows, goats and sheep---while the majority livestock value (${lstock_pct_0}%) for the control group is in the lowest-return asset, chickens (not shown)."
	
/* Page 35 - it's the % that need to be checked 

[...] they [TUP households] continue to report lower income and revenues
(-17%, p-value = 0.024), consumption (-10%, p-value = 0.098) [...],
than non-UP households in their villages (Table 11).*/

use "$data_for_analysis_phonesvy", clear  

	* Income 
	reg tot_hh_income_1_usd treatment ${controls}, r		
	sum tot_hh_income_1_usd if treatment == 0 & e(sample) == 1 
	local inc_treat = _b[treatment] + `r(mean)'
	
	gen control = 1 if treatment == 0 
	replace control = 0 if treatment == 1  
	 
	gen non_ultra_poor = (missing(control)) 

	reg tot_hh_income_1_usd non_ultra_poor ${controls} if treatment != 0, r 
	sum tot_hh_income_1_usd if non_ultra_poor == 0 & e(sample) == 1 
	local inc_nup _b[non_ultra_poor]
	
	global inc_nup_treat : di %10.0fc 100*(`inc_nup' / `inc_treat')
	
use "$data_for_analysis_phonesvy_long", clear
	
	* Consumption  
	reg exp_tot_m_pc_noh_ca21 treatment ${controls}, r		
	sum exp_tot_m_pc_noh_ca21 if treatment == 0 & e(sample) == 1 
	local cons_treat = _b[treatment] + `r(mean)'
	 
	gen non_ultra_poor = (missing(control)) 

	reg exp_tot_m_pc_noh_ca21 non_ultra_poor ${panel_controls} if treatment != 0, r 
	local cons_nup _b[non_ultra_poor]
	
	global cons_nup_treat : di %10.0fc 100*(`cons_nup' / `cons_treat')

	
di "[...] they [TUP households] continue to report lower income and revenues (-$inc_nup_treat%, p-value = 0.024), consumption (-$cons_nup_treat%, p-value = 0.098) [...], than non-UP households in their villages (Table 11)"	

/* [...] the difference in incomes and revenues between non-UP and UP households
is driven by non-UP having more income and revenues from non-agricultural
business (p-value = 0.022) and paid labor (p-value = 0.061) than TUP households.*/

use "${data_for_analysis_phonesvy}", clear
	drop if treatment == 0 // drop controls 
	
	replace treatment = 2 if mi(treatment)
	tab treatment 
	
	recode treatment (1=0) (2=1)
	tab treatment // nup = 1, treatment is 0
		
	* Non-ag biz 	
	reg tot_biz_rev_imp_1_usd treatment ${controls}, r
	matrix list r(table)
	
	global nup_biz_p: di %10.3fc r(table)[4,1]
	
	* Paid labor 
	reg tot_hh_pay_imp_1_usd treatment ${controls}, r
	matrix list r(table)
	
	global nup_labor_p: di %10.3fc r(table)[4,1]	
	
di "[...] the difference in incomes and revenues between non-UP and UP households is driven by non-UP having more income and revenues from non-agricultural business (p-value = $nup_biz_p) and paid labor (p-value = $nup_labor_p) than TUP households"

/* Page 36 -- stat computed just above 

[N]on-UP households [...] derive a higher income from non-agricultural businesses
(p-value = 0.022) */

di "[N]on-UP households [...] derive a higher income from non-agricultural businesses (p-value = $nup_biz_p)"
















































*******************************************************************************
* Appendix
*******************************************************************************

/* Page 49 (Real Value Estimates) 
From these estimates, food ination is equivalent to 10.84% per year during this period (or 36% in total).

Estimated overall inflation totaled 25% between midline and endline, or 7.63% per year.*/

	 global infl_food_year: di %10.2fc  ((${cpi_food_phone}/100)^(1/3) - 1)*100
	 global infl_all_year:  di %10.2fc  ((${cpi_econ_phone}/100)^(1/3) - 1)*100
di "From these estimates, food ination is equivalent to $infl_food_year% per year during this period (or 36% in total). [...] Estimated overall inflation totaled 25% between midline and endline, or $infl_all_year% per year."

	 

/* Page 50 - CBA 

[...] calculate total household annual consumption by multiplying estimated
monthly per capita consumption (consumption (US $6.8) by household size (6.48)*/

* Midline HH size -- for the Endline sample 
use "${roster_final_fl1}", clear 
	merge m:1 hhid using "${data_for_analysis_fl1_phonesvy}", keepusing(exp_tot_m_pc_noh_ca21_s) keep(1 3) nogen 

	keep hhid b3 ultra_poor exp_tot_m_pc_noh_ca21_s
	duplicates drop hhid ultra_poor, force

	sum b3 if ultra_poor == 1 & exp_tot_m_pc_noh_ca21_s == 1 
	
	global hhsize_mid : di %10.2fc `r(mean)'
	di "$hhsize_mid"
* Midline [487 AFN]
	
use "${data_for_analysis_fl1}", clear 

reg exp_tot_m_pc treatment ${controls}

* In nominal USD
global fullcons_mid : di %10.1fc (_b[treatment]/$exchange_rate_2018)
di $fullcons_mid

di "[...] calculate total household annual consumption by multiplying estimated monthly per capita consumption (consumption (US $$fullcons_mid) by household size ($hhsize_mid)"
	
/*[...] we calculate the consumption proxy using midline data (US $4.38)*/

* Midline - Midline sample [316], N = 1,147
use "${data_for_analysis_fl1_phonesvy}", clear 

reg exp_tot_m_pc_noh_ca18_fl1 treatment ${controls}

* In nominal USD
global proxycons_mid : di %10.2fc (_b[treatment]/$exchange_rate_2018) 
di $proxycons_mid

di "[...] we calculate the consumption proxy using midline data (US $$proxycons_mid)"

/*Footnote 31: 

This estimate comes from the full midline sample; using the endline sample,
this results in US $3.27.*/

* Midline - Endline sample [236], N = 839
use "${data_for_analysis_fl1_phonesvy}", clear 

reg exp_tot_m_pc_noh_ca18_fl1 treatment ${controls} if exp_tot_m_pc_noh_ca21_s == 1

global proxycons_mid_endsamp : di %10.2fc (_b[treatment]/$exchange_rate_2018) 
di $proxycons_mid_endsamp

di "This estimate comes from the full midline sample; using the endline sample,this results in US $$proxycons_mid_endsamp."

/*[...] a scaling factor of 1.55 to reach full consumption*/

global upscale_ratio: di %10.2fc $fullcons_mid / $proxycons_mid
di $upscale_ratio

di "[...] a scaling factor of $upscale_ratio to reach full consumption"

/*[...] estimated per capita monthly consumption found at endline (US $1.83) b
the household size at the time (7.3) and the scaling factor.*/

* Endline HH size 
use "${roster_final_phonesvy}", clear 

	keep hhid hh_mem round ultra_poor
	duplicates drop hhid round ultra_poor, force

	sum hh_mem if ultra_poor == 1
	
	global hhsize_end : di %10.1fc `r(mean)'
	di "$hhsize_end"
	
	* Endline [142]
	use "${data_for_analysis_phonesvy_long}", clear

	reg exp_tot_m_pc_noh treatment ${panel_controls} treatment

	* In nominal USD
	global proxycons_end : di %10.2fc (_b[treatment]/$exchange_rate_2021)
	di $proxycons_end

di "[...] estimated per capita monthly consumption found at endline (US $$proxycons_end) by the household size at the time ($hhsize_end) and the scaling factor."	
	
/*This yields an annual consumption estimate at midline and endline of US $393
and US $245 respectively.*/

* Midline
global ann_cons_mid : di %10.0fc ($proxycons_mid_endsamp * $upscale_ratio * $hhsize_mid * 12)
di $ann_cons_mid

* Endline
global ann_cons_end : di %10.0fc ($proxycons_end * $upscale_ratio * $hhsize_end * 12)
di $ann_cons_end

di "This yields an annual consumption estimate at midline and endline of US $$ann_cons_mid and US $$ann_cons_end respectively."