/* coeff_treat is used to calculate and save the different outputs of a regression in globals which will be used
to automatically generate tables in latex. Options to change the format of the figures using "N_dec"
It should be run after a regression and a summary of the dependent variable
*/
cap prog drop coeff_treat //clearing any program that might exist under that name. Always start with that line

	prog def coeff_treat

args name_coeff name_var N_dec

local dec = 3
if "`N_dec'" != "3" & "`N_dec'"!= "" {
local dec = `N_dec'
}

local mean = `r(mean)'
if `mean' >= 0 {
	global meanpos = `mean'
}
if `mean' < 0 {
	global meanpos = -`mean'
}

local sd = `r(sd)'
	* Round indices to 3 decimals before formatting 
	if regexm("`name_coeff'", "zscore") | regexm("`name_coeff'", "index") | regexm("`name_coeff'", "z_sd") | regexm("`name_coeff'", "sdC") {
	global `name_coeff'm0 = round(`r(mean)',0.001)
	} 
	else {
	global `name_coeff'm0 = `r(mean)'
	}


	if `dec'==1 & `r(mean)'>=100 {
	global `name_coeff'm0 :  di %10.0fc ${`name_coeff'm0}
	} 
	else {
	global `name_coeff'm0 :  di %10.`dec'fc ${`name_coeff'm0}
	}

	if `dec'==1 & `r(sd)'>=100 {
	global `name_coeff's0 :  di %10.0fc `r(sd)'
	} 
	else {
	global `name_coeff's0 :  di %10.`dec'fc `r(sd)'
	}

	if `dec'==1 & _b[`name_var']>=100 {
	global `name_coeff't :  di %10.0fc _b[`name_var']
	} 
	else {
	global `name_coeff't :  di %10.`dec'fc _b[`name_var']
	}

	if `dec'==1 & _se[`name_var']>=100 {
	global `name_coeff'tse :  di %10.0fc _se[`name_var']
	} 
	else {
	global `name_coeff'tse :  di %10.`dec'fc _se[`name_var']
	}



*Impact in percentage:

 	global `name_coeff'imp1 =   _b[`name_var'] /$meanpos * 100

if ${`name_coeff'imp1} >= 10 {
	global `name_coeff'imp1 :  di %2.0f ${`name_coeff'imp1}	
}
if ${`name_coeff'imp1} < 10 {
	global `name_coeff'imp1 :  di %1.0f ${`name_coeff'imp1}	
}

if mi(${`name_coeff'imp1}) {
global `name_coeff'imp1 " NA"
} 

*Impact in standard deviation: 
global `name_coeff'imp2 = _b[`name_var']/`sd'	
global `name_coeff'imp2 : di %10.3fc ${`name_coeff'imp2}

if mi(${`name_coeff'imp2}) {
global `name_coeff'imp2 " NA"
} 

*Other locals
global R_`name_coeff' :  di %10.3f e(r2)

global N_`name_coeff' : di %10.0fc e(N)


*Pvalues
global `name_coeff'p :  di %10.3f (2 * ttail(e(df_r), abs(_b[`name_var']/_se[`name_var'])))


global `name_coeff't = "$" + "${`name_coeff't}" + "$"
*Adding the star
	*disp "`i'"
		if  ${`name_coeff'p} <= 0.1 {
		global `name_coeff't = "${`name_coeff't}" + "*"
			
			if ${`name_coeff'p} <= 0.05 {
			global `name_coeff't = "${`name_coeff't}" + "*"

				if ${`name_coeff'p} <= 0.01 {
				global `name_coeff't = "${`name_coeff't}" + "*"
				
			}				
		}
	}


	
*Putting all numbers in string to have them in math mode in Latex
global `name_coeff'm0 = "$" + "${`name_coeff'm0}" + "$"
global `name_coeff's0 = "$" + "${`name_coeff's0}" + "$"
global `name_coeff'tse = "$" + "${`name_coeff'tse}" + "$"
global `name_coeff'p = "$" + "${`name_coeff'p}" + "$"
global N_`name_coeff' = "$" + "${N_`name_coeff'}" + "$"
global R_`name_coeff' = "$" + "${R_`name_coeff'}" + "$"
global `name_coeff'imp1 = "$" + "${`name_coeff'imp1}" + "$"
global `name_coeff'imp2 = "$" + "${`name_coeff'imp2}" + "$"
	end //