   * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *               Analysis of endline results                            *
   *               MASTER DO_FILE                                         *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      This master do file run all the analysis do file generating the results presented in the endline paper 

       ** OUTLINE:      PART 0: Standardize settings and install packages
                        PART 1: Prepare folder path globals
                        PART 2: Run the master dofiles for each high-level task

       ** IDS VAR:        hhid       //Uniquely identifies households

       ** NOTES:

       ** WRITEN BY:    Yulia Belyakova (ybelyakova@worldbank.org)
						Thomas Escande (tescande@worldbank.org)

       */

*iefolder*0*StandardSettings****************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 0:  INSTALL PACKAGES AND STANDARDIZE SETTINGS
   *
   *           - Install packages needed to run all dofiles called
   *            by this master dofile.
   *           - Use ieboilstart to harmonize settings across users
   *
   * ******************************************************************** *

   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           - Set the global box to point to the project folder
   *            on each collaborator's computer.
   *           - Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *

* These lines are used to test that the name is not already used (do not edit manually)

   * Project folder globals
   * ---------------------


*iefolder*1*FolderGlobals*IE_Phone_paper****************************************
*iefolder will not work properly if the line above is edited


   *Encrypted round sub-folder globals
   global IE_Phone_paper         "$dataWorkFolder/IE_Phone_paper" 

   *Encrypted round sub-folder globals
   global IE_Phone_paper_encrypt "$encryptFolder/Round IE_Phone_paper Encrypted" 
   global IE_Phone_paper_dtRaw   "$IE_Phone_paper_encrypt/Raw Identified Data" 
   global IE_Phone_paper_doImp   "$IE_Phone_paper_encrypt/Dofiles Import" 
   global IE_Phone_paper_HFC     "$IE_Phone_paper_encrypt/High Frequency Checks" 

   *DataSets sub-folder globals
   global IE_Phone_paper_dt      "$IE_Phone_paper/DataSets" 
   global IE_Phone_paper_dtDeID  "$IE_Phone_paper_dt/Deidentified" 
   global IE_Phone_paper_dtInt   "$IE_Phone_paper_dt/Intermediate" 
   global IE_Phone_paper_dtFin   "$IE_Phone_paper_dt/Final" 

   *Dofile sub-folder globals
   global IE_Phone_paper_do      "$IE_Phone_paper/Dofiles" 
   global IE_Phone_paper_doCln   "$IE_Phone_paper_do/Cleaning" 
   global IE_Phone_paper_doCon   "$IE_Phone_paper_do/Construction" 
   global IE_Phone_paper_doAnl   "$IE_Phone_paper_do/Analysis" 

   *Output sub-folder globals
   global IE_Phone_paper_out     "$IE_Phone_paper/Output" 
   global IE_Phone_paper_outRaw  "$IE_Phone_paper_out/Raw" 
   global IE_Phone_paper_outFin  "$IE_Phone_paper_out/Final" 

   *Questionnaire sub-folder globals
   global IE_Phone_paper_prld    "$IE_Phone_paper_quest/PreloadData" 
   global IE_Phone_paper_doc     "$IE_Phone_paper_quest/Questionnaire Documentation" 

*iefolder*1*End_FolderGlobals***************************************************
*iefolder will not work properly if the line above is edited


*iefolder*2*StandardGlobals*****************************************************
*iefolder will not work properly if the line above is edited

   * Set all non-folder path globals that are constant accross
   * the project. Examples are conversion rates used in unit
   * standardization, different sets of control variables,
   * adofile paths etc.

   do "$dataWorkFolder/global_setup.do" 


*iefolder*2*End_StandardGlobals*************************************************
*iefolder will not work properly if the line above is edited

   * Dataset globals
   * ---------------------
   
	* Baseline data for balance checks 
	global  data_for_analysis_bl_phonesvy		"${TUP_DB}/Baseline_Phone/DataSets/Final/data_for_analysis_bl_phonesvy.dta"
	global  schooling_bl						"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"
	global  total_expenditure_bl_phones 		"${TUP_DB}/Baseline_PhoneSample/DataSets/Intermediate/total_expenditure_bl_phones.dta"

	* Baseline data for attrition estimations 
	global data_for_analysis_bl					"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	
	* Follow-up 1 data with Phone Survey construction changes 
	global data_for_analysis_fl1_phonesvy		"${TUP_DB}/Followup_1_Phone/DataSets/Final/data_for_analysis_fl1_phonesvy.dta"
	global data_for_analysis_fl1_phone_full		"${TUP_DB}/Followup_1_Phone/DataSets/Final/data_for_analysis_fl1_phone_full.dta"
	global data_for_analysis_fl1_phones			"${TUP_DB}/Followup_1_PhoneSample/DataSets/Final/data_for_analysis_fl1_phones.dta"
	global schooling_fl1_phonesvy				"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/schooling_fl1_phonesvy.dta"
	global food_consumption_shares_fl1			"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/food_consumption_shares_fl1_phonesvy.dta"	 
	global  schooling_bl_phonesvy				"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/schooling_bl_phonesvy.dta"
	global  covars_bl_phonesvy					"${TUP_DB}/Baseline_Phone/DataSets/Final/covars_bl_phonesvy.dta"
	
	* Fl1 data with no changes
	global data_for_analysis_fl1				"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

	* Phone survey data 
	global data_for_analysis_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy.dta" // not IE 
	global schooling_phonesvy					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_phonesvy.dta"
	global data_for_analysis_phonesvy_long 		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy_long.dta" //
	global phone_svy_profile   					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	global food_consumption_shares_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_consumption_shares_phonesvy.dta"	 
	
	
	* For baseline characteristics 
	global schooling_bl						"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"
	global psy_bl_gender2 	  				"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_gender_all_bl.dta"	
	global data_for_analysis_bl				"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl_IEpaper.dta"
	global roster_bl						"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"
	global all_HH_nopii_bl 					"${TUP_DB}/Baseline/DataSets/Intermediate/all_HH_nopii_bl.dta"
	global total_expenditure_bl_ca18		"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/total_expenditure_bl.dta"
	global total_expenditure_fl1_ca18		"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/total_expenditure_fl1.dta"

	* Country comparison dataset 	
	global we_pol_comp 						"${Dropbox}/TUP_Afghanistan/External resources/Data & do-files/Banerjee_Science_2015/New_results/women_empower_pol_involvement.xlsx"	
	global export_labor 					"${Dropbox}/TUP_Afghanistan/External resources/Data & do-files/Banerjee_Science_2015/New_results/mean_labor_participation.xlsx" 
	
	*DHS dataset 
	global DHS_data 						"${Dropbox}/TUP_Afghanistan/External resources/Data & do-files/DHS_Afghanistan_2015/Data/Women/AFIR70FL.DTA"
	
	*Rosters


	* Programs 	- change the file path eventually 
	global coeff_treat				"${IE_Phone_paper_do}/MasterData/Programs/coeff_treat.do"			
	global coeff_treat_excel		"${IE_Phone_paper_do}/MasterData/Programs/coeff_treat_excel.do"
	global stat_estim				"${IE_Phone_paper_do}/MasterData/Programs/stat_estim.do"	
	global test_interaction			"${IE_Phone_paper_do}/MasterData/Programs/test_interaction.do"	
	global impact_interaction		"${IE_Phone_paper_do}/MasterData/Programs/impact_interaction.do"	
	global means_desc				"${IE_Phone_paper_do}/MasterData/Programs/means_desc.do"	

	*Output (TUP Dropbox)
	global	output					"${TUP_DB}/IE_Phone_Paper/Output/Final"
	global	output_raw				"${TUP_DB}/IE_Phone_Paper/Output/Raw"
	global	output_raw_figures		"${TUP_DB}/IE_Phone_Paper/Output/Raw/Figures"
	
	/* Output (Overleaf)
	global	output_table_overleaf_main			"${Dropbox}\Apps\Overleaf\TUP_Endline_working_version\Tables"
 	global	output_figure_overleaf_main			"${Dropbox}\Apps\Overleaf\TUP_Endline_working_version\Figures"
	global	output_overleaf_online_appendix		"${Dropbox}\Apps\Overleaf\TUP_Endline_working_version\Online_appendix"*/
	
	global	output_table_overleaf_main			"${dataWorkFolder}/TUP_Endline_working_version/Tables" 
	global	output_figure_overleaf_main			"${dataWorkFolder}/TUP_Endline_working_version/Figures" 
	global	output_overleaf_online_appendix		"${dataWorkFolder}/TUP_Endline_working_version/Online_appendix"
	
	*Output 
	global table_loc 							"${TUP_DB}/IE_Phone_Paper/Output/Final/"
	global figure_loc 							"${TUP_DB}/IE_Phone_Paper/Output/Final/Figures" 
	global main_table_dofile_loc  				"${IE_Phone_paper_doAnl}/Tables"
	global main_figure_dofile_loc  				"${IE_Phone_paper_doAnl}/Figures"
	global online_appendix_dofile_loc  			"${IE_Phone_paper_doAnl}/Online_Appendix"
	global appendix_figure_R_script_loc  		"${IE_Phone_paper}/R Script/Analysis"	 

	* Color figures for the brief 
	global brief_figure_loc 					"${Dropbox}/TUP_Afghanistan/Papers Reports and Briefs/Briefs/Phone_IE_results_brief/Figures"
	global brief_figure_loc_overleaf 			"${Dropbox}/Apps/Overleaf/DIME TUP 5 year brief"
	
	* Globals for controls 
	global controls i.PRA_lottery
	global panel_controls i.PRA_lottery ib(4).round

*iefolder*3*RunDofiles**********************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 3: - RUN DOFILES CALLED BY THIS MASTER DOFILE
   *
   *           - A task master dofile has been created for each high-
   *            level task (cleaning, construct, analysis). By 
   *            running all of them all data work associated with the 
   *            IE_Phone_paper should be replicated, including output of 
   *            tables, graphs, etc.
   *           - Feel free to add to this list if you have other high-
   *            level tasks relevant to your project.
   *
   * ******************************************************************** *


   * Run programs (ado files written by us to facilitate saving numbers in latex tables)
	do "${coeff_treat}"
	do "${means_desc}"
	
********************************************************************************
* Construction of the livestock transition dataset: evolution of livestock ownership between baseline, midline and endline 
********************************************************************************	

 do  "${IE_Phone_paper_doCon}/lstock_transition_datasets.do"

********************************************************************************
* Main Tables 
********************************************************************************

/*Table 1: Ultra-Poor Households' Socioeconomic Characteristics at Baseline*/
	texdoc do	"${main_table_dofile_loc}/table_hhsocioec_chars.do", replace 

/*Table 2: Impacts on Consumption, Food Security and Nutritional Diversity*/
	texdoc do	"${main_table_dofile_loc}/table_impacts_consump.do", replace
	
/*Table 3: Impacts on Household Finances*/	
	texdoc do	"${main_table_dofile_loc}/table_impacts_finance.do", replace 

/*Table 4: Impacts on Household Durable and Productive Assets*/
	texdoc do	"${main_table_dofile_loc}/table_impacts_assets.do", replace 

/*Table 5: Impacts on Labor Supply and Time Use, Primary Woman and Man, Past Month*/	
	texdoc do	"${main_table_dofile_loc}/table_impacts_timeuse.do", replace  

/*Table 6: Impacts on Total Household Income and Revenues Proxy (USD), Month*/	
	texdoc do	"${main_table_dofile_loc}/table_impacts_income.do", replace 

/*Table 7: Impacts on Psychological Well-Being and Education*/	
	texdoc do	"${main_table_dofile_loc}/table_impacts_psy_detail.do", replace
	
/*Table 8: Impacts on Women's Empowerment, by Index Component*/	
	texdoc do	"${main_table_dofile_loc}/table_impacts_we_detail.do", replace

/*Table 9: Shocks and Coping Mechanisms*/
	texdoc do	"${main_table_dofile_loc}/table_impacts_shocks_new.do", replace
	
/*Table 10: Comparison of Ultra-Poor and Non-Ultra Poor Households*/	
	texdoc do	"${main_table_dofile_loc}/table_nup_compare_gaps.do", replace 
	
********************************************************************************
* Main Figures
********************************************************************************
/*Figure I, II and III are contextual and not directly linked to the analysis, the code to reproduce them is then not included here*/ 

/*Figure IV: Midline and Endline Comparison of Select Indicators Ultra-Poor Control and Non-Ultra Poor Households*/
	do	"${main_figure_dofile_loc}/figure_context.do"
	
/*Figure V: Number of Livestock Owned and Mean Value of Livestock Owned*/	
	do	"${main_figure_dofile_loc}/figure_dynamic_lstock_value.do"
	
	* This do-file needs to be run after "figure_dynamic_lstock_value" since it 
	* combines the two graphs into one:
	do	"${main_figure_dofile_loc}/figure_dynamic_lstock_cowequiv.do"

********************************************************************************
* Online Appendix Tables 
******************************************************************************** 

/* Table A1: Mapping of Endline Outcomes to Data Collection Rounds

This table does not show analysis results. */

/* Table A2: Explanatory Power of Total Consumption Proxy*/
	texdoc do	"${online_appendix_dofile_loc}/table_proxy_consumption_validation.do", replace 	

/*Figure A: Estimated Inflation Between Midline and Endline (3-year period): Food, Non-Food Items, and Overall 2018-Q3 to 2021-Q2*/
	do	"${online_appendix_dofile_loc}/figure_inflation.do"		
	
/*Table A3: Cost-Benefit Analysis

Tha calculations for the table are done in Excel, the following do-file exports numerical inputs related 
to household size and consumption impacts into the Excel. The Excel can be found here:
Dropbox/DataWork/Phone_Survey/Output/Final/Cost benefit analysis table.xlsx.
	 
Inputs are exported into sheet "CBA inputs_April2023" and pulled into the sheet "cba" using formulas. 
All other rcalculations for the CBA are done in sheet "cba" using Excel formulas. */

	texdoc do	"${online_appendix_dofile_loc}/table_cba.do", replace 
	
/*Table A4-A: Baseline Balance Test: HHs Surveyed in Any Round*/
	texdoc do	"${online_appendix_dofile_loc}/table_balance_anyround.do", replace
	
/*Table A4-B: Baseline Balance Test: HHs Surveyed in All Rounds*/
	texdoc do	"${online_appendix_dofile_loc}/table_balance_allrounds.do", replace
	
/*Table A5: Endline Attrition and Response Rate*/
	texdoc do	"${online_appendix_dofile_loc}/table_attrition.do", replace

/*Table A6: Robustness Check: Impacts on Main Outcomes with Baseline Controls*/
	texdoc do	"${online_appendix_dofile_loc}/table_robust_bl_controls.do", replace
	
/*Table A7: Robustness Check: Impacts on Main Outcomes for a Subsample of HHs Surveyed in All Rounds*/	
	texdoc do	"${online_appendix_dofile_loc}/table_robust_allrounds.do", replace
	
/*Table A8: Impacts on Women's Empowerment Excluding Market Work Participation, by Index Component*/	
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_we_detail_nomkt.do", replace		
	
/*Table A9: Impacts on Psychological Well-Being and Women's Empowerment Indices */	
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_psy_we.do", replace	
	
/*Figure A2: Livestock Ownership Transition, Number of Livestock in Cow Equivalents*/ 
	rsource using "${appendix_figure_R_script_loc}/alluvial_lstock.R", rpath(`"${Rterm}"') roptions(`"--vanilla"')   // change version number, if necessary 	

/*Table A10: Impacts on Diversification of Income Sources*/ 
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_diversification.do", replace	
	
/*Figure A3: UP and Non-UP Comparison at Endline Total Household Income and Revenues Proxy (USD)*/	
	do	"${online_appendix_dofile_loc}/figure_equity_income_paper.do"
	
/*Table A11: Comparison Between Midline and Endline Samples and Indicators for Midline Impacts*/
	texdoc do	"${online_appendix_dofile_loc}/table_sample_impact_compare.do", replace	
	
/*Table A12: Two-Year Follow-Up Impacts on Consumption, Food Security and Nutritional Diversity*/
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_consump_ca21_fl1.do", replace
	
/*Table A13: Two-Year Follow-Up Impacts on Proxy Household Income and Revenues (Nominal USD), Past 4 Weeks*/	
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_income_fl1.do", replace

/*Table A14: Two-Year Follow-Up Impacts on Household Finances (Nominal USD)*/
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_finance_fl1.do", replace

/*Table A15: Two-Year Follow-Up Impacts on Household Durable and Productive Assets*/	
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_assets_fl1.do", replace
	
/*Table A16: Two-Year Follow-Up Impacts on Labor Supply and Time Use, Primary Woman and Man, Past 4 Weeks*/	
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_timeuse_fl1.do", replace

/*Table A17: Two-Year Follow-Up Impacts on Psychological Well-Being and Education*/	
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_psy_detail_fl1.do", replace
	
/*Table A18: Two-Year Follow-Up Impacts on Women's Empowerment, by Index Component*/	
	texdoc do	"${online_appendix_dofile_loc}/table_impacts_we_detail_fl1.do", replace
	
********************************************************************************
* This do-file computes and displays numbers used in the paper that do not directly
* appear in the tables or figures.
********************************************************************************	
 
	do	"${IE_Phone_paper_doAnl}/numbers_not_shown.do" 
 
 

