# RiverPlot for evolution of livestock across all rounds of data collection 

# Setup ------------------------------------------------------------------------
if(Sys.info()[["user"]] == "wb464819") project_file_path <- "C:/Users/wb614536/OneDrive - WBG/Documents/Reproducibility/20230905-afg-tup-phonesvy-v2/DataWork_IE_Phone_Paper_Review/Phone_Survey"
if(Sys.info()[["user"]] == "wb464819") output_file_path  <- "C:/Users/wb614536/Github/AFG-TUP/DataWork/TUP_Endline_working_version/Figures_appendix/"


library(tidyverse)
library(rgdal)
library(haven)
library(riverplot)
library(alluvial)
library(ggplot2)

TEXT_COLOR <- "black" # "white"
PLOT_BACKGROUND_COLOR <- "white" # "gray10"


#--------------------#
# Project subfolders #
#--------------------#
Data              <- file.path(project_file_path,"DataSets")

# Load and Collapse Data -------------------------------------------------------
data_t <- read_dta(file.path(Data, "Intermediate", "lstock_transition_graph_treatment.dta"))
data_c <- read_dta(file.path(Data, "Intermediate", "lstock_transition_graph_control.dta"))

#Transfer
data_t$Transfer <- factor(data_t$Transfer,
                        levels=c(0,1,2,3),
                        labels=c("< 0.5",
                                 "0.5-1",
                                 "1-1.5",
                                 "> 1.5"),
                        ordered=T)

data_c$Transfer <- factor(data_c$Transfer,
                          levels=c(0,1,2,3),
                          labels=c("< 0.5",
                                   "0.5-1",
                                   "1-1.5",
                                   "> 1.5"),
                          ordered=T)

#Midline
data_t$Midline <- factor(data_t$Midline,
                        levels=c(0,1,2,3),
                       labels=c("< 0.5",
                                "0.5-1",
                                "1-1.5",
                                "> 1.5"),
                        ordered=T)

data_c$Midline <- factor(data_c$Midline,
                         levels=c(0,1,2,3),
                         labels=c("< 0.5",
                                  "0.5-1",
                                  "1-1.5",
                                  "> 1.5"),
                         ordered=T)

#Endline
data_t$Endline <- factor(data_t$Endline,
                        levels=c(0,1,2,3),
                       labels=c("< 0.5",
                                "0.5-1",
                                "1-1.5",
                                "> 1.5"),
                        ordered=T)

data_c$Endline <- factor(data_c$Endline,
                         levels=c(0,1,2,3),
                         labels=c("< 0.5",
                                  "0.5-1",
                                  "1-1.5",
                                  "> 1.5"),
                         ordered=T)


########## Plotting and saving graphs 
# PNG device
png(file.path(output_file_path,"alluvial_treatment.png"),width = 4.5*480, height = 3.4*480,res=300,bg=PLOT_BACKGROUND_COLOR)
# PLot
alluvial(data_t[,1:3], freq=data_t$Freq, cex=0.7, axis_labels = c("Transfer", "Midline", "Endline"))
# Close device
dev.off()

#### Same for Control 
png(file.path(output_file_path,"alluvial_control.png"),width = 4.5*480, height = 3.4*480,res=300,bg=PLOT_BACKGROUND_COLOR)
 
alluvial(data_c[,1:3], freq=data_c$Freq, cex=0.7, axis_labels = c("Transfer", "Midline", "Endline"))

dev.off()






