/* ---------------------------------------------------------------------------
	
	AFGHANISTAN
	ALCS 2016-17
 
	Poverty Profile file
	
	Christina Wieser
	cwieser@worldbank.org
	
	Nandini Krishnan
	nkrishnan@worldbank.org

	Zihao (Tobias) Wang
	zwang5@worldbank.org
	
	This version: November 21, 2017

 -------------------------------------------------------------------------- */ 
 
 
//	Set environment

	version 13
	clear all
	set more off
	

//	Set working directories
	
	* CW's path
	global path07 "C:\Users\wb458837\OneDrive - WBG\Afghanistan\ALCS 2016\running three rounds\2007-08"
	global path11 "C:\Users\wb458837\OneDrive - WBG\Afghanistan\ALCS 2016\running three rounds\2011_12"
	global path16 "C:\Users\wb458837\OneDrive - WBG\Afghanistan\ALCS 2016"
	
	* NK's path
	*global path ""
		
	* TW's path
	*global path "D:\Afghanistan\ALCS 2016\ALCS 2016"
	
	//2016-17
	global input16		"$path16/data/Data 31.07.2017/clean"		/* inputdata  directory */
	global output16		"$path16/data_constructed"  				/* outputdata directory */
	global auxiliary16 	"$path16/data/Auxiliary files"				/* auxiliary files directory */

	//2011-12
	global input11 		"$path11/data_original"
	global output11		"$path11/data_constructed"  				/* outputdata directory */

	//2007-08
	global input07 		"$path07/data_original"
	global output07 		"$path07/data_constructed"  				/* outputdata directory */

//POVERTY PROFILE IN 2016-17

	******************
	** LABOR MARKET **
	******************
	
	use "$output16/temp_pov.dta", clear
	rename hhid hh_id
	merge 1:m hh_id using "$path16/data/Data 21.11.2017/Labour file - 171108 BdB.dta", keepusing(hh_id ind_id hh_weight ///
		ind_weight activity_status vuln_employ weekly_hours hh_size five_year ten_year major_year season decent q12_17_b ///
		q12_16_b q_3_3 q_3_4 q_3_5 q_3_6 q12_13)
	keep if _merge==3
	drop _merge
	rename hh_id hhid
	
	*Create employment status of HHH
	gen emp_hhh=activity_status if q_3_3==1 
	gen emp=(emp_hhh==1 | emp_hhh==2)
	gen under=(emp_hhh==2)
	gen unemp=(emp_hhh==3)
	gen inact=(emp_hhh==4)
	
	foreach i in emp under unemp inact {
		bys hhid: egen hhh_`i'=max(`i')
	}
	
	gen emp_=(activity_status==1 | activity_status==2)
	bys hhid: egen emp__=total(emp_)
	bys hhid: gen emp_one=(emp__>0) if emp__!=.
	drop emp_ emp__
	
	*Vulnerable employment
	bys hhid: egen vul_hh=min(vuln_employ)
	bys hhid: gen nvul_one=(vul_hh==0)
	bys hhid: egen vul_num=total(vuln_employ)
	bys hhid: gen vul_one=(vul_n>0)
	drop vul_hh vul_num
	
	*Industry of HHH
	gen ag=(q12_16_b==1) if q_3_3==1
	gen ind=(q12_16_b>=2 & q12_16_b<=5) if q_3_3==1
	gen serv=(q12_16_b>=6 & q12_16_b<=9) if q_3_3==1
	
	foreach i in ag ind serv {
		bys hhid: egen hhh_`i'=min(`i')
	}
	drop ag ind serv 
	
	gen sector=q12_16_b if q_3_3==1
	bys hhid: egen hhh_sector=min(sector)
	drop sector

	*Create sex
	gen sex=q_3_5 if q_3_3==1 
	bys hhid: egen hhh_sex=min(sex) 
	drop sex
	/*
	*Create q12_13
	gen dayl=(q12_13==1) if q_3_3==1
	gen salpr=(q12_13==2) if q_3_3==1
	gen salpu=(q12_13==3) if q_3_3==1
	gen selfwo=(q12_13==4) if q_3_3==1
	gen self=(q12_13==5) if q_3_3==1
	gen unpaid=(q12_13==6) if q_3_3==1
	
	gen hhh_status=1 if q12_13==1 & q_3_3==1
	replace hhh_status=2 if (q12_13==2 | q12_13==3)  & q_3_3==1
	replace hhh_status=3 if (q12_13==4 | q12_13==5) & q_3_3==1
	replace hhh_status=4 if q12_13==6 & q_3_3==1
	
	label define hhh_status 1 "Day labourer" 2 "Salaried worker" 3 "Self-employed" 4 "Unpaid family worker"
	label val hhh_status hhh_status
*/
	gen dayl=(q12_13==1) if q_3_3==1
	gen salary=(q12_13==2 | q12_13==3) if q_3_3==1
	gen self=(q12_13==4 | q12_13==5) if q_3_3==1
	gen unpaid=(q12_13==6) if q_3_3==1

	foreach i in dayl salary self unpaid {
		bys hhid: egen hhh_`i'=min(`i')
	}
	drop dayl salary self unpaid
	
	*Create labels
	label var emp_hhh 	"Activity status of HHH"
	label var hhh_emp 	"HHH is employed"
	label var hhh_under "HHH is underemployed"
	label var hhh_unemp "HHH is unemployed"
	label var hhh_inact "HHH is inactive"
	label var hhh_ag 	"HHH works in agricultural"
	label var hhh_ind 	"HHH works in industry"
	label var hhh_serv 	"HHH works in service sector"
	label var nvul_one 	"At least 1 HH member NOT in vulnerable employment"
	label var vul_one 	"At least 1 HH member in vulnerable employment"
	label var emp_one 	"At least 1 HH member employed"
	label var hhh_sex	"Sex of HHH (2=female)"
	label var hhh_dayl		"Work type: Day labourer"
	label var hhh_salary	"Work type: Salaried worker"
	label var hhh_self		"Work type: Self employed"
	label var hhh_unpaid	"Work type: Unpaid family worker"
	
	//produce tables
	keep hhid-ind_weight hhh_emp-hhh_unpaid
	duplicates drop
	tabstat hhh_* nvul_one vul_one emp_one [aw=hh_weight], by(poor)
	
	preserve 
		collapse (mean) hhh_* nvul_one vul_one emp_one [w=hh_weight] if poor~=., by(poor)  
    	export excel using "$output16/temp/poverty_profile_.xlsx", sheet("Employment") sheetmodify cell(A1) firstrow(variables) 
	restore
	
	povdeco pcexall_adj [aw=ind_weight] if hhh_emp==1, varpline(pline)		//employed
	
	********************************
	** HOUSEHOLD CHARACTERTISTICS **
	********************************
	use "$output16/temp_pov.dta", clear
	rename hhid hh_id
	merge 1:m hh_id using "$path16/data/Data 21.11.2017/HH and HoH variables - 171123 BdB.dta"
	keep if _merge==3
	drop _merge
	rename hh_id hhid
	
	gen hhh_edu=0 if HoH_educ==0
	replace hhh_edu=1 if HoH_educ==1 | HoH_educ==2 
	replace hhh_edu=2 if HoH_educ==3 
	replace hhh_edu=3 if HoH_educ==4 | HoH_educ==5
	
	label define hhh_edu 0 "No education" 1 "Completed primary education" 2 "Completed upper secondary education" 3 "Completed tertiary"
	label val hhh_edu hhh_edu

	****************
	** DEMOGRAPHY **
	****************
	
	use "$input16/M_03", clear
	merge m:1 hhid using "$input16/F_22.dta", keepusing(hh_size)
	drop _merge
	
    *Sex Ratio
	recode q3_5 (9=.) (1=0)
	recode q3_5 (2=1)
	label def q3_5 0 "male" 1 "female"
	label val q3_5 q3_5 
	
	bys hhid: egen sex=sum(q3_5) 
	gen sex_ratio=100*sex/hh_size
	label var sex_ratio "sex ratio: percentage of female present in household"
	drop sex 

	*Dependency ratio- under 15 or beyond 64 (align with NRVA 2011-12 poverty profile, page9) 
	recode q3_4 (99=.)					//is 99 missing?
	*Children and elderly in HH
	gen dep=q3_4<15 | q3_4>64 if q3_4!=.
	bys hhid: egen dep1=sum(dep) 
	*Productive age in HH
	gen prod=(q3_4>14 & q3_4<=64)
	bys hhid: egen prod1=sum(prod) 

	bys hhid: gen depcy_ratio=100*dep1/prod1
	label var depcy_ratio "Dependency ratio: dependents under 15 or above 64"
	drop dep1 dep prod
	
	*Child dependency ratio
	gen dep=(q3_4<15)
	bys hhid: egen dep1=sum(dep) 
	bys hhid: gen child2=100*dep1/prod1
	label var child "Child dependency ratio: Number of children aged 0-14 over the population in the most productive ages (15-64)"
	drop dep1 dep 
	
	*Elderly dependency ratio
	gen dep=q3_4>64 if q3_4!=.
    bys hhid: egen dep1=sum(dep) 
	bys hhid: gen aged=100*dep1/prod1
	label var aged "Elderly dependency ratio: Number of elderly aged 65 and above over the population in the most productive ages (15-64)"
	drop dep1 dep

	*Number of children under five 
	gen agefive=q3_4<5
    bysort hhid: egen age5=sum(agefive) 
	drop agefive
    label var age5 "# of children under age five"
	
    *Number of children under 14 
	gen age14_=q3_4<14
    bysort hhid: egen age14=sum(age14_) 
	drop age14_
	label var age14 "# of children under age fourteen"
	
	*Number of female members 
    gen female1=(q3_5==1)
	bysort hhid: egen female=sum(female1) 
	label var female "# of female HH members"
	
	*Average household size 
	merge m:1 hhid using "$input16/F_22.dta", keepusing(hh_size)
	drop _merge
	
	*Households with widows 
	gen widow=(q3_6==2 & q3_5==1)
	bys hhid: egen hh_widow_=total(widow)
	bys hhid: gen hh_widow=(hh_widow_>0)
	drop hh_widow_ widow

	*Households where the oldest working age member is a woman
	rename hhid hh_id
	merge 1:1 hh_id ind_id using "$path16/data/Data 21.11.2017/Labour file - 171108 BdB.dta"
	rename hh_id hhid
	drop _merge
	
	gen agemale_=q3_4 if q3_5==0 & (activity_status==1 | activity_status==2)
	gen agefemale_=q3_4 if q3_5==1 & (activity_status==1 | activity_status==2)
	
	bys hhid: egen agemale=max(agemale_)
	bys hhid: egen agefemale=max(agefemale_)
	
	bys hhid: gen workfemale=(agefemale>agemale)
	drop agemale_ agefemale_
	
	
	keep hhid Province_Code Province_Name District_Code Con_Area_Enum_Code cid hh_weight ind_weight ///
		sex_ratio depcy_ratio child aged age5 age14 female hh_size hh_widow agemale agefemale workfemale
	
	duplicates drop
	count

    label var female "# of female HH members"
	label var age14 "# of children under age fourteen"
	label var age5 "# of children under age five"
	label var aged "aged dependency ratio: dependents above 64"
	label var child "child dependency ratio: dependents under 15"
	label var hh_size "household size"
	label var sex_ratio "sex ratio"

	merge 1:1 hhid using "$output16/temp_pov.dta"
	keep if _merge==3
	drop _merge
	
	*Child dependency ratio categories
	gen cdep=1 if child<100
	replace cdep=2 if child>=100 & child<200
	replace cdep=3 if child>=200 & child<300
	replace cdep=4 if child>=300 & child!=.
	
	mean poor [aw=ind_weight], over(cdep)

	*Dependency ratio categories
	gen dep=1 if depcy_ratio<100
	replace dep=2 if depcy_ratio>=100 & depcy_ratio<200
	replace dep=3 if depcy_ratio>=200 & depcy_ratio<300
	replace dep=4 if depcy_ratio>=300 & depcy_ratio!=.
	
	mean poor [aw=ind_weight], over(dep)

	tabstat sex_ratio age5 age14 depcy_ratio child aged female hh_size [w=hh_weight], by(poor)

	preserve 
		collapse (mean) sex_ratio age5 age14 depcy_ratio child aged female hh_size [w=hh_weight], by(poor)  
    	export excel using "$output16/temp/poverty_profile_.xlsx", sheet("Demographic") sheetmodify cell(A1) firstrow(variables) 
	restore

	************************************************************************
    ** Household head characteristics: age, education, sex, literacy rate ** 
    ************************************************************************

    use "$input16/M_03", clear
    merge 1:1 ind_id using "$input16/M_12"
	drop _merge
	
	/*
	    Result                           # of obs.
    -----------------------------------------
    not matched                        33,219
        from master                    33,219  (_merge==1)
        from using                          0  (_merge==2)

    matched                           122,465  (_merge==3)
    -----------------------------------------*/

    keep if  q3_3==1   
	keep hhid ind_id hh_weight ind_weight q3_4 q3_5 q11_2 q11_7 
	recode q11_2 (9=.) 
	recode q11_7 (9=.) 
	
	*Literacy rate and illiteracy rate 
	tab q11_2, gen(lit_) 
	rename lit_1 literate
	rename lit_2 illiterate 

    *Education 
	tab q11_7, gen(edu_) 
	gen hhh_prim=(q11_7==1)
	gen hhh_lsec=(q11_7==2)
	gen hhh_usec=(q11_7==3)
	gen hhh_ter=(q11_7==4 | q11_7==5 | q11_7==6)
	gen hhh_noedu=(q11_7==.)

    *Sex 
	tab q3_5, gen(sex_) 
	rename sex_1 male 
	rename sex_2 female 

	//LABEL
	label var literate 		"HHH is literate"
	label var illiterate 	"HHH is illiterate"
	label var hhh_prim 		"HHH attended Primary School (Grade 1-6)"
	label var hhh_lsec		"HHH attended Lower Secondary (Grade 7-9)"
	label var hhh_usec		"HHH attended Upper secondary (Grade 10-12)"
	label var hhh_ter		"HHH attended Tertiary (Teacher college, university, post graduate"
	label var hhh_noedu 	"No formal education"
	label var male			"HHH is male"
	label var female		"HHH is female"
	
	merge 1:1 hhid using "$output16/temp_pov.dta"
	keep if _merge==3
	drop _merge
	
	tabstat literate illiterate hhh_prim hhh_lsec hhh_usec hhh_ter hhh_noedu male female [w=hh_weight], by(poor)

	preserve 
		collapse (mean) literate illiterate hhh_prim hhh_lsec hhh_usec hhh_ter hhh_noedu male female [w=hh_weight], by(poor)  
    	export excel using "$output16/temp/poverty_profile_.xlsx", sheet("HH head") sheetmodify cell(A1) firstrow(variables) 
    restore 

	********************
    ** Household size ** 
    ********************
	use "$output16/temp_pov.dta", clear
	
	gen hhs=1 if hh_size>=1 & hh_size<=5
	replace hhs=2 if hh_size>=6 & hh_size<=7
	replace hhs=3 if hh_size>=8 & hh_size<=9
	replace hhs=4 if hh_size>=10 & hh_size<=12
	replace hhs=5 if hh_size>12
	
	label define lhhs 1 "1-5 members" 2 "6-7 members" 3 "8-9 members" 4 "10-12 members" 5 "13 or more members"
	label val hhs lhhs
	label var hhs "Categories of HH size"

	mean poor [aw=ind_weight], over(hhs)
	tab hhs [fw=ind_weight]
	tab hhs poor [fw=ind_weight]

	
	********************
    ** Income sources ** 
    ********************
	
	use "$input16/M_09.dta", clear
	merge 1:1 hhid using "$output16/temp_pov.dta"
	keep if _merge==3
	drop _merge
	
	gen income=.
	replace income=1 if q8_1>=1 & q8_1<=5
	replace income=2 if q8_1==6 | q8_1==7
	replace income=3 if q8_1>=11 & q8_1<=17
	replace income=4 if q8_1==21 | q8_1==22 | q8_1==25 | q8_1==26 | q8_1==27 | q8_1==30
	replace income=5 if q8_1==28 
	replace income=6 if q8_1==23 | q8_1==24 | q8_1==29
	replace income=7 if q8_1>=41 & q8_1<=43
	replace income=8 if q8_1==51 | q8_1==52
	replace income=9 if q8_1==62 | q8_1==65
	replace income=10 if q8_1==61 | q8_1==63 | q8_1==64 | q8_1==66 | q8_1==67
	
	label define income 1 "Agriculutre" 2 "Livestock" 3 "Production & manufacturing" ///
		4 "Health, Eduction, general government services" 5 "Transport" 6 "Security-related" ///
		7 "Trade" 8 "Other labor" 9 "Other income" 10 "Vulnerable income/transfers"
	label val income income
	
	gen income2=.
	replace income2=1 if q8_1>=1 & q8_1<=5
	replace income2=2 if q8_1==6 | q8_1==7
	replace income2=3 if q8_1>=11 & q8_1<=17
	replace income2=4 if q8_1==21 | q8_1==22 | q8_1==25 | q8_1==26 | q8_1==27 | q8_1==30
	replace income2=5 if q8_1==28 
	replace income2=6 if q8_1==23 | q8_1==24 | q8_1==29
	replace income2=7 if q8_1>=41 & q8_1<=43
	replace income2=8 if q8_1==51 | q8_1==52
	replace income2=9 if q8_1==62 | q8_1==65
	replace income2=10 if q8_1==61 | q8_1==64 | q8_1==66 | q8_1==67
	replace income2=11 if q8_1==63
	
	label define income2 1 "Agriculutre" 2 "Livestock" 3 "Production & manufacturing" ///
		4 "Health, Eduction, general government services" 5 "Transport" 6 "Security-related" ///
		7 "Trade" 8 "Other labor" 9 "Other income" 10 "Vulnerable income/transfers" 11 "Remittances"
	label val income2 income2

	mean poor [aw=ind_weight], over(income)
	
	replace income= if q8_1== | q8_1==
	replace income= if q8_1== | q8_1==
	
	****************
    ** Inequality ** 
    ****************

/*	ginidesc
	egen_inequal
	ineqdeco
	
