/*-----------------------------------------------------------------------------
Date: October 18 , 2017                                                                
Revised:                                                                            
Title: WFPALCS                                                                    
Purpose: create caloric table dataset based on information in the WFP table
Author:  Germiniasi, Andrea                                                             
Contact: a.germiniasi@gmail.com                                                                               |
-----------------------------------------------------------------------------*/

* Import the codes correspondance between ALCS and WFP
import excel "$auxiliary\table_calories_codes_match.xlsx", sheet("tabcal_codes") cellrange("A1:D100") firstrow clear 
rename item_2008 item
sort item_tabcal
tempfile code_match
save `code_match'	

** Prepare WFP's food composition table
** Information received from WFP on October 19 with corrections on October 20
import excel "$auxiliary\ALCS 2016_2017 Food composition (Kcal composition)-20171020.xls", sheet("ALCS 2016_17 updated in Oct2017") cellrange("A3:F94") clear 

rename A item_tabcal
rename B item_n
rename C kcalppiece
rename D kcal100g
rename E kcaledible
rename F kcalskg

merge 1:m item_tabcal using `code_match'  // 1:m as two types of rice are associated to same item_tabcal
* _merge = 1 broccoli
* _merge = 2 items in ALCS16 without caloric content info (e.g. nuts with shell)
replace _merge = 3 if item == 205 // wheat farm gate
keep if  _merge == 3  
drop _merge
br

replace kcaledible = "" if kcaledible == "Sheeled (Edible portion)/100gr"
destring kcaledible, replace

*Wheat flour farm gate
su kcalskg if item == 2  // wheat
replace kcalskg = r(mean) if item == 205
replace kcal100g = kcalskg/10 if item == 205
replace item_n = "WheatFlour_local_farm_gate" if item == 205

*For nuts, ensure to use unshelled valoric content (nuts without shells)
replace kcal100g = kcaledible if inlist(item,74,75,76)
replace kcalskg = kcal100g*10 if inlist(item,74,75,76)
replace item_n = "Walnuts (without shells)" if item == 74
replace item_n = "Pistachio (without shells)" if item == 75
replace item_n ="Almonds (without shell)" if item == 76

drop descr item_tabcal item_2016 kcalppiece
order item item_n
sort item

do "$do\labels.do" 
label val item item
br

saveold "$output\nutrients_16-17.dta", replace
