
/*--------------------------------------------------------------------------------------------------------------------------\
| Date:    	29th Aug 2017                                                                                                   |
| Revised: 	4th Oct 2017                                                                                                   	|
| Title:   	cons.do                                                                                                         |
| Purpose: 	1) Prepare food consumption aggregate using imputed prices.                    				     				|
|	  		2) Create a consumption aggregate                                                                               |
| Author:  Christina Wieser (based on 2011-12 do files)                                                                     | 
| Contact: cwieser@worldbank.org                                                                       						|
\---------------------------------------------------------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------------------
Sensitivity Tests: 
B. Test 5 line 289, ALCS note 8.1.2 
-----------------------------------------------------------------------------------------*/

clear
capture log close
set type double, perm
set more off
version 13

/*	N.B.: 	
	Module No. changed, in accordance with the 2011-12 NRVA questionnaire. 
	a. H_01 H_02 (16-17 ALCS) to M_01_02 (11-12 NRVA) 
	b. H_03 (16-17 ALCS) to M_03 (11-12 NRVA) 
	c. H_04 (16-17 ALCS) to M_04 (11-12 NRVA) 
	d. H_05 (16-17 ALCS) to M_05 (11-12 NRVA)
	e. H_06 (16-17 ALCS) to M_06 (11-12 NRVA) 
	f. H_07 (16-17 ALCS) to M_07a M_07b M_07c (11-12 NRVA) 
	g. H_08 (16-17 ALCS) to M_09 (11-12 NRVA) 
	h. H_09 (16-17 ALCS) to M_10 (11-12 NRVA)
	i. H_10 (16-17 ALCS) to M_13 (11-12 NRVA)
	j. H_11 (16-17 ALCS) to M_12 (11-12 NRVA)
	k. H_12 (16-17 ALCS) to M_08 (11-12 NRVA)
	l. H_13 (16-17 ALCS) to M_11 (11-12 NRVA)
	m. H_21 (16-17 ALCS) to F_21 (11-12 NRVA) 
	n. H_22 (16-17 ALCS) to F_22 (11-12 NRVA) 
	o. H_23 (16-17 ALCS) to F_23 (11-12 NRVA)
	p. H_25 (16-17 ALCS) to F_24 (11-12 NRVA)
*/

**********************************************************************************************
**PART I: PREPARE THE SHURA DATA FOR IDENTIFYING MARKETS THAT HOUSEHOLDS IN A CLUSTER ACCESS**
**********************************************************************************************

**I.A.THE CID CODES HAVE ERRORS WHICH NEED TO BE FIXED IN BOTH THE HHOLD FILES AND THE SHURA FILES. 
use "$input\M_1_2.dta", clear 
rename q1_5 urruku
bys cid: egen c_hh=count(hhid)
bys cid Province_Code urruku : egen c_hh2=count(hhid)
gen double cid2=cid
la var cid2 "Corrected Cluster IDs"
rename q2_5_b int_month_s
rename q2_5_c int_year_s
keep hhid cid2 cid Province_Code District_Code hhid int_month_s int_year_s hh_weight ind_weight
replace District_Code = Province_Code*100 + District_Code 
********************************************************************************
*ATTENTION
*TEMPORARY FIXES

* Replace District_Code 808 with adjacent one (808 is n/a in mapping 07-12)
//CW: replace District_Code = 807 if District_Code == 808
********************************************************************************
tempfile hhmain
saveold `hhmain', replace

use "$input\SM_1_2.dta", clear
//SM_1&2 is at cluster level  
destring(cid), replace
bys cid : gen dup = cond(_N==1,0,_n)
gen double cid2=cid 
rename m3_a_7 Q_3_7
rename m3_a_8 Q_3_8
keep Province_Code District_Code Con_Area_Enum_Code cid cid2 urruku Q_3_7 Q_3_8 Q_3_9_District Q_3_9_District_Office_Code Q_3_9_Province Q_3_9_Province_Office_Code //TE: no variable urru and not used after so deleted
replace District_Code = Province_Code*100 + District_Code 
tempfile market
saveold `market', replace

**I.B.CREATE PROVINCE CENTER CODES
use "$output\district_code_12.dta", clear
by Province_Code, sort: gen j=_n
keep if j==1
rename District_Code prov_center_district_code
la var prov_center_district_code "District Code of Province Center"
drop j
ren Province_Code Province_Code
tempfile province
saveold `province', replace

**I.C.CLEAN MARKET LOCATIONS; MERGE HHOLD AND SHURA FILES WITH MARKET LOCATION
use `market', clear
merge m:1 Province_Code using `province'
numlabel, add
drop _merge
*MKT LOCATION CODE CREATED BECAUSE THE MARKET CODES NEED TO BE COMBINED WITH THE PROVINCE CODES TO CREATE CODES MATCHING NRVA DISTRICT CODES
gen dist_mkt_code2=(Q_3_9_Province_Office_Code*100)+Q_3_9_District_Office_Code
gen mkt_loc_district_code=District_Code                  if Q_3_8==1 
replace mkt_loc_district_code=prov_center_district_code  if Q_3_8==4
replace mkt_loc_district_code=dist_mkt_code2             if Q_3_8==2 | Q_3_8==3
replace mkt_loc_district_code= District_Code if Q_3_8==.
ren cid cid_shura 
keep cid2 cid_shura mkt_loc_district_code
merge 1:m cid2 using `hhmain'
drop if _merge==1
drop _merge
replace mkt_loc_district_code=District_Code if mkt_loc_district_code==.
la var mkt_loc_district_code "District-Location of market accessed by hhold"

//Price market dataset uses Gregorian calendar, food consumption uses Shamsi calendar
//Convert from int_month_s to int_month_g
gen int_year_g=.
replace int_year_g=16 if int_year_s==95
replace int_year_g=17 if int_year_s==96

gen int_month_g = .
replace int_month_g = 1  if int_month_s==11 & int_year_s==95
replace int_year_g=17 if int_month_s==11 & int_year_s==95
replace int_month_g = 2  if int_month_s==12 & int_year_s==95
replace int_year_g=17 if int_month_s==12 & int_year_s==95
replace int_month_g = 3  if int_month_s==1 & int_year_s==95
replace int_month_g = 4  if int_month_s==2 & int_year_s==95
replace int_month_g = 5  if int_month_s==3 & int_year_s==95
replace int_month_g = 6  if int_month_s==4 & int_year_s==95
replace int_month_g = 7  if int_month_s==5 & int_year_s==95
replace int_month_g = 8  if int_month_s==6 & int_year_s==95
replace int_month_g = 9  if int_month_s==7 & int_year_s==95
replace int_month_g = 10  if int_month_s==8 & int_year_s==95
replace int_month_g = 11 if int_month_s==9 & int_year_s==95
replace int_month_g = 12 if int_month_s==10 & int_year_s==95

replace int_month_g = 3  if int_month_s==1 & int_year_s==96
*Price survey was not conducted until April 2016. Therefore, change dates of households 
*interviewed in March 2016 to April 2016. 
replace int_month_g=4 if int_month_g==3 & int_year_g==16
compress
tempfile master
saveold `master', replace	

erase `hhmain'
erase `market'
erase `province'
use "$output\imp_dps.dta", clear							
replace District_Code = 2718  if District_Code == 2716
replace District_Code = 3014 if District_Code == 3013
capture ren District_Code mkt_loc_district_code
drop Province_Name
tempfile imp_dps
saveold `imp_dps', version(13)	


***********************************************
**PART II: PREPARE FOOD CONSUMPTION AGGREGATE**
***********************************************
use "$input\F_23.dta", clear
keep hhid q23_1 q23_2 q23_3 q23_7_* q23_8_* q23_9_*
reshape long q23_7_ q23_8_ q23_9_, i(hhid) j(item_n) string

gen item=.
replace item=0 if item_n=="Rice_High_Quality"
replace item=1 if item_n=="Rice_Low_Quality"
replace item=2 if item_n=="Wheat_Flour"
replace item=3 if item_n=="Purchased_Nan"
replace item=4 if item_n=="Barley"
replace item=5 if item_n=="Maize"
replace item=6 if item_n=="Beans"
replace item=7 if item_n=="Mung"
replace item=8 if item_n=="Chick_Peas"
replace item=9 if item_n=="Lentils"
replace item=10 if item_n=="Pasta"
replace item=11 if item_n=="Other_Bread"
replace item=12 if item_n=="Beef"
replace item=13 if item_n=="Veal"
replace item=14 if item_n=="Mutton"
replace item=15 if item_n=="Goat"
replace item=16 if item_n=="Chicken"
replace item=17 if item_n=="Liver"
replace item=18 if item_n=="Dried_Meat"
replace item=19 if item_n=="Fish"
replace item=20 if item_n=="Other_Meat"	
replace item=21 if item_n=="Milk_Fresh"
replace item=22 if item_n=="Milk_Powdered"
replace item=23 if item_n=="Yogurt"
replace item=24 if item_n=="Curd"
replace item=25 if item_n=="Krut"
replace item=26 if item_n=="Dogh"
replace item=27 if item_n=="Ghee"
replace item=28 if item_n=="Butter"
replace item=29 if item_n=="Cheese"
replace item=30 if item_n=="Eggs"
replace item=31 if item_n=="Other_Dairy"
replace item=32 if item_n=="Vegetable_Oil"
replace item=33 if item_n=="Animal_Fat"
replace item=34 if item_n=="Other_Oils"
replace item=35 if item_n=="Potato"
replace item=36 if item_n=="Sweet_Potato"
replace item=37 if item_n=="Onion"
replace item=38 if item_n=="Tomato"
replace item=39 if item_n=="Okra"
replace item=40 if item_n=="Spinach"
replace item=41 if item_n=="Cauliflower"
replace item=42 if item_n=="Eggplant"
replace item=43 if item_n=="Carrots"
replace item=44 if item_n=="Pumpkin"
replace item=45 if item_n=="Cucumber"
replace item=46 if item_n=="Radish"
replace item=47 if item_n=="Turnip"
replace item=48 if item_n=="Cabbage"
replace item=49 if item_n=="Leek"
replace item=50 if item_n=="Baracoli"			//missing in labels.do
replace item=51 if item_n=="Hot_Pepper"
replace item=52 if item_n=="Wild_Leafy"
replace item=53 if item_n=="Coriander"
replace item=54 if item_n=="Mint"
replace item=55 if item_n=="Dried_Tomatoes"
replace item=56 if item_n=="Dried_Vegetables"
replace item=57 if item_n=="Pickled_Vegetables"
replace item=58 if item_n=="Green_Beans"
replace item=59 if item_n=="Other_Vegetables"
replace item=60 if item_n=="Apple"
replace item=61 if item_n=="Grapes"
replace item=62 if item_n=="Melon"
replace item=63 if item_n=="Peach"
replace item=64 if item_n=="Dried_Apricots"
replace item=65 if item_n=="Orange"
replace item=66 if item_n=="Pomegranate"
replace item=67 if item_n=="Plum"
replace item=68 if item_n=="Pear"
replace item=69 if item_n=="Banana"
replace item=70 if item_n=="Raisins"
replace item=71 if item_n=="Fresh_Mulberries"
replace item=72 if item_n=="Dried_Mulberries"
replace item=73 if item_n=="Mangoes"
replace item=74 if item_n=="Walnuts"
replace item=75 if item_n=="Pistachio"
replace item=76 if item_n=="Almonds"
replace item=77 if item_n=="Other_Fruit"		
replace item=78 if item_n=="White_Sugar"
replace item=79 if item_n=="Brown_Sugar"
replace item=80 if item_n=="Honey"
replace item=81 if item_n=="Chocolates"
replace item=82 if item_n=="Black_Tea"
replace item=83 if item_n=="Green_Tea"
replace item=84 if item_n=="Bottled"
replace item=85 if item_n=="Other_Beverages"	
replace item=86 if item_n=="Salt"
replace item=87 if item_n=="Black_Pepper"
replace item=88 if item_n=="Ginger_Garlic"
replace item=89 if item_n=="Tomato_Sauce"
replace item=90 if item_n=="Mixed_Spices"
replace item=91 if item_n=="Other_Spices"		
replace item=201 if item_n=="Fresh_Apricots"

foreach i in 7 8 9 {
	cap rename q23_`i'_ q23_`i'
}
recode q23_8 (9=.)
label define source 1 "Purchase" 2 "Own production" 3 "Bartered/payment in kind" 4 "Borrowed/taken on credit" 5 "Received as gift" 6 "Food aid" 
label val q23_8 source

*Currently, we are using local wheat flour prices for all sources of flour. the price data includes "farm gate" prices
*and a decision was taken to use farm gate prices for all quantities that were of the source "own production"
*item number fo farm gate wheat is 205 "Wheat_local_farm_gate"
replace item=205 if item==2 & q23_8==2
replace item_n="Wheat_local_farm_gate" if item==205

recode q23_9 (.a=.)
bys hhid: egen foodmis=total(q23_9)
preserve
	keep hhid q23_9 foodmis
	duplicates drop
	*5 households have all missing food items -- hhid: 020102007020503; 130107033077004; 280103014049005; 300236173101106; 310420089085605
restore
drop if foodmis==0
drop foodmis

preserve
	use "$raw\weight file.dta", clear
	rename hh_id hhid
	tempfile weights
	saveold `weights', version(13)
restore
merge m:1 hhid using `weights', keepusing(hh_weight ind_weight)
*tabstat q23_9 [aw=hh_weight], by(item_n) stat(mean p50 sd p10 p90 p99)
drop _merge
label var q23_9 "Amount used in last 7 days"
label var q23_8 "Source of item"
label var q23_7 "No. of days item was eaten"
label var item "Item code"
label var item_n "Item name"

compress

**ADJUST MEASUREMENT UNITS (convert everything in KG)
*ITEMS MEASURED IN GRAMS: black tea (82), green tea (83), black pepper (87), ginger and garlic (88), tomato sauce (89), mixed spices (90), other spices (91)
replace q23_9=q23_9/1000 if (item==82|item==83|item==87|item==88|item==89|item==90|item==91)

*ITEMS MEASURED IN PIECES/NUMBER: Purchased nan (3), Eggs (30), cauliflower (41), banana (69) - edible portion only
* one piece of nan 200g
replace q23_9=q23_9*0.2 if item==3
* average sized egg 59g
replace q23_9=q23_9*0.059 if item==30
* average size cauliflower 750g
replace q23_9=q23_9*0.75 if item==41
* average-sized banana weighs 83 grams
replace q23_9=q23_9*0.083 if item==69
* average size mango 215g 
replace q23_9=q23_9*0.215 if item == 73

**VISUALLY INSPECT DENSITY PLOTS OF QUANTITIES (KG) per capita (hh_size)
merge m:1 hhid using "$output/core.dta"
assert _merge==3				
drop _merge
merge m:1 hhid using "$input/F_22.dta", keepusing(hh_size)
assert _merge==3				
drop _merge

gen cons_pc=q23_9/hh_size if !mi(q23_9)
label var cons_pc "Quantities consumed per capita"

saveold "$output\junk_food.dta", replace

** Define and replace outliers
	do "$do\outlier_quant_2016.do"

use "$output/quant_out_top.dta", clear
cap drop lncons_pc district med_ea med_rd med_ud med_d med_rp med_up med_rn med_un med_n nr_ea nr_dur nr_d nr_p nr_n

*correct wrong entry
replace q23_9=. if q23_9>99.9 & item_n=="Animal_Fat" & item!=.
replace cons_pc=. if q23_9>99.9 & item_n=="Animal_Fat" & item!=.

*top-code for wheat and nan: top-code 99th percentile for wheat flour and nan (replace with r(99))
sum cons_pc if item==2, d
replace cons_pc=r(p99) if cons_pc>r(p99) & cons_pc!=. & item==2

sum cons_pc if item==205, d
replace cons_pc=r(p99) if cons_pc>r(p99) & cons_pc!=. & item==205

sum cons_pc if item==3, d
replace cons_pc=r(p99) if cons_pc>r(p99) & cons_pc!=. & item==3

cap drop _merge
merge m:1 hhid using `master'
assert _merge==3
drop _merge region

merge m:1 mkt_loc_district_code int_year_g int_month_g item using `imp_dps'
/*
    Result                           # of obs.
    -----------------------------------------
    not matched                       405,922
        from master                         0  (_merge==1)
        from using                    405,922  (_merge==2)

    matched                         1,825,096  (_merge==3)
    -----------------------------------------

Possible sources of mismatch:
1) Date mismatch but taken care of due to coding March 2016 households with April 2016
	
2) Item mismatch: The following items are included in the imp_dps file but not in the hh dataset
	item 200 "Dry_bread"
	item 202 "Walnuts_with_shells" 
	item 203 "Pistachio_with_shells"
	item 204 "Almonds_with_shells" 
	item 205 "Wheat_local_farm_gate"
	item 206 "Wheat_local_market"
	item 207 "Wheat_imported"
	Total of 36,218 observations
*/
save "$output/temp/regstratTEMP.dta", replace

use "$output/temp/regstratTEMP.dta", clear
*====================================================================================
*adding regstrat and quarter to the price data; create item 205 price filler for four regstrat-quarter pairs  
preserve 
	use "$output\core.dta" , clear
	gen mkt_loc_district_code=Province_Code*100+District_Code
	tempfile core
	saveold `core', replace 

	 use "$output/temp/regstratTEMP.dta" , clear 
	  keep if _merge==2
		drop _merge
		drop regstrat
		replace quarter2=1 if int_month_g>=4 & int_month_g<=7 & int_year_g==16 & quarter2==.
		replace quarter2=2 if int_month_g>=8 & int_month_g<=10 & int_year_g==16 & quarter2==.                                   
		replace quarter2=3 if (((int_month_g>=11 & int_month_g<=12 & int_year_g==16) | (int_month_g==1 & int_year_g==17))) & quarter2==.
		replace quarter2=4 if int_month_g>=2 & int_month_g<=4 & int_year_g==17 & quarter2==.
		keep Province_Code quarter2 item mkt_loc_district_code int_year_g int_month_g price District_Name region	
		merge m:m mkt_loc_district_code using `core', keepusing(regstrat)
		keep if _merge==3
		
		collapse (mean) price, by(item regstrat quarter2)
		keep if ((regstrat==4&quarter==3)|(regstrat==12&quarter==2)|(regstrat==1&quarter==4)|(regstrat==4&quarter==4))&item==205
		su if item==205 & regstrat==12, d 
		saveold "$output\temp\205_filler.dta", replace 
restore 
*====================================================================================

keep if _merge==3
drop _merge

gen exp = price*q23_9
label var exp "food expenditure"

sort hhid
compress
saveold  "$output\temp_longfoodexp", replace

***********************************************************************************************************************************
**PART III: CREATE CONSUMPTION AGGREGATE

** III. A: FOOD  CONSUMPTION 
**FRESH APRICOTS INCLUDED
use "$output\temp_longfoodexp", clear
collapse (sum) exp, by(hhid)
rename exp fex_all
label var fex_all "Food exp.-weekly: all items in 2016-17"
sort hhid
tempfile fex_all
saveold `fex_all', replace
	
** III. B: NON FOOD CONSUMPTION

use "$input\M_10.dta", clear

merge 1:1 hhid using "$input\M_04.dta", keepusing(q4_18_*)
drop _merge

merge 1:1 hhid using "$input\F_22.dta", keepusing(q22_15_*)
drop _merge
*N.B. In 2011-12, only expenditure on “cosmetics and beauty supplies” (Q22.10) and “personal grooming for women and girls (Q22.11) 
*but in 2016-17, they also added expenditure on “baby powder milk, “cerilac baby food”, and “diapers”. 

*EXPENDITURE ITEMS - LAST 30 DAYS (EXCLUDED ITEMS: FOOD CONSUMED AT HOME, MISCELLANEOUS EXPENSES)
egen nfx_mall = rsum(q9_03-q9_20 q22_15_a-q22_15_e)
label var nfx_mall "Non-food exp: 30-day items"
*N.B. In 2016-17, a new category “shoe polish” was included

*EXPENDITURE ITEMS - LAST YEAR (EXCLUDED ITEMS: HOUSE CONSTRUCTION AND REPAIRS, FINES OR DEPT PAYMENTS, WEDDING AND FUNERALS, HAJ, ANNUAL CELEBRATIONS AND CHARITABLE DONATIONS)
*SCHOOL UNIFORMS ARE INCLUDED IN NRVA 2007-08 BUT UNDER CHILDREN'S CLOTHING 
*EXPENDITURE ON HEALTH LEFT OUT - NO CORRESPONSIND QUESTIONS IN NRVA 07-08

egen nfx_yall = rsum(q9_23-q9_35)
label var nfx_yall "Non-food exp: 12-month items (excl health)"

*ENERGY EXPENDITURE
egen nfx_nrg = rsum(q4_18_*)
label var nfx_nrg "Energy exp: previous month"
*N.B. in 2011-12, there was an additional expenditure itme on charcoal, coal which is removed in 2016-17

*TOTAL NON-FOOD EXPENDITURE
gen nfx_all = nfx_yall/12 + nfx_mall + nfx_nrg
label var nfx_all "Total monthly non-food exp: all items (excl health)"

sort hhid 
merge 1:1 hhid using `fex_all'
keep if _merge==3
drop _merge

** III. C Total expenditure 
* ADD EXP ON FOOD AWAY FROM HOME TO TOTAL FOOD EXP 
gen zz = fex_all*4.2
egen fex_tot = rsum(zz q9_02)
label var fex_tot "Food exp monthly: all items incl food away from home"
drop zz

merge 1:1 hhid using "$output\temp_rent"
keep if _merge==3
drop _merge
sort hhid
merge 1:1 hhid using "$output\temp_durables"
keep if _merge==3
drop _merge

** HH level consumption variables are: food, durables, rent, non-food
**RENT AND DURABLE VARIABLES COMPARABLE TO 2007-08 USED
gen double hexnom_f = fex_tot
gen double hexnom_n = nfx_all
gen double hexnom_d = durables
gen double hexnom_r = rent_fin
egen double hexnom_t = rsum(hexnom*)
label var hexnom_f "HH monthly food cons-all items, nominal"
label var hexnom_n "HH monthly nonfood cons-all items (excl health), nominal"
label var hexnom_d "HH monthly durable cons, nominal"
label var hexnom_r "HH monthly rent, nominal"
label var hexnom_t "HH monthly total cons-all items, nominal"

drop q9_01-q22_15_e nfx_mall nfx_yall nfx_nrg nfx_all fex_all fex_tot rent_fin rent_fin_alt durables durables_comp

compress
saveold "$output\temp_aggcons", replace

***********************************************************************************************************************************
**PART IV: CREATE CALORIES PER DAY

use "$output\temp_longfoodexp", clear
  sort hhid
merge m:1 hhid using "$output\temp_aggcons"
  keep if _merge==3
  drop _merge
  drop if price==. 
drop Province_Name
merge m:1 hhid using "$output/cid.dta", keepusing(Province_Name hh_weight ind_weight)
  keep if _merge==3
  drop _merge
merge m:1 hhid using "$input/F_22.dta", keepusing(hh_size)
  keep if _merge==3				
  drop _merge

replace q23_9=0 if q23_9==.
replace cons_pc=0 if cons_pc==.

gen pcdq = cons_pc / 7
drop if inlist(item,11,20,31,34,59,77/*,82,83,84*/,85/*,86*/,91,201)
sort item

merge m:1 item using "$output\nutrients_16-17.dta", keepusing(kcalskg)
keep if _merge==3					//"other" food items are dropped
drop _merge

*keep Province_Name hhid item item_n hh_weight ind_weight pcdq effdq kcalskg
sort hhid

* calculate total kcal per capita per day
gen double kcalpcd=kcalskg*pcdq

collapse (sum) kcalpcd (first) Province_Name hh_weight ind_weight, by(hhid)
label val Province_Name province_name
label var kcalpcd "total kcal per capita per day "

/*--------------------------------End of do file--------------------------------*/
