
/*--------------------------------------------------------------------------------------\
| Date:    	Aug 15, 2017																|
| Project:  AFGHANISTAN ALCS 2016-17													|
| Title:   	coredata.do																	|
| Purpose: 	prepare core data 															|
| Author: 	Tobias Zihao Wang & Christina Wieser										|  
| Contact: 	zwang5@worldbank.org & cwieser@worldbank.org								|
\--------------------------------------------------------------------------------------*/


/* ---------------------------------------------------------------------------
 1. renaming raw datasets 
    ID&monitoring: M_1_2.dta
	Roster: M_03.dta
	Housing: M_04.dta
	Livestock: M_05.dta 
	Farming: M_06.dta 
	Household asset a: M_07a.dta
	Household asset b: M_07b.dta
	Household asset c: M_07c.dta
    Household income: M_09.dta  
    Household expenditure: M_10.dta 
    Shock, coping strategy: M_13.dta 
    Education: M_12.dta 
	Labor: M_08.dta 
    Migration: M_11.dta 
	Missing HH members: F_21.dta 
	General Living Conditions: F_22.dta 
	Food Consumption: F_23.dta 
	Maternal and Child Health: F_24.dta 
	Male Shure: SM_1_2.dta
 2. cleaning 
 3. core household data 
    3.1 region
	    3.1.1  building geographical regions 
		3.1.2  building STRATA 
	3.2 quarter 
	    3.2.1  season variable
		3.2.2  quarter
 
	N.B.: 
	
	H14.dta and H24.dta(disability) have no corresponding data in 11/12 NRVA 
	
	Module No. changed, in accordance with the 2011-12 NRVA questionnaire. 
	a. H_01 H_02 (16-17 ALCS) to M_01_02 (11-12 NRVA) 
	b. H_03 (16-17 ALCS) to M_03 (11-12 NRVA) 
	c. H_04 (16-17 ALCS) to M_04 (11-12 NRVA) 
	d. H_05 (16-17 ALCS) to M_05 (11-12 NRVA)
	e. H_06 (16-17 ALCS) to M_06 (11-12 NRVA) 
	f. H_07 (16-17 ALCS) to M_07a M_07b M_07c (11-12 NRVA) 
	g. H_08 (16-17 ALCS) to M_09 (11-12 NRVA) 
	h. H_09 (16-17 ALCS) to M_10 (11-12 NRVA)
	i. H_10 (16-17 ALCS) to M_13 (11-12 NRVA)
	j. H_11 (16-17 ALCS) to M_12 (11-12 NRVA)
	k. H_12 (16-17 ALCS) to M_08 (11-12 NRVA)
	l. H_13 (16-17 ALCS) to M_11 (11-12 NRVA)
	m. H_21 (16-17 ALCS) to F_21 (11-12 NRVA) 
	n. H_22 (16-17 ALCS) to F_22 (11-12 NRVA) 
	o. H_23 (16-17 ALCS) to F_23 (11-12 NRVA)
	p. H_25 (16-17 ALCS) to F_24 (11-12 NRVA)

	3.2.1: the variable "season" was available in the dummy data. It is not
	available in the data shared on July 31 2017. 
    
	3.2.2: the definition of "quarter" has been changed 
 -------------------------------------------------------------------------- */ 

	version 13
	clear all
	set more off
	set mem 150m
	set matsize 200
	capture log close
	set type double, perm

	*******************************************************************************
	*1 Renaming raw datasets and their variables in the same fashion as NRVA 11/12
	*******************************************************************************
	*To follow nomenclature of previous surveys, renaming i.e. “q_1_1” as "q1_1" and renaming identfier variables
	cap program drop name
	program name 
		foreach v of varlist q_* {
			 local V: subinstr local v "_" ""
			 rename `v' `V'
		}
		cap rename q1_1 Province_Code
		cap rename q1_2 District_Code
		cap rename q1_3 Con_Area_Enum_Code
		cap rename q1_4 cid
		cap rename q1_1a Province_Name
		cap rename q1_8 HH_No
		cap rename hh_id hhid
	end

	*ID&monitoring 
	use "$raw\H_01.dta" 
	name
	tempfile H_01
	saveold `H_01', version(13) 

	*Weights
	use "$raw\weight file.dta"
	rename hh_id hhid
	tempfile weights
	saveold `weights', version(13)

	use "$raw\H_02.dta"
	name
	merge 1:1 hhid using `H_01'
	keep if _merge==3
	drop _merge
	merge 1:1 hhid using `weights'
	keep if _merge==3
	drop _merge
	saveold "$input\M_1_2.dta", replace version(13)			

*roster 
use "$raw\H_03.dta", clear
merge m:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
drop _merge
name
saveold "$input\M_03.dta", replace version(13)

*housing, farming
foreach i in 4 6 {
	use "$raw\H_04-10.dta" 
	merge 1:1 hh_id using "$raw\weight file.dta"
	keep if _merge==3
	drop _merge
	keep q_`i'* hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8	
	name
	saveold "$input\M_0`i'.dta", replace version(13)
}

*livestock
use "$raw\H_04-10.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_5* q5* hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8		
name
saveold "$input\M_05.dta", replace version(13)

*household asset a
use "$raw\H_04-10.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
drop _merge
keep q_7_1_* q_7_2 hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
saveold "$input\M_07a.dta", replace version(13)

*household asset b
use "$raw\H_04-10.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_7_3_* q_7_4_* q_7_5_* hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
*organize format: the dataset is in a wide format and is not organized in a way that the reshpae command could be used 
stack hhid hh_weight ind_weight q7_3_01_a q7_3_01_b q7_4_01 q7_5_01  hhid hh_weight ind_weight q7_3_02_a q7_3_02_b q7_4_02 q7_5_02  hhid hh_weight ind_weight q7_3_03_a q7_3_03_b q7_4_03 q7_5_03  hhid hh_weight ind_weight q7_3_04_a q7_3_04_b q7_4_04 q7_5_04  hhid hh_weight ind_weight q7_3_05_a q7_3_05_b q7_4_05 q7_5_05  hhid hh_weight ind_weight q7_3_06_a q7_3_06_b q7_4_06 q7_5_06  hhid hh_weight ind_weight q7_3_07_a q7_3_07_b q7_4_07 q7_5_07  hhid hh_weight ind_weight q7_3_08_a q7_3_08_b q7_4_08 q7_5_08  hhid hh_weight ind_weight q7_3_09_a q7_3_09_b q7_4_09 q7_5_09  hhid hh_weight ind_weight q7_3_10_a q7_3_10_b q7_4_10 q7_5_10  hhid hh_weight ind_weight q7_3_11_a q7_3_11_b q7_4_11 q7_5_11  hhid hh_weight ind_weight q7_3_12_a q7_3_12_b q7_4_12 q7_5_12  hhid hh_weight ind_weight q7_3_13_a q7_3_13_b q7_4_13 q7_5_13  hhid hh_weight ind_weight q7_3_14_a q7_3_14_b q7_4_14 q7_5_14  hhid hh_weight ind_weight q7_3_15_a q7_3_15_b q7_4_15 q7_5_15  hhid hh_weight ind_weight q7_3_16_a q7_3_16_b q7_4_16 q7_5_16  hhid hh_weight ind_weight q7_3_17_a q7_3_17_b q7_4_17 q7_5_17  hhid hh_weight ind_weight q7_3_18_a q7_3_18_b q7_4_18 q7_5_18  hhid hh_weight ind_weight q7_3_19_a q7_3_19_b q7_4_19 q7_5_19  hhid hh_weight ind_weight q7_3_20_a q7_3_20_b q7_4_20 q7_5_20  hhid hh_weight ind_weight q7_3_21_a q7_3_21_b q7_4_21 q7_5_21  hhid hh_weight ind_weight q7_3_22_a q7_3_22_b q7_4_22 q7_5_22  hhid hh_weight ind_weight q7_3_23_a q7_3_23_b q7_4_23 q7_5_23  hhid hh_weight ind_weight q7_3_24_a q7_3_24_b q7_4_24 q7_5_24  hhid hh_weight ind_weight q7_3_25_a q7_3_25_b q7_4_25 q7_5_25  hhid hh_weight ind_weight q7_3_26_a q7_3_26_b q7_4_26 q7_5_26  hhid hh_weight ind_weight q7_3_27_a q7_3_27_b q7_4_27 q7_5_27  hhid hh_weight ind_weight q7_3_28_a q7_3_28_b q7_4_28 q7_5_28  hhid hh_weight ind_weight q7_3_29_a q7_3_29_b q7_4_29 q7_5_29  hhid hh_weight ind_weight q7_3_30_a q7_3_30_b q7_4_30 q7_5_30  hhid hh_weight ind_weight q7_3_31_a q7_3_31_b q7_4_31 q7_5_31  hhid hh_weight ind_weight q7_3_32_a q7_3_32_b q7_4_32 q7_5_32  hhid hh_weight ind_weight q7_3_33_a q7_3_33_b q7_4_33 q7_5_33  hhid hh_weight ind_weight q7_3_34_a q7_3_34_b q7_4_34 q7_5_34  hhid hh_weight ind_weight q7_3_35_a q7_3_35_b q7_4_35 q7_5_35  hhid hh_weight ind_weight q7_3_36_a q7_3_36_b q7_4_36 q7_5_36  hhid hh_weight ind_weight q7_3_37_a q7_3_37_b q7_4_37 q7_5_37  hhid hh_weight ind_weight q7_3_38_a q7_3_38_b q7_4_38 q7_5_38  hhid hh_weight ind_weight q7_3_39_a q7_3_39_b q7_4_39 q7_5_39  hhid hh_weight ind_weight q7_3_40_a q7_3_40_b q7_4_40 q7_5_40, into(hhid hh_weight ind_weight asset q7_3 q7_4 q7_5) clear
drop _stack 
*recoding missing values
label var q7_3 "Item bought in last 12 months"
label var q7_4 "Item price"
label var q7_5 "Current Item Value"
*recode the polar question q7_3 "Yes" 1 "No" 2 to "Yes" 1 "No" 0 and Missing value 9 to . 
recode q7_3 (2=0) (9=.)
*recode missing value .a to . 
foreach i in asset q7_4 q7_5 {
	recode `i' (.a=.)
}
label def asset 1 "a. refrigerator" 2 "b. Washing machine" 3 "c. Vacuum cleaner" 4 "d. Meat grinder" 5 "e. bread oven (dash)" 6 "f. Stove / gas balloon" 7 "g. Gas heater" 8 "h. Sewing machine" 9 "i. Iron" 10 "j. Electric fan (stand)" 11 "k. Radio, tape recorder" 12 "l. TV" 13 "m. VCR/DVD" 14 "n. Computer" 15 "o. Bicycle" 16 "p. Motorcycle" 17 "q. Car" 18 "r. tractor/thresher"
label val asset asset
label def q7_3 1 "Yes" 0 "No"
label val q7_3 q7_3
saveold "$input\M_07b.dta", replace version(13)

*household asset c
use "$raw\H_04-10.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_7_6_* q_7_7_* q_7_9 q_7_10 q_7_11 hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
*renaming variables comparable to NRVA 2007-08
rename q7_6_a Q_7_6_Mobile_Own 
rename q7_7_a Q_7_7_Mobile_Sold
rename q7_6_b Q_7_6_Carpets_Own 
rename q7_7_b Q_7_7_Carpets_Sold
rename q7_6_c Q_7_6_Gilim_Own 
rename q7_7_c Q_7_7_Gilim_Sold
rename q7_6_d Q_7_6_Blankets_Own
rename q7_7_d Q_7_7_Blankets_Sold
rename q7_6_e Q_7_6_Satellitedishes_Own
rename q7_7_e Q_7_7_SatelliteDishes_Sold
rename q7_6_f Q_7_6_SolarPanel_Own
rename q7_7_f Q_7_7_SolarPanel_Sold
rename q7_7_g Q_7_7_Kitchen_Utensils_Sold
saveold "$input\M_07c.dta", replace version(13)

*household income 
use "$raw\H_04-10.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_8_* hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
saveold "$input\M_09.dta", replace version(13)

*household expenditure 
use "$raw\H_04-10.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_9_* hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
saveold "$input\M_10.dta", replace version(13)

*shock, coping strategy
use "$raw\H_04-10.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_10_* q10_* hh_weight ind_weight hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
saveold "$input\M_13.dta", replace version(13)

*education 
use "$raw\H_11.dta", clear 
merge m:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
*3 observations deleted from using
drop _merge
name
saveold "$input\M_12.dta", replace version(13)

*labor 
use "$raw\H_12.dta", clear
merge m:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
*1 observation deleted from using
drop _merge
name
saveold "$input\M_08.dta", replace version(13)
 
*migration 
use "$raw\H_13.dta", clear 
merge m:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
drop _merge
name
saveold "$input\M_11.dta", replace version(13)

*Missing hh members  
use "$raw\H_21.dta", clear 
name
saveold "$input\F_21.dta", replace version(13)

*General Living Conditions 
use "$raw\H_22-23.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_22_* hh_weight ind_weight hh_size hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
saveold "$input\F_22.dta", replace version(13)

*Food Consumption  
use "$raw\H_22-23.dta", clear 
merge 1:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
keep q_23_* hh_weight ind_weight hh_size hh_id q_1_1 q_1_2 q_1_3 q_1_4 q_1_8
name
rename q23_7_a q23_7_Rice_High_Quality 
rename q23_8_a q23_8_Rice_High_Quality 
rename q23_9_a q23_9_Rice_High_Quality 
rename q23_7_b q23_7_Rice_Low_Quality
rename q23_8_b q23_8_Rice_Low_Quality 
rename q23_9_b q23_9_Rice_Low_Quality
rename q23_7_c q23_7_Wheat_Flour 
rename q23_8_c q23_8_Wheat_Flour 
rename q23_9_c q23_9_Wheat_Flour 
rename q23_7_d q23_7_Purchased_Nan
rename q23_8_d q23_8_Purchased_Nan 
rename q23_9_d q23_9_Purchased_Nan
rename q23_7_e q23_7_Barley 
rename q23_8_e q23_8_Barley 
rename q23_9_e q23_9_Barley 
rename q23_7_f q23_7_Maize 
rename q23_8_f q23_8_Maize  
rename q23_9_f q23_9_Maize 
rename q23_7_g q23_7_Beans  
rename q23_8_g q23_8_Beans  
rename q23_9_g q23_9_Beans  
rename q23_7_h q23_7_Mung   
rename q23_8_h q23_8_Mung  
rename q23_9_h q23_9_Mung   
rename q23_7_i q23_7_Chick_Peas   
rename q23_8_i q23_8_Chick_Peas 
rename q23_9_i q23_9_Chick_Peas 
rename q23_7_j q23_7_Lentils    
rename q23_8_j q23_8_Lentils 
rename q23_9_j q23_9_Lentils 
rename q23_7_k q23_7_Pasta     
rename q23_8_k q23_8_Pasta
rename q23_9_k q23_9_Pasta 
rename q23_7_l q23_7_Other_Bread      
rename q23_8_l q23_8_Other_Bread 
rename q23_9_l q23_9_Other_Bread 
rename q23_7_m q23_7_Beef      
rename q23_8_m q23_8_Beef 
rename q23_9_m q23_9_Beef 
rename q23_7_n q23_7_Mutton    
rename q23_8_n q23_8_Mutton 
rename q23_9_n q23_9_Mutton 
rename q23_7_o q23_7_Veal    
rename q23_8_o q23_8_Veal 
rename q23_9_o q23_9_Veal 
rename q23_7_p q23_7_Goat     
rename q23_8_p q23_8_Goat 
rename q23_9_p q23_9_Goat  
rename q23_7_q q23_7_Chicken      
rename q23_8_q q23_8_Chicken     
rename q23_9_q q23_9_Chicken    
rename q23_7_r q23_7_Liver  
rename q23_8_r q23_8_Liver    
rename q23_9_r q23_9_Liver
rename q23_7_s q23_7_Dried_Meat   
rename q23_8_s q23_8_Dried_Meat      
rename q23_9_s q23_9_Dried_Meat   
rename q23_7_t q23_7_Fish  
rename q23_8_t q23_8_Fish       
rename q23_9_t q23_9_Fish    
rename q23_7_u q23_7_Other_Meat   
rename q23_8_u q23_8_Other_Meat         
rename q23_9_u q23_9_Other_Meat 
rename q23_7_v q23_7_Milk_Fresh  
rename q23_8_v q23_8_Milk_Fresh         
rename q23_9_v q23_9_Milk_Fresh 
rename q23_7_w q23_7_Milk_Powdered  
rename q23_8_w q23_8_Milk_Powdered          
rename q23_9_w q23_9_Milk_Powdered  
rename q23_7_x q23_7_Yogurt   
rename q23_8_x q23_8_Yogurt           
rename q23_9_x q23_9_Yogurt 
rename q23_7_y q23_7_Curd    
rename q23_8_y q23_8_Curd           
rename q23_9_y q23_9_Curd 
rename q23_7_z q23_7_Krut    
rename q23_8_z q23_8_Krut           
rename q23_9_z q23_9_Krut
rename q23_7_aa q23_7_Dogh  
rename q23_8_aa q23_8_Dogh           
rename q23_9_aa q23_9_Dogh
rename q23_7_ab q23_7_Ghee  
rename q23_8_ab q23_8_Ghee           
rename q23_9_ab q23_9_Ghee
rename q23_7_ac q23_7_Butter  
rename q23_8_ac q23_8_Butter           
rename q23_9_ac q23_9_Butter
rename q23_7_ad q23_7_Cheese  
rename q23_8_ad q23_8_Cheese             
rename q23_9_ad q23_9_Cheese  
rename q23_7_ae q23_7_Eggs 
rename q23_8_ae q23_8_Eggs             
rename q23_9_ae q23_9_Eggs  
rename q23_7_af q23_7_Other_Dairy 
rename q23_8_af q23_8_Other_Dairy              
rename q23_9_af q23_9_Other_Dairy 
rename q23_7_ag q23_7_Vegetable_Oil  
rename q23_8_ag q23_8_Vegetable_Oil             
rename q23_9_ag q23_9_Vegetable_Oil  
rename q23_7_ah q23_7_Animal_Fat   
rename q23_8_ah q23_8_Animal_Fat            
rename q23_9_ah q23_9_Animal_Fat
rename q23_7_ai q23_7_Other_Oils 
rename q23_8_ai q23_8_Other_Oils           
rename q23_9_ai q23_9_Other_Oils
rename q23_7_aj q23_7_Potato  
rename q23_8_aj q23_8_Potato           
rename q23_9_aj q23_9_Potato
rename q23_7_ak q23_7_Sweet_Potato  
rename q23_8_ak q23_8_Sweet_Potato           
rename q23_9_ak q23_9_Sweet_Potato
rename q23_7_al q23_7_Onion   
rename q23_8_al q23_8_Onion           
rename q23_9_al q23_9_Onion
rename q23_7_am q23_7_Tomato  
rename q23_8_am q23_8_Tomato          
rename q23_9_am q23_9_Tomato
rename q23_7_an q23_7_Okra 
rename q23_8_an q23_8_Okra          
rename q23_9_an q23_9_Okra 
rename q23_7_ao q23_7_Spinach 
rename q23_8_ao q23_8_Spinach           
rename q23_9_ao q23_9_Spinach 
rename q23_7_ap q23_7_Cauliflower 
rename q23_8_ap q23_8_Cauliflower           
rename q23_9_ap q23_9_Cauliflower
rename q23_7_aq q23_7_Eggplant 
rename q23_8_aq q23_8_Eggplant           
rename q23_9_aq q23_9_Eggplant 
rename q23_7_ar q23_7_Carrots 
rename q23_8_ar q23_8_Carrots            
rename q23_9_ar q23_9_Carrots 
rename q23_7_as q23_7_Pumpkin 
rename q23_8_as q23_8_Pumpkin           
rename q23_9_as q23_9_Pumpkin
rename q23_7_at q23_7_Cucumber 
rename q23_8_at q23_8_Cucumber          
rename q23_9_at q23_9_Cucumber
rename q23_7_au q23_7_Radish 
rename q23_8_au q23_8_Radish          
rename q23_9_au q23_9_Radish 
rename q23_7_av q23_7_Turnip 
rename q23_8_av q23_8_Turnip         
rename q23_9_av q23_9_Turnip
rename q23_7_awa q23_7_Cabbage 
rename q23_8_awa q23_8_Cabbage        
rename q23_9_awa q23_9_Cabbage 
rename q23_7_aw q23_7_Leek 
rename q23_8_aw q23_8_Leek       
rename q23_9_aw q23_9_Leek 
rename q23_7_ax q23_7_Hot_Pepper 
rename q23_8_ax q23_8_Hot_Pepper      
rename q23_9_ax q23_9_Hot_Pepper
rename q23_7_ay q23_7_Wild_Leafy 
rename q23_8_ay q23_8_Wild_Leafy       
rename q23_9_ay q23_9_Wild_Leafy 
rename q23_7_az q23_7_Coriander 
rename q23_8_az q23_8_Coriander        
rename q23_9_az q23_9_Coriander 
rename q23_7_ba q23_7_Mint 
rename q23_8_ba q23_8_Mint        
rename q23_9_ba q23_9_Mint 
rename q23_7_bb q23_7_Dried_Tomatoes 
rename q23_8_bb q23_8_Dried_Tomatoes        
rename q23_9_bb q23_9_Dried_Tomatoes
rename q23_7_bc q23_7_Dried_Vegetables  
rename q23_8_bc q23_8_Dried_Vegetables       
rename q23_9_bc q23_9_Dried_Vegetables  
rename q23_7_bd q23_7_Pickled_Vegetables  
rename q23_8_bd q23_8_Pickled_Vegetables       
rename q23_9_bd q23_9_Pickled_Vegetables  
rename q23_7_be q23_7_Green_Beans   
rename q23_8_be q23_8_Green_Beans         
rename q23_9_be q23_9_Green_Beans   
rename q23_7_bf q23_7_Other_Vegetables   
rename q23_8_bf q23_8_Other_Vegetables           
rename q23_9_bf q23_9_Other_Vegetables    
rename q23_7_bg q23_7_Apple    
rename q23_8_bg q23_8_Apple           
rename q23_9_bg q23_9_Apple 
rename q23_7_bh q23_7_Grapes    
rename q23_8_bh q23_8_Grapes            
rename q23_9_bh q23_9_Grapes  
rename q23_7_bi q23_7_Melon    
rename q23_8_bi q23_8_Melon             
rename q23_9_bi q23_9_Melon  
rename q23_7_bj q23_7_Peach  
rename q23_8_bj q23_8_Peach             
rename q23_9_bj q23_9_Peach 
rename q23_7_bk q23_7_Fresh_Apricots 
rename q23_8_bk q23_8_Fresh_Apricots             
rename q23_9_bk q23_9_Fresh_Apricots  
rename q23_7_bl q23_7_Dried_Apricots 
rename q23_8_bl q23_8_Dried_Apricots            
rename q23_9_bl q23_9_Dried_Apricots  
rename q23_7_bm q23_7_Orange 
rename q23_8_bm q23_8_Orange             
rename q23_9_bm q23_9_Orange    
rename q23_7_bn q23_7_Plum
rename q23_8_bn q23_8_Plum            
rename q23_9_bn q23_9_Plum   
rename q23_7_bo q23_7_Pomegranate 
rename q23_8_bo q23_8_Pomegranate           
rename q23_9_bo q23_9_Pomegranate  
rename q23_7_bp q23_7_Pear 
rename q23_8_bp q23_8_Pear           
rename q23_9_bp q23_9_Pear
rename q23_7_bq q23_7_Banana  
rename q23_8_bq q23_8_Banana          
rename q23_9_bq q23_9_Banana
rename q23_7_br q23_7_Raisins  
rename q23_8_br q23_8_Raisins           
rename q23_9_br q23_9_Raisins 
rename q23_7_bs q23_7_Fresh_Mulberries  
rename q23_8_bs q23_8_Fresh_Mulberries           
rename q23_9_bs q23_9_Fresh_Mulberries
rename q23_7_bt q23_7_Dried_Mulberries  
rename q23_8_bt q23_8_Dried_Mulberries           
rename q23_9_bt q23_9_Dried_Mulberries
rename q23_7_bu q23_7_Mangoes 
rename q23_8_bu q23_8_Mangoes           
rename q23_9_bu q23_9_Mangoes
rename q23_7_bv q23_7_Walnuts 
rename q23_8_bv q23_8_Walnuts           
rename q23_9_bv q23_9_Walnuts
rename q23_7_bw q23_7_Pistachio 
rename q23_8_bw q23_8_Pistachio         
rename q23_9_bw q23_9_Pistachio 
rename q23_7_bx q23_7_Almonds 
rename q23_8_bx q23_8_Almonds          
rename q23_9_bx q23_9_Almonds 
rename q23_7_by q23_7_Other_Fruit 
rename q23_8_by q23_8_Other_Fruit           
rename q23_9_by q23_9_Other_Fruit 
rename q23_7_bz q23_7_White_Sugar 
rename q23_8_bz q23_8_White_Sugar           
rename q23_9_bz q23_9_White_Sugar
rename q23_7_ca q23_7_Brown_Sugar 
rename q23_8_ca q23_8_Brown_Sugar           
rename q23_9_ca q23_9_Brown_Sugar
rename q23_7_cb q23_7_Honey  
rename q23_8_cb q23_8_Honey             
rename q23_9_cb q23_9_Honey  
rename q23_7_cc q23_7_Chocolates  
rename q23_8_cc q23_8_Chocolates            
rename q23_9_cc q23_9_Chocolates
rename q23_7_cd q23_7_Black_Tea  
rename q23_8_cd q23_8_Black_Tea            
rename q23_9_cd q23_9_Black_Tea 
rename q23_7_ce q23_7_Green_Tea  
rename q23_8_ce q23_8_Green_Tea             
rename q23_9_ce q23_9_Green_Tea 
rename q23_7_cf q23_7_Bottled   
rename q23_8_cf q23_8_Bottled             
rename q23_9_cf q23_9_Bottled 
rename q23_7_cg q23_7_Other_Beverages   
rename q23_8_cg q23_8_Other_Beverages           
rename q23_9_cg q23_9_Other_Beverages 
rename q23_7_ch q23_7_Salt    
rename q23_8_ch q23_8_Salt           
rename q23_9_ch q23_9_Salt 
rename q23_7_ci q23_7_Black_Pepper     
rename q23_8_ci q23_8_Black_Pepper          
rename q23_9_ci q23_9_Black_Pepper
rename q23_7_cj q23_7_Ginger_Garlic 
rename q23_8_cj q23_8_Ginger_Garlic          
rename q23_9_cj q23_9_Ginger_Garlic
rename q23_7_ck q23_7_Tomato_Sauce 
rename q23_8_ck q23_8_Tomato_Sauce           
rename q23_9_ck q23_9_Tomato_Sauce 
rename q23_7_cl q23_7_Mixed_Spices
rename q23_8_cl q23_8_Mixed_Spices           
rename q23_9_cl q23_9_Mixed_Spices
rename q23_7_cm q23_7_Other_Spices
rename q23_8_cm q23_8_Other_Spices           
rename q23_9_cm q23_9_Other_Spices
saveold "$input\F_23.dta", replace version(13)

*Maternal and Child Health  
use "$raw\H_25.dta", clear 
merge m:1 hh_id using "$raw\weight file.dta"
keep if _merge==3
*1,503 observations deleted from using
drop _merge
name
saveold "$input\F_24.dta", replace version(13)

*Male Shura
use "$raw\Male shura.dta", clear
	rename q_1_1 Province_Code
	rename q_1_2 District_Code
	rename q_1_3 Con_Area_Enum_Code
	rename q_1_4 cid
	foreach v of varlist m_* {
		 local V: subinstr local v "_" ""
		 rename `v' `V'
	}
	rename m1_5 urruku
	rename m3_a_9_b1 Q_3_9_District 
	rename m3_a_9_b2 Q_3_9_District_Office_Code 
	rename m3_a_9_a1 Q_3_9_Province 
	rename m3_a_9_a2 Q_3_9_Province_Office_Code
saveold "$input\SM_1_2.dta", replace version(13)

*Market Price 
use "$raw\market price.dta", clear 
	rename q_1_1 Province_Code
	rename q_1_1a Province_Name
	rename q_1_2 District_Code
	rename q_1_3 Con_Area_Enum_Code
	rename q_1_4 cid
    rename p_2_1_a  int_day_g
    rename p_2_1_b  int_month_g
    rename p_2_1_c  int_year_g
    rename q_1_6    Nahi_Code
    rename q_1_7    Village_Code
	
	foreach v of varlist p_* {
		 local V: subinstr local v "_" ""
		 rename `v' `V'
	}
saveold "$input\Price.dta", replace version(13) 

***************************************************************************
*2 Cleaning
***************************************************************************
*2.1) building cid.dta which is identical to the combination of cid.dta and Core_household.dta in NRVA 2011-12 
use "$input\M_1_2.dta", clear
*code in 2011-12: keep hhid hh_weight ind_weight Cluster_Code District_Name Nahia_Code Nahia_Name Con_Area_Enum_Code Village_Code Village_Name GPS_Code
keep hhid hh_weight ind_weight cid District_Code q1_6 Con_Area_Enum_Code q1_7 Province_Code Province_Name hhid q2_5_a q2_5_b q2_5_c q1_5 /*hh_size season*/ 
sort hhid
rename q2_5_a int_day_s
rename q2_5_b int_month_s
rename q2_5_c int_year_s
rename q1_6 Nahia_Code
rename q1_7 Village_Code
saveold "$output\cid.dta", replace version(13)

***************************************************************************
*3 Core Household Data 
***************************************************************************
*3.1) Region 
*3.1.1) building geographical regions 
use "$output\cid.dta", clear 
gen str region =""
replace region = "Central" if Province_Name==1| Province_Name==2 |Province_Name==3 | Province_Name==4  | Province_Name==5 | Province_Name==8
replace region = "South" if Province_Name==13 | Province_Name==11 | Province_Name==12 | Province_Name==14
replace region = "East" if Province_Name==6 |Province_Name==15 | Province_Name==7 | Province_Name==16
replace region = "Northeast" if Province_Name==18 | Province_Name==17 | Province_Name==9 | Province_Name==19
replace region = "North" if Province_Name==20 | Province_Name==21 |Province_Name==22 | Province_Name==28 | Province_Name==29
replace region = "West" if Province_Name==31|Province_Name==32|Province_Name==33
replace region = "Southwest" if Province_Name==34 |Province_Name==30|Province_Name==27|Province_Name==26|Province_Name==25
replace region = "West-central" if Province_Name==23|Province_Name==10|Province_Name==24
count if region==""
la var region "8 geographical regions - STRING"
tab region 
/*         8 |
geographical |
   regions - |
      STRING |      Freq.     Percent        Cum.
-------------+-----------------------------------
     Central |      4,360       21.98       21.98
        East |      1,910        9.63       31.61
       North |      2,960       14.92       46.53
   Northeast |      2,490       12.55       59.08
       South |      2,009       10.13       69.21
   Southwest |      2,400       12.10       81.30
        West |      2,079       10.48       91.78
West-central |      1,630        8.22      100.00
-------------+-----------------------------------
       Total |     19,838      100.00*/
* NOTE: Province codes differ between NRVA 2007/08 and NRVA 2016/17
* generate old-province identifiers to brigde to the old province codes as in NRVA 2007/08
gen oldprovincec = .	
replace oldprovincec = 14 if Province_Name == 17		
replace oldprovincec = 23 if Province_Name == 31		
replace oldprovincec = 16 if Province_Name == 9		
replace oldprovincec = 19 if Province_Name == 21		
replace oldprovincec = 32 if Province_Name == 10		
replace oldprovincec = 34 if Province_Name == 24		
replace oldprovincec = 25 if Province_Name == 33		
replace oldprovincec = 22 if Province_Name == 29		
replace oldprovincec = 6 if Province_Name == 11		
replace oldprovincec = 31 if Province_Name == 23		
replace oldprovincec = 27 if Province_Name == 30	
replace oldprovincec = 24 if Province_Name == 32		
replace oldprovincec = 20 if Province_Name == 28		
replace oldprovincec = 1 if Province_Name == 1		
replace oldprovincec = 28 if Province_Name == 27		
replace oldprovincec = 2 if Province_Name == 2		
replace oldprovincec = 9 if Province_Name == 14		
replace oldprovincec = 11 if Province_Name == 15		
replace oldprovincec = 17 if Province_Name == 19		
replace oldprovincec = 12 if Province_Name == 7	
replace oldprovincec = 5 if Province_Name == 5		
replace oldprovincec = 10 if Province_Name == 6		
replace oldprovincec = 26 if Province_Name == 34		
replace oldprovincec = 13 if Province_Name == 16		
replace oldprovincec = 7 if Province_Name == 12		
replace oldprovincec = 8 if Province_Name == 13		
replace oldprovincec = 33 if Province_Name == 8		
replace oldprovincec = 3 if Province_Name == 3		
replace oldprovincec = 18 if Province_Name == 20		
replace oldprovincec = 21 if Province_Name == 22		
replace oldprovincec = 15 if Province_Name == 18		
replace oldprovincec = 30 if Province_Name == 25		
replace oldprovincec = 4 if Province_Name == 4
replace oldprovincec = 29 if Province_Name == 26		
la var oldprovincec "Province code as in NRVA 2007/08"

gen regionn = .
replace regionn = 1 if oldprovincec >=1 & oldprovincec <=5
replace regionn = 5 if oldprovincec >=6 & oldprovincec <=9
replace regionn = 2 if oldprovincec >=10 & oldprovincec <=13
replace regionn = 4 if oldprovincec >=14 & oldprovincec <=17
replace regionn = 3 if oldprovincec >=18 & oldprovincec <=22
replace regionn = 7 if oldprovincec >=23 & oldprovincec <=25
replace regionn = 6 if oldprovincec >=26 & oldprovincec <=30
replace regionn = 8 if oldprovincec >=31 & oldprovincec <=34
replace regionn = 1 if oldprovincec == 33
label def regionn 1 "Central" 5 "South" 2 "East" 4 "Northeast" 3 "North" 7 "West" 6 "Southwest" 8 "WestCentral"
label val regionn regionn
label var regionn "8 geographical regions - NUMERIC"

*3.1.2) building STRATA 
rename q1_5 urruku
gen urru = 1 if urruku==1
replace urru = 2 if urru==.
la var urru "Urban, Rural (if Kuchi => rural)"
sort region urru
* NOTE: 14 REGION-STRATA CONSTRUCTED TO MATCH NRVA 2007/08, WHICH HAS 14 geo regions. 
* SOUTH-urban and Wcent-Urban are replaced with South-rural and Wcent-rural, respectively.
egen regstrat0 = group(region urru)
label def regstrat0 1 "Central-U" 2 "Central-R" 3 "East-U" 4 "East-R" 5 "North-U" 6 "North-R" 7 "NE-U" 8 "NE-R" 9 "South-U" 10 "South-R" 11 "SW-U" 12 "SW-R" 13 "West-U" 14 "West-R" 15 "WCent-U" 16 "WCent-R"
label val regstrat0 regstrat0
replace regstrat0 =10 if regstrat0 ==9
replace regstrat0 =16 if regstrat0 ==15

**CREATE REGSTRAT MATCHING 2007-08
gen regstrat=1      if regstrat0==1
replace regstrat=2  if regstrat0==2
replace regstrat=3  if regstrat0==10
replace regstrat=4  if regstrat0==3
replace regstrat=5  if regstrat0==4
replace regstrat=6  if regstrat0==7
replace regstrat=7  if regstrat0==8
replace regstrat=8  if regstrat0==5
replace regstrat=9  if regstrat0==6
replace regstrat=10 if regstrat0==13
replace regstrat=11 if regstrat0==14
replace regstrat=12 if regstrat0==11
replace regstrat=13 if regstrat0==12
replace regstrat=14 if regstrat0==16
la define regstrat 1"Central-U" 2"Central-R" 3"South-R" 4"East-U" 5"East-R" 6"NE-U" 7"NE-R" 8"North-U" 9"North-R" 10"West-U" 11"West-R" 12"SW-U" 13"SW-R" 14"WCent-R"
la val regstrat regstrat
label var regstrat "14 geographical regions (for spat. price index)"

* alternative regional grouping
gen regstrat9 = regionn+1
replace regstrat9 = 1 if regionn==1&urru==1
label def regstrat9 1 "Central-U" 2 "Central-R" 3 "East" 4 "North" 5 "NE" 6 "South" 7 "SW" 8 "West" 9 "WCent"
label val regstrat9 regstrat9
label var regstrat9 "9 geographical regions (for spat. price index)"

*3.2) quarter
*3.2.1) season variable
*unnecessary: we should have already had season variable that is based on gregorian calendar in the data
*season variable was available in the dummy data
*besides: variable for christian year/month/day not available 
/* TRIALS FOR GENERATING THE QUARTER VARIABLE. NONE OF THESE ARE USED LATER
gen trial1=.
replace trial1=1 if int_month_c>=4&int_month_c<=8&int_year_c==2011
replace trial1=2 if int_month_c>=9&int_month_c<=12&int_year_c==2011
replace trial1=3 if int_month_c>=1&int_month_c<=4&int_year_c==2012
replace trial1=4 if int_month_c>=5&int_month_c<=8&int_year_c==2012
tab trial1
gen trial2=.
replace trial2=1 if int_month_c>=4&int_month_c<=9&int_year_c==2011
replace trial2=2 if (int_month_c>=10&int_month_c<=12&int_year_c==2011)|(int_month_c==1&int_year_c==2012)
replace trial2=3 if int_month_c>=2&int_month_c<=5&int_year_c==2012
replace trial2=4 if int_month_c>=6&int_month_c<=8&int_year_c==2012
tab trial2
gen trial3=.
replace trial3=1 if int_month_c>=4&int_month_c<=9&int_year_c==2011
replace trial3=2 if (int_month_c>=10&int_month_c<=12&int_year_c==2011)|(int_month_c<=2&int_year_c==2012)
replace trial3=3 if int_month_c>=3&int_month_c<=5&int_year_c==2012
replace trial3=4 if int_month_c>=6&int_month_c<=8&int_year_c==2012
tab trial3
*THIS QUARTER VARIABLE MATCHES THE SEASONS BUT IS NOT THE ONE USED FOR POVERTY ESTIMATION
drop trial2 trial3
rename trial1 quarter
la var quarter "Quarters (Seasonally Defined)"*/


*3.2.2) quarter
**ASSIGN MONTH OF INTERVIEW BASED ON DATE OF INTERVIEW
gen mint = .
replace mint = 1  if int_month_s==1 & int_year_s==95
replace mint = 2  if int_month_s==2 & int_year_s==95
replace mint = 3  if int_month_s==3 & int_year_s==95
replace mint = 4  if int_month_s==4 & int_year_s==95
replace mint = 5  if int_month_s==5 & int_year_s==95
replace mint = 6  if int_month_s==6 & int_year_s==95
replace mint = 7  if int_month_s==7 & int_year_s==95
replace mint = 8  if int_month_s==8 & int_year_s==95
replace mint = 9  if int_month_s==9 & int_year_s==95
replace mint = 10  if int_month_s==10 & int_year_s==95
replace mint = 11 if int_month_s==11 & int_year_s==95
replace mint = 12 if int_month_s==12 & int_year_s==95
replace mint = 13 if int_month_s==1 & int_year_s==96
la def shamo 1 "Hmal", add
la def shamo 2 "Swar", add
la def shamo 3 "Jawza", add
la def shamo 4 "Saratan", add
la def shamo 5 "Asad", add
la def shamo 6 "Sunbula", add
la def shamo 7 "Mizan", add
la def shamo 8 "Aqrab", add
la def shamo 9 "Qaws", add
la def shamo 10 "Jadi", add
la def shamo 11 "Dalwa", add
la def shamo 12 "Hoot", add
la def shamo 13 "Hmal", add
la val mint shamo

*check the distribution of year/month in 2016-17
/*                    |    Q2.5c. Date of
       Q2.5b. Date of |    interview _Year
    interview - Month |  95. 1395   96. 1396 |     Total
----------------------+----------------------+----------
  1. 1-Hmal (Mar-Apr) |       308      1,257 |     1,565 
  2. 2-Swar (Apr-May) |     1,857          0 |     1,857 
 3. 3-Jawza (May-Jun) |     2,087          0 |     2,087 
4. 4-Saratan (Jun-Jul |       822          0 |       822 
  5. 5-Asad (Jul-Aug) |     1,762          0 |     1,762 
6. 6-Sunbula (Aug-Sep |     1,494          0 |     1,494 
 7. 7-Mizan (Sep-Oct) |     2,098          0 |     2,098 
 8. 8-Aqrab (Oct-Nov) |     1,408          0 |     1,408 
 9. 9-Qaws (Nov-Dec)  |     1,680          0 |     1,680 
10. 10-Jadi (Dec-Jan) |     1,800          0 |     1,800 
11. 11-Dalwa (Jan-Feb |     1,566          0 |     1,566 
12. 12-Hoot (Feb-Mar) |     1,699          0 |     1,699 
----------------------+----------------------+----------
                Total |    18,581      1,257 |    19,838 */			
*NRVA 2011-12 code to define quarter-- MONTHS GROUPED INTO QUARTERS 1-4 SERIALLY
/*gen quarter2=.
replace quarter2=1 if q2_5_b>=2&q2_5_b<=6&q2_5_c==95	
replace quarter2=2 if q2_5_b>=7&q2_5_b<=11&q2_5_c==95
replace quarter2=3 if (q2_5_b>=12&q2_5_b<=12&q2_5_c==95)| (q2_5_b>=1&q2_5_b<=2&q2_5_c==96)
replace quarter2=4 if q2_5_b>=3&q2_5_b<=6&q2_5_c==96
la var quarter2 "Quarters of survey data collection"*/

*Since ALCS 16/17 only has 13 survey months vis-a-vis 17 survey months in NRVA 2011/12, 
*we need a new definiton of quarter. To ensure evenly distributed households across months,
*first quarter has four months whereas other quarters each has three. 
gen quarter2=.
replace quarter2=1 if int_month_s>=1&int_month_s<=4&int_year_s==95	
replace quarter2=2 if int_month_s>=5&int_month_s<=7&int_year_s==95
replace quarter2=3 if int_month_s>=8&int_month_s<=10&int_year_s==95
replace quarter2=4 if (int_month_s>=11&int_month_s<=12&int_year_s==95)|(int_month_s==1&int_year_s==96)
tab quarter2
/* quarter2 |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |      5,074       25.58       25.58
          2 |      5,354       26.99       52.57
          3 |      4,888       24.64       77.21
          4 |      4,522       22.79      100.00
------------+-----------------------------------
      Total |     19,838      100.00 */
sort hhid
*compared to core.dta in NRVA 2011-12, we don't have ind_weight, HH_weight so far, as well as GPS variables which were not collected in 2016-17
drop mint regstrat0	oldprovincec
saveold "$output\core.dta", replace version(13)
