/*--------------------------------------------------------------------------------------\
| Date:    	October 17, 2013															|
| Revised:																				|
| Title:   	povline.do																	|
| Purpose: 	A. Create food bundle based on 2007-08 data, including farmgate wheat 		|
| Author:  	Christina Wieser									                    	|
| Contact: 	cwieser@worldbank.org                                  	                    |
\--------------------------------------------------------------------------------------*/
clear
set mem 150m
set matsize 200
capture log close

*******************************************************************************
* Part A: Create food bundle based on 2007-08 data, including farmgate wheat **
*******************************************************************************
use "$data07\temp_longfoodexp", clear
  sort hhid
merge hhid using "$data07\temp_aggcons_noh"
  tab _merge
  drop _merge
  drop if price==. & item!=205 & item!=0
  sort hhid
preserve
	use "$data07\S15A", clear
	sort hhid
	tempfile S15A
	save `S15A'
restore
merge hhid using `S15A'
  tab _merge
  keep if _merge==3
  drop _merge
  sort hhid
merge hhid using "$data07\core"
  sort hhid
  tab _merge
  keep if _merge==3
  drop _merge

merge hhid using "$data07\temp_adjpovpop"

 keep if adjpovpop==1
  keep if item!=.
  gen um = 1

replace q_15_6 = 0 if q_15_6==.

	gen pcdq = q_15_6 / (7*q_15_1)
	gen tdq = q_15_6 / (7*q_15_1)
	
preserve
   duplicates drop hhid, force
   summ hhid
   sca def hhcnt=r(N)
   display "Number of households in the 20-50th percentile = " hhcnt
restore

*Create mean p.c. daily quantities for the 20th-50th percentile
*collapse (mean) pcdq (sum) tdq fbqnt [aw=hh_weight], by(item)
collapse (sum) fbqnt=q_15_6 pcdq [aw=hh_weight], by(item)

/*Merge 2007-08 prices
merge 1:1 item using "$output/price_base_2007.dta"
drop if item==50  //Broccoli is dropped 
*keep if _merge==3 								//We have 92 food items (exclude broccoli and fresh apricots)
drop _merge

merge 1:1 item using "$output/temp/item_price_filler.dta", keepusing(price)  //introducing 4 item prices into the matrix 
replace p0=price if _merge==3
drop _merge price 
*/
* Weights are normalized to sum to sample size in numerator when using collapse
replace fbqnt = fbqnt/hhcnt
replace pcdq  = pcdq/hhcnt

keep if item!=11 & item!=20 & item!=31 & item!=59 & item!=77 & item!=85 & item!=91
	sort item
	merge 1:1 item using "$data07\nutrients_16-17.dta", keepusing(kcalskg)
	keep if _merge==3					//Broccoli and "other" food items are dropped
	drop _merge

* calculate total kcal per capita per day
gen  double pcdkcal      = kcalskg*pcdq
egen double tkcalpcpday = sum(kcalskg*pcdq)

	label var pcdq "Food quantities for poverty line, per capita, daily"
	label var pcdkcal "caloric intake, per capita, daily (pcdq times kcalskg)"
	label var tkcalpcpday "total kcal per capita per day of reference group"
	label var kcalskg "Caloric content per kg"

* FPL = 2100*((q2007 * p2016)/tcalpcday) 

	gen scal_fact=2100/tkcalpcpday
	gen quantity07=pcdq*scal_fact
	replace quantity07=0 if quantity==.
	
label var quantity07 "Caloric intake, per capita per day of reference group for 2100 caloric diet"
 
saveold "$data07/food_bundle.dta", replace

/*--------------------------------End of do file--------------------------------*/
