/*--------------------------------------------------------------------------------------\
| Date:    	January 22, 2020															|
| Revised:																				|
| Title:   	food_bundle_2016.do																	|
| Purpose: 	A. Create food bundle based on 2016-17 data, including farmgate wheat 		|
| Author:  	Erwin Knippenberg									                    	|
| Contact: 	eknippenberg@worldbank.org                                  	                    |
\--------------------------------------------------------------------------------------*/
clear
set mem 150m
set matsize 200
capture log close

*******************************************************************************
* Part A: Create food bundle based on 2007-08 data, including farmgate wheat **
*******************************************************************************
use "$output\temp_longfoodexp", clear
  sort hhid

  *** Trim outliers
  gen q23_9_w= q23_9
  
  *foreach i of num 1/91 201 205 {
  *winsor q23_9 if item==`i', gen(temp_win) p(.025)
  * replace q23_9_w=temp_win if item==`i' & temp_win!=q23_9
  * drop temp_win}
  
  replace q23_9_w = 0 if q23_9_w==.
  
	gen pcdq = q23_9_w / (7*q23_1)
	
** population deciles
  	merge m:1 hhid using "$output\temp_pccons", keepusing(pcexall_adj)
	
	xtile q_pcexall_adj = pcexall_adj  [aw=ind_weight], nq(10)
	
	keep if q_pcexall_adj>=2 &  q_pcexall_adj<=5
	egen x = group(hhid)
    summ x
    sca def hhcnt=r(max)
   display "Number of households in the 20-50th percentile = " hhcnt

collapse (sum) pcdq [aw=hh_weight], by(item)

* Weights are normalized to sum to sample size in numerator when using collapse
replace pcdq  = pcdq/hhcnt

keep if item!=11 & item!=20 & item!=31 & item!=59 & item!=77 & item!=85 & item!=91
	merge 1:1 item using "$data07\nutrients_16-17.dta", keepusing(kcalskg)
	keep if _merge==3					//Broccoli and "other" food items are dropped
	drop _merge

* calculate total kcal per capita per day
gen  double pcdkcal      = kcalskg*pcdq
egen double tkcalpcpday = sum(kcalskg*pcdq)

	label var pcdq "Food quantities for poverty line, per capita, daily"
	label var pcdkcal "caloric intake, per capita, daily (pcdq times kcalskg)"
	label var tkcalpcpday "total kcal per capita per day of reference group"
	label var kcalskg "Caloric content per kg"

	gen scal_fact=2100/tkcalpcpday
	gen quantity16=pcdq*scal_fact
	replace quantity16=0 if quantity==.
	
label var quantity16 "Caloric intake, per capita per day of reference group for 2100 caloric diet"

save "$output\food_bundle_16.dta", replace
 