/*--------------------------------------------------------------------------------------\
| Date:    	November 22, 2017															|
| Revised:																				|
| Title:   	implicit inflation.do														|
| Purpose: 	A. Calculate implicit inflation from poverty lines between 2007, 2011, 2016	|
|			B. Apply implicit inflation to expenditures									|
| Author:  	Christina Wieser									                    	|
| Contact: 	cwieser@worldbank.org                                  	                    |
\--------------------------------------------------------------------------------------*/
clear
set mem 150m
set matsize 200
capture log close

global path07 	"C:\Users\wb458837\OneDrive - WBG\Afghanistan\ALCS 2016\running three rounds\2007-08"
global path11	"C:\Users\wb458837\OneDrive - WBG\Afghanistan\ALCS 2016\running three rounds\2011_12"
global path16	"C:\Users\wb458837\OneDrive - WBG\Afghanistan\ALCS 2016"

*******************************************
* A. Implicit inflation 2007, 2011, 2016 **
*******************************************

	*Use 2007-08
	use "$path07\data_constructed\povlines.dta", clear
	foreach i in fline pline nfline {
		rename `i' `i'_07
	}

	*Merge 2011-12
	merge 1:1 regstrat using "$path11\data_constructed\povlines.dta"
	drop _merge
	foreach i in fline pline nfline {
		rename `i' `i'_11
	}

	*Merge 2016-17
	merge 1:1 regstrat using "$path16\data_constructed\povlines.dta"
	drop _merge
	foreach i in fline pline nfline {
		rename `i' `i'_16
	}

	*Caluclate inflation rates
	*2007-2011
	foreach i in fline nfline pline {
		gen inf_`i'_0711=((`i'_11-`i'_07)/`i'_07)+1
	}
	
	*2007-2016
	foreach i in fline nfline pline {
		gen inf_`i'_0716=((`i'_16-`i'_07)/`i'_07)+1
	}

	*2011-2016
	foreach i in fline nfline pline {
		gen inf_`i'_1116=((`i'_16-`i'_11)/`i'_11)+1
	}

	label var inf_fline_0711 	"Implicit inflation food line 2007-2011"
	label var inf_nfline_0711 	"Implicit inflation non-food line 2007-2011"
	label var inf_pline_0711 	"Implicit inflation poverty line 2007-2011"
	label var inf_fline_1116 	"Implicit inflation food line 2011-2016"
	label var inf_nfline_1116 	"Implicit inflation non-food line 2011-2016"
	label var inf_pline_1116 	"Implicit inflation poverty line 2011-2016"
	label var inf_fline_0716 	"Implicit inflation food line 2007-2016"
	label var inf_nfline_0716 	"Implicit inflation non-food line 2007-2016"
	label var inf_pline_0716 	"Implicit inflation poverty line 2007-2016"

keep regstrat quarter2 inf_*

saveold "$path16\data_constructed\implicit inflation.dta", replace

********************************
* A. Apply implicit inflation **
********************************

	*2007-08
	use "$path07\data_constructed\temp_pov.dta", clear
	merge m:1 regstrat using "$path16\data_constructed\implicit inflation.dta"
	assert _merge==3
	drop _merge
	
	gen pcexnf_adj=pcexn_adj+pcexd_adj+pcexr_adj
	
	*Bring expenditures of 2007 to 2016 levels
	gen pcexf_adj_ii=pcexf_adj*inf_fline_0716
	gen pcexn_adj_ii=pcexn_adj*inf_nfline_0716
	gen pcexd_adj_ii=pcexd_adj*inf_nfline_0716
	gen pcexr_adj_ii=pcexr_adj*inf_nfline_0716
	gen pcexall_adj_ii=pcexall_adj*inf_pline_0716
	gen pcexnf_adj_ii=pcexnf_adj*inf_nfline_0716
	
	label var pcexf_adj_ii	"PC monthly food cons, adj for implicit inflation"
	label var pcexn_adj_ii	"PC monthly non-food cons, adj for implicit inflation"
	label var pcexd_adj_ii	"PC monthly durables, adj for implicit inflation"
	label var pcexr_adj_ii	"PC monthly rent, adj for implicit inflation"
	label var pcexall_adj_ii	"PC monthly total cons, adj for implicit inflation"
	label var pcexnf_adj_ii	"PC monthly total non-food cons, adj for implicit inflation"

	keep hhid cid hh_size hh_weight Province_Name Province_Code urru regstrat quarter ind_weight *_ii

	xtile quin=pcexall_adj_ii, n(5)
	tabstat *_ii [aw=ind_weight], by(quin)
	
	*2011-12 
	use "$path11\data_constructed\temp_pov.dta", clear
	merge m:1 regstrat using "$path16\data_constructed\implicit inflation.dta"
	assert _merge==3
	drop _merge
	
	gen pcexnf_adj=pcexn_adj+pcexd_adj+pcexr_adj

	*Bring expenditures of 2011 to 2016 levels
	gen pcexf_adj_ii=pcexf_adj*inf_fline_1116
	gen pcexn_adj_ii=pcexn_adj*inf_nfline_1116
	gen pcexd_adj_ii=pcexd_adj*inf_nfline_1116
	gen pcexr_adj_ii=pcexr_adj*inf_nfline_1116
	gen pcexall_adj_ii=pcexall_adj*inf_pline_1116
	gen pcexnf_adj_ii=pcexnf_adj*inf_nfline_1116

	label var pcexf_adj_ii	"PC monthly food cons, adj for implicit inflation"
	label var pcexn_adj_ii	"PC monthly non-food cons, adj for implicit inflation"
	label var pcexd_adj_ii	"PC monthly durables, adj for implicit inflation"
	label var pcexr_adj_ii	"PC monthly rent, adj for implicit inflation"
	label var pcexall_adj_ii	"PC monthly total cons, adj for implicit inflation"
	label var pcexnf_adj_ii	"PC monthly total non-food cons, adj for implicit inflation"

	xtile quin=pcexall_adj_ii, n(5)
	tabstat *_ii [aw=ind_weight], by(quin)

	*2016-17 
	use "$path16\data_constructed\temp_pov.dta", clear
	gen pcexnf_adj=pcexn_adj+pcexd_adj+pcexr_adj
 	
	xtile quin=pcexall_adj, n(5)
	tabstat pcex*  [aw=ind_weight], by(quin)

/*--------------------------------End of do file--------------------------------*/
