	/*--------------------------------------------------------------------------------------\
	| Date: October 4 2017                                                                 `|
	|                                                                                       |
	| Title: poverty.do                                                                     |
	|                                                                                       |
	| Compute poverty estimates                                                    			|
	| Method: 07/08 food bundle x 16/17 prices, update non-food using non-food CPI         	|
	|                                                                                       |
	| Authors: Christina Wieser (cwieser@worldbank.org)										|
	\--------------------------------------------------------------------------------------*/

	clear all
	set more off
	capture log close
	set type double, perm
	version 13
	
	*****************************************************************************************************
	* Compute poverty estimates
	*****************************************************************************************************

	use "$output\temp_pccons", clear
	sort hhid
	merge 1:1 hhid using "$output\core.dta", keepusing(hh_weight cid urru regstrat Province_Code Province_Name quarter2)
	keep if _merge==3
	drop _merge
	merge 1:1 hhid using "$input\F_23.dta", keepusing(hh_size)
	keep if _merge==3
	drop _merge

	* merge poverty lines
	sort regstrat
	merge m:1 regstrat using "$output\povlines.dta"
	assert _merge==3
	drop _merge
	
	gen poor=pcexall_adj<pline
	gen fpoor=pcexf_adj<fline
	gen ind_weight=hh_weight*hh_size

	sum *poor [w=ind_weight]
	mean poor [w=ind_weight], over(Province_Name)
	mean poor [w=ind_weight]

//	povdeco pcexall_adj [w=ind_weight], varpline(pline) by(Province_Name)
// 	sepov pcexall_adj [w=ind_weight],  p(pline) level(95) psu(cid)
//	ineqdeco pcexall_adj [aw=ind_weight] 
//	svyset cid [pw = ind_weight], strata(Province_Code)
//	svylorenz pcexall_adj, ngp(1) qlevel(95) 
//	svylorenz pcexall_adj, ngp(2) level(95) subpop(urru)
	
	capture log close
	saveold "$output\temp_pov.dta", replace

exit
/*
	*Food budget shares
	use "$output\temp_pov.dta", clear

	gen shf=hexnom_f/hexnom_t

	gen bmed_f=.
	forvalues p=1(1)34{
		sum hexnom_f if Province_Code==`p', d
		replace bmed_f=(hexnom_f<r(p50)) if Province_Code==`p'
	}
	label var bmed_f "Food expenditure below median expenditure"
	
	gen bmed_shf=.
	forvalues p=1(1)34{
		sum shf if Province_Code==`p', d
		replace bmed_shf=(shf<r(p50)) if Province_Code==`p'
	}
	label var bmed_shf "Food expenditure below median of food share"
	
	*Variance for all households below the median food share
	gen var_bmshf=.
	forvalues p=1(1)34{
		sum shf if Province_Code==`p' & bmed_shf==1, d 
		replace var_bmshf=r(max)-r(min) if Province_Code==`p' & bmed_shf==1
	}	
	label var var_bmshf "Variability (r(max)-r(min)) of food shares of HHs below median of food shares"

	*Variance for all households below the median of total food consumption
	gen var_bmed=.
	forvalues p=1(1)34{
		sum shf if Province_Code==`p' & bmed_f==1, d 
		replace var_bmed=r(max)-r(min) if Province_Code==`p' & bmed_f==1
	}	
	label var var_bmed "Variability (r(max)-r(min)) of food shares of HHs below median food expenditure"
	
	*Variance for all households
	gen var_all=.
	forvalues p=1(1)34{
		sum shf if Province_Code==`p', d 
		replace var_all=r(max)-r(min) if Province_Code==`p'
	}	
	label var var_all "Variability (r(max)-r(min)) of food shares of all HHs"
	
	*Variance IQR
	gen var_iqr=.
	forvalues p=1(1)34{
		sum shf if Province_Code==`p', d 
		replace var_iqr=r(p75)-r(p25) if Province_Code==`p'
	}	
	label var var_iqr "Variability (r(max)-r(min)) of food shares of HHs in IQR (p25-p75)"

	collapse (mean) shf var_bmshf var_bmed var_all var_iqr [aw=hh_weight] , by(Province_Code)
*/	
/*--------------------------------End of do file--------------------------------*/
