/*-----------------------------------------------------------------------------
Date:    September 8 , 2017                                                                
Revised: October 20, 2017                                                                           
Title: price_tests.do                                                                      
Purpose: 1) clean price data, 2) make full price matrix under
1) base scenario
3) base scenario + Test 5
	  
Author:  Germiniasi, Andrea                                                             
Contact: a.germiniasi@gmail.com                                                                               |
-----------------------------------------------------------------------------*/

clear
capture log close
set more off
version 13.1
set type double, perm

save "$output\wd", emptyok replace

set logtype text
cap log using "$logfolder\log_dps_10_19_17.txt", replace

*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*
* SENSITIVITY TESTS
*1- The do-file produces two separate datasets under the two scenarios of Test 5

*1 Test 5: Order of imputation (base: 0, Test 5: 1)
global test5 = 0
*------------------------------------------------------------------------------*
*------------------------------------------------------------------------------*


***************************************************************
* A. PREPARE DATASET
**   assign district names
**   create district_code_16.dta
***************************************************************
clear
use "$input\Price.dta", clear

replace District_Code = Province_Code*100 + District_Code // as in cons.do

sort District_Code

tab cid if District_Code == 808

/* 
    Cluster |
       Code |      Freq.     Percent        Cum.
------------+-----------------------------------
         48 |          1       25.00       25.00
        398 |          1       25.00       50.00
       1767 |          1       25.00       75.00
       1925 |          1       25.00      100.00
------------+-----------------------------------
      Total |          4      100.00
*/

* Obtain District Names (same as 2012)
rename District_Code District_Code_12 
rename Province_Code Province_Code_12

merge m:1 District_Code_12 using "$output\district_code_map_07_12" //The name is District_Code_12 in the other file we are merging with. 
tab _merge   // no correspondence - 4 observations in District 808 in Province 8 (Panjsher). 
drop if _merge == 2
drop _merge

rename District_Code_12 District_Code 
rename Province_Code_12 Province_Code 

rename p3_97_b p3_98  // so that next loops work

* For prices of melon in Takhar, we will have to recode values of 88 and set to 98 (not available in the market) - email Oct 16
replace p3_64 = 98 if p3_64 == 88 & Province_Name == "Takhar"  // Province_Code == 18

foreach x of varlist p3_* {
	replace `x' = . if `x' == .a | `x' == 9999 | `x' == 98 | `x' == 998 | `x' == 9998  // email September 30th 2017
}

rename p3_98 p3_97_b

*-----------------------Update based on email October 18-----------------------*
* Vegetable oil in Kandarhar
replace p3_56 = p3_56/4.5 if p3_56 >= 400 & Province_Name == "Kandahar"  // (32 real changes made)

* Potatoes and wheat flour in Zabul
replace p3_32 = . if p3_32 > 35 & Province_Name == "Zabul"  // (16 real changes made, 16 to missing)

* Drop all prices for Nimroz province
foreach x of varlist p3_* {
	replace `x' = . if Province_Name == "Nimroz"  // (50 real changes made
}
*------------------------------------------------------------------------------*

preserve
	use "$raw\H_01.dta", clear
	rename q_1_1 	Province_Code
	rename q_1_5 urban
	rename q_1_4    cid
	rename hh_id hhid
	gen District_Code = Province_Code*100 + q_1_2 
	merge 1:1 hhid using "$output/core.dta", keepusing(urru)   
	drop _merge
	keep Province_Code District_Code cid urban urru

	collapse urban urru, by(Province_Code District_Code cid)
	sort Province_Code District_Code cid

	tempfile urban
	save `urban'
restore

merge 1:1 Province_Code District_Code cid using `urban'
drop _merge

/* ATTENTION
tab District_Code if _merge == 1
      +---------------------------------------------------------------------------------------------+
      | Distr~de      District_Name   Distr~07   Provi~de   Provin~me   Provi~07   Cluste~e   urban |
      |---------------------------------------------------------------------------------------------|
 565. |      905   Baghlan-I-Jadeed       1602          9     Baghlan         16        237       . |
1187. |     2205         Sangcharak       2106         22   Sar-e-Pul         21        462       . |
      +---------------------------------------------------------------------------------------------+
*/

saveold "$input/price_clean.dta", replace

* Create district_code_16 and map_07_16
bys Province_Name District_Name: gen n = _n
keep if n == 1
drop n

rename District_Code District_Code_16
rename Province_Code Province_Code_16

keep Province_Code_16 Province_Name District_Code_16 District_Name
drop if Province_Name==""
saveold "$output\district_code_16.dta", replace

* Keep all the mapping (also for districts n/a in 2016)
use "$output\district_code_map_07_12", clear
rename District_Code_12 District_Code_16
rename Province_Code_12 Province_Code_16
merge 1:1 Province_Code_16 District_Code_16 using "$output\district_code_16.dta"
replace District_Code_07=807 if _merge==2 & District_Code_07==.					//CW: Check with CSO if 808 used to be in 807 in 2007 and 2011
replace Province_Code_07=8 if _merge==2 & Province_Code_07==.							
drop _merge
saveold "$output\district_code_map_07_16", replace

*****************************************
* CREATE BASE PRICE DATASET
*****************************************
use "$input\price_clean.dta", clear

*** ASSIGN MARKET LOCATION CODE AS THE DISTRICT CODE
gen mkt_loc_district_code = District_Code
label var mkt_loc_district_code "Dist code of mkt location-from DPS"

** 3) CLEAN FOOD ITEM PRICES
*** 3.1) CLEAN PRICE: REPLACE PRICE OF 0 WITH MISSING
foreach x of varlist p3_*  {
	replace `x' = . if `x' == 0
	}

** 1) CLEAN PRICE OF BREAD: USE PRICE OF "PURCHASED NAN" AND ASSUME THAT THE WEIGHT IS 200 GRAM
replace p3_1 = p3_1*5

** 2) CONVERT EGG PRICE, FROM PIECE TO KG
** MEDIUM EGGS WEIGHT 59 GRAMS PER EGG = 17 EGGS PER KILO
replace p3_26 = p3_26*17

** 3) NO CONVERSION FOR BANANA PRICE AS PRICE IS COLLECTED BY DOZEN -- > SO THE PRICE IS PER KILO IF WE ASSUME THE FOLLOWING:
** MEDIUM BANANA WEIGHT 83 GRAMS; APPROX 12 BANANAS PER KILO
*replace p3_72 = p3_72*12

gen price_dry_bread = p3_97_b*1000/p3_97  // price per kg               

* Note: some outliers (probably due to measurement error of quantity, e.g. 12 grams and 10 Aghani)
* They will be dropped when we correct for outliers
su price_dry_bread

drop p3_97*
rename price_dry_bread p3_97

* Deal with OUTLIERS & FIX INCONSISTENCIES in prices

foreach var of varlist p3_* {

	local item = real(substr("`var'",4,.))

	qui gen outlier_`item' = . // we need to separate outliers from missing observations
	
	qui   sum `var', detail
	local min`var' = r(min)
	local med`var' = r(p50)
	local max`var' = r(max)
	
	* When the variance of uv exists and is different from zero we detect and delete outliers
	if r(Var) != 0 & r(Var) < . {
		qui gen ln`var' = ln(`var')
	    qui levelsof Province_Code, local(prov)
        foreach p of local prov {
			qui sum ln`var' if Province_Code == `p', detail
			local amean`var' = r(mean)
			local asd`var'   = r(sd)
			* identify and delete outliers
		 	qui replace  `var' = . if (abs((ln`var' - `amean`var'') / `asd`var'') > 3 & ~mi(ln`var') & `asd`var'' != . & `asd`var'' > 0 ) & Province_Code == `p' 
		 	qui replace outlier_`item' = 1 if (abs((ln`var' - `amean`var'') / `asd`var'') > 3 & ~mi(ln`var') & `asd`var'' != . & `asd`var'' > 0 ) & Province_Code == `p' 
			
			qui count if `var' > 0 & ~mi(`var') & Province_Code == `p'
			qui count if mi(`var') & Province_Code == `p'
			local post`var' = r(N) // in case we want to store them later in matrix for printing
		}
	}
}
drop ln*

foreach var of varlist p3_* {
	
	local item = real(substr("`var'",4,.))

	/* ==========================================================================
	We impute the MEDIAN values at different levels subject to the 
	 number of observations available in each level. We start from the lowest or 
	 closest level (cluster) to the highest level (country):
		1. By EA if at least 6 households have non-missing values
		2. By urban district/by rural district if urban/rural district has at least 20 non-missing observations
		3. By district if district has at least 20 non-missing observations
		4. By urban province/by rural province if urban/rural province has at least 20 non-missing observations
		5. By province if province has at least 20 non-missing observations
	 ========================================================================= */
	 /*
	* 1- Calculate median by EA --> as very few EAs have more than 5 observations, this step is ineffective and will not be run (to save time)
	  qui levelsof cid, local(eacod)
	  qui gen median_ea_`item' = . 

	  foreach e of local eacod {
		qui su cid if cid == `e' 
		loc tot_ea = r(N)
		qui su p3_`item' if cid == `e', detail
		qui replace median_ea_`item' = r(p50) if cid == `e' &  median_ea_`item' == .  & `tot_ea' >= 6
	  }
	*/
	* 2- Calculate median by URBAN/RURAL DISTRICT(KUCHI?)
	  qui levelsof District_Code, local(dist)
	  qui gen median_disturb_`item' = .
	  
	  foreach d of local dist {
		  qui levelsof urru, local(urb)
		  foreach u of local urb {
		  	qui su urru if urru == `u' & District_Code == `d'    
			loc tot_disturb = r(N)
			qui su p3_`item' if urru == `u' & District_Code == `d', detail
			qui replace median_disturb_`item' = r(p50) if urru == `u' & District_Code == `d' &  median_disturb_`item' == .  & `tot_disturb' >= 20
		  }
	   }
	
	* 3- Calculate median by DISTRICT
	  qui levelsof District_Code, local(dist)
	  qui gen median_dist_`item' = . 

	  foreach d of local dist {
		qui su District_Code if District_Code == `d' 
		loc tot_dis = r(N)
		qui su p3_`item' if District_Code == `d', detail
		qui replace median_dist_`item' = r(p50) if District_Code == `d' &  median_dist_`item' == .  & `tot_dis' >= 20
	  }
	  
	 * 4- Calculate median by URBAN/RURAL PROVINCE
	  qui levelsof Province_Code, local(prov)
	  qui gen median_provurb_`item' = .
	  
	  foreach p of local prov {
		  qui levelsof urru, local(urb)  
		  foreach u of local urb {
		  	qui su urru if urru == `u' & Province_Code == `p' 
			loc tot_provurb = r(N)
			qui su p3_`item' if urru == `u' & Province_Code == `p', detail
			qui replace median_provurb_`item' = r(p50) if urru == `u' & Province_Code == `p' &  median_provurb_`item' == .  & `tot_provurb' >= 20
		  }
	   }

	* 5- Calculate median by urban rural nation         	  
    qui levelsof urru, local(urb)  
	qui gen median_naturb_`item' = .

		foreach u of local urb {
		qui su urru if urru == `u'
		loc tot_nat = r(N)
		qui su p3_`item' if urru == `u', detail
		qui replace median_naturb_`item' = r(p50) if urru == `u' &  median_naturb_`item' == .	& `tot_nat' >= 20
	  }
	  
		
	* 6- Calculate median by COUNTRY
	  qui su p3_`item', detail
	  qui gen median_`item' = r(p50)   
	  
	  ***********************************
	  * ATTENTION: WE WANT TO REPLACE ONLY THE OUTLIERS, NOT ALL THE MISSING VALUES
	  * TAG THE OUTLIERS
	  ***********************************
	  /*di in ye "Replacing by EA"
	  replace p3_`item' = median_ea_`item' if p3_`item' == . & outlier_`item' == 1 */
		
	  di in ye "Replacing by urban/rural district"
	  replace p3_`item' = median_disturb_`item' if p3_`item' == . & outlier_`item' == 1 

	  di in ye "Replacing by district"
	  replace p3_`item' = median_dist_`item' if p3_`item' == . & outlier_`item' == 1 
	  
	  di in ye "Replacing by urban/rural province"
	  replace p3_`item' = median_provurb_`item' if p3_`item' == . & outlier_`item' == 1 

	  di in ye "Replacing by urban/rural nation"
	  replace p3_`item' = median_naturb_`item' if p3_`item' == . & outlier_`item' == 1

	  di in ye "Replacing by nation"
	  replace p3_`item' = median_`item'    if p3_`item' == .	& outlier_`item' == 1

	  cap drop median_*
	  cap drop count_*
}	

drop outlier*


** 4. 1) COLLAPSE TO DEAL WITH MULTIPLE DPS QUESTIONNAIRES PER DISTRICT-MONTH
*SAMPLE SIZE REDUCES TO 1475 FROM 2045

gen numdist = 1

if $test5 == 0 collapse (median) p3_* (sum) numdist, by(int_month_g int_year_g Province_Code District_Code)

/*****************************************************************************
*D. Test 5: preserving market price 
*the collapse command above would be asterisked out to keep raw market prices
*****************************************************************************/

drop if int_year_g ==. & int_month_g ==.
sum  int_year_g int_month_g Province_Code District_Code numdist
 

*4.2) IMPUTE PRICES FOR "OTHER" CATEGORIES
*FOOD ITEMS 2016--PROXY PRICE
*101: OTHER BREAD AND CEREALS: MEDIAN, EXCLUDING NAN AND INCLUDING DRIED BREAD (ITEM 97)
*102: OTHER MEAT AND FISH: MEDIAN, EXCLUDING DRIED MEAT
*103: OTHER DAIRY PRODUCTS:  MEDIAN OF LOWER PRICE DAIRY PRODUCTS (DOGH, MILK, AND YOGHURT)
*104: OTHER VEGETABLES: MEDIAN OF FRESH VEGETABLES
*105: OTHER FRUIT: MEDIAN OF FRESH FRUITS
*106: OTHER BEVERAGES: PRICE OF BOTTLED/ CANNED BEVERAGES AND MINERAL WATER
*107: OTHER SPICES: PRICE OF MIXED SPICE
*OTHER OILS/ FAT: PRICE EXISTS

egen  p3_101 = rowmedian(p3_89 p3_90 p3_91 p3_92 p3_97 p3_2 p3_3 p3_4 p3_5 p3_6 p3_7 p3_8)
egen  p3_102 = rowmedian(p3_9 p3_10 p3_11 p3_16 p3_13 p3_14 p3_16)
egen  p3_103 = rowmedian(p3_17 p3_19 p3_22)
egen  p3_104 = rowmedian(p3_32 p3_33 p3_34 p3_35 p3_36 p3_37 p3_38 p3_39 p3_40 p3_41 p3_42 p3_43 p3_44 p3_45 p3_46 p3_47 p3_48 p3_49 p3_50 p3_54)
egen  p3_105 = rowmedian(p3_62 p3_63 p3_64 p3_65 p3_66 p3_68 p3_69 p3_70 p3_71 p3_72 p3_74 p3_76 )
gen   p3_106 =  p3_85
gen   p3_107 =  p3_31

**NOTE: CONSUMPTION DATA DO NOT ALLOW TO DISTINGUISH IMPORTED AND LOCAL WHEAT FLOUR.
**AS PRICES (AT THE PROVINCIAL LEVEL) DO NOT DIFFER MUCH - WE TAKE AVERAGE OF LOCAL-IMPORTED WHEAT FLOUR

tabstat p3_89 p3_90, by(Province_Code)
egen p3_108 = rowmean(p3_89 p3_90)

if $test5 == 0 reshape long p3_, i(int_month_g int_year_g Province_Code District_Code) j(item_16) 
if $test5 == 1 reshape long p3_, i(int_month_g int_year_g Province_Code District_Code cid) j(item_16) 


la var item_16 "Item Codes from NRVA 2011-12"
destring item_16, replace

**CREATE ITEM CODES MATCHING NRVA 2007-08 CODES
gen item=. 	
	
preserve
import excel using "$auxiliary/codes_2008_2016.xlsx", firstrow clear
mkmat _all, matrix(C)
local r = rowsof(C)
restore

forval i = 1/`r' {
	replace item = C[`i',1] if item_16 == C[`i',2]
}

drop if item==.
drop numdist

if $test5 == 0 {
	ren  p3_ pdm
}

***************************************************************************************
*D. Test 5 preserving market price 
*the base price is from markets rather than the district median prices 

if $test5 == 1 {
	ren  p3_ pmm
	label var pmm "price-market monthly raw"
}
***************************************************************************************/

**QUARTERS (gregorian month/year) 
/****************************************************
* ATTENTION
* include April 2017 in Q4-2017 (56 obs)
* NEW PRICE DATASET CORRECTS FOR JAN-MARCH 2016 OBS
******************************************************/

*QUARTER2 
*1) INITIAL DEFINITION -- MONTHS GROUPED INTO QUARTERS 1-4 SERIALLY
gen quarter2 = .
replace quarter2 = 1 if inrange(int_month_g,4,7)  & int_year_g == 16    
replace quarter2 = 2 if inrange(int_month_g,8,10)   & int_year_g == 16  
replace quarter2 = 3 if (inrange(int_month_g,11,12) & int_year_g == 16)|(int_month_g==1&int_year_g==17)
replace quarter2 = 4 if inrange(int_month_g,2,4)   & int_year_g == 17 
la var quarter2 "Quarters of survey data collection"

sort Province_Code District_Code int_year_g int_month_g item
saveold "$output\temp_basep.dta", replace

** 5.2) MAKE PRICE MATRIX

*** 5.2) CALC AVERAGES
use "$output\temp_basep.dta", clear

***************************************************************************************
*D. Test 5 preserving market price 
*** 5.1.0) District-monthly 

if $test5 == 1 {
	collapse (median) pmm , by(Province_Code District_Code quarter2 int_year_g int_month_g item)  // ag: add quarter2 (for quarterly average below)
	rename pmm pdm 
	la var pdm "Price--district monthly median"
	sort Province_Code District_Code int_year_g int_month_g item
	saveold "$output\dim.dta", replace
}

***************************************************************************************/

*** 5.2.1) PROVINCE-MONTHLY
preserve
collapse (median) pdm , by(Province_Code int_year_g int_month_g item)
rename pdm ppm
la var ppm "Price--Province monthly median"
sort Province_Code int_year_g int_month_g item
tempfile prom
save `prom'
restore

*** 5.2.2) NATIONAL MEDIAN PRICE-MONTHLY
preserve
collapse (median) pdm , by(int_year_g int_month_g item)
rename pdm pnm
la var pnm "Price--National monthly median"
sort int_year_g int_month_g item
tempfile natm
save `natm'
restore

*** 5.2.3) PROVINCE-QUARTER(2)LY
preserve
collapse (median) pdm , by(Province_Code int_year_g quarter2 item)
rename pdm ppq
la var ppq "Price--Province quarter2ly median"
sort Province_Code int_year_g quarter2 item
tempfile proq
save `proq'
restore

*** 5.2.4) NATIONAL AVERAGE OF THAT QUARTER2
preserve
collapse (median) pdm , by(int_year_g quarter2 item)
rename pdm pnq
la var pnq "Price--National quarter2ly median"
sort int_year_g quarter2 item
tempfile natq
save `natq'
restore

*** 5.2.5) NATIONAL AVERAGE OF THAT YEAR
collapse (median) pdm , by(item)
rename pdm pny
la var pny "Price--National Average"
sort item
tempfile naty
save `naty'


** 5.3 ADD DISTRICT NAME FROM --DISTRICT CSO--FILE (WITH DISTRICT CODES CORRESPONDING TO 2007-08)
* Eliminate: these steps were creating the mapping 07_12 (with issues) which we now already have in its correct form (see Tobias email June 6)

**5.4)   CALCULATE PRICE USING NEIGHBORING DISTRICTS'

**5.4.1  PREPARE MAP DATA
*        DISTANCE WEIGHT FROM 20-NEAREST NEIGHBORS
*        NOTE DISTRICT AND PROVINCE CODES IN NRVA 2016 ARE DIFFERENT FROM THE NRVA 2007-08 CODES
clear
infile origid destid distance using "$auxiliary\district_k20.txt"
gen double wtd20 = 1/distance
tempfile district_weight
save `district_weight', replace

* USE NEW FILE FROM MRRD, JUNE 5, 06
use "$raw\398_district_07.dta", clear
ren unique_code District_Code_07
merge 1:m District_Code_07 using "$output\district_code_map_07_16.dta"
rename id destid
tab _merge
drop _merge
sort destid
tempfile name
save `name', replace

*  5.4.2. PREPARE AND MERGE ORIGINAL AND RECEIVING DISTRICTS
****** MAKE SURE THAT PRICE 0 WERE DROPPED
use `district_weight', clear
sort destid
merge destid using `name'
tab _merge
drop if _merge==2
drop _merge
drop province_n district_n
foreach var in District_Code_07 Province_Name District_Name Province_Code_07 Province_Code_16 District_Code_16 {
	ren `var' `var'_dest
}
tempfile one
save `one', replace

use "$raw\398_district_07.dta", clear
ren unique_code District_Code_07
merge 1:m District_Code_07 using "$output\district_code_map_07_16.dta"
tab _merge
drop _merge
rename id origid
foreach var in District_Code_07 Province_Name District_Name Province_Code_07 Province_Code_16 District_Code_16 {
	ren `var' `var'_orig
}
sort origid
tempfile name2
save `name2', replace

use `one', clear
sort origid
merge origid using `name2'
tab _merge
drop _merge
drop province_n district_n
tempfile two
save `two', replace

** 5.4.3: ADD PRICE TO THE STRUCTURE
use "$output\temp_basep.dta", clear
if $test5 == 1 use "$output\dim.dta", clear
ren District_Code District_Code_16_dest
ren Province_Code Province_Code_16_dest
sort District_Code_16_dest
tempfile qqq
save `qqq', replace

*sort District_Code_16_dest
/*
forval i=0/397 {  // 397
	di in red "loop `i'"
	use `two', clear
	sort origid
	keep if origid == `i'
	merge 1:m District_Code_16_dest using `qqq'
	tab _merge
	keep if _merge == 3
	rename _m mpricedest
	drop if  origid == . & destid == .
	append using "$output\wd"
	sleep 5000
	save "$output\wd", replace
}
*/
forval i=0/397 {
	use `two', clear
	sort origid
	keep if origid==`i'
	merge 1:m District_Code_16_dest using `qqq'
	tab _merge
	keep if _merge==3
	rename _merge mpricedest
	drop if  origid== . & destid == .
        tempfile wd_`i'
        save `wd_`i''
	}

use `wd_0', clear
forval i=1/397 {
        append using `wd_`i''
}

saveold "$output\wd", replace


* 5.4.4: WEIGHT BY DISTANCE
** COLLAPSE BY MONTH
use "$output\wd", clear
by District_Code_16_orig int_year_g int_month_g item, sort: egen sw = sum(wtd20) if pdm !=.
gen dwpdm = pdm
gen double weight = wtd20/sw
collapse (median) dwpdm [w= weight], by(Province_Name_orig District_Name_orig District_Code_16_orig int_year_g int_month_g item)
drop if  District_Code_16_orig==.
drop if int_year_g==. & int_month_g==. & item==.
replace dwpdm = . if dwpdm==0
su
sort District_Code_16_orig int_year_g int_month_g item
tempfile navprice_mo
save `navprice_mo', replace
saveold "$output/navprice_mo", replace

** COLLAPSE BY QUARTER - * USE QUARTER2 (defined n temp_basep.dta)
use "$output\wd", clear
by District_Code_16_orig int_year_g quarter2 item, sort: egen sw = sum(wtd20) if pdm !=.
gen dwpdq = pdm
gen weight = wtd20/sw
collapse (median) dwpdq [w= weight], by(Province_Name_orig District_Name_orig District_Code_16_orig int_year_g quarter2 item)
drop if  District_Code_16_orig==.
drop if int_year_g==. & quarter2==. & item==.
replace dwpdq = . if dwpdq==0
su
sort District_Code_16_orig int_year_g quarter2 item
tempfile navprice_quarter2
save `navprice_quarter2', replace
saveold "$output/navprice_quarter2", replace


*** 5.5 PUT APPROPRIATE PRICES IN THE MATRIX

** 5.5.1 CREATE STRUCTURE OF THE MATRIX
use "$output\temp_basep.dta", clear 
if $test5 == 1 use "$output\dim.dta", clear
preserve
drop if int_year_g ==. & int_month_g == .
gen um = 1
collapse um, by(int_year_g int_month_g)
tempfile m
save `m', replace
restore

drop if item == .
gen um = 1
collapse um, by(item)
tempfile item
save `item', replace

use "$output\district_code_map_07_16.dta", clear
drop Province_Code_07 Province_Name District_Name District_Code_07
gen um = 1
sort um
cross using `m'      // 398*13 = 5,174 obs   (398 districts, 13 months)
cross using `item'   // 5,174*99  = 512,226  (99 items)

rename Province_Code_16 Province_Code
rename District_Code_16 District_Code

gen quarter2 = .
replace quarter2 = 1 if inrange(int_month_g,4,7)  & int_year_g == 16  
replace quarter2 = 2 if inrange(int_month_g,8,10)   & int_year_g == 16
replace quarter2 = 3 if (inrange(int_month_g,11,12) & int_year_g == 16)|(int_month_g==1&int_year_g==17)
replace quarter2 = 4 if inrange(int_month_g,2,4)   & int_year_g == 17  
la var quarter2 "Quarters of survey data collection"


** 5.5.2 FILL IN PRICES
sort Province_Code District_Code int_year_g int_month_g item
merge Province_Code District_Code int_year_g int_month_g item using "$output\temp_basep.dta"  // load pmm

********************************************************************************************************/
**ITEMS DROPPED

/*
     _merge |      Freq.     Percent        Cum.
------------+-----------------------------------
          1 |    393,822       76.83       76.83
          2 |        396        0.08       76.90   // 808 district
          3 |    118,404       23.10      100.00
------------+-----------------------------------
      Total |    512,622      100.00
*/


drop if item==.
tab District_Code if _merge==2
**THE THREE DISTRICTS WITH WRONG DISTRICT CODES GET DROPPED  // note 8 30 I have only one district dropped (808, n/a in the map) - the map_07_12 was already correcting for those 3 districts
drop if _merge==2
drop _merge

*********************************************************************************************************

sort Province_Code District_Code int_year_g int_month_g item

*D. Test 5: preserving market price
*merging with dim.ta to put district monthly medians in the first place of the price matrix 
if $test5 == 1 {
	merge Province_Code District_Code int_year_g int_month_g item using "$output\dim.dta"
	tab _merge
	drop _merge
}

rename District_Code District_Code_16_orig 
sort District_Code_16_orig int_year_g int_month_g item
merge District_Code_16_orig int_year_g int_month_g item using `navprice_mo'
*merge District_Code_16_orig int_year_g int_month_g item using "$output/navprice_mo"
tab _merge
drop _merge

sort Province_Code int_year_g int_month_g item
merge Province_Code int_year_g int_month_g item using `prom'
tab _merge
drop _merge
sort int_year_g int_month_g item
merge int_year_g int_month_g item using `natm'
tab _merge
drop _merge

sort District_Code_16_orig int_year_g quarter2 item
*merge District_Code_16_orig int_year_g quarter2 item using "$output/navprice_quarter2"
merge District_Code_16_orig int_year_g quarter2 item using `navprice_quarter2'
tab _merge
drop _merge
sort Province_Code int_year_g quarter2 item
merge Province_Code int_year_g quarter2 item using `proq'
tab _merge
drop _merge
sort int_year_g quarter2 item
merge int_year_g quarter2 item using `natq'
tab _merge
drop _merge
sort item
merge item using `naty'
tab _merge
drop _merge
drop if item==.
*** 
*** PECKING ORDER OF PRICE IMPUTING
*** BASE OF PRICE MATRIX: MEDIAN PRICE OF THE DISTRICT DURING THAT MONTH OF INTERVIEW
*** 1) AVERAGE PRICE OF 20 NEIGHBORING DISTRICTS OF THE MONTH
*** 2) PROVINCE AVERAGE OF THAT MONTH
*** 3) NATIONAL AVERAGE OF THAT MONTH
*** 4) AVERAGE PRICE OF 20 NEIGHBORING DISTRICTS OF THE QUARTER
* NB: THE ORDER OF REPLACEMENT WAS CHANGED ON AUG 20, 09.  NUMBER 3) AND 4) WERE FLOPPED.
*** STOP GAP ***
*** 5) PROVINCE AVERAGE OF THAT QUARTER
*** 6) NATIONAL AVERAGE OF THAT QUARTER
*** 7) NATIONAL AVERAGE OF THAT YEAR

if $test5 == 0 {
gen price = .
	replace price = pdm   if price==.
	replace price = dwpdm if price==.
	replace price = ppm   if price==.
	replace price = pnm   if price==.
	replace price = dwpdq if price==.

	replace price = ppq if price==.
	replace price = pnq if price==.
	replace price = pny if price==.
}

******************************************************************************************
*** D. Test 5: preserving market prices 
*** PECKING ORDER OF PRICE IMPUTING
*** BASE OF PRICE MATRIX: MARKET PRICE DURING THAT MONTH OF INTERVIEW
*** 0) District Avg Monthly
*** 1) AVERAGE PRICE OF 20 NEIGHBORING DISTRICTS OF THE MONTH
*** 2) PROVINCE AVERAGE OF THAT MONTH
*** 3) NATIONAL AVERAGE OF THAT MONTH
*** 4) AVERAGE PRICE OF 20 NEIGHBORING DISTRICTS OF THE QUARTER
* NB: THE ORDER OF REPLACEMENT WAS CHANGED ON AUG 20, 09.  NUMBER 3) AND 4) WERE FLOPPED.
*** STOP GAP ***
*** 5) PROVINCE AVERAGE OF THAT QUARTER
*** 6) NATIONAL AVERAGE OF THAT QUARTER
*** 7) NATIONAL AVERAGE OF THAT YEAR

if $test5 == 1 {
	gen price = .
	replace price = pmm if price==.
	replace price = pdm if price==.
	replace price = dwpdm if price==.
	replace price = ppm if price==.
	replace price = pnm if price==.
	replace price = dwpdq if price==.

	replace price = ppq if price==.
	replace price = pnq if price==.
	replace price = pny if price==.
}
******************************************************************************************/

label var price "imputed price"

** CHECK IF THERE IS DUPLICATION IN PRICES

if $test5 == 0 {
	ren District_Code_16_orig District_Code
	by Province_Code District_Code int_year_g int_month_g item, sort: gen j=_n
	tab j
	collapse (median) price , by(Province_Code District_Code int_year_g int_month_g item)
	label var price "imputed price"
}

*****************************************************
*D. Test 5: preserving market prices

if $test5 == 1 {
	drop Province_Name District_Name
	rename Province_Name_orig Province_Name  // useless as we are going to collapse
	rename District_Name_orig District_Name  // useless as we are going to collapse
	ren District_Code_16_orig District_Code
	by Province_Code District_Code mkt_loc_district_code cid int_year_g int_month_g item, sort: gen j=_n
	tab j
	collapse (median) price , by(Province_Code District_Code mkt_loc_district_code cid int_year_g int_month_g item)
	count
	label var price "imputed price"
	*drop mkt_loc_district_code
}
******************************************************/
tempfile imp_dps_temp
save `imp_dps_temp', replace  // temporary


**ADD IN OLD PROVINCE CODES AND CREATE REGIONS BASED ON THEM

use "$output\district_code_map_07_16.dta", clear
ren Province_Code_16 Province_Code
ren District_Code_16 District_Code
sort District_Code Province_Code
tempfile prov
save `prov', replace

use `imp_dps_temp', clear
sort District_Code Province_Code
merge District_Code Province_Code using `prov'
tab _merge
drop _merge

gen region = .
replace region = 1 if Province_Code_07 >=1  & Province_Code_07<=5
replace region = 2 if Province_Code_07 >=6  & Province_Code_07<=9
replace region = 3 if Province_Code_07 >=10 & Province_Code_07<=13
replace region = 4 if Province_Code_07 >=14 & Province_Code_07<=17
replace region = 5 if Province_Code_07 >=18 & Province_Code_07<=22
replace region = 6 if Province_Code_07 >=23 & Province_Code_07<=25
replace region = 7 if Province_Code_07 >=26 & Province_Code_07<=30
replace region = 8 if Province_Code_07 >=31 & Province_Code_07<=34
replace region = 1 if Province_Code_07 == 33
label def region 1"Central" 2"South" 3"East" 4"Northeast" 5"North" 6"West" 7"Southwest" 8"WestCentral"
label val region region
label var region "Region: 8 regions, NRVA definition"

drop Province_Code_07 District_Code_07

******************************
* NEW CODE
do "$do/labels.do"
la val item item
*****************************

compress

if $test5 == 0 saveold "$output\imp_dps.dta", replace
if $test5 == 1 saveold "$output\imp_dps_test5.dta", replace

capture log close

/*--------------------------------End of do file--------------------------------*/
