/*-----------------------------------------------------------------------------
Date: September 8 , 2017                                                                
Revised:                                                                            
Title: tables_price.do  
This do-file creates tables by:
- quarter (averages and other statistics)
- province (annual averages and by quarter)
- region (annual averages and by quarter)

Author:  Germiniasi, Andrea                                                             
Contact: a.germiniasi@gmail.com    
-----------------------------------------------------------------------------*/
set more off 

*AG
global path "C:\Users\Andrea\Desktop/Afghanistan\ALCS 2016"
global output "$path/data_constructed"  

*CW
*global path "C:\Users\wb458837\OneDrive - WBG\Afghanistan\ALCS 2016"


********************************************************
* Choose data to tabulate 
* base: 1
* Test 5: 2
********************************************************
local d = 1

if `d' == 1 {
	use "$output\imp_dps.dta", clear
	local tabout "C:\Users\Andrea\Desktop\Afghanistan\ALCS 2016\tables\base"
	local file ""
}

if `d' == 2 {
	use "$output\imp_dps_test5.dta", clear
	local tabout "C:\Users\Andrea\Desktop\Afghanistan\ALCS 2016\tables\test5"
	local file "_test5"
}

*1) INITIAL DEFINITION -- MONTHS GROUPED INTO QUARTERS 1-4 SERIALLY
gen quarter2 = .
replace quarter2 = 1 if inrange(int_month_g,4,6)   & int_year_g == 16 
replace quarter2 = 2 if inrange(int_month_g,7,9)   & int_year_g == 16
replace quarter2 = 3 if inrange(int_month_g,10,12) & int_year_g == 16
replace quarter2 = 4 if inrange(int_month_g,1,4)   & int_year_g == 17
la var quarter2 "Quarters of survey data collection"

eststo clear
/*
******************************************
*1. QUARTERS
******************************************
putexcel set "`tabout'/table_prices_summary_quarters`file'.xls", replace sheet("All quarters") 

forval i = 1/4 {
	if `i' == 1 local wkb "replace"
	else local wkb "append"

	eststo: estpost tabstat price if quarter2 ==`i', by(item) c(stat) 
}

esttab est1 est2 est3 est4, cells(mean(fmt(a3)))

mat C =r(coefs)
matmap C C, map(round(@, 0.01))
mat colnames C = Q1 Q2 Q3 Q4
matrix coleq C = " "
putexcel A1 = ("Table 1. Average prices by quarter")
putexcel A3= matrix(C, names)


forval i = 1/4 {
	estpost tabstat price if quarter2 ==`i', by(item) s(min mean max sd) 
	esttab . , cells(min(fmt(a3)) mean(fmt(a3)) max(fmt(a3)) sd(fmt(a3)))
	mat Q`i' = r(coefs)
	matmap Q`i' Q`i', map(round(@, 0.01))
	matrix coleq Q`i' = " "
	putexcel set "`tabout'/table_prices_summary_quarters`file'.xls", modify sheet("Quarter `i'") 
	putexcel A1 = ("Table 2-`i'. Min, Average, Max prices in quarter `i'")
	putexcel A3= matrix(Q`i', names)
}


******************************************
*2. REGIONS
******************************************
putexcel set "`tabout'/table_prices_summary_regions`file'.xls", replace 

forval i = 1/5 {
eststo clear
levelsof(region), local(reg)
	foreach r of local reg {
		if `i' <= 4 eststo: estpost tabstat price if region == `r' & quarter2 == `i', by(item) c(stat)
		if `i' == 5 eststo: estpost tabstat price if region == `r' & inrange(quarter2,1,4), by(item) c(stat)
	}	
	
	esttab est1 est2 est3 est4 est5 est6 est7 est8, cells(mean(fmt(a3)))  // format does not affect r(coefs), use matmap
	
	mat QR`i' =r(coefs)
	matmap QR`i' QR`i', map(round(@, 0.01))
	mat colnames QR`i' = Central South East Northeast North West Southwest WestCentral 
	matrix coleq QR`i' = " "
	if `i' <= 4 putexcel set "`tabout'/table_prices_summary_regions`file'.xls", modify sheet("Regions - Q`i'") 
	if `i' == 5 putexcel set "`tabout'/table_prices_summary_regions`file'.xls", modify sheet("Regions - Year") 
	if `i' <= 4 putexcel A1 = ("Table 3-`i'. Average prices by region in Q`i'")
	if `i' == 5 putexcel A1 = ("Table 3-`i'. Average prices by region (annual)")
	putexcel A3= matrix(QR`i', names)
}

*/
******************************************
*3. PROVINCES
******************************************
putexcel set "`tabout'/table_prices_summary_provinces`file'.xls", replace 

forval i = 1/5 {
eststo clear
levelsof(Province_Name), local(prov)
	foreach p of local prov {
		if `i' <= 4 eststo: qui estpost tabstat price if Province_Name == "`p'" & quarter2 == `i', by(item) c(stat)
		if `i' == 5 eststo: qui estpost tabstat price if Province_Name == "`p'", by(item) c(stat)
	}	
	
	#delimit ;
	local estimates "est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 est13 est14 est15 
	est16 est17 est18 est19 est20 est21	est22 est23	est24 est25	est26 est27	est28 est29	est30	
	est31 est32	est33 est34";
	#delimit cr
	
	esttab `estimates', cells(mean(fmt(a3)))  // format does not affect r(coefs), use matmap
	
	mat QP`i' =r(coefs)
	matmap QP`i' QP`i', map(round(@, 0.01))
	
	#delimit ;
	mat colnames QP`i' = Badakhshan Badghis Baghlan Balkh Bamyan Daykundi Farah Faryab Ghazni Ghor Helmand Herat 
	Jawzjan Kabul Kandahar Kapisa Khost Kunarha Kunduz Laghman Logar Nangarhar Nimroz Nooristan
	Paktika Paktya Panjsher Parwan Samangan Sar-I-Pul Takhar Urozgan Wardak Zabul;
	#delimit cr
	matrix coleq QP`i' = " "
	
	if `i' <= 4 putexcel set "`tabout'/table_prices_summary_provinces`file'.xls", modify sheet("Provinces - Q`i'") 
	if `i' == 5 putexcel set "`tabout'/table_prices_summary_provinces`file'.xls", modify sheet("Provinces - year") 
	if `i' <= 4 putexcel A1 = ("Table 4-`i'. Average prices by province in Q`i'")
	if `i' == 5 putexcel A1 = ("Table 4-`i'. Average prices by province (annual)")

	putexcel A3= matrix(QP`i', names)
}


