texdoc init "${output_raw}/Balance_PhoneSvy_R1_R2_${date}.tex", replace hardcode nokeep


/* Baseline balance for:

	- sample for replicating impact from fl1 (HHs we surveyed in (1) R1 or (2) R2, or (3) both?) 


For attrition, include attrition dummies as OUTCOMES at the bottom of the table.

	- How do we define attrition? A range:
		a. Anyone who (1) reported having a phone at fl1 (2022 HH) and (2) does not have a complete interview in either of R1/R2 (or both)?  
			or 
		b. Anyone who (1) ever reported having a phone (2398 HH) and (2) does not have a complete interview in either of R1/R2 (or both)?
*/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************


/***
\documentclass[8pt]{article}
\usepackage[utf8]{inputenc}
\usepackage{titlesec}
\usepackage[usenames,dvipsnames]{xcolor}
\usepackage{geometry}
\usepackage{graphicx}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{ragged2e}
\usepackage{caption}
\usepackage{longtable}
\usepackage[title]{appendix}
\usepackage[justification=centering]{caption}
\usepackage{hyperref}
\newcommand{\subsubsubsection}[1]{\paragraph{#1}\mbox{}\\}
\setcounter{secnumdepth}{4}
\setcounter{tocdepth}{4}
\usepackage{titlesec}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{longtable}
\usepackage[title]{appendix}
\usepackage{hyperref}
\usepackage[english]{babel}
\usepackage{amsmath}
\usepackage[colorinlistoftodos]{todonotes}
\usepackage{pdflscape}
\begin{document}
\date{Version: \today}
\title{Online Appendix \\  NO HOUSEHOLD LEFT BEHIND: TESTING AN ULTRA-POOR GRADUATION PROGRAM IN AFGHANISTAN}
\maketitle
\thispagestyle{empty}
\newpage
\renewcommand*\contentsname{Table of Contents: Online Appendix}
\tableofcontents
\renewcommand\listfigurename{\normalsize Figures}
\renewcommand\listtablename{\normalsize Tables}
\listoftables
\listoffigures

\renewcommand{\thefigure}{A\arabic{figure}}
\renewcommand{\thetable}{A}
***/

* Table notes
gl note_table_a4 "\footnotesize{\textit{Note:} The table reports the baseline balance test for the primary outcomes of interest. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in Section 1 of this appendix. For each outcome variable, we report the coefficients of interest and their robust standard errors in parentheses. We report the naive p-values in brackets. Column (1) reports the mean (standard deviation) of each outcome for the control group at follow-up. Column (2) reports the treatment estimates in levels. Column (3) reports the total sample size for each treatment estimate. School-age is 6 to 18 years. Our consumption estimate includes food (purchased, produced, and received as a gift), personal and household items, education, health, household repairs, social expenses (weddings, funerals, religious expenses, and other ceremonies), temptation goods, and legal expenses. All monetary amounts are PPP-adjusted US\textdollar\ terms, set at 2018 prices using the Afghanistan Consumer Price Index and PPP conversion factor from the International Monetary Fund. The psychological well-being index is a standardized index including different complementary measures of psychological well-being. HH = household; PCA = principal component analysis; PPP = purchasing power parity; PRA = participatory rural appraisal; SD = standard deviation.  ***, **, and * denote significance at the 1\%, 5\%, and 10\% levels, respectively.}"


*---------------------------------*
* Table A4: Baseline Balance Test *
*---------------------------------* 
	/***
	\restoregeometry
	\addtolength{\topmargin}{-1.5in}
	\addtolength{\textheight}{3in}
	\begin{landscape}
	\begin{small} 
	\newpage
	\renewcommand{\arraystretch}{0.9}
	\small
	\centering	
	\begin{longtable}{@{\extracolsep{1pt}}p{4cm}cccccccccccc}
	\caption{Phone Survey Baseline Balance Test}\\  
	\\[-1.8ex] \hline \\[-1.8ex]
	& \multicolumn{3}{c}{Follow-up Sample} & \multicolumn{3}{c}{Phone Svy R1 Sample} & \multicolumn{3}{c}{Phone Svy R2 Sample} & \multicolumn{3}{c}{Phone Svy R1 and R2 Sample} \\
	\\[-1.8ex]	\cline{2-4} \cline{5-7} \cline{8-10} \cline{11-13} \\[-1.8ex] 
	& \makecell{Control \\Mean (SD)} & \makecell{Adjusted\\Difference}  & \makecell{N}  & \makecell{Control \\Mean (SD)} & \makecell{Adjusted\\Difference}  & \makecell{N}  & \makecell{Control \\Mean (SD)} & \makecell{Adjusted\\Difference}  & \makecell{N} & \makecell{Control \\Mean (SD)} & \makecell{Adjusted\\Difference}  & \makecell{N} \\    
	& (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) & (10) & (11) & (12) \\ \hline \\
	\endhead
	***/
	texdoc stlog, nolog

	
	use "${data_for_analysis_bl}", clear
		merge 1:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition* no_round) // 47 HHs are missing BL data
	
	* Keep fl1 sample 
		keep if fl1_sample == 1 // out of 2,495, 2,454 have baseline data 
	
	* Looking at complete interviews only (as most partial ones only have roster data, maybe consumption, and there are only a few)
		cou  if call_status_r1 == 1 // R1 only (of 1,735, 1,710 have BL data)
		cou  if call_status_r2 == 1 // R2 only (of 1,671, 1,647 have BL data) [DHS assets, Crops, HH Expenditures Decisions Index, Children's Human Capital Investments and Marriage Decisions Index]
		cou  if call_status_r1 == 1  & call_status_r2 == 1 // R1 and R2 (of 1,548, 1,527 have BL data)

	foreach var in $hh_general_bl {
		global `var'_lab : variable label `var'
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample 
		reg `var' treatment ${controls} if call_status_r1 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample 
		reg `var' treatment ${controls} if call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample 
		reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}	
	
	preserve
	
	use "${schooling_bl}", clear
		merge m:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition*)
		
	* Keep fl1 sample 
		keep if fl1_sample == 1
		
	foreach var in $enrollment_bl {
		global `var'_lab : variable label `var'
		reg `var' treatment ${controls}, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample		
		reg `var' treatment ${controls} if call_status_r1 == 1, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}	
*R2 sample		
		reg `var' treatment ${controls} if call_status_r2 == 1, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample		
		reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}  \\  \\[-1.8ex]
	}	

	restore
	
	tex \textbf{Consumption and Food Security} &  &    &  &    & &     \\  \\[-1.8ex]
	
	foreach var in $consump_bl {
		global `var'_lab : variable label `var'
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample		
		reg `var' treatment ${controls} if call_status_r1 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}	
*R2 sample		
		reg `var' treatment ${controls} if call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample		
		reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}	
	
	local var fin_index_sdC_bl
	reg `var' treatment ${controls}, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex \textbf{Financial Inclusion Index} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	
*R1 sample
	reg `var' treatment ${controls} if call_status_r1 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample
	reg `var' treatment ${controls} if call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample
	reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]

	tex \textbf{Assets} &  &   &  &   &  &   &  &  &  & \\  \\[-1.8ex]

	foreach var in $asset_sum_bl {
		global `var'_lab : variable label `var'
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		if "`var'" == "tot_lstock_value_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
		reg `var' treatment ${controls} if call_status_r1 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		if "`var'" == "tot_lstock_value_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample
		reg `var' treatment ${controls} if call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		if "`var'" == "tot_lstock_value_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample
		reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		if "`var'" == "tot_lstock_value_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}
	
	tex \textbf{Engaged in Productive Activities, Primary Woman} & & & & & & & & & & \\  \\[-1.8ex]
 
	foreach var in $labor_pf_bl {
		global `var'_lab : variable label `var'
		reg `var' treatment ${controls}, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment
		
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
		reg `var' treatment ${controls} if call_status_r1 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment
		
		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample
		reg `var' treatment ${controls} if call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment
		
		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample
		reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment
		
		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}

	local var psy_5index_z_f
	global `var'_lab : variable label `var'
	reg `var' treatment ${controls}, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex \textbf{${`var'_lab}}  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
	reg `var' treatment ${controls} if call_status_r1 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample
	reg `var' treatment ${controls} if call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample
	reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]

	local var index_sdC_hhexp
	global `var'_lab : variable label `var'
	reg `var' treatment ${controls} , r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex \textbf{${`var'_lab}} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
	reg `var' treatment ${controls} if call_status_r1 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample
	reg `var' treatment ${controls} if call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample
	reg `var' treatment ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	
	* Attrition
	tex \hline \\[-1.8ex]
	tex \textbf{Attrition} &  &    &  &    & &   & &  & &  \\  \\[-1.8ex]
	
* R1 Attrition
foreach var in $attrition_r1 {
	global `var'_lab : variable label `var'
	reg `var' treatment, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
	tex  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}   & N/A
*R2 sample
	reg `var' treatment if call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample
	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}  \\  \\[-1.8ex]
}
* R2 Attrition
foreach var in $attrition_r2 {
	global `var'_lab : variable label `var'
	reg `var' treatment, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
	reg `var' treatment if call_status_r1 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample
	tex  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}   & N/A
*R1 & R2 sample
	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}   \\  \\[-1.8ex]
}

* HH not surveyed in ANY round
	local var no_round
	global `var'_lab : variable label `var'
	reg `var' treatment, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment
	
	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	
* HH not surveyd in ANY round [this matches PEI reporting figures based on the number of HHs surveyed in at least one round out of HHs that had a phone at fl1]	
	local var no_round
	global `var'_lab "HH not surveyed in ANY round (out of HH reported owning a phone at fl1 (883 UP)) [PEI]"
	reg `var' treatment if phone_fl1 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]

	*Regressing treatment on all the outcomes 
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls}, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test   :  di %10.2fc  r(F)
	local f_test_p :  di %10.3fc  r(p)

*R1 sample 	
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls} if call_status_r1 == 1, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test_r1   :  di %10.2fc  r(F)
	local f_test_p_r1 :  di %10.3fc  r(p)
	
*R2 sample 	
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls} if call_status_r2 == 1, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test_r2   :  di %10.2fc  r(F)
	local f_test_p_r2 :  di %10.3fc  r(p)
	
*R1 & R2 sample 	
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test_r1_r2   :  di %10.2fc  r(F)
	local f_test_p_r1_r2 :  di %10.3fc  r(p)
	
	tex \hline \\[-1.8ex]
	tex F-test from regression of treatment on all 18 outcome variables listed above (except attrition) & \multicolumn{3}{c}{`f_test'} & \multicolumn{3}{c}{`f_test_r1'}  & \multicolumn{3}{c}{`f_test_r2'} & \multicolumn{3}{c}{`f_test_r1_r2'} \\  \\[-1.8ex]
	tex P-value & \multicolumn{3}{c}{`f_test_p'} & \multicolumn{3}{c}{`f_test_p_r1'} & \multicolumn{3}{c}{`f_test_p_r2'} & \multicolumn{3}{c}{`f_test_p_r1_r2'} \\  \\[-1.8ex]
	
	tex \hline \\[-1.8ex]
	tex \multicolumn{13}{p{20cm}}{${note_table_a4}} \\
	
	texdoc stlog close
	
	/***
	\end{longtable}
	\end{small}
	\end{landscape}
	\end{document}
	***/