texdoc init "${output_raw}/baseline_balance_shocked_${date}.tex", replace hardcode nokeep


* Table notes
gl note_table_a4 "\footnotesize{\textit{Note:} The table reports the baseline balance test for the primary outcomes of interest for households that experienced any shock (columns 1-3) or an illness shock (defined as serious illness or death of a HH member) (columns 4-6) since April 2020 until the date of survey. All regressions include 133 randomization PRA controls. Outcomes are listed on the left and described in detail in Section 1 of this appendix. For each outcome variable, we report the coefficients of interest and their robust standard errors in parentheses. We report the naive p-values in brackets. Column (1) reports the mean (standard deviation) of each outcome for the control group at follow-up. Column (2) reports the treatment estimates in levels. Column (3) reports the total sample size for each treatment estimate. School-age is 6 to 18 years. Our consumption estimate includes food (purchased, produced, and received as a gift), personal and household items, education, health, household repairs, social expenses (weddings, funerals, religious expenses, and other ceremonies), temptation goods, and legal expenses. All monetary amounts are PPP-adjusted US\textdollar\ terms, set at 2018 prices using the Afghanistan Consumer Price Index and PPP conversion factor from the International Monetary Fund. The psychological well-being index is a standardized index including different complementary measures of psychological well-being. HH = household; PCA = principal component analysis; PPP = purchasing power parity; PRA = participatory rural appraisal; SD = standard deviation.  ***, **, and * denote significance at the 1\%, 5\%, and 10\% levels, respectively.}"

/***
\documentclass[8pt]{article}
\usepackage[utf8]{inputenc}
\usepackage{titlesec}
\usepackage[usenames,dvipsnames]{xcolor}
\usepackage[margin=0.5in]{geometry}
\usepackage{graphicx}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{ragged2e}
\usepackage{caption}
\usepackage{longtable}
\usepackage[title]{appendix}
\usepackage[justification=centering]{caption}
\usepackage{hyperref}
\newcommand{\subsubsubsection}[1]{\paragraph{#1}\mbox{}\\}
\setcounter{secnumdepth}{4}
\setcounter{tocdepth}{4}
\usepackage{titlesec}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{longtable}
\usepackage[title]{appendix}
\usepackage{hyperref}
\usepackage[english]{babel}
\usepackage{amsmath}
\usepackage[colorinlistoftodos]{todonotes}
\usepackage{pdflscape}
\begin{document}
***/

*---------------------------------*
* Table A4: Baseline Balance Test *
*---------------------------------* 
	/***
	\begin{landscape}
	\thispagestyle{empty}
	\begin{small}
	\small
	\centering	
	\begin{longtable}{@{\extracolsep{1pt}}p{7cm}cccccc}
	\caption{Phone Survey Baseline Balance Test for Households that Experienced a Shock since April 2020}\\  
	\\[-1.8ex] \hline \\[-1.8ex]
	& \multicolumn{3}{c}{Any shock} & \multicolumn{3}{c}{Illness or death} \\
	\\[-1.8ex]	\cline{2-4} \cline{5-7} \\[-1.8ex] 
	& \makecell{Control \\Mean (SD)} & \makecell{Adjusted\\Difference}  & \makecell{N}  & \makecell{Control \\Mean (SD)} & \makecell{Adjusted\\Difference}  & \makecell{N} \\    
	& (1) & (2) & (3) & (4) & (5) & (6) \\ \hline \\
	\endhead
	***/

	texdoc stlog, nolog
	
global 	shocks							"${TUP_DB}\Phone_Survey\DataSets\Intermediate\shocks_roster_phonesvy.dta"
global  phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

if $round_1_2 == 0 {
	* Datatset with all rounds
	gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy.dta"
}
else {
	* Dataset restricted to R1-R2 outcomes
	gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy_r1.dta"
}

	
	* Prepare shocks variables 
use "${shocks}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) keepusing(treatment ultra_poor PRA_lottery call_status_r1 date_r*) nogen

	* Create a dummy for illness or death of HH member 
	gen illness = (inlist(shock,5,6) & g1_a == 1) 
	
	collapse (max) g1 treatment illness PRA_lottery, by(hhid round)
	
	* Do not include R4 is restricting to R1-R2 data 
	if $round_1_2 == 1 {
		keep if round != 4 
	}
	
	* Experience of a shock	(At any point)	
	* Limiting this to just R1 and R2, the time period would be "since April 2020" for everyone 
	collapse (max) g1 treatment illness, by(hhid)

	gen anyshock = g1 

	keep hhid anyshock illness

	tempfile shocks
	save `shocks'

	use "${data_for_analysis_bl}", clear
		merge 1:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition* no_round treatment ultra_poor) // 47 HHs are missing BL data
		* merge on shocks 
		merge m:1 hhid using "`shocks'", assert(1 3) nogen 
	
	* Keep Phone survey R1 and R2 sample  
		keep if call_status_r1 == 1 | call_status_r2 == 1 
	
	foreach var in $hh_general_bl {
		global `var'_lab : variable label `var'
*any shock
		reg `var' treatment ${controls} if anyshock == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	
*illness 
		reg `var' treatment ${controls} if illness == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}	
	
preserve
	
	use "${schooling_bl}", clear
		merge m:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition*)
		merge m:1 hhid using "`shocks'", assert(1 3) nogen 
		
	* Keep Phone survey R1 and R2 sample  
		keep if call_status_r1 == 1 | call_status_r2 == 1 
		
	foreach var in $enrollment_bl {
		global `var'_lab : variable label `var'
*any shock
		reg `var' treatment ${controls} if anyshock ==1, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 

*illness	
		reg `var' treatment ${controls} if illness == 1, r cluster(hhid)
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}  \\  \\[-1.8ex]
	}	

	restore
	
	tex \textbf{Consumption and Food Security} &  &    &  &    & &     \\  \\[-1.8ex]
	
	foreach var in $consump_bl {
		global `var'_lab : variable label `var'
*any shock		
		reg `var' treatment ${controls} if anyshock == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*illness	
		reg `var' treatment ${controls} if illness == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}	
	
	local var fin_index_sdC_bl
*any shock 	
	reg `var' treatment ${controls} if anyshock == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex \textbf{Financial Inclusion Index} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	
*illness 
	reg `var' treatment ${controls} if illness == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]

	tex \textbf{Assets} &  &   &  &   \\  \\[-1.8ex]

	foreach var in $asset_sum_bl {
		global `var'_lab : variable label `var'
*an yshock 	
		reg `var' treatment ${controls} if anyshock == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		if "`var'" == "tot_lstock_value_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex  ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*illness 
		reg `var' treatment ${controls} if illness == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		if "`var'" == "tot_lstock_value_ppp" {		
		coeff_treat `var' treatment 1
		}		
		else {
		coeff_treat `var' treatment
		}

		tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}
	
	tex \textbf{Engaged in Productive Activities, Primary Woman} & & & & \\  \\[-1.8ex]
 
	foreach var in $labor_pf_bl {
		global `var'_lab : variable label `var'
*any shock 
		reg `var' treatment ${controls} if anyshock == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment
		
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
		
*illness
		reg `var' treatment ${controls} if illness == 1, r
		sum `var' if treatment == 0 & e(sample) == 1
		coeff_treat `var' treatment
		
		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}

	local var psy_5index_z_f
	global `var'_lab : variable label `var'
*any shock 	
	reg `var' treatment ${controls} if anyshock == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex \textbf{${`var'_lab}}  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	
*illness
	reg `var' treatment ${controls} if illness == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]

	local var index_sdC_hhexp
	global `var'_lab : variable label `var'
*any shock	
	reg `var' treatment ${controls} if anyshock ==1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex \textbf{${`var'_lab}} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	
*illness 
	reg `var' treatment ${controls} if illness == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	
	/* Attrition
	tex \hline \\[-1.8ex]
	tex \textbf{Attrition} &  &    &  &    & &   & &  & &  \\  \\[-1.8ex]
	
* R1 Attrition
foreach var in $attrition_r1 {
	global `var'_lab : variable label `var'
	reg `var' treatment, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
	tex  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}   & N/A
*R2 sample
	reg `var' treatment if call_status_r2 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R1 & R2 sample
	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}  \\  \\[-1.8ex]
}
* R2 Attrition
foreach var in $attrition_r2 {
	global `var'_lab : variable label `var'
	reg `var' treatment, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
*R1 sample
	reg `var' treatment if call_status_r1 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}
*R2 sample
	tex  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}  & \begin{tabular}[t]{@{}c@{}} N/A \end{tabular}   & N/A
*R1 & R2 sample
	tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}   \\  \\[-1.8ex]
}

* HH not surveyed in ANY round
	local var no_round
	global `var'_lab : variable label `var'
	reg `var' treatment, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment
	
	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	
* HH not surveyd in ANY round [this matches PEI reporting figures based on the number of HHs surveyed in at least one round out of HHs that had a phone at fl1]	
	local var no_round
	global `var'_lab "HH not surveyed in ANY round (out of HH reported owning a phone at fl1 (883 UP)) [PEI]"
	reg `var' treatment if phone_fl1 == 1, r
	sum `var' if treatment == 0 & e(sample) == 1
	coeff_treat `var' treatment

	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]

	*Regressing treatment on all the outcomes 
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls}, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test   :  di %10.2fc  r(F)
	local f_test_p :  di %10.3fc  r(p)

*R1 sample 	
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls} if call_status_r1 == 1, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test_r1   :  di %10.2fc  r(F)
	local f_test_p_r1 :  di %10.3fc  r(p)
	
*R2 sample 	
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls} if call_status_r2 == 1, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test_r2   :  di %10.2fc  r(F)
	local f_test_p_r2 :  di %10.3fc  r(p)
	
*R1 & R2 sample 	
	reg treatment hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp ${controls} if call_status_r1 == 1 & call_status_r2 == 1, r
	*Ftest for all coefficients
	test hhhead_female illiteracy_pf  exp_tot_m_pc_ppp index_sdC_food_sec fin_index_sdC_bl tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork psy_5index_z_f index_sdC_hhexp
	local f_test_r1_r2   :  di %10.2fc  r(F)
	local f_test_p_r1_r2 :  di %10.3fc  r(p)
	
	tex \hline \\[-1.8ex]
	tex F-test from regression of treatment on all 18 outcome variables listed above (except attrition) & \multicolumn{3}{c}{`f_test'} & \multicolumn{3}{c}{`f_test_r1'}  & \multicolumn{3}{c}{`f_test_r2'} & \multicolumn{3}{c}{`f_test_r1_r2'} \\  \\[-1.8ex]
	tex P-value & \multicolumn{3}{c}{`f_test_p'} & \multicolumn{3}{c}{`f_test_p_r1'} & \multicolumn{3}{c}{`f_test_p_r2'} & \multicolumn{3}{c}{`f_test_p_r1_r2'} \\  \\[-1.8ex]
	*/ 
	tex \hline \\[-1.8ex] \\
	tex \multicolumn{7}{p{17cm}}{${note_table_a4}} \\
	texdoc stlog close
	
	/***
	\end{longtable}
	\end{small}
	\end{landscape}
	\end{document}
	***/