texdoc init "${output_raw}/blfl_balance_shocked_up_${date}.tex", replace hardcode nokeep


gl note_shock_balance "\footnotesize{\textit{Note:} The table reports the baseline (columns 1-3) and follow-up (columns 4-6) balance test for the primary outcomes of interest for UP households that experienced an illness shock (defined as serious illness or death of a HH member) since April 2020 until the date of survey. All regressions include 133 randomization PRA controls. For each outcome variable, we report the coefficients of interest and their robust standard errors in parentheses. We report the naive p-values in brackets. Columns (1)-(4) report the mean (standard deviation) of each outcome for households that did not experience a shock at endline. Columns (2)-(5) report the difference (in levels) for households that experienced a shock at endline. Columns (3)-(6) report the total sample size for each estimate. School-age is 6 to 18 years. Our consumption estimate includes food (purchased, produced, and received as a gift), personal and household items, education, health, household repairs, social expenses (weddings, funerals, religious expenses, and other ceremonies), temptation goods, and legal expenses. All monetary amounts are PPP-adjusted US\textdollar\ terms, set at 2018 prices using the Afghanistan Consumer Price Index and PPP conversion factor from the International Monetary Fund. The psychological well-being index is a standardized index including different complementary measures of psychological well-being. HH = household; PCA = principal component analysis; PPP = purchasing power parity; PRA = participatory rural appraisal; SD = standard deviation.  ***, **, and * denote significance at the 1\%, 5\%, and 10\% levels, respectively.}"

global 	shocks							"${TUP_DB}\Phone_Survey\DataSets\Intermediate\shocks_roster_phonesvy.dta"
global  phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
global  data_for_analysis_bl_phonesvy   "${TUP_DB}/Phone_Survey/DataSets/Intermediate/data_for_analysis_bl_phonesvy.dta"
global  schooling_bl 					"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"
global  data_for_analysis_fl1_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/data_for_analysis_fl1_phonesvy.dta"
global 	schooling_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"

/***
\documentclass[8pt]{article}
\usepackage[utf8]{inputenc}
\usepackage{titlesec}
\usepackage[usenames,dvipsnames]{xcolor}
\usepackage[margin=0.5in]{geometry}
\usepackage{graphicx}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{ragged2e}
\usepackage{caption}
\usepackage{longtable}
\usepackage[title]{appendix}
\usepackage[justification=centering]{caption}
\usepackage{hyperref}
\newcommand{\subsubsubsection}[1]{\paragraph{#1}\mbox{}\\}
\setcounter{secnumdepth}{4}
\setcounter{tocdepth}{4}
\usepackage{titlesec}
\usepackage{makecell}
\usepackage{adjustbox}
\usepackage{float}
\usepackage{longtable}
\usepackage[title]{appendix}
\usepackage{hyperref}
\usepackage[english]{babel}
\usepackage{amsmath}
\usepackage[colorinlistoftodos]{todonotes}
\usepackage{pdflscape}
\begin{document}

***/

*----------------------------------------------------------*
* Table A4: Baseline and Follow-Up Shock "Balance" Test    *
*----------------------------------------------------------* 

	/***
	\begin{landscape}
	\thispagestyle{empty}
	\begin{small} 
	\small
	\centering	
	\begin{longtable}{@{\extracolsep{1pt}}p{7cm}cccccc}
	\caption{Phone Survey Balance Test for UP Households that Experienced \\Illness/Death since April 2020, Baseline and Follow-Up}\\  
	\\[-1.8ex] \hline \\[-1.8ex]
	& \multicolumn{3}{c}{Baseline} & \multicolumn{3}{c}{Follow-Up} \\
	\\[-1.8ex]	\cline{2-4} \cline{5-7} \\[-1.8ex] 
	& \makecell{No shock \\Mean (SD)} & \makecell{Shock\\Difference}  & \makecell{N}  & \makecell{No shock \\Mean (SD)} & \makecell{Shock\\Difference}  & \makecell{N} \\    
	& (1) & (2) & (3) & (4) & (5) & (6) \\ \hline \\
	\endhead
	***/
	
	texdoc stlog, nolog
	
	* Prepare shocks variables 
use "${shocks}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) keepusing(treatment ultra_poor PRA_lottery call_status_r1 date_r*) nogen

	* Do not include R4 is restricting to R1-R2 data 
	if $round_1_2 == 1 {
		keep if round != 4 
	}
	
	* Create a dummy for illness or death of HH member 
	gen illness = (inlist(shock,5,6) & g1_a == 1) 
	
	collapse (max) g1 treatment illness PRA_lottery, by(hhid)
	
	keep hhid illness

	tempfile shocks
	save `shocks'

* Prepare baseline phone svy sample 	
	use "${data_for_analysis_bl_phonesvy}", clear
		merge 1:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition* no_round treatment ultra_poor) // 47 HHs are missing BL data
		* merge on shocks 
		merge m:1 hhid using "`shocks'", assert(1 3) nogen 
		
		lab var tot_lstock_value_ppp "Value of Livestock (US\textdollar), Past 4 Weeks"  
		lab var tot_lstock_revenue_ppp "HH Livestock Revenue (US\textdollar)"
	
	* Keep Phone survey R1 and R2 sample  
		keep if call_status_r1 == 1 | call_status_r2 == 1 
	
		tempfile data_bl
		save `data_bl'
		
	foreach var in $hh_general_bl {
	use "`data_bl'", clear 
		
		global `var'_lab : variable label `var'
*baseline  
		reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness

		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 

* Prepare follow-up phone svy sample 		
	use "${data_for_analysis_fl1_phonesvy}", clear
		merge 1:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition* no_round treatment ultra_poor) // 47 HHs are missing BL data
		* merge on shocks 
		merge m:1 hhid using "`shocks'", assert(1 3) nogen 
		
		lab var tot_lstock_value_ppp "Value of Livestock (US\textdollar), Past 4 Weeks"  
		lab var tot_lstock_revenue_ppp "HH Livestock Revenue (US\textdollar)"
		
	* Keep Phone survey R1 and R2 sample  
		keep if call_status_r1 == 1 | call_status_r2 == 1 		
	
		tempfile data_fl1
		save `data_fl1'
		
*follow-up   
		reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}	
	
preserve
* Prepare baseline phone svy sample for schooling 
	use "${schooling_bl}", clear
		merge m:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition*)
		merge m:1 hhid using "`shocks'", assert(1 3) nogen 
		
		lab var boy_inschool_hh "School-Age Boys Are Enrolled at School"
		lab var girl_inschool_hh "School-Age Girls Are Enrolled at School"
		
	* Keep Phone survey R1 and R2 sample  
		keep if call_status_r1 == 1 | call_status_r2 == 1 
		
		tempfile school_bl
		save `school_bl'
		
	foreach var in $enrollment_bl {
	use "`school_bl'", clear 	
		global `var'_lab : variable label `var'
*baseline  
		reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness

		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
		
* Prepare follow-up phone svy sample for schooling 		
	use "${schooling_fl1}", clear
		merge m:1 hhid using "${phone_svy_profile}", keepusing(fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition*)
		merge m:1 hhid using "`shocks'", assert(1 3) nogen 
		
		lab var boy_inschool_hh "School-Age Boys Are Enrolled at School"
		lab var girl_inschool_hh "School-Age Girls Are Enrolled at School"
		
	* Keep Phone survey R1 and R2 sample  
		keep if call_status_r1 == 1 | call_status_r2 == 1

*follow-up	
		reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'}  \\  \\[-1.8ex]		
	}	

restore
	
	tex \textbf{Consumption and Food Security} &  &    &  &    & &     \\  \\[-1.8ex]
	
	foreach var in $consump_bl {
	use "`data_bl'", clear 
		global `var'_lab : variable label `var'
*baseline 	
		reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
		coeff_treat `var' illness 1
		}		
		else {
		coeff_treat `var' illness
		}

		tex  ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	
*follow-up   
	use "`data_fl1'", clear 

		reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		
		if "`var'" == "exp_tot_m_pc_ppp" {		
			coeff_treat `var' illness 1
		}	
		else {
			coeff_treat `var' illness
		}

		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]		
	}	
		
	tex \textbf{Financial Inclusion} &  &   &  &   \\  \\[-1.8ex]		
	
foreach var in $fin_bl {	
    use "`data_bl'", clear 	
    global `var'_lab : variable label `var'
*baseline 	
	reg `var' illness ${controls} if !mi(treatment), r
	sum `var' if illness == 0 & e(sample) == 1
	
	if "`var'" == "saving_ppp" | "`var'" == "loan_ppp" {		
		coeff_treat `var' illness 1
		}		
		else {
		coeff_treat `var' illness
		}

	tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	
	use "`data_fl1'", clear 	
	
*follow-up	
	reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
	sum `var' if illness == 0 & e(sample) == 1
	
	if "`var'" == "saving_ppp" | "`var'" == "loan_ppp" {		
		coeff_treat `var' illness 1
		}		
		else {
		coeff_treat `var' illness
		}
		
	tex & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]	

}
	tex \textbf{Assets} &  &   &  &   \\  \\[-1.8ex] 
	
	foreach var in $asset_sum_bl {
	use "`data_bl'", clear
		global `var'_lab : variable label `var'
*baseline  
		reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		
		if "`var'" == "tot_lstock_value_ppp" {		
		coeff_treat `var' illness 1
		}		
		else {
		coeff_treat `var' illness
		}

		tex  ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 		
		
*follow-up	
	use "`data_fl1'", clear 
		reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
		sum `var' if illness == 0 & e(sample) == 1
		
		if "`var'" == "tot_lstock_value_ppp" {		
			coeff_treat `var' illness 1
		}		
		else {
			coeff_treat `var' illness
		}

		tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]		
	}
	
tex \multicolumn{7}{@{}l}{\textbf{Income and Revenues from Productive Activities, Past 4 Weeks}} \\ \\[-1.8ex]
	
	foreach var in $rev_bl {
	    use "`data_bl'", clear
		
		global `var'_lab : variable label `var'
*baseline  
	if "`var'" == "tot_hh_pay_ppp" {
		tex  ${`var'_lab} &  &  & 
		}
	else {
	    reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness 1
		
	    tex  ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
	}

	use "`data_fl1'", clear 		
		
*follow-up	
		reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
		sum `var' if illness == 0 & e(sample) == 1
	
		coeff_treat `var' illness 1

		tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]		
	}	
	
tex \multicolumn{7}{@{}l}{\textbf{Engaged in Productive Activities, Primary Woman}} \\ \\[-1.8ex]
 
	foreach var in $labor_pf_bl {
	    use "`data_bl'", clear 
		global `var'_lab : variable label `var'
*baseline  
		reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness
		
		tex ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
		
	use "`data_fl1'", clear 		
		
*follow-up	
		reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness
		
		tex  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]
	}

	local var psy_5index_z_f
	
	use "`data_bl'", clear 	
	
	global `var'_lab : variable label `var'

*baseline  
	reg `var' illness ${controls} if !mi(treatment), r
	sum `var' if illness == 0 & e(sample) == 1
	coeff_treat `var' illness

	tex \textbf{${`var'_lab}}  & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 

	use "`data_fl1'", clear 	
	
*follow-up	
	reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
	sum `var' if illness == 0 & e(sample) == 1
	coeff_treat `var' illness

	tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]	

	tex \textbf{Women's Empowerment} & & & & \\  \\[-1.8ex]
	
	foreach var in $empower_bl {
	    use "`data_bl'", clear 
		global `var'_lab : variable label `var'
*baseline  
		reg `var' illness ${controls} if !mi(treatment), r
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness
		
		if "`var'" == "index_sdC_f_empowerment" {
			tex \textbf{${`var'_lab}} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
		}
		else {
			tex \everypar{\hangindent=0.7cm\hangafter=0} ${`var'_lab} & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} 
		}
		
	use "`data_fl1'", clear 		
		
*follow-up	
		reg `var' illness ${controls} if !mi(treatment), r cluster(hhid)
		sum `var' if illness == 0 & e(sample) == 1
		coeff_treat `var' illness
		
		tex   & \begin{tabular}[t]{@{}c@{}} ${`var'm0} \\ (${`var's0})  \end{tabular}  & \begin{tabular}[t]{@{}c@{}} ${`var't} \\ (${`var'tse}) \\ $[$${`var'p}$]$ \end{tabular}   & ${N_`var'} \\  \\[-1.8ex]	
	}

*baseline 	
	use "`data_bl'", clear 
	
*Regressing illness on all the outcomes 
	reg illness	hhhead_female illiteracy_pf illiteracy_pm diarrhea_yes exp_tot_m_pc_ppp index_sdC_food_sec tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital index_sdC_social_norms fin_index_sdC_bl psy_5index_z_f ${controls} if !mi(treatment), r
*Ftest for all coefficients
	test	hhhead_female illiteracy_pf illiteracy_pm diarrhea_yes exp_tot_m_pc_ppp index_sdC_food_sec tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital index_sdC_social_norms fin_index_sdC_bl psy_5index_z_f
	local f_test_bl   :  di %10.2fc  r(F)
	local f_test_bl_p :  di %10.3fc  r(p)

*follow-up
	use "`data_fl1'", clear 

	*Regressing illness on all the outcomes 
	reg illness		hhhead_female illiteracy_pf illiteracy_pm diarrhea_yes exp_tot_m_pc_ppp index_sdC_food_sec tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital index_sdC_social_norms fin_index_sdC_bl psy_5index_z_f ${controls} if !mi(treatment), r
*Ftest for all coefficients
	test	hhhead_female illiteracy_pf illiteracy_pm diarrhea_yes exp_tot_m_pc_ppp index_sdC_food_sec tot_lstock_value_ppp wealth_score property_score did_livestock did_ownFarming did_ownBiz did_oFarm did_maid /*did_outWork*/ did_salEmp did_oPaidWork index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital index_sdC_social_norms fin_index_sdC_bl psy_5index_z_f
	local f_test_fl1   :  di %10.2fc  r(F)
	local f_test_fl1_p :  di %10.3fc  r(p)

	
	tex \hline \\[-1.8ex]
	tex F-test from regression of shock on all outcome variables listed above (except schooling) & \multicolumn{3}{c}{`f_test_bl'} & \multicolumn{3}{c}{`f_test_fl1'} \\  \\[-1.8ex]
	tex P-value & \multicolumn{3}{c}{`f_test_bl_p'} & \multicolumn{3}{c}{`f_test_fl1_p'} \\  \\[-1.8ex]
	
	tex \hline \\[-1.8ex] \\
	tex \multicolumn{7}{p{18cm}}{${note_shock_balance}} \\
	texdoc stlog close
	
	/***
	\end{longtable}
	\end{small}
	\end{landscape}
	\end{document}
	***/