/*******************************************************************************	
Project:  	AFG-TUP
********************************************************************************/
********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off
set maxvar 30000

global end_consumption 						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_phonesvy_corrected.dta"
global phone_svy_profile   					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
global data_for_analysis_bl_phonesvy		"${TUP_DB}/Baseline_Phone/DataSets/Final/data_for_analysis_bl_phonesvy.dta"
	
	
********************************************************************************
** Part 1: Ranking consumption at each level 
********************************************************************************

* Baseline 
use "${data_for_analysis_bl_phonesvy}", clear
merge 1:1 hhid using "${phone_svy_profile}", keepusing(pweight) assert(2 3) keep(3) nogen
	
* https://www.stata.com/support/faqs/statistics/percentile-ranks-and-plotting-positions/
egen n = count(exp_tot_m_pc_ca21)
egen i = rank(exp_tot_m_pc_ca21), track 
gen pcrank_bl = (i - 1) / (n - 1)  

keep hhid pcrank_bl treatment pweight
keep if !mi(pcrank_bl)

tempfile cons_dist_bl
save `cons_dist_bl'

/* Midline 
use "${data_for_analysis_fl1_phonesvy}", clear
merge 1:1 hhid using "${phone_svy_profile}", keepusing(pweight) assert(2 3) keep(3) nogen

* https://www.stata.com/support/faqs/statistics/percentile-ranks-and-plotting-positions/
egen n = count(exp_tot_m_pc_ca21_fl1)
egen i = rank(exp_tot_m_pc_ca21_fl1), track 
gen pcrank = (i - 1) / (n - 1)  

collapse (mean) pcrank [w=pweight], by(treatment)

gen round = 2 

tempfile cons_dist_fl1
save `cons_dist_fl1'*/

* Endline 
use "${end_consumption}", clear
	
* https://www.stata.com/support/faqs/statistics/percentile-ranks-and-plotting-positions/
egen n = count(exp_tot_m_pc_ca21)
egen i = rank(exp_tot_m_pc_ca21), track 
gen pcrank_phone = (i - 1) / (n - 1)  

keep hhid pcrank_phone treatment pweight
keep if !mi(pcrank_phone)

merge 1:1 hhid using "`cons_dist_bl'", keep(3) nogen

* Control 
scatter pcrank_bl pcrank_phone [w=pweight] if treatment == 0, msize(vsmall) title("Proxy Consumption Percentile Distribution: Control Group") ytitle("Baseline percentile rank") xtitle("Endline percentile rank") legend(order(2 "Fitted line")) || lfit pcrank_bl pcrank_phone [w=pweight] if treatment == 0 

graph export "${output_raw_figures}/cons_distribution_control.png" , replace


* Treatment 
scatter pcrank_bl pcrank_phone [w=pweight] if treatment == 1, msize(vsmall) title("Proxy Consumption Percentile Distribution: Treatment Group") ytitle("Baseline percentile rank") xtitle("Endline percentile rank") legend(order(2 "Fitted line")) || lfit pcrank_bl pcrank_phone [w=pweight] if treatment == 1

graph export "${output_raw_figures}/cons_distribution_treatment.png" , replace


* NUP
scatter pcrank_bl pcrank_phone [w=pweight] if treatment == ., msize(vsmall) title("Proxy Consumption Percentile Distribution: NUP") ytitle("Baseline percentile rank") xtitle("Endline percentile rank") legend(order(2 "Fitted line")) || lfit pcrank_bl pcrank_phone [w=pweight] if treatment == . 

graph export "${output_raw_figures}/cons_distribution_NUP.png" , replace
