gl food_consumption_all_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/food_consumption_all_bl.dta"
gl market_imputed_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"
gl food_consumption_all_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_consumption_all_phonesvy.dta"	

		
use "${food_consumption_all_bl}", clear 
	
	* Keep only items that were consumed at baseline to fix the baseline consumption basket 
	* in terms of quantity for each HH
	keep if consumed == 1 
	
	* Keep the 25 food items that are included in the Phone Survey
	keep if inlist(item,1,2,3,4,7,14,15,16,17,18,24,26,27,29,33,41,44,45,50,64,66,72,76,80,84)
		
	keep hhid district item consumed_qty_pc price
	rename (price consumed_qty_pc) (price_bl consumed_qty_pc_bl)
	
	* Merge fl1 prices 
	merge m:1 district item using "${market_imputed_fl1}", assert(2 3) keep(3) keepusing(price) nogen
	rename price price_fl1
	
	* Merge endline prices [price for mango is missing - but no one ate it at baseline so it's ok]
	preserve 
		use "${food_consumption_all_phonesvy}", clear 
		keep item district price
		duplicates drop 
		rename price price_phonesvy
		tempfile phonesvy_prices
		save `phonesvy_prices'
	restore 
	
	merge m:1 district item using "`phonesvy_prices'" , keepusing(price_phonesvy) keep(1 3) nogen
	
	* Keep the endline sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(attrition_r1_or_r2 ultra_poor) keep(3) nogen
	keep if attrition_r1_or_r2 == 0
	
	
	foreach suffix in "_bl" "_fl1" "_phonesvy" {
		gen exp_f_m_pc_item`suffix' = consumed_qty_pc_bl * price`suffix' * (30.5/7)
		
		bys hhid: egen exp_f_m_pc`suffix' = sum(exp_f_m_pc_item`suffix')
	}
	
	
	gen food_exp = consumed_qty_pc_bl * price_bl * (30.5/7)
	bys hhid: egen tot_food_exp = sum(food_exp)
	
	gen share_bl = exp_f_m_pc_item_bl/tot_food_exp
	
	gen infl = 
	
	//table share_bl 
	
	//table item, c(mean share_bl count share_bl)
	
	stop
	keep item district price_bl price_fl1 price_phonesvy
	collapse (mean) price_bl price_fl1 price_phonesvy, by(item)
	
	stop
	collapse (mean) exp_f_m_pc_bl exp_f_m_pc_fl1 exp_f_m_pc_phonesvy, by(ultra_poor)
	