* This do-file calculates Food Consumption CPI based on market price data for the endline sample 
* proxy food consumption basket. It excludes 2 items that are not comparable with previous rounds 
* of data collection (see notes in do-files).

* Inputs 
gl food_consumption_all_bl			"${TUP_DB}/Baseline/DataSets/Intermediate/food_consumption_all_bl.dta"
gl market_imputed_fl1 				"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"
gl food_consumption_all_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_consumption_all_phonesvy.dta"	
gl food_consumption_all_fl1		    "${TUP_DB}/Followup_1/DataSets/Intermediate/food_consumption_all_fl1.dta"
gl market_imputed_bl 				"${TUP_DB}/Baseline/DataSets/Intermediate/market_imputed_bl.dta"
gl market_imputed_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/market_imputed_phonesvy.dta"
gl phone_svy_profile				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* Outputs 
gl food_cpi_data					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_cpi_data.dta"	


use "${food_consumption_all_bl}", clear 

	* Keep only items that were consumed at baseline to fix the baseline consumption basket 
	* in terms of quantity for each HH
	keep if consumed == 1 
	
	* Keep the 25 food items that are included in the Phone Survey
	* Exclude "Other fruits" and "Other vegetables" since these are not comparable between rounds (items 64 and 84)
	keep if inlist(item,1,2,3,4,7,14,15,16,17,18,24,26,27,29,33,41,44,45,50,66,72,76,80)
		
	keep hhid district item consumed_qty_pc price
	rename (price consumed_qty_pc) (price_bl consumed_qty_pc_bl)
	
	* Fix eggs at baseline 
	replace price_bl = price_bl*12 if inlist(item, 33)
	
	preserve 
		use "${food_consumption_all_fl1}", clear 
		keep item district price
		duplicates drop 
		drop if price==. // no sweetener
		rename price price_fl1
		tempfile midline_prices
		save `midline_prices'
	restore 
	
	merge m:1 district item using "`midline_prices'" , keepusing(price_fl1) keep(1 3) nogen

	preserve 
	use "${market_imputed_phonesvy}", clear 
			
		keep district item round price_mean price_midlinecomp_mean
		duplicates drop
		
		* Since R1 is missing info on Dawlatabad, take info from R2  
		expand 2 if district == 1 & round == 2, gen(expand)
		replace round = 1 if expand == 1 
		
		drop expand
		
		* Using R2 market prices instead of R1 for R1 consumption data 
		reshape wide price_mean price_midlinecomp_mean, i(district item) j(round)
		
		gen price_mean = price_mean2 if item != 80
		* Fill in prices for Mango from R1 market survey 
		replace price_mean2 = price_mean1 if item == 80
		replace price_mean3 = price_mean1 if item == 80
		replace price_mean4 = price_mean1 if item == 80
		
		* Do the same for the inflation variable
		gen price_midlinecomp_mean = price_midlinecomp_mean2 if item != 80
		* Fill in prices for Mango from R1 market survey 
		replace price_midlinecomp_mean2 = price_midlinecomp_mean1 if item == 80
		replace price_midlinecomp_mean3 = price_midlinecomp_mean1 if item == 80
		replace price_midlinecomp_mean4 = price_midlinecomp_mean1 if item == 80
		
		rename (price_midlinecomp_mean1 price_midlinecomp_mean2 price_midlinecomp_mean3 price_midlinecomp_mean4 price_midlinecomp_mean) ///
			(price_phone1 price_phone2 price_phone3 price_phone4 price_phone)
	
		tempfile phonesvy_prices
		save `phonesvy_prices'
	restore 	
	
	merge m:1 district item using "`phonesvy_prices'" , keepusing(price_phone*) keep(1 3) nogen
	
	* Keep the endline sample (for now, if HH was survyed in at least one of the rounds)
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround ultra_poor) keep(3) nogen
	
	* Keep HHs surveyed in at least one of the rounds 
	keep if anyround == 1
	
	foreach suffix in "bl" "fl1" "phone" "phone1" "phone2" "phone3" "phone4" {
		
		* Fix baseline basket
		gen prox_exp_f_m_pc_item_base_`suffix' = consumed_qty_pc_bl * price_`suffix' * (30.5/7)
			lab var prox_exp_f_m_pc_item_base_`suffix' "Baseline basket item-level proxy expenditure, `suffix' price"
		
		bys hhid: egen prox_exp_f_m_pc_base_`suffix' = sum(prox_exp_f_m_pc_item_base_`suffix')
			lab var prox_exp_f_m_pc_base_`suffix' "Baseline basket proxy total expenditure, `suffix' price"
	}
	
	gen prox_food_exp_base = consumed_qty_pc_bl * price_bl * (30.5/7)
	lab var prox_food_exp_base "Baseline proxy food expenditure, item-level"	
		
		bys hhid: egen prox_tot_food_exp_base = sum(prox_food_exp_base)
		lab var prox_tot_food_exp_base "Proxy total baseline food expenditure"
		
		gen prox_share_bl = prox_exp_f_m_pc_item_base_bl / prox_tot_food_exp_base
		lab var prox_share_bl "Share of item in baseline proxy total food expenditure"
		
	gen inf_bl = (price_fl1 / price_bl) - 1	
	lab var inf_bl "Baseline to midline item-level inflation"
	
	gen inf_fl1 = (price_phone / price_fl1) - 1	
	lab var inf_fl1 "Midline to endline item-level inflation"
	
	/*table item, c(mean inf_bl mean inf_fl1) 
	
	table item if inf_bl > 1, c(mean inf_bl) 
	table item if inf_fl1 > 1, c(mean inf_fl1) 

	table item if inf_bl > 1, c(mean prox_share_bl count prox_share_bl)
	table item if inf_fl1 > 1, c(mean prox_share_bl count prox_share_bl)*/
	
	collapse (mean) prox_exp_f_m_pc_base_bl prox_exp_f_m_pc_base_fl1 prox_exp_f_m_pc_base_phone prox_exp_f_m_pc_base_phone1 prox_exp_f_m_pc_base_phone2 prox_exp_f_m_pc_base_phone3 prox_exp_f_m_pc_base_phone4
	
	* Create CPI variables / globals  
	gen cpi_food_fl1 = 100 
	gen cpi_food_bl = prox_exp_f_m_pc_base_bl / prox_exp_f_m_pc_base_fl1 * 100
	gen cpi_food_phone = prox_exp_f_m_pc_base_phone / prox_exp_f_m_pc_base_fl1 * 100
	
	sum cpi_food_fl1
	global cpi_food_fl1 `r(mean)'
	di "$cpi_food_fl1"
	
	sum cpi_food_phone
	global cpi_food_phone = round(r(mean),0.00001)
	di "$cpi_food_phone"

	sum cpi_food_bl
	global cpi_food_bl = round(r(mean),0.00001)
	di "$cpi_food_bl"
	
	gl cpi_econ_bl = $cpi_food_bl * 0.6 + $cpi_non_food_bl * 0.4
	gl cpi_econ_fl1 = 100
	gl cpi_econ_phone = $cpi_food_phone * 0.6 + $cpi_non_food_phone * 0.4	

	save "${food_cpi_data}", replace 
	
	
	