/*******************************************************************************	

Project:  		TUP - Afghanistan

Written by:  	Thomas Escande (tescande@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	 Computes the treatment effect on all main outcomes and present them in a unique graph in standard deviations. Figure 1  

CONTENT:		Part 0 - Create globals for directories and files	
				Part 1 - Preparing the dataset for the graph
				Part 2 - Running the first N-1 graphs
				Part 3 - Running the last graph (Child Schooling) which will contain the x axis and combining all graphs
				
				
INPUTS:     	

OUTPUTS:		* Figure 1   	

Notes: 			

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************
	clear all
	set more off
	set maxvar 20000


	global graph_opts title(, justification(left) color(black) span pos(11)) graphregion(color(white)) ylab(,angle(0) nogrid) xtit(,placement(center) justification(center)) yscale(noline) legend(on region(lc(none) fc(none)))
	
	global data_for_analysis			"${TUP_DB}/IE_Main_Paper/DataSets/Final/data_for_analysis_fl1_IEpaper.dta"
	global time_activities_up 			"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"
	global schooling_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"
	global health_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/health_fl1.dta"

	global output_gr 					"${TUP_DB}/Phone_Survey/Output/Raw"
	global output_gr2 					"${TUP_DB}/Phone_Survey/Output/Final/Figures"

	global controls				i.PRA_lottery
	global time_var				labor_particip tot_hh_pay hr_tot_labor_nohh_4w_d hr_livestock_4w_d hr_ownFarming_4w_d hr_ownBusiness_4w_d hr_oFarm_4w_d hr_maid_4w_d hr_outsideWork_4w_d hr_salEmp_4w_d hr_othPaidWork_4w_d 	

	global phone_svy_profile 			"${TUP_DB}/Phone_Survey\DataSets\Intermediate/phone_svy_profile.dta"
	
********************************************************************************
** Part 1: Preparing the dataset for the graph
********************************************************************************	

	use "${data_for_analysis}", clear
		merge 1:1 hhid using "${phone_svy_profile}"
		
	gen phone = (call_status_r1 == 1 | call_status_r2 == 1)
	gen fl1 = 1 
	
	keep if ultra_poor == 1
	
	*Aggregating most other time spent
		gen hr_othwork_4w_pf   		= hr_oFarm_4w_pf + hr_maid_4w_pf + hr_oPaidWork_4w_pf + hr_salEmp_4w_pf + hr_outWork_4w_pf
		gen hr_othwork_4w_pm   		= hr_oFarm_4w_pm + hr_maid_4w_pm + hr_oPaidWork_4w_pm + hr_salEmp_4w_pm + hr_outWork_4w_pm

	*Setting globals for the loop: main outcomes
		global all 					consumption_sum asset_sum time_sum time_sum_pm fin_sum revenues_sum psy_sum fem_empo childhealth 	
 
		global consumption_sum 		index_sdC_food_sec exp_tot_m_pc_ppp
		global fin_sum 				loan_ppp access_credit saving_4w_ppp  
		global asset_sum 			wealth_score tot_lstock_value_ppp
		global time_sum				hr_othwork_4w_pf hr_ownBiz_4w_pf hr_ownFarming_4w_pf hr_livestock_4w_pf hr_labor_nohh_4w_pf labor_particip_pf 	
		global time_sum_pm			hr_othwork_4w_pm hr_ownBiz_4w_pm hr_ownFarming_4w_pm hr_livestock_4w_pm hr_labor_nohh_4w_pm labor_particip_pm 	
		global revenues_sum			tot_hh_pay_ppp tot_biz_revenue_ppp tot_crop_revenue_ppp tot_lstock_revenue_ppp tot_hh_income_ppp
		global psy_sum 				psy_indexC_sdC_fl1_m psy_indexC_sdC_fl1
		global fem_empo 			index_sdC_f_empowerment index_sdC_hhexp
		global childhealth	   		diarrhea_yes
		

	*Label variable for the figure

		label var exp_tot_m_pc_ppp 			"Consumption per Capita"
	
		label var wealth_score 				"Household Asset Ownership Index"
		label var tot_lstock_value_ppp 		"Livestock Value" 

		label var tot_lstock_revenue_ppp 	"HH Livestock Revenues"
		label var tot_crop_revenue_ppp  	"HH Agriculture Revenues"
		label var tot_biz_revenue_ppp  		"HH Non-agricultural Business Revenues"
		label var tot_hh_pay_ppp 			"Paid Labor Income"
		label var tot_hh_income_ppp			"Total Household Income and Revenues"

		label var psy_indexC_sdC_fl1 		"Psychological Well-Being Index, Primary Woman"
		label var psy_indexC_sdC_fl1_m 		"Psychological Well-Being Index, Primary Man"

		label var index_sdC_hhexp 			"Household Expenditures Decision Index (1 Dimension)"

		label var diarrhea_yes				"Diarrhea Rate in Oldest U5 Child"

		label var loan_ppp 					"Household Total Outstanding Cash Loans"
		label var saving_4w_ppp				"Household Savings"
		label var access_credit				"Household Members Can Access Formal Credit if Needed"

		label var hr_livestock_4w_pm 		"Time Spent Working, HH Livestock"
		label var hr_ownFarming_4w_pm  		"Time Spent Working, HH Agriculture"
		label var hr_ownBiz_4w_pm  			"Time Spent Working, HH Non-Agricultural Business"
		label var hr_labor_nohh_4w_pm 		"Total Time Spent Working"
		label var hr_othwork_4w_pm 			"Time Spent Working, Other Work"
	
		label var hr_livestock_4w_pf 		"Time Spent Working, HH Livestock"
		label var hr_ownFarming_4w_pf  		"Time Spent Working, HH Agriculture"
		label var hr_ownBiz_4w_pf  			"Time Spent Working, HH Non-Agricultural Business"
		label var hr_labor_nohh_4w_pf		"Total Time Spent Working"
		label var hr_othwork_4w_pf 			"Time Spent Working, Other Work"	


********************************************************************************
** Part 2: Running the first N-1 graphs
********************************************************************************	
	*Generating control variables to use the standardization command
	gen 	control = 0 if treatment == 1
	replace control = 1 if treatment == 0
	
	local lab_loc = -1.5
	gen loc = `lab_loc' //For the location of the labels

	*Standradizing all the main outcomes with respect to the control group
	foreach group in $all {
		foreach var in ${`group'} {
			egen `var'_ind = weightave(`var'), normby(control)
		}
	}

	
		local k 	= 1
	foreach group in $all {
	*Creating parameters which will be useful throughout the loop
		gen counter = _n
		local i 	= 1	


		gen CI_l_fl1 	= .
		gen CI_h_fl1 	= .
		gen estim_fl1 	= .
		gen CI_l_phone 	= .
		gen CI_h_phone	= .
		gen estim_phone	= .
		
		local theLabels ""
		
	if "`group'" == "childhealth" {
		global title "Child Health"
	}
	if "`group'" == "consumption_sum" {
		global title "Consumption & Food Security"
	}
	if "`group'" == "fem_empo" {
		global title "Women's Empowerment"
	}
	if "`group'" == "fin_sum" {
		global title "Finance"
	}
	if "`group'" == "asset_sum" {
		global title "Assets"
	}
	if "`group'" == "revenues_sum" {
		global title "Income and Revenues"
	}
	if "`group'" == "psy_sum" {
		global title "Psychological Well-Being"
	}
	if "`group'" == "time_sum" {
		global title "Labor Supply and Time Use, Primary Woman"
	}
	if "`group'" == "time_sum_pm" {
		global title "Labor Supply and Time Use, Primary Man"
	}
	
		local j = 0
	foreach var in ${`group'} {
	
	*Running the treatment impact regression and saving coefficients and CI
	foreach sample in fl1 phone {	
		reg `var'_ind treatment $controls if `sample' == 1, r
			
			cap mat drop A_`var' 
			mat A_`var'  = r(table)
			replace CI_l_`sample' 	= A_`var'[5,1] 	if counter == `i'
			replace CI_h_`sample' 	= A_`var'[6,1]  if counter == `i'
			replace estim_`sample' 	= A_`var'[1,1] 	if counter == `i' 
			local theLabel : var label `var'
			local theLabels `"`theLabels' `i' "`theLabel'""'
			disp `theLabels'
	}		
			
			local i = `i' + 1	
			local j = `j' + 1
	}
	
			local j = `j' * 4 + 5 // Parameter for the y position: depends on the number of variables within the graph
		gen include = 1 if counter < `i'
		replace counter = . if counter >= `i'

		label define test`k' `theLabels'
		label value counter test`k'
		local k = `k' + 1

	*Generating the graph
	tw ///
		(rcap CI_l_fl1 CI_h_fl1 counter if include == 1 , hor lc(navy)) /// 
		(rcap CI_l_phone CI_h_phone counter if include == 1 , hor lc(red)) /// 
		(scatter counter estim_fl1 if include == 1, mc(navy)) ///
		(scatter counter estim_phone if include == 1, mc(red)) ///
		(scatter counter loc if include == 1, ms(none) mla(counter) mlabpos(0) mlabc(gs4) mlabsize(small)) ///		
		,	$graph_opts title("	$title",size(medsmall)) ylab("") ytit(" ") xlab("") xscale(range(-2.5 2.5)) ///
		xline(1, lc(gs11) lp(dash))  xline(0 , lc(gs11) lp(dash) ) legend(label(8 "Fl1 sample" 10 "Phone Survey sample")) fxsize(120) fysize(`j')  graphregion(margin(0 0 0 0)) plotregion(margin(0 0 2 2))  
 
	qui graph save "${output_gr}/figure1_`group'.gph" , replace

	*Dropping variables that will need to be re created
	drop  counter CI_l_* CI_h_* estim_* include
	}
	
	
********************************************************************************
** Part 3: Running the last graph (Child Schooling) which will contain the x axis
********************************************************************************

	use "${schooling_fl1}", clear
		merge m:1 hhid using "${phone_svy_profile}"
			
		gen phone = (call_status_r1 == 1 | call_status_r2 == 1)
		gen fl1 = 1 
		
		global all2 			schoolchild
		global schoolchild		days_missed_school_hh child_inschool_hh 

		label var child_inschool_hh  	"School Enrollment"
		label var days_missed_school_hh "School Absenteeism"

		gen 	control = 0 if treatment == 1
		replace control = 1 if treatment == 0

		gen loc = `lab_loc' //For the location of the labels
		drop if mi(treatment)

	*Standardizing the added variables
	foreach group in $all2 {
		foreach var in ${`group'} {
			egen `var'_ind = weightave(`var'), normby(control)
		}
	}
	
	
		local k 	= 1
		
	foreach group in $all2 {
	
		gen counter = _n
		local i 	= 1	
		
		gen CI_l_fl1 	= .
		gen CI_h_fl1 	= .
		gen estim_fl1 	= .
		gen CI_l_phone 	= .
		gen CI_h_phone	= .
		gen estim_phone	= .
		local theLabels ""
		
		if "`group'" == "schoolchild" {
			global title "Child Education"
		}

		local j = 0
	foreach var in ${`group'} {
	
	*Running the treatment impact regression and saving coefficients and CI		
		foreach sample in fl1 phone {	
			reg `var'_ind treatment $controls if `sample' == 1, r cluster(hhid)
		
			cap mat drop A_`var' 
			mat A_`var'  = r(table)
			replace CI_l_`sample' 	= A_`var'[5,1] 	if counter == `i'
			replace CI_h_`sample' 	= A_`var'[6,1]  	if counter == `i'
			replace estim_`sample' 	= A_`var'[1,1] 	if counter == `i' 
	
		}
		
		local theLabel : var label `var'
		local theLabels `"`theLabels' `i' "`theLabel'""'
		
		disp `theLabels'
		local i = `i' + 1	
		local j = `j' + 1
	}
	
	local j = `j' * 4 + 6
	gen include = 1 if counter < `i'
	replace counter = . if counter >= `i'

	label define test`k' `theLabels'
	label value counter test`k'
	local k = `k' + 1

	*Generating the graph
	tw ///
		(rcap CI_l_fl1 CI_h_fl1 counter if include == 1 , hor lc(navy)) /// 
		(rcap CI_l_phone CI_h_phone counter if include == 1 , hor lc(red)) /// 
		(scatter counter estim_fl1 if include == 1, mc(navy)) ///
		(scatter counter estim_phone if include == 1, mc(red)) ///
		(scatter counter loc if include == 1, ms(none) mla(counter) mlabpos(0) mlabc(gs4) mlabsize(small)) ///	
			,	$graph_opts title("	$title",size(medsmall)) ylab("") ytit(" ") xlab(-2.5(0.2)2.5 0 "0",format(%9.1f) labsize(vsmall)) xscale(range(-2.5 2.5)) ///
			xline(1, lc(gs11) lp(dash))  xline(0 , lc(gs11) lp(dash) ) fxsize(120) fysize(22)  graphregion( margin(0 0 0 0)) plotregion(margin(0 0 2 2)) ///
			xtit("Effect size in standard deviations of the control group", size(small)  margin(medsmall) justification(center))

	qui graph save "${output_gr}/figure1_`group'.gph" , replace
}


grc1leg2 ///
	"${output_gr}/figure1_consumption_sum.gph" ///
	"${output_gr}/figure1_asset_sum.gph" ///
	"${output_gr}/figure1_revenues_sum.gph" ///	
	"${output_gr}/figure1_time_sum.gph" ///	
	"${output_gr}/figure1_time_sum_pm.gph" ///	
	"${output_gr}/figure1_fin_sum.gph" ///
	"${output_gr}/figure1_psy_sum.gph" ///
	"${output_gr}/figure1_fem_empo.gph" ///
	"${output_gr}/figure1_childhealth.gph" ///
	"${output_gr}/figure1_schoolchild.gph" ///
	,  ysize(8) c(1)  graphregion(color(white)) imargin(0 0 0 0) name(Figure1) ///
		title("Follow-up 1 impacts on Phone Survey sample (HHs in R1 or R2)",size(small))
		
* Apply recording (figure out the commands to include in the do-file)
	gr_edit .legend.plotregion1.key[1].draw_view.setstyle, style(no)
// key[1] edits

	gr_edit .legend.plotregion1.key[2].draw_view.setstyle, style(no)
// key[2] edits

	gr_edit .legend.plotregion1.key[5].draw_view.setstyle, style(no)
// key[5] edits

	gr_edit .legend.plotregion1.label[1].draw_view.setstyle, style(no)
// label[1] edits

	gr_edit .legend.plotregion1.label[2].draw_view.setstyle, style(no)
// label[2] edits

	gr_edit .legend.plotregion1.label[5].draw_view.setstyle, style(no)
// label[5] edits

	gr_edit .legend.plotregion1.label[3].text = {}
	gr_edit .legend.plotregion1.label[3].text.Arrpush Follow-up 1 sample
// label[3] edits

	gr_edit .legend.plotregion1.label[4].text = {}
	gr_edit .legend.plotregion1.label[4].text.Arrpush Phone Survey R1, R2 sample
// label[4] edits

	gr_edit .legend.plotregion1.label[3].style.editstyle size(12-pt) editcopy
// label[3] size

	gr_edit .legend.plotregion1.label[4].style.editstyle size(12-pt) editcopy
// label[4] size

         	
graph export "${output_gr2}/1_impact_all.pdf" , replace as(pdf)


