/*******************************************************************************	

Project:  		AFG-TUP

Written by:  	Thomas Escande and Maria Camila Ayala		

Revision: 		

********************************************************************************	

THIS DO FILE: 	Generates tables for report


	** OUTLINE:		PART 1:  INSTALL NECESSARY PACKAGES  	
					PART 2:  SET DIRECTORIES	
					PART 3:  COPY stata.sty		
					PART 4:  CREATE DOCUMENT			
				  
	** WRITEN BY:   Thomas Escande (tescande@worldbank.org)
					Maria Camila Ayala (mayalaguerrero@worldbank.org)


********************************************************************************
					   INSTALL NECESSARY PACKAGES  							   
********************************************************************************/
	
	* Install necessary packages
	*ssc install texdoc				// Write a .tex document from Stata
	*ssc install texify				// Compile the document into PDF

/*******************************************************************************
							SET DIRECTORIES					   
********************************************************************************/
clear all
set more off
set maxvar 30000
	* Set folder paths
	global	do							"${Phone_Survey_do}/Analysis"
	global	ct							"${Phone_Survey_do}/Construct"
	global	ct_bl						"${Baseline_do}/Construct"
	global  data_for_analysis			"${TUP_DB}/IE_Main_Paper/DataSets/Final/data_for_analysis_fl1_IEpaper.dta"
	global  data_for_analysis_bl		"${TUP_DB}/IE_Main_Paper/DataSets/Final/data_for_analysis_bl_IEpaper.dta"
	global 	phone_svy_profile			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	
*Rosters
	global schooling_fl1				"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"
	global schooling_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/schooling_bl.dta"
	global health_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/health_fl1.dta"
	global village_bl					"${TUP_DB}/Baseline/DataSets/Intermediate/village_clean_bl.dta"
	global profile_info 				"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	global time_activities_ses 			"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta"
	global mobile_phone_ownership_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/mobile_phone_ownership_fl1.dta"
	global wellbeing_index_gender 		"${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_gender_fl1.dta"	
	global psy_bl 						"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta"
	global roster_bl_balance 			"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"
	
*Output
	global	output						"${TUP_DB}/Phone_Survey/Output/Final"
	global	output_raw					"${TUP_DB}/Phone_Survey/Output/Raw"
	

/*****************************************************************************************************************
							Updating merged databases if needed to make sure the most up to date one is being used			   
******************************************************************************************************************/
/*
do "${ct}/data_for_analysis_fl1.do"
do "${ct_bl}/data_for_analysis_bl.do"
*/
/*******************************************************************************
							COPY stata.sty				   
********************************************************************************
	This is a tex style to format stata code. It can be donwloaded as below 
	and needs to be saved in the same folder as your .tex file. You can also
	copy it to wherever your tex styles are saved and then you only need to 
	do it once. If you can figure out where that is.
	
	This file is already on the GitHub folder (as the code below may break),
	but this is how we got it originally.	
------------------------------------------------------------------------------*/

	* Change current directory to the directory where the .tex file will be saved
	cd 	"${output}"
	
	* Copy the style to the folder path / If not working, copy directly in the output folder
	*copy 	https://www.stata-journal.com/production/sjlatex/stata.sty 	stata.sty


*	Create the globals which will be used later on in the texdoc dofile

	* Controls
		global controls				i.PRA_lottery
		global controls_all			i.PRA_lottery property_score_bl did_livestock_bl 

		global round_1_2 1
		
*-------------------------------------------------------------------------------*
* 		MAIN TABLES 														   	*
*-------------------------------------------------------------------------------*

if $round_1_2 == 0 {
	* Variables which should be controlled for in the FWER computation
		global fwer_outcomes 		exp_tot_m_pc_ppp tot_lstock_value_ppp wealth_score fin_index_sdC_fl1 psy_indexC_sdC_fl1 psy_indexC_sdC_fl1_m hr_labor_nohh_4w_pf hr_labor_nohh_4w_pm index_sdC_f_empowerment
	
	* Table 1: Impact on Consumption, Food Security and Assets
		global consumption 			exp_tot_m_pc_ppp exp_tot_m_pc_c_ppp exp_tot_m_pc_1_ppp exp_tot_m_pc_c_1_ppp exp_tot_m_pc_3_ppp exp_tot_m_pc_c_3_ppp exp_tot_m_pc_4_ppp exp_tot_m_pc_c_4_ppp
		global foodsecurity			index_sdC_food_sec c14_7 c14_3_ac c14_5_ac ///
										index_sdC_food_sec_1 c14_7_1 c14_3_1_ac c14_5_1_ac ///
										index_sdC_food_sec_4 c14_7_4 c14_3_4_ac c14_5_4_ac // issue
		global asset_sum 			tot_lstock_value_ppp tot_lstock_w_value_ppp tot_lstock_w95_value_ppp wealth_score_0 wealth_score_2 wealth_score_4 // issue 
	
	* Table 2: Impact on Financial Inclusion and Income and Revenues from Productive Activities
		global fin_sum 				fin_index_sdC_4 access_credit_4 saving_ppp saving_win_ppp saving_1_ppp saving_win_1_ppp saving_3_ppp saving_win_3_ppp  saving_4_ppp saving_win_4_ppp loan_dummy_1 loan_dummy_3 loan_dummy_4 loan_1_ppp loan_win_1_ppp loan_3_ppp loan_win_3_ppp loan_4_ppp loan_win_4_ppp 
		global revenues_sum			tot_hh_income_1_ppp tot_hh_income_1_w_ppp tot_hh_income_4_ppp tot_hh_income_4_w_ppp tot_lstock_revenue_1_ppp tot_lstock_revenue_1_w_ppp tot_lstock_revenue_4_ppp tot_lstock_revenue_4_w_ppp tot_crop_revenue_ppp tot_crop_revenue_win_ppp tot_biz_revenue_ppp tot_biz_revenue_win_ppp tot_hh_pay_ppp		
	
	* Table 3: Impact on Labor Supply and Time Use, Primary Woman and Man, Last 4 Weeks
		global time_sum				labor_particip did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp ///
										did_oPaidWork k30_out_hrs_4w k30_in_hrs_4w

	* Table 4: Impact on Psychological Well-being	
		global index5				psy_indexC_sdC_0 satisf_z_sdC_0 hap_z_sdC_0  ///
										psy_indexC_sdC_10 satisf_z_sdC_10 hap_z_sdC_10 ///
										psy_indexC_sdC_2  satisf_z_sdC_2 hap_z_sdC_2  cesd_z_sdC_2
		
	* Table 5: Impact on Education and Health
		global enrollment_hh 		child_inschool_hh
		global health_sum			diarrhea_yes	
		
	* Table 6: Impact on Women's Empowerment
		global f_empowerment		index_sdC_f_empowerment index_sdC_hhexp index_sdC_child_decisions index_sdC_body_econopp ///
			index_sdC_role_prod_act index_sdC_social_norms index_sdC_social_capital
			
	* Deatils of food / non-food consumption		
		global cons_detail 			exp_tot_m_pc_ppp exp_tot_m_pc_c_ppp exp_tot_m_pc_ppp exp_tot_m_pc_c_ppp exp_f_tot_m_pc_ppp ///
									exp_f_tot_m_pc_c_ppp exp_nf_tot_m_pc_ppp exp_nf_tot_m_pc_c_ppp exp_tot_m_pc_1_ppp exp_tot_m_pc_c_1_ppp /// 		   
									exp_f_tot_m_pc_1_ppp exp_f_tot_m_pc_c_1_ppp exp_nf_tot_m_pc_1_ppp exp_nf_tot_m_pc_c_1_ppp exp_tot_m_pc_3_ppp ///
									exp_tot_m_pc_c_3_ppp exp_f_tot_m_pc_3_ppp exp_f_tot_m_pc_c_3_ppp exp_nf_tot_m_pc_3_ppp exp_nf_tot_m_pc_c_3_ppp ///
									exp_tot_m_pc_4_ppp exp_tot_m_pc_c_4_ppp exp_f_tot_m_pc_4_ppp exp_f_tot_m_pc_c_4_ppp exp_nf_tot_m_pc_4_ppp  ///
									exp_nf_tot_m_pc_c_4_ppp
									
	* Shocks for impact tables 
		global shock_impact			anyshock illness recover g2_0 g2_1 g2_2 g2_3 g2_4 g2_5 g2_6 g2_7 g2_8
			
	* Additional outcomes 
		global other_vars 			trans_rec trans_value_ppp trans_value_win_ppp hasid_pf hasid_pm ///
										z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 t5_score t5_2_score ///
										t6_yn t6_2_yn t9_ratio t10_ratio t8 t4_yn t4_1_1 t4_1_2 t4_1_3		
	* WE detail 									
		global empower_vars 		index_sdC_f_empowerment $hhexp $child_decision $body_econopp $role_prod_act $social_norms $social_capital
		
	* Vars for shocks 
		global shock_vars 			exp_tot_m_pc_ppp  exp_f_tot_m_pc_ppp exp_nf_tot_m_pc_ppp exp_tot_m_pc_1_ppp /// 		   
									exp_f_tot_m_pc_1_ppp exp_nf_tot_m_pc_1_ppp exp_tot_m_pc_3_ppp ///
									exp_f_tot_m_pc_3_ppp exp_nf_tot_m_pc_3_ppp ///
									exp_tot_m_pc_4_ppp exp_f_tot_m_pc_4_ppp exp_nf_tot_m_pc_4_ppp  ///
									index_sdC_food_sec index_sdC_food_sec_1 index_sdC_food_sec_4 ///
									tot_lstock_w_value_ppp wealth_score_0 wealth_score_2 wealth_score_4 ///
									fin_index_sdC_4 saving_win_ppp saving_win_1_ppp saving_win_3_ppp saving_win_4_ppp ///
									access_credit_4 loan_dummy_1 loan_win_1_ppp loan_win_3_ppp loan_win_4_ppp ///
									tot_hh_income_1_w_ppp tot_hh_income_4_w_ppp tot_lstock_revenue1 tot_lstock_revenue4 ///
									tot_crop_revenue_w tot_biz_revenue_w tot_hh_pay_ppp ///
									psy_indexC_sdC_0 satisf_z_sdC_0 hap_z_sdC_0  ///
									psy_indexC_sdC_10 satisf_z_sdC_10 hap_z_sdC_10 ///
									psy_indexC_sdC_2  satisf_z_sdC_2 hap_z_sdC_2  cesd_z_sdC_2 ///
									f_empowerment index_sdC_hhexp child_decisions body_econopp role_prod_act social_norms social_capital
	}
	
		
if $round_1_2 == 1 {
	* Variables which should be controlled for in the FWER computation
		global fwer_outcomes 		exp_tot_m_pc_ppp tot_lstock_value_ppp wealth_score fin_index_sdC_fl1 psy_indexC_sdC_fl1 psy_indexC_sdC_fl1_m hr_labor_nohh_4w_pf hr_labor_nohh_4w_pm index_sdC_f_empowerment
	
	* Table 1: Impact on Consumption, Food Security and Assets
		global consumption 			exp_tot_m_pc_1_ppp exp_f_tot_m_pc_1_ppp exp_nf_tot_m_pc_1_ppp
		global foodsecurity			index_sdC_food_sec_1 c14_7_1 c14_3_1_ac c14_5_1_ac
								
		global asset_sum 			wealth_score_2 num_radio_CD_2  num_TV_2  num_DishTV_2  num_VCR_DVD_2  num_fridge_2  num_generator_2  num_matress_2  ///
			num_mobile_phone_2  num_non_mobilephone_2 num_iron_2  num_bedframe_2  num_jewelry_2  num_mosquitonet_2  /// 
			num_mosq_repel_candle_2  num_fan_2  num_camera_2 property_score_2 own_house_Land_2 own_nonHouse_Land_2 own_othHouse_2
	
	* Table 2: Impact on Financial Inclusion and Income and Revenues from Productive Activities
		global fin_sum 				saving_1_ppp saving_win_1_ppp loan_dummy_1 loan_1_ppp loan_win_1_ppp  
		global revenues_sum			tot_hh_income_1_ppp tot_hh_income_1_w_ppp tot_hh_income_1_noag_ppp tot_hh_income_1_w_noag_ppp ///
										tot_lstock_revenue_1_ppp tot_lstock_revenue_1_w_ppp tot_crop_revenue_ppp ///
										tot_crop_revenue_win_ppp tot_biz_revenue_ppp tot_biz_revenue_win_ppp tot_hh_pay_ppp ///
										tot_pf_pay_ppp tot_pf_pay_win_ppp tot_pm_pay_ppp tot_pm_pay_win_ppp		 
	* Table 3: Impact on Labor Supply and Time Use, Primary Woman and Man, Last 4 Weeks
		global time_sum				labor_particip did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp ///
										did_oPaidWork

	* Table 4: Impact on Psychological Well-being	
		global index5					psy_indexC_sdC_10 satisf_z_sdC_10 hap_z_sdC_10 cesd_z_sdC_2 ///
										psy_indexC_sdC_2 satisf_z_sdC_2 hap_z_sdC_2
										
	* Table 5: Impact on Education and Health
		global health_sum	
		global enrollment_hh 		child_inschool_hh
		
	* Table 6: Impact on Women's Empowerment
		global f_empowerment		index_sdC_f_empowerment index_sdC_hhexp index_sdC_child_decisions index_sdC_body_econopp ///
			index_sdC_role_prod_act index_sdC_social_capital
			
	* Deatils of food / non-food consumption		
		global cons_detail 			exp_tot_m_pc_1_ppp exp_tot_m_pc_c_1_ppp exp_f_tot_m_pc_1_ppp exp_f_tot_m_pc_c_1_ppp ///
										exp_nf_tot_m_pc_1_ppp exp_nf_tot_m_pc_c_1_ppp 
	* WE detail 									
		global empower_vars 		index_sdC_f_empowerment $hhexp $child_decision $body_econopp $role_prod_act $social_capital
	
	* Shocks for impact tables 
		global shock_impact			anyshock illness recover g2_0 g2_1 g2_2 g2_3 g2_4 g2_5 g2_6 g2_7 g2_8
		
	* Additional outcomes 
		global other_vars 			trans_rec trans_value_ppp trans_value_win_ppp trans_rec_shock trans_value_shock_ppp trans_value_shock_win_ppp ///
										hasid_pf hasid_pm ///
										z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0
										//t5_score t5_2_score t6_yn t6_2_yn t9_ratio t10_ratio t8 t4_yn t4_1_1 t4_1_2 t4_1_3	
										
	* Additional livestock outcomes 
		global livestock_sales 		k7_1 k7_2 k7_3 k7_4 tot_lstock_unit tot_lstock_unit_cow k36 k36_shock tot_lstock_value_ppp tot_lstock_value_cow

										
	* Additional income vars 
		global income_vars 			k44_1 k44_2 k44_3 k44_4 k44_5 k46_1 k46_2 k46_3 k46_4 k46_5 

	* Vars for shocks 
		global shock_vars 			exp_tot_m_pc_1_ppp exp_f_tot_m_pc_1_ppp exp_nf_tot_m_pc_1_ppp ///
									celeb_pc_c_1_ppp hh_items_pc_c_1_ppp hhrepair_pc_c_1_ppp medical_pc_c_1_ppp wedd_pc_c_1_ppp ///
									index_sdC_food_sec_1 /// 
									wealth_score_2 ///
									saving_win_1_ppp loan_win_1_ppp loan_dummy_1 ///
									tot_hh_income_1_w_ppp tot_lstock_revenue1 ///
									tot_crop_revenue_w tot_biz_revenue_w tot_hh_pay_ppp ///
									psy_indexC_sdC_10 satisf_z_sdC_10 hap_z_sdC_10 ///
									psy_indexC_sdC_2  satisf_z_sdC_2 hap_z_sdC_2  cesd_z_sdC_2 ///
									f_empowerment index_sdC_hhexp child_decisions body_econopp role_prod_act social_capital
	}		

		
*-------------------------------------------------------------------------------*
* 		APPENDIX 														   		*
*-------------------------------------------------------------------------------*

	* Table A1. Household Socioeconomic Conditions
		global hh_general_desc		hhhead_female illiteracy_pf illiteracy_pm
		global enrollment_table1	girl_inschool_hh boy_inschool_hh
		global consump_assets		exp_tot_m_pc_ppp
		global consump_assets3 		below_pov_af savings_dummy loan_dummy own_Land_yes own_mobile_phone
		global psych_bl	 			happy_i27_f cesd_f_md happy_i27_m  cesd_m_md
		global panelb				employment_pf employment_pm lstock_yes_cow lstock_yes_goat lstock_yes_chicken crop_yes biz_yes	
		
	* Table A2: Baseline Village Characteristics
		global inst_presence 		prim_any secon_any health_any vet_present bank_any microfin_any
		global inst_dist			prim_near_dur secon_near_dur health_near_dur vet_near_dur bank_near_dur microfin_near_dur
		global electricity			elect_grid_days
		global conflict				conflict_yes	
	 
	* Table A4: Baseline Balance Test
		global hh_general_bl		hhhead_female illiteracy_pf illiteracy_pm diarrhea_yes
		global enrollment_bl		girl_inschool_hh boy_inschool_hh
		global consump_bl			exp_tot_m_pc_ppp index_sdC_food_sec
		global fin_bl 				fin_index_sdC_bl loan_ppp saving_ppp
		global rev_bl				tot_hh_income_ppp tot_lstock_revenue_ppp tot_crop_revenue_ppp tot_biz_revenue_ppp tot_hh_pay_ppp
		global asset_sum_bl			tot_lstock_value_ppp wealth_score property_score
        global labor_pf_bl          did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork		
		global empower_bl           index_sdC_f_empowerment index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital index_sdC_social_norms  
		global attrition_r1			attrition_r1 attrition_phone_r1 /*attrition_anytime_r1*/
		global attrition_r2 		attrition_r2 attrition_phone_r2 /*attrition_anytime_r2*/

	* Table A5: Treatment Compliance Based on Follow-up 1
		global element_vars 	 	r80 r81 r13 r54 r1 r3 r9 r11 r16 r24

	* Table A6: Impact on Livestock Tenancy and Revenues From Animal Products
		global lstock_type			lstock_yes lstock_yes_cow lstock_yes_sheep lstock_yes_goat lstock_yes_chicken
		global revenue_type			lstock_rev_sales_ppp prod_revenue_yogurt_ppp  prod_revenue_milk_ppp prod_revenue_egg_ppp prod_revenue_butter_ppp 

	* Table A7: Impact on Outstanding Loans and Type of Loan
		global loan_index 			loan_dummy consumption_loan productive_loan formal_loan_dummy
		
	* Table A8: Impact on Household Expenditures Decisions Index and Children's Investment Decisions Index
		gl hhexp 					index_sdC_hhexp h1_ac h2_ac h3_ac h4_ac h5_ac h6_ac h7_ac h8_ac
		gl child_decision 			index_sdC_child_decisions h9_ac h10_ac h11_ac h12_ac h13_ac
		
	* Table A9: Impact on Fertility and Mobility Decisions/Access to Inputs Index and Economic Opportunities Index
		gl body_econopp				index_sdC_body_econopp h14_ac h28_ac h31_ac h24_ac h30 mobile_yes_pf
		gl role_prod_act 			index_sdC_role_prod_act did_labor_nohh owner_manager_pf

	* Table A10: Impact on Aspirations for Daughters Index, Political Involvement and Social Capital Index
		gl social_norms				index_sdC_social_norms ed_level_d ed_help_d age_marriage_d
		gl social_capital			index_sdC_social_capital z2_index z1_3_index n1 n2			
	
	* Table A11. Impact on Women's Empowerment in Households with Primary Woman and Primary Man
		global f_empowerment_maleh	index_sdC_f_empowerment_m index_sdC_hhexp_m index_sdC_child_decisions_m index_sdC_body_econopp_m index_sdC_role_prod_act_m index_sdC_social_norms_m index_sdC_social_capital_m		
	
	* Table A12: Balance Checks on Household Gender Composition at Baseline
		gl hh_comp	   				hh_only_pf hh_only_pm pm_pf_hh tot_oth_f_adult_fl1 tot_oth_m_adult_fl1 tot_kidf_6_14_fl1 tot_kidm_6_14_fl1 tot_kidf_15_17_fl1 tot_kidm_15_17_fl1 	
		
	* Table A13: Impact on Time Use by Activity with Male Interaction, 4 weeks
		global activities   		labor_nohh  HHChores 
	
	* Table A14. Impact on Psychological Well-Being, Phone Ownership and Children's Education with Male Interaction
		global psychological     	psy_indexC_sdfC_fl1   
		global school 				child_inschool_hh days_missed_school_hh
		
	* Table A15: Conditional Average Treatment Effect on Consumption and Value of Livestock by Baseline Entrepreneurial Traits
		gl entrepreneurial  		entreppower entrepachiev entreplocus entreppoly entreptenac entrepimpuls  
		gl cate_outcome 			exp_tot_m_pc_ppp tot_lstock_value_ppp	
		
	* Table A16: Robustness Checks: Impact on Winsorized Values
		gl winsorized_v				exp_tot_m_pc_w_ppp loan_win_ppp tot_lstock_revenue_w_ppp exp_tot_m_pc_c_ppp	
	
	* Date 
		global date = word(c(current_date),1) + word(c(current_date),2) + word(c(current_date),3)

******************** Program for the do file
/* coeff_treat is used to calculate and save the different outputs of a regression in globals which will be used
to automatically generate tables in latex. Options to change the format of the figures using "N_dec"
It should be run after a regression and a summary of the dependent variable
*/
cap prog drop coeff_treat //clearing any program that might exist under that name. Always start with that line

	prog def coeff_treat

args name_coeff name_var N_dec


local dec = 3
if "`N_dec'" != "3" & "`N_dec'"!= "" {
local dec = 1
}

local mean = `r(mean)'
if `mean' >= 0 {
	global meanpos = `mean'
}
if `mean' < 0 {
	global meanpos = -`mean'
}

local sd = `r(sd)'
	if `dec'==1 & `r(mean)'>=100 & `sd'!=0 {
	global `name_coeff'm0 :  di %10.0fc `r(mean)'
		if `sd'==0 {
			global `name_coeff'm0 " "
		}
	}
	else {
	global `name_coeff'm0 :  di %10.`dec'fc `r(mean)'
	}
	if `dec'==1 & `r(sd)'>=100 & `sd'!=0 {
	global `name_coeff's0 :  di %10.0fc `r(sd)' 
		if `sd'==0 {
			global `name_coeff's0 " "
		}
	}
	else {
	global `name_coeff's0 :  di %10.`dec'fc `r(sd)'
			}
	if `dec'==1 & _b[`name_var']>=100 & `sd'!=0 {
	global `name_coeff't :  di %10.0fc _b[`name_var']
		if `sd'==0 {
			global `name_coeff't " "
		}
	}
	else {
	global `name_coeff't :  di %10.`dec'fc _b[`name_var']
	}

	if `dec'==1 & _se[`name_var']>=100 & `sd'!=0 {
	global `name_coeff'tse :  di %10.0fc _se[`name_var']
		if `sd'==0 {
			global `name_coeff'tse " "
		}
	}
	else {
	global `name_coeff'tse :  di %10.`dec'fc _se[`name_var']
	}



*Impact in percentage:

 	global `name_coeff'imp1 =   _b[`name_var'] /$meanpos * 100

if ${`name_coeff'imp1} >= 10 {
	global `name_coeff'imp1 :  di %2.0f ${`name_coeff'imp1}	
}
if ${`name_coeff'imp1} < 10 {
	global `name_coeff'imp1 :  di %1.0f ${`name_coeff'imp1}	
}

if mi(${`name_coeff'imp1}) & `sd'!=0 {
global `name_coeff'imp1 " NA"
}
if `sd'==0 {
global `name_coeff'imp1 " "
}  

*Impact in standard deviation: 
global `name_coeff'imp2 = _b[`name_var']/`sd'	
global `name_coeff'imp2 : di %10.3fc ${`name_coeff'imp2}

if mi(${`name_coeff'imp2}) & `sd'!=0 {
global `name_coeff'imp2 " NA"
} 
if `sd'==0 {
global `name_coeff'imp2 " "
} 

*Other locals
if `sd' != 0 { // change from ${`name_coeff'm0}
	global R_`name_coeff' :  di %10.3f e(r2)
	global N_`name_coeff' : di %10.0fc e(N)
}
else {
	global R_`name_coeff' " "
	global N_`name_coeff' " "
}

*Pvalues
if `sd' != 0 { // change from ${`name_coeff'm0}
global `name_coeff'p :  di %10.3f (2 * ttail(e(df_r), abs(_b[`name_var']/_se[`name_var'])))


global `name_coeff't = /*"$" +*/ "${`name_coeff't}" /*+ "$"*/ // Commenting this out while using Excel	
*Adding the star
	*disp "`i'"
		if  ${`name_coeff'p} <= 0.1 {
		global `name_coeff't = "${`name_coeff't}" + "*"
			
			if ${`name_coeff'p} <= 0.05 {
			global `name_coeff't = "${`name_coeff't}" + "*"

				if ${`name_coeff'p} <= 0.01 {
				global `name_coeff't = "${`name_coeff't}" + "*"
				
			}				
		}
	}
}
else {
	global `name_coeff'p = " "
	global `name_coeff't = " "
}

// Commenting this out while using Excel	
/*Putting all numbers in string to have them in math mode in Latex
global `name_coeff'm0 = "$" + "${`name_coeff'm0}" + "$"
global `name_coeff's0 = "$" + "${`name_coeff's0}" + "$"
global `name_coeff'tse = "$" + "${`name_coeff'tse}" + "$"
global `name_coeff'p = "$" + "${`name_coeff'p}" + "$"
global N_`name_coeff' = "$" + "${N_`name_coeff'}" + "$"
global R_`name_coeff' = "$" + "${R_`name_coeff'}" + "$"
global `name_coeff'imp1 = "$" + "${`name_coeff'imp1}" + "$"
global `name_coeff'imp2 = "$" + "${`name_coeff'imp2}" + "$" */
	end // 

	
****************Program 2****************************************
/* stat_estim is used to calculate and save the different outputs of a regression for a specific variable in globals which will be used
to automatically generate tables in latex. Options to change the format of the figures using "N_dec"
It should be run after a regression 
*/
	cap prog drop stat_estim
	prog def stat_estim
	args name_var var N_dec

local dec = 3
if "`N_dec'" != "3" & "`N_dec'"!= "" {
local dec = 1
}
	* Coefficient
	global `name_var' :  di %4.`dec'f _b[`var']
							
	* Standard error
	global `name_var'sd :  di %4.`dec'f _se[`var']
							
	* P-value
	global `name_var'p: di %4.3f (2 * ttail(e(df_r), abs(_b[`var']/_se[`var'])))
	
	*Other locals
	global `name_var'_R :  di %10.3f e(r2)
	global `name_var'_N :  di %15.0f e(N)

	global `name_var'_number = ${`name_var'}	
	*global `name_var' = "$" + "${`name_var'}" + "$"
*Adding the star
	*disp "`i'"
		if  ${`name_var'p} <= 0.1 {
		global `name_var' = "${`name_var'}" + "*"			
			if ${`name_var'p} <= 0.05 {
			global `name_var' = "${`name_var'}" + "*"
				if ${`name_var'p} <= 0.01 {
				global `name_var' = "${`name_var'}" + "*"				
			}				
		}
	}	

		/*if  ${`name_var'p} > 0.1 {
		global `name_var' = "${`name_var'}" + "\hspace*{0.5cm}"			
			if ${`name_var'p} > 0.05 & ${`name_var'p} <=0.01 {
			global `name_var' = "${`name_var'}" + "\hspace*{0.34cm}"
				if ${`name_var'p} > 0.01 & ${`name_var'p} <=0.05 {
				global `name_var' = "${`name_var'}" + "\hspace*{0.167cm}"				
			}				
		}
	} 

	if  ${`name_var'_number} >= 0 {
global `name_var' = "\hspace*{0.27cm}" + "${`name_var'}" 
		}
	
	global `name_var'p 	= "$" + "${`name_var'p}" + "$"
	global `name_var'sd = "$" + "${`name_var'sd}" + "$"
	global `name_var'_N = "$" + "${`name_var'_N}" + "$"
	global `name_var'_R = "$" + "${`name_var'_R}" + "$"*/
			end //
	
	
*****************Program 3 *Test of equality****************************************
/* test_interaction is used to calculate and save the different outputs of an equality test. Generally used after a regression
with an interaction to test the significance of the effect combining the main effect and the interacted effect.
*/
	cap prog drop test_interaction //clearing any program that might exist under that name. Always start with that line

	prog def test_interaction
	args name_var  treatment indep_var_t
	
	*Test of equality
	test `treatment' + `indep_var_t'  = 0
	global `name_var'_t :  di %4.3f r(p)
	
	*Adding the star
		*disp "`i'"
			global `name_var'_p  ${`name_var'_t}
			if  ${`name_var'_t} <= 0.1 {
			global `name_var'_p = "${`name_var'_p}" + "*"			
				if ${`name_var'_t} <= 0.05 {
				global `name_var'_p = "${`name_var'_p}" + "*"
					if ${`name_var'_t} <= 0.01 {
					global `name_var'_p = "${`name_var'_p}" + "*"				
				}				
			}
		}	
		
	end //	
	
*****************Program 3b *Test of equality for Shocks****************************************
/* test_interaction is used to calculate and save the different outputs of an equality test. Generally used after a regression
with an interaction to test the significance of the effect combining the main effect and the interacted effect.
*/
	cap prog drop test_interaction_shock //clearing any program that might exist under that name. Always start with that line

	prog def test_interaction_shock
	args name_var  treatment indep_var_t
	
	*Test of equality
	test `treatment' + `indep_var_t'  = "$shock"
	global `name_var'_x :  di %4.3f r(p)
	
	*Adding the star
		*disp "`i'"
			global `name_var'_y  ${`name_var'_x}
			if  ${`name_var'_x} <= 0.1 {
			global `name_var'_y = "${`name_var'_y}" + "*"			
				if ${`name_var'_x} <= 0.05 {
				global `name_var'_y = "${`name_var'_y}" + "*"
					if ${`name_var'_x} <= 0.01 {
					global `name_var'_y = "${`name_var'_y}" + "*"				
				}				
			}
		}	
		
	end //	
	
	
*****************Program 4 *Impact in SD and % when interaction ****************************************
/* impact_interaction is used to calculate and save the different outputs of a specific variable in regression. Generally used after a regression
with an interaction to gather the outputs of the interaction.
*/
	cap prog drop impact_interaction //clearing any program that might exist under that name. Always start with that line

	prog def impact_interaction
	args name_var  treatment indep_var_t indep_var indic //indic will be 1 if want to run the impact on treatment only, 2 if want to run on treatment + interaction term

	local mean = `r(mean)'
if `mean' >= 0 {
	global meanpos = `mean'
}
if `mean' < 0 {
	global meanpos = -`mean'
}

local sd = `r(sd)'
	
if `indic' == 1 {
	global `name_var'imp2_1 :  di %4.2f (_b[`treatment']) / `sd'
	global `name_var'imp1_1 =   (_b[`treatment']) /$meanpos * 100
			if ${`name_var'imp1_1} >= 10 {
				global `name_var'imp1_1 :  di %2.0f ${`name_var'imp1_1}
					}
			if ${`name_var'imp1_1} < 10 {
						global `name_var'imp1_1 :  di %1.0f ${`name_var'imp1_1}
					}
}	
if `indic' == 2 {					
	global `name_var'imp2_2 :  di %4.2f (_b[`treatment'] + _b[`indep_var_t']) / `sd'
	global `name_var'imp1_2 =   (_b[`treatment'] + _b[`indep_var_t']) /$meanpos * 100
			if ${`name_var'imp1_2} >= 10 {
				global `name_var'imp1_2 :  di %2.0f ${`name_var'imp1_2}
					}
			if ${`name_var'imp1_2} < 10 {
						global `name_var'imp1_2 :  di %1.0f ${`name_var'imp1_2}
					}
}
if `indic' == 3 {					
	global `name_var'imp2_3 :  di %4.2f (_b[`treatment'] + _b[`indep_var_t']+ _b[`indep_var']) / `sd' // add "+ + _b[`indep_var']"
	global `name_var'imp1_3 =   (_b[`treatment'] + _b[`indep_var_t'] + _b[`indep_var']) /$meanpos * 100 // add "+ + _b[`indep_var']"
			if ${`name_var'imp1_3} >= 10 {
				global `name_var'imp1_3 :  di %2.0f ${`name_var'imp1_3}
					}
			if ${`name_var'imp1_3} < 10 {
						global `name_var'imp1_3 :  di %1.0f ${`name_var'imp1_3}
					}
}
	end //	

/*******************************************************************************
							CREATE DOCUMENT			   
*******************************************************************************/

* Main tables - without baseline controls 
	do					"${do}/prelim_analysis.do"	
	
	stop stop
	texdoc do			"${do}/blfl_balance_shocked_up.do", replace 
	texify 				"${output_raw}/blfl_balance_shocked_up_${date}.tex"		// Turns it into a PDF document
	copy				"${output_raw}/blfl_balance_shocked_up_${date}.tex"    /// 
						"${output}/blfl_balance_shocked_up_${date}.tex", replace
	
	stop
	
	texify 				"${output_raw}/baseline_balance_shocked_up_${date}.tex"		// Turns it into a PDF document
	copy				"${output_raw}/baseline_balance_shocked_up_${date}.tex" /// Save in final outputs folder
						"${output}/baseline_balance_shocked_up_${date}.tex", replace

	
stop*/
	do					"${do}/shocks_interaction.do"
	
	stopstop
	do					"${do}/prelim_analysis.do"*/
	
	*texify 			"${output_raw}/MainTables_AFG_TUP_WP_${date}.tex"		// Turns it into a PDF document

	*copy			"${output_raw}/MainTables_AFG_TUP_WP_${date}.tex" /// Save in final outputs folder
				*	"${output}/MainTables_AFG_TUP_WP_${date}.tex", replace

 /*Main tables in current USD
	texdoc do		"${do}/IE_WP_main_tables_currentUSD.do", replace	// Creates a .tex document
	texify 			"${output_raw}/MainTables_AFG_TUP_WP_currentUSD_${date}.tex"		// Turns it into a PDF document 

	copy			"${output_raw}/MainTables_AFG_TUP_WP_currentUSD_${date}.tex" /// Save in final outputs folder
					"${output}/MainTables_AFG_TUP_WP_currentUSD_${date}.tex", replace*/
	
* Online Appendix
	texdoc do		"${do}/baseline_balance.do", replace	// Creates a .tex document
	texify 			"${output_raw}/Balance_PhoneSvy_R1_R2_${date}.tex"		// Turns it into a PDF document 
	
	copy			"${output_raw}/Balance_PhoneSvy_R1_R2_${date}.tex" /// Save in final outputs folder
					"${output}/Balance_PhoneSvy_R1_R2_${date}.tex", replace
/*
* Online Appendix in current USD
	texdoc do		"${do}/IE_WP_appendix_currentUSD.do", replace	// Creates a .tex document
	texify 			"${output_raw}/APPENDIX_AFG_TUP_WP_currentUSD_${date}.tex"		// Turns it into a PDF document 
	
	copy			"${output_raw}/APPENDIX_AFG_TUP_WP_currentUSD_${date}.tex" /// Save in final outputs folder
					"${output}/APPENDIX_AFG_TUP_WP_currentUSD_${date}.tex", replace*/
					
