global assets_data_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/l_hhassets_bl.dta"
global assets_data_fl1 	"${TUP_DB}/Followup_1/DataSets/Intermediate/l_hhassets_fl1.dta"
global asset_index_ses 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_ses_phonesvy.dta"
global IPA_presentation_figure_loc "${Dropbox}/TUP_Afghanistan\Presentations\Endline_phone\IPA_2022\Figures"

global land l3_bl_win90 l3_fl1_win90 l3_win90 

use $assets_data_bl, clear 
keep if inlist(asset,5,6)
keep hhid asset l3 l5
recode l3 (0.99=.d) (99=.d) (0.98=.r) (98=.r)
recode l5 (0.99=.d) (99=.d) (0.98=.r) (98=.r)

rename (l3 l5) (l3_ l5_)

reshape wide l3_ l5_, i(hhid) j(asset)

rename * *_bl 
rename hhid_bl hhid

tempfile baseline_land
save `baseline_land'

use $assets_data_fl1, clear 
keep if inlist(asset,5,6)
keep hhid asset l3 l5
recode l3 (0.99=.d) (99=.d) (0.98=.r) (98=.r)
recode l5 (0.99=.d) (99=.d) (0.98=.r) (98=.r)

rename (l3 l5) (l3_ l5_)

reshape wide l3_ l5_, i(hhid) j(asset)

rename * *_fl1
rename hhid_fl1 hhid

tempfile midline_land
save `midline_land'

use $asset_index_ses, clear 
keep if round == 0
keep hhid l3_2_5 l3_2_6 treatment ultra_poor

rename (l3_2_5 l3_2_6) (l3_5 l3_6)

* Merge 
cap drop _merge 
merge 1:1 hhid using `baseline_land', keep(1 3) nogen
merge 1:1 hhid using `midline_land', keep(1 3) nogen

merge 1:1 hhid using "${phone_svy_profile}", keepusing(attrition_r1_or_r2) keep(3)
keep if attrition_r1_or_r2 == 0


egen l3 = rsum(l3_5 l3_6), missing
egen l3_bl = rsum(l3_5_bl l3_6_bl), missing
egen l3_fl1 = rsum(l3_5_fl1 l3_6_fl1), missing

foreach var in l3 l3_bl l3_fl1 {
	winsor2 `var' if `var'>0, by(ultra_poor) cuts(0 95) suffix(_win95)
	winsor2 `var' if `var'>0, by(ultra_poor) cuts(0 90) suffix(_win90)
} 

***********************


	gen counter = 1 if _n == 1 
	gen CI_l 	= .
	gen CI_h 	= .
	gen estim 	= .
	gen control_mean = .
	gen estim_point = .
	gen se = .
	gen counter_l = .	
	
	
	local i = 1 
	
	foreach var in $land {
		
	replace counter = `i' if _n ==  `i'
	
	* Get the treatment estimate 	
		estimates clear
		reg `var' treatment $controls, r 
		replace estim 	= _b[treatment] if counter == `i'
		gen sample = e(sample)
		
		replace se 	= r(table)[2,1]  if counter == `i' // SE of the treatment estimate 
			
	* Get the control mean
		sum `var' if treatment == 0 & sample == 1
		replace control_mean = `r(mean)' if counter == `i'
		
		drop sample 
		
		local i = `i' + 1 
		}
	
		format %3.2fc estim_point
		format %3.2fc control_mean
		
		replace estim_point 	= control_mean + estim 
		
		*Computes confidence interval by testing the significance of the sum of the coefficient and using the usual OLS CI formula
		replace CI_l 	= (estim - 1.96 * se) + control_mean
		replace CI_h 	= (estim + 1.96 * se) + control_mean
		
		replace counter_l = counter + 0.1
		
		gen date = .
			replace date = date("15mar2016","DMY") if counter == 1 // baseline 
			replace date = date("12aug2018","DMY") if counter == 2
			replace date = date("02mar2021","DMY") if counter == 3 // R1
			replace date = date("16may2021","DMY") if counter == 4 // R3 
			replace date = date("02jun2021","DMY") if counter == 5 // R4 
			
		gen date_l = date + 50

		gen estim_point_l = estim_point - 0.01
		gen control_mean_l = control_mean - 0.01

	local title "Land Holdings Size Dynamic"
	local subtitle "(Hectares)"
	local 	ytitle 	"ytitle("")"
	local 	ylabel 	"ylabel(0.3(0.1)1, format(%9.2f) labsize(small) angle(0))"

	*Main graph
	twoway  connected estim_point date, msymbol(smcircle) msize(small) lpattern(solid) lcolor(eltblue) mfcolor(eltblue) mlcolor(none) || ///
				connected control_mean date, msymbol(smcircle) msize(small) lpattern(longdash) lcolor(ebblue) mfcolor(ebblue) mlcolor(none) || ///
				scatter estim_point_l date_l, msym(none) mlab(estim_point) mlabpos(12) mlabcolor(black) mlabsize(vsmall) ytitle(" ") xtitle(" ") || ///
				scatter control_mean_l date_l, msym(none) mlab(control_mean) mlabpos(12) mlabcolor(black) mlabsize(vsmall) ytitle(" ") xtitle(" ") ///
				xlabel(20528 "Baseline" 21408 `""Two-Year" "Follow-Up""' 22341 `""Five-Year" "Follow-Up""', labsize(vsmall) angle(horizontal)) ///
				legend(row(1) order(1 "UP Treatment" 2 "UP Control")  size(small) region(style(none))) ///
				graphregion(color(white)) ylabel(,nogrid)  ///
				`ylabel' /// 
				subtitle("`subtitle'", margin(b=5) size(small)) `ylabel' /// 
				title("`title'", size(medium) color(black)) /// 
				graphregion(color(white))
 
	graph export "${IPA_presentation_figure_loc}\figure_dynamic_land_size.png", replace width(1000)	










