/* 

Draft analysis tables

*/



set trace off

if $round_1_2 == 0 {
	* Datatset with all rounds
	gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy.dta"
	gl schooling_phonesvy				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_phonesvy.dta"
}
else {
	* Dataset restricted to R1-R2 outcomes
	gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy_r1.dta"
	gl schooling_phonesvy				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_phonesvy_r1.dta"
}

gl phone_svy_profile   					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* fl1 data matching phone survey  
gl data_for_analysis_fl1			    "${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
* Unchanged (original) fl1 dataset
gl data_for_analysis_fl1_all 			"${Dropbox}/DataWork_MDC/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
gl covariates_fl1_bl					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/covariates_fl1_bl.dta"

gl schooling_fl1						"${TUP_DB}/Followup_1/DataSets/Intermediate/schooling_fl1.dta"

gl date 1130
	
* Define name of the Excel fine (depending on whether it contains R3-R4 data or not)	
	if $round_1_2 == 0 {
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}.xlsx", modify sheet(main_outcomes)	
	}
	else {
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}_r1.xlsx", modify sheet(main_outcomes)
	}
	
* Define "list" local with rounds that need to be "created" in fl1 data (that do not exist there)	
	if $round_1_2 == 0 {
		local list 0/4 10
		local school_list share_inschool_1 share_inschool_4
	}
	else {
		local list 0/2 10
		local school_list share_inschool_1
	}
	
/** Phone survey	
	use "${data_for_analysis_phonesvy}", clear
	
	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
	
	foreach var in $consumption $foodsecurity $asset_sum $fin_sum $revenues_sum $index5 $health_sum $f_empowerment {
		
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'
		
		if "`var'"=="exp_tot_m_pc_ppp" | "`var'"=="index_sdC_food_sec" | "`var'"=="c14_7" | "`var'"=="c14_3_ac" | "`var'"=="c14_5_ac"| "`var'"=="wealth_score_0" | "`var'"=="saving_ppp"| "`var'"=="psy_indexC_sdC_0" | "`var'"=="satisf_z_sdC_0" | "`var'"=="hap_z_sdC_0" {	
			* Cluster at HHID level when using ALL rounds 
			reg `var' treatment ${controls}, vce(cluster hhid)
			sum `var' if treatment == 0 & e(sample) == 1
		}
		* Do not cluster is doing each round separately; add Baseline controls and covariate missingness dummy
		else {
			reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
			sum `var' if treatment == 0 & e(sample) == 1
		}
			
			coeff_treat `var' treatment
								
					* Titles
					putexcel A1 = "MAIN OUTCOMES"
					putexcel B2 = "Follow-up 1 (Phone survey sample - all items)"
					putexcel H2 = "Follow-up 1 (Phone survey sample - subset items)"
					putexcel N2 = "Phone survey"
					
					putexcel B3 = "Control Mean"
					putexcel C3 = "Level"
					putexcel D3 = "% Control Mean"
					putexcel E3 = "SD Control"
					putexcel F3 = "N" 
					
					putexcel H3 = "Control Mean"
					putexcel I3 = "Level"
					putexcel J3 = "% Control Mean"
					putexcel K3 = "SD Control"
					putexcel L3 = "N" 
					
					putexcel N3 = "Control Mean"
					putexcel O3 = "Level"
					putexcel P3 = "% Control Mean"
					putexcel Q3 = "SD Control"
					putexcel R3 = "N" 
					
					* Results 
					putexcel A`row' = "${`var'_lab}"
					putexcel N`row' = "${`var'm0}"
					putexcel O`row' = "${`var't}"
					if !regexm("`var'","index") & !regexm("`var'","Index") { // change here from ndex 
						if "${`var'imp1}"!="" { // change here 
							putexcel P`row' = "${`var'imp1}%" 
						}
						else {
							putexcel P`row' = ""
						}
					}
					putexcel Q`row' = "${`var'imp2}"
					putexcel R`row' = "${N_`var'}"
					
					putexcel N`row_se' = "(${`var's0})"
					putexcel O`row_se' = "(${`var'tse})"
					putexcel O`row_p' = "[${`var'p}]"	
							
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
			}
			
		}
		
		
** Follow-up 1	
	use "${data_for_analysis_fl1}", clear
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 

	* Rename vars and create fake vars for fl1 so that we can run this on both fl1 and phone svy data together 
	foreach round of numlist `list' {
		gen exp_tot_m_pc_`round'_ppp = exp_tot_m_pc_ppp
		gen exp_tot_m_pc_c_`round'_ppp = exp_tot_m_pc_c_ppp
		gen saving_`round'_ppp = saving_ppp
		gen saving_win_`round'_ppp = saving_win_ppp
		
		gen tot_lstock_revenue_`round'_ppp = tot_lstock_revenue_ppp
		gen tot_lstock_revenue_`round'_w_ppp = tot_lstock_revenue_w_ppp 
		gen tot_hh_income_`round'_ppp = tot_hh_income_ppp
		gen tot_hh_income_`round'_w_ppp = tot_hh_income_w_ppp
		
		gen index_sdC_food_sec_`round' = index_sdC_food_sec
		gen c14_7_`round' = c14_7
		
		gen psy_indexC_sdC_`round' = psy_indexC_sdC_fl1 
		gen satisf_z_sdC_`round' = satisf_z_sdC_fl1
		gen hap_z_sdC_`round' = hap_z_sdC_fl1
		gen cesd_z_sdC_`round' = cesd_z_sdC_fl1
		
		gen wealth_score_`round' = wealth_score
		
		gen c14_3_`round'_ac = c14_3_ac	
		gen c14_5_`round'_ac = c14_5_ac
		
		gen fin_index_sdC_`round' = fin_index_sdC_fl1
		gen access_credit_`round' = access_credit
	}

	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values		

	foreach var in $consumption $foodsecurity $asset_sum $fin_sum $revenues_sum $index5 $health_sum $f_empowerment {
		
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'
			
			reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
			sum `var' if treatment == 0 & e(sample) == 1
		
			coeff_treat `var' treatment
					
					putexcel H`row' = "${`var'm0}"
					putexcel I`row' = "${`var't}"
					if !regexm("`var'","ndex") {
						putexcel J`row' = "${`var'imp1}%" 
					}
					putexcel K`row' = "${`var'imp2}"
					putexcel L`row' = "${N_`var'}"
					
					putexcel H`row_se' = "(${`var's0})"
					putexcel I`row_se' = "(${`var'tse})"
					putexcel I`row_p' = "[${`var'p}]"
					
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
			
		}
			
	} 
	
	
** Fl1 data with ALL items (NOT limited to items from phone survey)	
	
	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
	
	use "${data_for_analysis_fl1_all}", clear
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 

	* Rename vars and create fake vars for fl1 so that we can run this on both fl1 and phone svy data together 
	foreach var in tot_crop_revenue tot_biz_revenue {
		winsor2 `var'_ppp if `var'_ppp>0, by(ultra_poor) cuts(0 95)
		replace `var'_ppp_w = 0 if `var'_ppp == 0
		rename `var'_ppp_w `var'_win_ppp
	}
	egen tot_hh_income_w_ppp = rowtotal(tot_hh_pay_ppp tot_lstock_revenue_w_ppp tot_crop_revenue_win_ppp tot_biz_revenue_win_ppp), missing

	foreach round of numlist `list' {
		gen tot_lstock_revenue_`round'_ppp = tot_lstock_revenue_ppp
		gen tot_lstock_revenue_`round'_w_ppp = tot_lstock_revenue_w_ppp 
		gen tot_hh_income_`round'_ppp = tot_hh_income_ppp
		gen tot_hh_income_`round'_w_ppp = tot_hh_income_w_ppp
			
		gen exp_tot_m_pc_`round' = exp_tot_m_pc
		gen exp_tot_m_pc_c_`round' = exp_tot_m_pc_c
		gen saving_`round' = saving
		gen saving_win_`round' = saving_win
		
		gen index_sdC_food_sec_`round' = index_sdC_food_sec
		gen c14_7_`round' = c14_7
		
		gen psy_indexC_sdC_`round' = psy_indexC_sdC_fl1 
		gen satisf_z_sdC_`round' = satisf_z_sdC_fl1
		gen hap_z_sdC_`round' = hap_z_sdC_fl1
		gen cesd_z_sdC_`round' = cesd_z_sdC_fl1
		
		gen wealth_score_`round' = wealth_score
		
		gen c14_3_`round'_ac = c14_3_ac	
		gen c14_5_`round'_ac = c14_5_ac
		
		gen fin_index_sdC_`round' = fin_index_sdC_fl1
		gen access_credit_`round' = access_credit
	}
	
	* Temporary quick solution before this var is generated 	
	gen tot_lstock_w95_value_ppp = 0 

	 * PPP variables
	local ppp_vars "exp_tot_m_pc exp_tot_m_pc_c exp_tot_m_pc_1 exp_tot_m_pc_c_1 exp_tot_m_pc_3 exp_tot_m_pc_c_3 exp_tot_m_pc_4 exp_tot_m_pc_c_4 saving saving_win saving_1 saving_3 saving_4 saving_win_1 saving_win_3 saving_win_4 tot_hh_income_1 tot_hh_income_4 tot_lstock_revenue_1 tot_lstock_revenue_4 tot_crop_revenue tot_biz_revenue tot_hh_pay tot_lstock_value tot_lstock_w_value"
		
	foreach var in `ppp_vars' {
		cap confirm var `var'
		if !_rc{
			cap drop `var'_ppp
			local l_`var' : variable label `var'
			gen `var'_ppp = `var' / $ppp_2021
			lab var `var'_ppp "`l_`var''"
		}
	}
	
	foreach var in $consumption $foodsecurity $asset_sum $fin_sum $revenues_sum $index5 $health_sum $f_empowerment {
		
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'
			
			reg `var' treatment ${controls}, r
			sum `var' if treatment == 0 & e(sample) == 1
	
			coeff_treat `var' treatment
	
			putexcel B`row' = "${`var'm0}"
			putexcel C`row' = "${`var't}"
			if !regexm("`var'","ndex") {
				putexcel D`row' = "${`var'imp1}%" 
			}
			putexcel E`row' = "${`var'imp2}"
			putexcel F`row' = "${N_`var'}"
			
			putexcel B`row_se' = "(${`var's0})"
			putexcel C`row_se' = "(${`var'tse})"
			putexcel C`row_p' = "[${`var'p}]"
			
			local row = 	`row' + 3
			local row_se = 	`row_se' + 3
			local row_p = 	`row_p' + 3
		}
	} 
	
	
** Schooling / enrollment
	* Follow-up 
	use "${schooling_fl1}", clear
	
	* Keep the phone survey sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 
	
	clonevar child_inschool_hh_0 = child_inschool_hh
	clonevar child_inschool_hh_1 = child_inschool_hh
	clonevar share_inschool_1    = share_inschool
	
	if $round_1_2 == 0 {
		clonevar child_inschool_hh_4 = child_inschool_hh
		clonevar share_inschool_4    = share_inschool
	} 

	foreach var in `school_list' {
		if "`var'"=="share_inschool_1" | "`var'"=="share_inschool_4" {	
			* Cluster at HHID level when using ALL rounds 
			reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
			sum `var' if treatment == 0 & e(sample) == 1
		}
			* Not sure if this is any different from vce(cluster hhid)
		else {
			reg `var' treatment ${controls}, r cluster(hhid)
			sum `var' if treatment == 0 & e(sample) == 1
		}
		
		sum `var' if treatment == 0
		coeff_treat `var' treatment	
		
		* Results for fl1 
			putexcel H`row' = "${`var'm0}"
			putexcel I`row' = "${`var't}"
			if !regexm("`var'","ndex") {
				putexcel J`row' = "${`var'imp1}%" 
			}
			putexcel K`row' = "${`var'imp2}"
			putexcel L`row' = "${N_`var'}"
			
			putexcel H`row_se' = "(${`var's0})"
			putexcel I`row_se' = "(${`var'tse})"
			putexcel I`row_p' = "[${`var'p}]"
			
		* Identical for the unchanged fl1 data, just copy over the results
			putexcel B`row' = "${`var'm0}"
			putexcel C`row' = "${`var't}"
			if !regexm("`var'","ndex") {
				putexcel D`row' = "${`var'imp1}%" 
			}
			putexcel E`row' = "${`var'imp2}"
			putexcel F`row' = "${N_`var'}"
			
			putexcel B`row_se' = "(${`var's0})"
			putexcel C`row_se' = "(${`var'tse})"
			putexcel C`row_p' = "[${`var'p}]"
	
			local row = 	`row' + 3
			local row_se = 	`row_se' + 3
			local row_p = 	`row_p' + 3
	}
	
	* Phone survey 
if $round_1_2 == 1 {	
	local row = 	`row' - 3
	local row_se = 	`row_se' - 3
	local row_p = 	`row_p' - 3
}
else {	
	local row = 	`row' - 6
	local row_se = 	`row_se' - 6
	local row_p = 	`row_p' - 6
}
	
	use "${schooling_phonesvy}", clear
		merge m:1 hhid using "${phone_svy_profile}", keepus(treatment PRA_lottery ultra_poor) assert(2 3) keep(3) nogen
		
		lab var child_inschool_hh_0 "School Enrollment (ages 6 to 18 years) (all rounds)"
		lab var child_inschool_hh_1 "School Enrollment (ages 6 to 18 years) (round 1)"
		lab var share_inschool_1    "School Enrollment - share of children in school (ages 6 to 18 years) (round 1)"
		
		cap noi lab var child_inschool_hh_4 "School Enrollment (ages 6 to 18 years) (round 4)"
		cap noi lab var share_inschool_4    "School Enrollment - share of children in school (ages 6 to 18 years) (round 4)"
		
	foreach var in `school_list' {
		global `var'_lab : variable label `var'
		
		if "`var'"=="child_inschool_hh_0" {	
			* Cluster at HHID level when using ALL rounds 
			reg `var' treatment ${controls}, vce(cluster hhid)
			sum `var' if treatment == 0 & e(sample) == 1
		}
		
		if "`var'"=="share_inschool_1" | "`var'"=="share_inschool_4" {	
			* Cluster at HHID level when using ALL rounds 
			reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
			sum `var' if treatment == 0 & e(sample) == 1
		}
			* Not sure if this is any different from vce(cluster hhid)
		else {
			reg `var' treatment ${controls}, r cluster(hhid)
			sum `var' if treatment == 0 & e(sample) == 1
		}
		
		coeff_treat `var' treatment	
		
		* Results 
			putexcel A`row' = "${`var'_lab}"
			putexcel N`row' = "${`var'm0}"
			putexcel O`row' = "${`var't}"
			if !regexm("`var'","ndex") {
				putexcel P`row' = "${`var'imp1}%" 
			}
			putexcel Q`row' = "${`var'imp2}"
			putexcel R`row' = "${N_`var'}"
			
			putexcel N`row_se' = "(${`var's0})"
			putexcel O`row_se' = "(${`var'tse})"
			putexcel O`row_p' = "[${`var'p}]"	
			
			local row = 	`row' + 3
			local row_se = 	`row_se' + 3
			local row_p = 	`row_p' + 3
	} 	
	
	
** Consumption
* Define name of the Excel fine (depending on whether it contains R3-R4 data or not)	
	if $round_1_2 == 0 {
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}.xlsx", modify sheet(consumption)
	}
	else {
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}_r1.xlsx", modify sheet(consumption)
	}
	
	** Phone survey	
	use "${data_for_analysis_phonesvy}", clear
	
	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
		
	foreach var in $cons_detail {
			
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'
			
			if "`var'"=="exp_tot_m_pc_ppp" | "`var'"=="exp_f_tot_m_pc_ppp" | "`var'"=="exp_nf_tot_m_pc_ppp" {	
				* Cluster at HHID level when using ALL rounds 
				reg `var' treatment ${controls}, vce(cluster hhid)
				sum `var' if treatment == 0 & e(sample) == 1
			}
				* Do not cluster is doing each round separately 
			else {
				reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
				sum `var' if treatment == 0 & e(sample) == 1
			}
			
			coeff_treat `var' treatment
					
					* Titles
					putexcel A1 = "CONSUMPTION DETAIL"
					putexcel B2 = "Follow-up 1 (Phone survey sample - all items)"
					putexcel H2 = "Follow-up 1 (Phone survey sample - subset items)"
					putexcel N2 = "Phone survey"
					
					putexcel B3 = "Control Mean"
					putexcel C3 = "Level"
					putexcel D3 = "% Control Mean"
					putexcel E3 = "SD Control"
					putexcel F3 = "N" 
					
					putexcel H3 = "Control Mean"
					putexcel I3 = "Level"
					putexcel J3 = "% Control Mean"
					putexcel K3 = "SD Control"
					putexcel L3 = "N" 
					
					putexcel N3 = "Control Mean"
					putexcel O3 = "Level"
					putexcel P3 = "% Control Mean"
					putexcel Q3 = "SD Control"
					putexcel R3 = "N" 
					
					* Results 
					putexcel A`row' = "${`var'_lab}"
					putexcel N`row' = "${`var'm0}"
					putexcel O`row' = "${`var't}"
					if !regexm("`var'","ndex") {
						putexcel P`row' = "${`var'imp1}%" 
					}
					putexcel Q`row' = "${`var'imp2}"
					putexcel R`row' = "${N_`var'}"
					
					putexcel N`row_se' = "(${`var's0})"
					putexcel O`row_se' = "(${`var'tse})"
					putexcel O`row_p' = "[${`var'p}]"	
							
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
			}
			
		}
		
** Follow-up 1	
	use "${data_for_analysis_fl1}", clear
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 
	
	* Rename vars and create fake vars for fl1 so that we can run this on both fl1 and phone svy data together 
	foreach round of numlist `list' {
		gen exp_tot_m_pc_`round'_ppp    = exp_tot_m_pc_ppp
		gen exp_nf_tot_m_pc_`round'_ppp = exp_nf_tot_m_pc_ppp
		gen exp_f_tot_m_pc_`round'_ppp  = exp_f_tot_m_pc_ppp
		
		gen exp_tot_m_pc_c_`round'_ppp    = exp_tot_m_pc_c_ppp
		gen exp_nf_tot_m_pc_c_`round'_ppp = exp_nf_tot_m_pc_c_ppp
		gen exp_f_tot_m_pc_c_`round'_ppp  = exp_f_tot_m_pc_c_ppp
	}

	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
	
	foreach var in $cons_detail {
		
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'
			reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
			sum `var' if treatment == 0 & e(sample) == 1
		
			coeff_treat `var' treatment
	
				putexcel H`row' = "${`var'm0}"
				putexcel I`row' = "${`var't}"
				if !regexm("`var'","ndex") {
					putexcel J`row' = "${`var'imp1}%" 
				}
				putexcel K`row' = "${`var'imp2}"
				putexcel L`row' = "${N_`var'}"
				
				putexcel H`row_se' = "(${`var's0})"
				putexcel I`row_se' = "(${`var'tse})"
				putexcel I`row_p' = "[${`var'p}]"
				
				local row = 	`row' + 3
				local row_se = 	`row_se' + 3
				local row_p = 	`row_p' + 3	
		}	
	}	
	
** Fl1 data with ALL items (not limited to items from phone survey)	
	
	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
	
	use "${data_for_analysis_fl1_all}", clear
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 
	
	 * PPP variables
	local ppp_vars "exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc exp_tot_m_pc_c exp_f_tot_m_pc_c exp_nf_tot_m_pc_c"
		
	foreach var in `ppp_vars' {
		cap drop `var'_ppp
		local l_`var' : variable label `var'
		gen `var'_ppp = `var' / $ppp_2021
		lab var `var'_ppp "`l_`var''"
	}
	
	* Rename vars and create fake vars for fl1 so that we can run this on both fl1 and phone svy data together 
	foreach var in exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc exp_tot_m_pc_c exp_f_tot_m_pc_c exp_nf_tot_m_pc_c {	
		foreach round of numlist `list' {
			gen `var'_`round'_ppp 	= `var'_ppp
			
		}
	}
	
	foreach var in $cons_detail {
		
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'
			
			reg `var' treatment ${controls}, r
			sum `var' if treatment == 0 & e(sample) == 1
	
			coeff_treat `var' treatment
	
			putexcel B`row' = "${`var'm0}"
			putexcel C`row' = "${`var't}"
			if !regexm("`var'","ndex") {
				putexcel D`row' = "${`var'imp1}%" 
			}
			putexcel E`row' = "${`var'imp2}"
			putexcel F`row' = "${N_`var'}"
			
			putexcel B`row_se' = "(${`var's0})"
			putexcel C`row_se' = "(${`var'tse})"
			putexcel C`row_p' = "[${`var'p}]"
			
			local row = 	`row' + 3
			local row_se = 	`row_se' + 3
			local row_p = 	`row_p' + 3
		}	
	} 
	
	
** Women's Empowerment 	
* Define name of the Excel fine (depending on whether it contains R3-R4 data or not)	
	if $round_1_2 == 0 {
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}.xlsx", modify sheet(empower)
	}
	else {
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}_r1.xlsx", modify sheet(empower)
	}	
	
	** Phone survey	
	use "${data_for_analysis_phonesvy}", clear

	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
	
	foreach var in $empower_vars {
		
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
		if "`var'"=="mobile_yes_pf" | "`var'"=="z2_index" | "`var'"=="z1_3_index" {
			global `var'_lab : variable label `var'
			reg `var' treatment ${controls}, r
		}	
		else {
			global `var'_lab : variable label `var'
			reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
		}	
		
		sum `var' if treatment == 0 & e(sample) == 1
				
				coeff_treat `var' treatment
				
				* Titles
					putexcel A1 = "WOMEN'S EMPOWERMENT DETAIL"
					putexcel B2 = "Follow-up 1 (Phone survey sample)"
					putexcel H2 = "Phone survey"
					
					putexcel B3 = "Control Mean"
					putexcel C3 = "Level"
					putexcel D3 = "% Control Mean"
					putexcel E3 = "SD Control"
					putexcel F3 = "N" 
					
					putexcel H3 = "Control Mean"
					putexcel I3 = "Level"
					putexcel J3 = "% Control Mean"
					putexcel K3 = "SD Control"
					putexcel L3 = "N" 
					
					putexcel A`row' = "${`var'_lab}"
					putexcel H`row' = "${`var'm0}"
					putexcel I`row' = "${`var't}"
					if !regexm("`var'","ndex") {
						putexcel J`row' = "${`var'imp1}%" 
					}
					putexcel K`row' = "${`var'imp2}"
					putexcel L`row' = "${N_`var'}"
					
					putexcel H`row_se' = "(${`var's0})"
					putexcel I`row_se' = "(${`var'tse})"
					putexcel I`row_p' = "[${`var'p}]"
		
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
			}
	}
			
		
** Follow-up 1	
	use "${data_for_analysis_fl1}", clear
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 
	
	* Rename vars to match phone survey
	rename (s21 s12) (z2_index z1_3_index)

	* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
	foreach var in $empower_vars {
		
		cap confirm var `var'
		if !_rc { // if the variable exists 
		
		if "`var'"=="mobile_yes_pf" | "`var'"=="z2_index" | "`var'"=="z1_3_index" {
			global `var'_lab : variable label `var'
			reg `var' treatment ${controls}, r
		}	
		else {
			global `var'_lab : variable label `var'
			reg `var' treatment ${controls} `var'_bl `var'_bl_mi, r
		}	
		
			sum `var' if treatment == 0 & e(sample) == 1
		
				coeff_treat `var' treatment
			
					putexcel B`row' = "${`var'm0}"
					putexcel C`row' = "${`var't}"
					if !regexm("`var'","ndex") {
						putexcel D`row' = "${`var'imp1}%" 
					}
					putexcel E`row' = "${`var'imp2}"
					putexcel F`row' = "${N_`var'}"
					
					putexcel B`row_se' = "(${`var's0})"
					putexcel C`row_se' = "(${`var'tse})"
					putexcel C`row_p' = "[${`var'p}]"
					
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
			}
		} */

		
*** Time use for PW and PM
if $round_1_2 == 0 {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}.xlsx", modify sheet(time_use)
}
else {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}_r1.xlsx", modify sheet(time_use)
}	
	

** Phone survey	
	use "${data_for_analysis_phonesvy}", clear
	
	* Locals for putexcel rows 
	local row 	 = 5
	local row_se = 6 // SE
	local row_p	 = 7 // p-values
		
	foreach var in $time_sum {	
		
		cap confirm var `var'_pf
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'_pf
			
			* For female
			reg `var'_pf treatment ${controls} `var'_pf_bl `var'_pf_bl_mi, r
			sum `var'_pf if treatment == 0 & e(sample) == 1
			
				coeff_treat `var'_pf treatment

			*For male
			reg `var'_pm treatment ${controls} `var'_pm_bl `var'_pm_bl_mi, r
			sum `var'_pm if treatment == 0 & e(sample) == 1
			
				coeff_treat `var'_pm treatment
	
					* Titles
					putexcel A1 = "TIME USE"
					putexcel B2 = "Follow-up 1 (Phone survey sample)"
					putexcel N2 = "Phone survey"
					
					putexcel N3 = "Primary Woman"
					putexcel T3 = "Primary Man"
					
					putexcel N4 = "Control Mean"
					putexcel O4 = "Level"
					putexcel P4 = "% Control Mean"
					putexcel Q4 = "SD Control"
					putexcel R4 = "N"
					
					putexcel T4 = "Control Mean"
					putexcel U4 = "Level"
					putexcel V4 = "% Control Mean"
					putexcel W4 = "SD Control"
					putexcel X4 = "N"
					
					* Results
						* Female 
					putexcel A`row' = "${`var'_lab}"
					putexcel N`row' = "${`var'_pfm0}" 
					putexcel O`row' = "${`var'_pft}"
					if !regexm("`var'","ndex") {
						putexcel P`row' = "${`var'_pfimp1}%" 
					}
					putexcel Q`row' = "${`var'_pfimp2}"
					putexcel R`row' = "${N_`var'_pf}"
					
					putexcel N`row_se' = "(${`var'_pfs0})"
					putexcel O`row_se' = "(${`var'_pftse})"
					putexcel O`row_p' = "[${`var'_pfp}]"
					
						* Male 
					putexcel T`row' = "${`var'_pmm0}" 
					putexcel U`row' = "${`var'_pmt}"
					if !regexm("`var'","ndex") {
						putexcel V`row' = "${`var'_pmimp1}%" 
					}
					putexcel W`row' = "${`var'_pmimp2}"
					putexcel X`row' = "${N_`var'_pm}"
					
					putexcel T`row_se' = "(${`var'_pms0})"
					putexcel U`row_se' = "(${`var'_pmtse})"
					putexcel U`row_p' = "[${`var'_pmp}]"
					
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
			}
			
		} 
		
** Follow-up 1	
	use "${data_for_analysis_fl1}", clear
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 

	* Locals for putexcel rows 
	local row 	 = 5
	local row_se = 6 // SE
	local row_p	 = 7 // p-values
		
	foreach var in $time_sum {	
		
		cap confirm var `var'_pf
		if !_rc { // if the variable exists 
		
			global `var'_lab : variable label `var'_pf
			
			* For female
			reg `var'_pf treatment ${controls} `var'_pf_bl `var'_pf_bl_mi, r
			sum `var'_pf if treatment == 0 & e(sample) == 1
			
				coeff_treat `var'_pf treatment

			*For male
			reg `var'_pm treatment ${controls} `var'_pm_bl `var'_pm_bl_mi, r
			sum `var'_pm if treatment == 0 & e(sample) == 1
			
				coeff_treat `var'_pm treatment
				
					* Titles
					putexcel B3 = "Primary Woman"
					putexcel H3 = "Primary Man"
					
					putexcel B4 = "Control Mean"
					putexcel C4 = "Level"
					putexcel D4 = "% Control Mean"
					putexcel E4 = "SD Control"
					putexcel F4 = "N"
					
					putexcel H4 = "Control Mean"
					putexcel I4 = "Level"
					putexcel J4 = "% Control Mean"
					putexcel K4 = "SD Control"
					putexcel L4 = "N"
					
					* Results
						* Female 
					putexcel B`row' = "${`var'_pfm0}"
					putexcel C`row' = "${`var'_pft}"
					if !regexm("`var'","ndex") {
						putexcel D`row' = "${`var'_pfimp1}%" 
					}
					putexcel E`row' = "${`var'_pfimp2}"
					putexcel F`row' = "${N_`var'_pf}"
					
					putexcel B`row_se' = "(${`var'_pfs0})"
					putexcel C`row_se' = "(${`var'_pftse})"
					putexcel C`row_p' = "[${`var'_pfp}]"	
					
						* Male 
					putexcel H`row' = "${`var'_pmm0}" 
					putexcel I`row' = "${`var'_pmt}"
					if !regexm("`var'","ndex") {
						putexcel J`row' = "${`var'_pmimp1}%" 
					}
					putexcel K`row' = "${`var'_pmimp2}"
					putexcel L`row' = "${N_`var'_pm}"
					
					putexcel H`row_se' = "(${`var'_pms0})"
					putexcel I`row_se' = "(${`var'_pmtse})"
					putexcel I`row_p' = "[${`var'_pmp}]"
					
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
			
		}
			
	}


/* School enrollment by gender
if $round_1_2 == 0 {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}.xlsx", modify sheet(school_enroll)
}
else {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/prelim_impacts_phonesvy_blcontrols_${date}_r1.xlsx", modify sheet(school_enroll)
}	
 
local Panel A_T1
local i = 1	
	
	* Follow-up 
	use "${schooling_fl1}", clear
	
	* Keep the phone survey sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround) keep(3) nogen
	keep if anyround == 1 
	
	keep hhid *kid_* child_inschool_hh PRA_lottery treatment ultra_poor
	rename * *_5
	rename (hhid_5 PRA_lottery_5 treatment_5 ultra_poor_5) (hhid PRA_lottery treatment ultra_poor) 
	
	tempfile fl1_schooling
	save `fl1_schooling'
	
	* Phone survey
	use "${schooling_phonesvy}", clear 
		append using "`fl1_schooling'"
	
	keep if ultra_poor == 1
	
	local i = 1	

	if $round_1_2 == 0 {	
		local list 1 4 5 0 // 5 = fl1; 0 = "all rounds" of phone svy
	}
	else {
		local list 1 5 // 5 = fl1; 0 = "all rounds" of phone svy
	}

	foreach age in "_6_14" "_15_18" "_6_18" {
		foreach round of numlist `list' { // 0 = fl1 
			local indep    kid`age'_m_`round'
			local indep_t  t_kid`age'_m_`round'

		reg child_inschool_hh_`round' treatment `indep' `indep_t' ${controls}, cluster(hhid)		
		gen sample_`Panel'_`round' = e(sample)
		*Saving all the coefficients 
		test_interaction L1_C`i'_`Panel'_`round' treatment `indep_t'
		stat_estim L1_C`i'_`Panel'_`round' treatment
		stat_estim L2_C`i'_`Panel'_`round' `indep_t'	
		stat_estim L3_C`i'_`Panel'_`round' `indep'	
		
		*control mean	
		sum child_inschool_hh_`round' if sample_`Panel'_`round' == 1 & treatment == 0 & `indep' == 1
		global L1_C`i'_`Panel'_m0_`round' :  di %4.3f `r(mean)'
			impact_interaction L1_C`i'_`Panel'_`round' treatment `indep_t' 2
		sum child_inschool_hh_`round' if sample_`Panel'_`round' == 1 & treatment == 0 & `indep' == 0
		global L2_C`i'_`Panel'_m0_`round' :  di %4.3f `r(mean)' 
			impact_interaction L1_C`i'_`Panel'_`round' treatment `indep_t' 1	
		drop sample_*
			*local i = `i' + 1	
		}	
		local i = `i' + 1	
	}
		
* Putexcel
	* Titles
	putexcel A1 = "Impacts on Children's School Enrollment with Male Interaction"
	putexcel B2 = "Follow-up 1 (Phone survey sample)" 
	putexcel F2 = "Phone survey - Round 1"
if $round_1_2 == 0 {		
	putexcel J2 = "Phone survey - Round 4"
	putexcel N2 = "Phone survey - All Rounds"
	local lista "B F J N"
	local listb "C G K O"
	local listc "D H L P"
}	
else {
	local lista "B F"
	local listb "C G"
	local listc "D H"
}	
	
	foreach col in `lista' {
		putexcel `col'3 = "Children 6 - 14"
	}
	foreach col in `listb' {
		putexcel `col'3 = "Children 15 - 18"
	}	
	foreach col in `listc' {
		putexcel `col'3 = "All Children 6 - 18"
	}
	
	putexcel A4 = "Treatment"
	putexcel A8 = "Treatment x Male"
	putexcel A12 = "Male"
	
	putexcel A16 = "N"
	putexcel A17 = "Control Mean Female"
	putexcel A18 = "Control Mean Male"
	putexcel A19 = "Impact Female"
	putexcel A20 = "Impact Male"
	putexcel A21 = "Test T + T x Male = 0"
	
	local row = 4
	
	* Phone survey
	forvalues j=1/3 {
		foreach round of numlist `list' {
			if `j' == 1 & `round' == 5 {
				local col "B"
			}
			if `j' == 2 & `round' == 5  {
				local col "C"
			}
			if `j' == 3 & `round' == 5  {
				local col "D"
			}
			if `j' == 1 & `round' == 1 {
				local col "F"
			}
			if `j' == 2 & `round' == 1  {
				local col "G"
			}
			if `j' == 3 & `round' == 1  {
				local col "H"
			}
			if `j' == 1 & `round' == 4 {
				local col "J"
			}
			if `j' == 2 & `round' == 4  {
				local col "K"
			}
			if `j' == 3 & `round' == 0  {
				local col "M"
			}
			if `j' == 1 & `round' == 0 {
				local col "N"
			}
			if `j' == 2 & `round' == 0  {
				local col "O"
			}
			if `j' == 3 & `round' == 0  {
				local col "P"
			}
				
				* Top panel
				putexcel `col'4 = "${L1_C`j'_`Panel'_`round'}"
				putexcel `col'5 = "(${L1_C`j'_`Panel'_`round'sd})"
				putexcel `col'6 = "[${L1_C`j'_`Panel'_`round'p}]"
				 
				putexcel `col'8 = "${L2_C`j'_`Panel'_`round'}"
				putexcel `col'9 = "(${L2_C`j'_`Panel'_`round'sd})"
				putexcel `col'10 = "[${L2_C`j'_`Panel'_`round'p}]"
				 
				putexcel `col'12 = "${L3_C`j'_`Panel'_`round'}"
				putexcel `col'13 = "(${L3_C`j'_`Panel'_`round'sd})"
				putexcel `col'14 = "[${L3_C`j'_`Panel'_`round'p}]"
				 
				 * Bottom panel
				putexcel `col'16 = "${L1_C`j'_`Panel'_`round'_N}"
				putexcel `col'17 = "${L2_C`j'_`Panel'_m0_`round'}"
				putexcel `col'18 = "${L1_C`j'_`Panel'_m0_`round'}"
				putexcel `col'19 = "{${L1_C`j'_`Panel'_`round'imp1_1}%;${L1_C`j'_`Panel'_`round'imp2_1}}"
				putexcel `col'20 = "{${L1_C`j'_`Panel'_`round'imp1_2}%;${L1_C`j'_`Panel'_`round'imp2_2}}"
				putexcel `col'21 = "${L1_C`j'_`Panel'_`round'_test}"
		}
		
	}

	

	