/*  
 
Draft analysis tables : Extra outcomes 
 
*/ 

gl phone_svy_profile   				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta" 
gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy.dta" 
gl all_hhlevel_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta" 
 

	
use "${data_for_analysis_phonesvy}", clear 
		

***********************************************************************************************
**************************************** Mechanisms     ***************************************
************************************************************************************************
	
* Finance 
	unab loan_purpose: m3_1 - m3_11 m3__97 
	unab loan_source: m22_0 - m22__97  
	global finance_oth `loan_purpose' am1_1 am1_2 am1_3 am1_4 am1_5 am1_6 am2_1 am2_2 am2_3 am2_4 am2_5 am2_6 `loan_source' 
 
* Reason for livestock sale in R1
	unab sale_reason_r1: sale_reason_*
	global sale_reason_r1 `sale_reason_r1'
	
* Past 3 years outcomes
	unab reason_biz_close: k27_1 - k27__99 
	global past_3years_biz k25 k25 `reason_biz_close'

* R3 livestock questions 
	global past_3years_lstock lstock_yes_3yrs_cow lstock_stillown_3yrs_cow k35_1_cow k35_2_cow k35_3_cow k35_4_cow k35__97_cow r44_1_cow r44_2_cow r44_3_cow r44_4_cow r44__97_cow k35_a_1_cow k35_a_2_cow k35_a_3_cow k35_a_4_cow k35_a_5_cow ///
		lstock_yes_3yrs_goat lstock_stillown_3yrs_goat k35_1_goat k35_2_goat k35_3_goat k35_4_goat k35__97_goat r44_1_goat r44_2_goat r44_3_goat r44_4_goat r44__97_goat k35_a_1_goat k35_a_2_goat k35_a_3_goat k35_a_4_goat k35_a_5_goat ///
		lstock_yes_3yrs_sheep lstock_stillown_3yrs_sheep k35_1_sheep k35_2_sheep k35_3_sheep k35_4_sheep k35__97_sheep r44_1_sheep r44_2_sheep r44_3_sheep r44_4_sheep r44__97_sheep k35_a_1_sheep k35_a_2_sheep k35_a_3_sheep k35_a_4_sheep k35_a_5_sheep ///
		lstock_yes_3yrs__chicken lstock_stillown_3yrs__chicken r44_1__chicken r44_2__chicken r44_3__chicken r44_4__chicken r44__97__chicken
	
* Health
	unab health: f23_0 - f25__99
	global health `health'

* Covid
	unab covid: x1 - x2_6 x5_1 x5_2 x5_3
	global covid `health'	
	
* Violence 
	unab violence: o1 num_attacks o1_b_1 - o1_b__97
	global violence `violence'
	
	
* Define name of the Excel fine  
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/other_impacts_phonesvy.xlsx", modify sheet(mechanisms)	 

 
	* Locals for putexcel rows  
	local row 	 = 4 
	local row_se = 5 // SE 
	local row_p	 = 6 // p-values 
	 
	foreach var in $finance_oth $sale_reason_r1 $reason_biz_close $past_3years_lstock $time_hours $health $covid { 
		 
		cap confirm var `var' 
		if !_rc { // if the variable exists  
		 
			global `var'_lab : variable label `var' 
		 
			* Do not cluster when doing each round separately (not panel)
	
			cap noi reg `var' treatment ${controls}, r 
			cap noi sum `var' if treatment == 0 & e(sample) == 1 
		
			cap noi coeff_treat_excel `var' treatment 
								 
					* Titles 
					putexcel A1 = "ADDITIONAL OUTCOMES" 
					putexcel A2 = "Phone survey" 
					
					putexcel B3 = "Control Mean" 
					putexcel C3 = "Level" 
					putexcel D3 = "% Control Mean" 
					putexcel E3 = "SD Control" 
					putexcel F3 = "N"  
					 
					* Results  
					putexcel A`row' = "${`var'_lab}" 
					putexcel B`row' = "${`var'm0}" 
					putexcel C`row' = "${`var't}" 
					if !regexm("`var'","index") & !regexm("`var'","Index") { // change here from ndex  
						if "${`var'imp1}"!="" { // change here  
							putexcel D`row' = "${`var'imp1}%"  
						} 
						else { 
							putexcel D`row' = "" 
						} 
					} 
					putexcel E`row' = "${`var'imp2}" 
					putexcel F`row' = "${N_`var'}" 
					 
					putexcel B`row_se' = "(${`var's0})" 
					putexcel C`row_se' = "(${`var'tse})" 
					putexcel C`row_p' = "[${`var'p}]"	 
							 
					local row = 	`row' + 3 
					local row_se = 	`row_se' + 3 
					local row_p = 	`row_p' + 3 
			} 
			 
		} 
	 
	 * Mult rounds of schooling and extra schooling outcomes 	
	use "${schooling_phonesvy}", clear 
	
	unab reason_notenrolled_r1:	b15b_1_1 - b15b_11_1
	unab reason_notenrolled_r4: b15b_1_4 - b15b_11_4
	
	gl schooling 		 `reason_notenrolled_r1' ///
						 `reason_notenrolled_r4' ///
							missed_any_exams
	
	lab var child_inschool_hh "School Enrollment (ages 6 to 18 years) (round 1)" 
	lab var child_inschool_hh_4 "School Enrollment (ages 6 to 18 years) (round 4)" 

	foreach var in $schooling { 
		global `var'_lab : variable label `var' 
		 
		* Cluster at HHID level (we have child-level data)
		reg `var' treatment ${controls}, vce(cluster hhid)
		sum `var' if treatment == 0 & e(sample) == 1 
		 
		coeff_treat_excel `var' treatment	 
		 
		* Results  
		putexcel A`row' = "${`var'_lab}" 
		putexcel B`row' = "${`var'm0}" 
		putexcel C`row' = "${`var't}" 
		if !regexm("`var'","index") & !regexm("`var'","Index") { // change here from ndex  
			if "${`var'imp1}"!="" { // change here  
				putexcel D`row' = "${`var'imp1}%"  
			} 
			else { 
				putexcel D`row' = "" 
			} 
		} 
		putexcel E`row' = "${`var'imp2}" 
		putexcel F`row' = "${N_`var'}" 
		 
		putexcel B`row_se' = "(${`var's0})" 
		putexcel C`row_se' = "(${`var'tse})" 
		putexcel C`row_p' = "[${`var'p}]"	 
				 
		local row = 	`row' + 3 
		local row_se = 	`row_se' + 3 
		local row_p = 	`row_p' + 3				
	}
	 

 
	