/*  
 
Draft analysis tables : panel regressions for panel outcomes
 
*/ 

* "Long" files 
gl data_for_analysis_phonesvy_long		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy_long.dta"

 
 
* Mult rounds of consumption and FS  
	gl consump_long exp_tot_m_pc_ca21 exp_f_tot_m_pc_ca21 exp_nf_tot_m_pc_ca21
	
	gl consump_long_lvl exp_tot_m_pc_ca18 exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc_ca18
	 	  
	gl foodsec_long index_sdC_food_sec c14_7 c14_3_ac c14_5_ac
  
* Mult rounds of finance   
	gl finance_long loan_dummy loan_usd saving_dummy saving_usd saving_usd 
	 
* Mult rounds of assets  
	gl assets_long 		wealth_score_sdC tup_lstock_yes lstock_yes_chicken
	gl assets2_long 	lstock_num_cow lstock_num_goat lstock_num_sheep lstock_num_chicken lstock_num_cow lstock_num_goat /// 
							lstock_num_sheep lstock_num_chicken 
	 
* Mult rounds of labor participation 
	gl labor_long	labor_particip_pf labor_particip_pm /// 
						employment_pf employment_pm /// 
						k5_1_pf k5_1_pm /// 
						did_livestock_pf did_livestock_pm /// 
						did_ownFarming_pf did_ownFarming_pm /// 
						did_ownBiz_pf did_ownBiz_pm  /// 
						did_oWork_pf did_oWork_pm 
 
* Mult rounds of income  
	gl income_long 	tot_hh_income_usd tot_lstock_revenue_usd tot_biz_revenue_usd tot_pmpw_pay_imp_usd ///
						tot_crop_revenue_imp_usd tot_crop_revenue_usd 
						 
 * Controls: set R4 as base level
	gl panel_controls i.PRA_lottery ib(4).round
	

* Define name of the Excel fine  
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/other_impacts_phonesvy.xlsx", modify sheet(panel_outcomes)	 
	 

	use $data_for_analysis_phonesvy_long, clear  
	 
	lab var tot_crop_revenue_imp_usd "Total crop revenue (USD), 4 weeks - imputed" 
	lab var tot_lstock_revenue_usd "Sales of livestock (last 4 weeks) (pooled)"
	
** Phone survey	 
 
	* Locals for putexcel rows  
	local row 	 = 4 
	local row_se = 5 // SE 
	local row_p	 = 6 // p-values 
	 
	foreach var in $consump_long $consump_long_lvl $foodsec_long $finance_long $assets_long $assets2_long $labor_long $income_long   { 
		 
		cap confirm var `var' 
		if !_rc { // if the variable exists  
		 
			global `var'_lab : variable label `var' 
		
		* Cluster at the HH level
			reg `var' treatment ${panel_controls}, vce(cluster hhid)
			sum `var' if treatment == 0 & e(sample) == 1 
			 
			coeff_treat_excel `var' treatment 
			
			* Number of unique HHs
			unique hhid if e(sample) == 1
			global Nhh_`var' `r(sum)'
			
			* Number of rounds included 
			unique round if e(sample) == 1
			global Nr_`var' `r(sum)'
			
					* Titles 
					putexcel A1 = "PANEL OUTCOMES" 
					putexcel A2 = "Phone survey" 
					
					putexcel B3 = "Control Mean" 
					putexcel C3 = "Level" 
					putexcel D3 = "% Control Mean" 
					putexcel E3 = "SD Control" 
					putexcel F3 = "N*t"
					putexcel G3 = "N"
					putexcel H3 = "t"
					 
					* Results  
					putexcel A`row' = "${`var'_lab}" 
					putexcel B`row' = "${`var'm0}" 
					putexcel C`row' = "${`var't}" 
					if !regexm("`var'","index") & !regexm("`var'","Index") { // change here from ndex  
						if "${`var'imp1}"!="" { // change here  
							putexcel D`row' = "${`var'imp1}%"  
						} 
						else { 
							putexcel D`row' = "" 
						} 
					} 
					putexcel E`row' = "${`var'imp2}" 
					putexcel F`row' = "${N_`var'}" 
					putexcel G`row' = "${Nhh_`var'}"
					putexcel H`row' = "${Nr_`var'}"
					 
					putexcel B`row_se' = "(${`var's0})" 
					putexcel C`row_se' = "(${`var'tse})" 
					putexcel C`row_p' = "[${`var'p}]"	 
							 
					local row = 	`row' + 3 
					local row_se = 	`row_se' + 3 
					local row_p = 	`row_p' + 3 
			} 
			 
		} 