/* Shocks subgroup analysis 
	
	- any shock
	- death of illness 
	
	
	Thomas: Would be interesting to check here for the different types of shocks, the ones that would impact income (and then decrease consumption) versus the ones which would increase non food consumption
	
*/

global 	shocks							"${TUP_DB}\Phone_Survey\DataSets\Intermediate\shocks_roster_phonesvy.dta"
global  phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

if $round_1_2 == 0 {
	* Datatset with all rounds
	gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy.dta"
}
else {
	* Dataset restricted to R1-R2 outcomes
	gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy_r1.dta"
}


* Prepare shocks variables 
use "${shocks}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) keepusing(treatment ultra_poor PRA_lottery call_status_r1 date_r*) nogen

	replace round = 3 if round == 2 & call_status_r1 == 1 // R3 since date of last survey  	

	* Create a dummy for illness or death of HH member 
	gen illness = (inlist(shock,5,6) & g1_a == 1) 
	
	/* To do: 
	
	- break up specific non-food items
	- add binary loan_yes_no variable 
	
	
	Create a dummy for shocks that are more likely to reduce consumption vs. increase non-food consumption
	
	Shocks expected to decrease income (and reduce consumption):
			Lost a job or cannot find work (outside of HH)
			Household business had to close
			Household business had a loss
			
	Shocks expected to result in increase non-food consumption (high one-time expense):
		
			
			Household livestock got sick or died 
			
			Household forced to move
			Severe illness or injury of a HH member (including accidents)
			Death of a HH member
			Imprisonment of a HH member
			Weather or natural disaster shock (e.g., drought, flood, storm, earthquake)
			Theft
			Destruction of house / other property (due to conflict or accident)
			HH member had to pay compensation
			Other violence/crime event
			Rise in food prices
			Lower crop yield
			Loss of household asset */

	collapse (max) g1 treatment illness PRA_lottery, by(hhid round)
	
	* No difference between T/C in experience of any shock OR illness or death specifically 
	preserve 
	
		rename (g1 illness) (g1_ illness_)
		reshape wide g1 illness, i(hhid) j(round)
		
		lab var g1_1 "Any shock (including illness or death) (round 1)"
		lab var g1_2 "Any shock (including illness or death) (round 2 - since April 2020)"
		lab var g1_3 "Any shock (including illness or death) (round 2 - since date of last survey)"
		lab var g1_4 "Any shock (including illness or death) (round 4)"
		
		lab var illness_1 "Illness or death (round 1)"
		lab var illness_2 "Illness or death (round 2 - since April 2020)"
		lab var illness_3 "Illness or death (round 2 - since date of last survey)"
		lab var illness_4 "Illness or death (round 4)"
		
		* Locals for putexcel rows 
		local row 	 = 3
		local row_se = 4 // SE
		local row_p	 = 5 // p-values
		
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks_phonesvy_${date}_r1.xlsx", modify sheet(exogeneity)

		foreach var in g1_1 g1_2 g1_3 g1_4 illness_1 illness_2 illness_3 illness_4 {
				
				global `var'_lab : variable label `var'
				reg `var' treatment ${controls}, r
				sum `var' if treatment == 0 & e(sample) == 1
				
				coeff_treat `var' treatment
					
					putexcel A1 = "Regression of Shock Indicator on Treatment with PRA Controls" 
					putexcel B2 = "Control Mean (SD)"
					putexcel C2 = "Adjusted difference"
					putexcel D2 = "N"
					
					putexcel A`row' = "${`var'_lab}"
					putexcel B`row' = "${`var'm0}"
					putexcel C`row' = "${`var't}"
					putexcel D`row' = "${N_`var'}"
					
					putexcel B`row_se' = "(${`var's0})"
					putexcel C`row_se' = "(${`var'tse})"
					putexcel C`row_p' = "[${`var'p}]"
					
					local row = 	`row' + 3
					local row_se = 	`row_se' + 3
					local row_p = 	`row_p' + 3
		}
				
	restore
	
	* Do not include R4 is restricting to R1-R2 data 
	if $round_1_2 == 1 {
		keep if round != 4 
	}
	
	* Experience of a shock	(At any point)	
	* Limiting this to just R1 and R2, the time period would be "since April 2020" for everyone 
	collapse (max) g1 treatment illness, by(hhid)

	gen anyshock = g1 

	keep hhid anyshock illness

	tempfile shocks
	save `shocks'

use "${data_for_analysis_phonesvy}", clear 
	merge m:1 hhid using "`shocks'", assert(1 3) nogen 
	
	bys hhid: egen maxshock = max(anyshock)
	bys hhid: egen maxill = max(illness)
		drop anyshock illness 
		rename (maxshock maxill) (anyshock illness)
		lab var anyshock "HH experienced any shock"
		lab var illness "HH experiences illness or death shock"
	
	gen t_anyshock = treatment*anyshock
	gen t_illness = treatment*illness
	
	* Rename vars that are too long 
	rename tot_biz_revenue_win_ppp tot_biz_revenue_w
	rename tot_crop_revenue_win_ppp tot_crop_revenue_w
	rename tot_lstock_revenue_1_w_ppp tot_lstock_revenue1
	rename tot_lstock_revenue_4_w_ppp tot_lstock_revenue4
	rename index_sdC_child_decisions child_decisions
	rename index_sdC_body_econopp body_econopp
	rename index_sdC_role_prod_act role_prod_act
	rename index_sdC_social_norms social_norms
	rename index_sdC_social_capital social_capital
	rename index_sdC_f_empowerment f_empowerment
	rename exp_nf_m_celeb_pc_c_1_ppp celeb_pc_c_1_ppp
	rename exp_nf_m_hh_items_pc_c_1_ppp hh_items_pc_c_1_ppp
	rename exp_nf_m_hhrepair_pc_c_1_ppp hhrepair_pc_c_1_ppp
	rename exp_nf_m_medical_pc_c_1_ppp medical_pc_c_1_ppp
	rename exp_nf_m_wedd_pc_c_1_ppp wedd_pc_c_1_ppp

* Locals for putexcel rows 
	local row 	 = 4
	local row_se = 5 // SE
	local row_p	 = 6 // p-values
	
global shock   anyshock // illness //	// anyshock		
	
if $round_1_2 == 0 & "$shock" == "anyshock" {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks_phonesvy_${date}.xlsx", modify sheet(anyshock)
}
if $round_1_2 == 1 & "$shock" == "anyshock" {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks_phonesvy_${date}_r1.xlsx", modify sheet(anyshock)
}	
if $round_1_2 == 0 & "$shock" == "illness" {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks_phonesvy_${date}.xlsx", modify sheet(illness)
}
if $round_1_2 == 1 & "$shock" == "illness" {
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks_phonesvy_${date}_r1.xlsx", modify sheet(illness)
}		

	
	if "$shock" == "anyshock" {
		putexcel A1 = "Impacts on Main Outcomes with Shock Interaction - Any shock"
	}
	else {
		putexcel A1 = "Impacts on Main Outcomes with Shock Interaction - Illness or death"
	}
	
	putexcel B2 = "Treatment"
	putexcel C2 = "Treatment x Shock"
	putexcel D2 = "Shock"
	putexcel E2 = "Control Mean - No Shock"
	putexcel F2 = "Control Mean - Shock"
	putexcel G2 = "Impact - No Shock [B/E]"
	putexcel H2 = "Impact - Shock [B+C+D/F]"
	putexcel I2 = "Test T + T x Shock = Shock"
	
	putexcel J2 = "Impact - Shock [B+C/E]"
	putexcel K2 = "Test T + T x Shock = 0"
	
	putexcel L2 = "UP N"
	
	* Move NUP means later 
	putexcel N2 = "NUP Mean - No Shock"
	putexcel O2 = "NUP Mean - Shock"
	putexcel P2 = "NUP N"
	
	
	foreach var in $shock_vars {
		cap confirm var `var'
		if !_rc { // if the variable exists 
			
			global `var'_lab : variable label `var'

			reg `var' treatment $shock t_$shock ${controls}, r	
			gen sample = e(sample)
			*Saving all the coefficients 
			test_interaction_shock L1_`var' treatment t_$shock
			stat_estim L1_`var' treatment
			stat_estim L2_`var' t_$shock
			stat_estim L3_`var' $shock	
			
			test_interaction L1_`var' treatment t_$shock
			
			*control mean	
			sum `var' if sample == 1 & treatment == 0 & $shock == 1
			global L1_`var'_m0 :  di %4.3f `r(mean)'
				impact_interaction L1_`var' treatment t_$shock $shock 3 // 3 is when we sum all 3 coefficients 
			sum `var' if sample == 1 & treatment == 0 & $shock == 0
			global L2_`var'_m0 :  di %4.3f `r(mean)' 
				impact_interaction L1_`var' treatment t_$shock $shock 1	// 1 is just for the treatmnent coefficient 
			sum `var' if sample == 1 & treatment == 0 & $shock == 1	
				impact_interaction L1_`var' treatment t_$shock $shock 2	// 2 is for coefficient and interaction
				
			drop sample
			
			* NUP means 
			sum `var' if mi(treatment) & $shock == 1
			global L1_`var'_mnup :  di %4.3f `r(mean)'
				
			sum `var' if mi(treatment) & $shock == 0
			global L2_`var'_mnup :  di %4.3f `r(mean)' 
			
			sum `var' if mi(treatment)
			global L1_`var'_Nnup :  di %15.0f `r(N)'
			
			* Putexcel
				putexcel A`row'= "${`var'_lab}"
			
				putexcel B`row' 	= "${L1_`var'}"
				putexcel B`row_se'	= "(${L1_`var'sd})"
				putexcel B`row_p' 	= "[${L1_`var'p}]"

				putexcel C`row' 	= "${L2_`var'}"
				putexcel C`row_se'	= "(${L2_`var'sd})"
				putexcel C`row_p' 	= "[${L2_`var'p}]"
				
				putexcel D`row' 	= "${L3_`var'}"
				putexcel D`row_se'	= "(${L3_`var'sd})"
				putexcel D`row_p' 	= "[${L3_`var'p}]"
				
				putexcel E`row' = "${L2_`var'_m0}"
				putexcel F`row' = "${L1_`var'_m0}"
				
				if "`var'" == "index_sdC_food_sec" | "`var'" == "index_sdC_food_sec_1" | "`var'" == "index_sdC_food_sec_4" | "`var'" == "wealth_score_0" | "`var'" == "wealth_score_2" | "`var'" == "wealth_score_4" | "`var'" == "fin_index_sdC_4" | "`var'" == "psy_indexC_sdC_0" | "`var'" == "satisf_z_sdC_0" | "`var'" == "hap_z_sdC_0" | "`var'" == "psy_indexC_sdC_10" | "`var'" ==  "satisf_z_sdC_10" | "`var'" ==  "hap_z_sdC_10" | "`var'" ==  "psy_indexC_sdC_2" | "`var'" ==  "satisf_z_sdC_2" | "`var'" ==  "hap_z_sdC_2" | "`var'" == "cesd_z_sdC_2" | "`var'" == "f_empowerment" | "`var'" == "index_sdC_hhexp" | "`var'" == "child_decisions" | "`var'" == "body_econopp" | "`var'" == "role_prod_act" | "`var'" == "social_norms" | "`var'" == "social_capital" {
					putexcel G`row' = "{NA;${L1_`var'imp2_1}}"
					putexcel H`row' = "{NA;${L1_`var'imp2_3}}"
					putexcel J`row' = "{NA;${L1_`var'imp2_2}}"
					
				}
				else {
					putexcel G`row' = "{${L1_`var'imp1_1}%;${L1_`var'imp2_1}}"
					putexcel H`row' = "{${L1_`var'imp1_3}%;${L1_`var'imp2_3}}"
					putexcel J`row' = "{${L1_`var'imp1_2}%;${L1_`var'imp2_2}}"
				}	
	
				putexcel I`row' = "${L1_`var'_y}"
				putexcel K`row' = "${L1_`var'_p}"
				
				
				putexcel L`row' = "${L1_`var'_N}"
				
				* NUP means - move later
				putexcel N`row' = "${L2_`var'_mnup}"
				putexcel O`row' = "${L1_`var'_mnup}"
				if ${L1_`var'_Nnup} != 0 {
					putexcel P`row' = "${L1_`var'_Nnup}"
				}
				else {
					putexcel P`row' = " "
				}

			local row = 	`row' + 3
			local row_se = 	`row_se' + 3
			local row_p = 	`row_p' + 3
		}
	}
	