/*** HH-level data (panel)

Note(s) on missing values:


		1. Recoding of unexplained missing values (recoded as .u) :
			k45_1: missing in 6 cases 
			k46: missing in 30 cases as this question was added a little later  


	(1) This is put together as a cross-section, where info from latest rounds is prioritized over previous info if an outcome
	has been collected more than once. Missingness in variables will come from the fact that some households have not been 
	surveyed in all rounds (i.e., a HH may have info on expenditure decisionmaking from R2, but have missingness for fertility 
	decisionmaking if it were not also surveyed in R1).
	(2) On mobile data questions v1 v3: in an earlier version of the form we did not ask mobile data questions and started a little later, so it is 
	missing for about 150 HHs. This is because all HHs in R1 have been verified by MISFA and we asked some version of this question in the MISFA survey.
	Option to go back to MISFA verification results to check if we can fill this in, though not sure it is very accurate.
	
I. Women's empowerment 

	1. HH Expenditures Decisions Index -- R2
		h1: What to cook on a daily basis
		h2: Buying groceries
		h3: Buying clothing
		h4: Buying expensive items (i.e. carpet, jewelry)
		h5: Buying small items (i.e. detergent, soap)
		h6: Buying or selling land or property
		h7: Managing household finances
		h8: Making home improvements/repair
		
	2. Children's Human Capital Investments and Marriage De-cisions Index -- R2
		h9: Whether your daughter should attend school
		h10: Whether your son should attend school
		h11: Marriage of daughters
		h12: Marriage of sons
		h13: Consulting a doctor when your child is ill
		
	3. Fertility and Mobility Decisions and Access to Resources Index -- R1

		h14: How many children to have 
		h28: If you wanted to take out a loan
		h31: If you wanted to pursue a job outside the home
		h24: If you wanted to open a new business
		Primary female has a mobile phone account = v1 v3_*
		Primary female has a loan in her name = in fl1 this was from a loan roster, we do not have this in the phone survey.
		h30: Primary female has savings/loans/other financial assets in your own name and separate from other
		
	4. Economic Opportunities Index -- R1, R3, R4 (market work participation only)

		Engaged in productive activities k30 -- R3, R4 [this in a roster "k_e_timeuse_phonesvy.dta"]
		Engaged in paid productive activities k30 -- R3, R4 [this is in a roster "k_e_timeuse_phonesvy.dta"]
		k24: Primary female is owner or manager of a HH non-agricultural bussiness -- R1, R4
		
	5. Aspirations for Daughters Index -- R4

		i1_d: What is the highest education level that you would like ${name_youngest_daughter} to complete?
		i2_d: How will this level of education help ${name_youngest_daughter}?
		i4_d: At what age would you like to see ${name_youngest_daughter} marry? 
		School-age girls are enrolled in school -- this needs to be added from the schooling roster 
		
	6. Political Involvement and Social Capital Index -- R1, R4

		s21: Has a Tazkira (Afghan national identification card) = z2 
		s10: Is a member of a political party - was not asked as was too sensitive
		n1:  Attended village meetings 
		n2:  Approached village leaders about village issue
		
	7. Additional indicators from the Suri paper -- R3 and R4

		e1: Are you allowed to buy things in the market without asking the permission of the head of the household or another member? -- R3
		e2: When an expensive item like a bicycle or a cow is purchased by the household, is your opinion listened to in the decision of what to buy? -- R3
		e3: Do you have to ask the permission of other household members to buy clothing for yourself? -- R3
		e4: Are you permitted to visit women in other parts of the village to talk with them? -- R3
		e5: Are you permitted to visit any place riding on public transport? -- R3
		e6: Are you allowed to go alone to meet your friends or relatives in the village for any reason? -- R4
		e7: Who do you consult with for decisions regarding your children's health care?
		e8: If money is available, who in your household decides whether to pay for expenses related to education (such as books and pencils) for your child?

II. Non-ag biz

	Round 1: k23_a k32 [panel]	
	Round 3: k25 k26 k27
	Round 4: k23_a k32 [panel]

III. Psy well-being 

	Round 1: i5 i27
	Round 2: i5 i27 [depression] i7 i10 i11 i12 i16 i23 i25
	Round 4: i5 i27 [only asked in the Full survey, not the short version]

IV. Loans and savings

	Round 1: m5 m20
	Round 3: m5 m20 m3
	Round 4: m5 m20
	
	
	3
	Tazkira 
	
V. 
	
*/



* Inputs 
global 	phone_svy_clean_r1			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r4.dta" 
global 	timeuse				     	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/timeuse_roster_phonesvy.dta"
global 	mobile						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/mobile_roster_phonesvy.dta"
global  roster_phonesvy				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"

* Outputs
global 	all_hhlevel_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"


*********************************************************************************
* Round 1
*********************************************************************************

use "${phone_svy_clean_r1}", clear 
	keep field_hhid hhid treatment PRA_lottery call_status numchild no_pm ///
		c14_* ///
		d8 - d9a_confirm_val ///
		h14 - h30 k24_* n1 n2 ///
		i5 i27 ///
		k23_a - k32_corr ///
		k45_2 - k46 ///
		m5_1 - m20_confirm_val ///
		z1 - z5_0 a11 a11_o
		
	drop *_warning *confirm* k32_1 k32_2 k32_3 k32 m5 m20 m5_1 m5_2 m5_3 m20_1 m20_2 m20_3 d9 d9a d8
	rename *_corr *
	destring no_pm, replace 
	drop d9_* d9a_*
	
	* Create round indicator
	gen round = 1 
	
	tempfile panel_r1
	save 	`panel_r1'

	
*********************************************************************************
* Round 2
*********************************************************************************	
	
use "${phone_svy_clean_r2}", clear 
	keep field_hhid hhid treatment PRA_lottery call_status no_pm ///
		h1 - h13 ///
		i5 - i25 ///
		t1 - t4 ///
		z1 - z5_0  a11 a11_o
		tostring a11_o, replace 
	
	* Drop select_multiple strings  
	drop t2 t0 t0_ret
	* t0_2_* has been renamed to t0_ret due to name conflict
	tabmiss t0_2_*
	drop t0_2_*
		
	* Create round indicator
	gen round = 2
	
	tempfile panel_r2
	save 	`panel_r2'

	
*********************************************************************************
* Round 3
*********************************************************************************
	
use "${phone_svy_clean_r3}", clear 
	keep field_hhid hhid treatment PRA_lottery call_status no_pm ///
		has_daughter i1_d - i4_d i5 i27 e1 - e8 ///
		k25 - k27__99 ///
		m5_1  - m20_confirm_val ///
		in_migration - migrant_remit_amt_99_warning ///
		o1 - o1_b__99 violence_ask ///
		z1 - z5_0  a11 a11_o
		tostring a11_o, replace 
	
	drop *_warning *confirm* *calc m5 m20 m5_1 m5_2 m5_3 m20_1 m20_2 m20_3 m3 o1_b
	rename *_corr *
	
	* Create round indicator
	gen round = 3
	
	tempfile panel_r3
	save 	`panel_r3'


*********************************************************************************
* Round 4
*********************************************************************************	

* Start with R4 so that we keep the late z1_2st non-missing variable value for outcomes collected more than once 
use "${phone_svy_clean_r4}", clear 
	keep field_hhid hhid treatment PRA_lottery call_status incomplete_hh numchild no_pm ///
		c14* ///
		k24_1 - k24_3_0 e6 has_daughter i1_d - i4_d h14 - h30 n1 n2 e6 ///
		k23_a - k32_dk ///
		m5_1 - m20_confirm_val ///
		i5 i27 ///
		in_migration -  migrant_remit_amt_99_warning ///
		am1 - m22__99 f23 - x5 ///
		z1 - z5_0  a11 a11_o
		
	tostring k24_1 k24_2 k24_3 a11_o, replace // so the merge below works 
	
	drop  *warning *confirm* *calc k32_1 k32_2 k32_3 k32 m5 m20 m5_1 m5_2 m5_3 m20_1 m20_2 m20_3 out_migration_num m22 f23 f25 x2
	rename *_corr *
	
	gen round = 4
	
	* Create round indicator
	tempfile panel_r4 
	save 	`panel_r4' 
	

*********************************************************************************
* Compile rounds
*********************************************************************************/
	
	* Instead of merging, do a simple append for now
		use "`panel_r1'"
			append using "`panel_r2'"
			append using "`panel_r3'"
			append using "`panel_r4'"

*********************************************************************************
* Check for missing values and recode 
*********************************************************************************
		
	* Food security
		assert c14_1!=. & c14_3!=. & c14_7 !=. if call_status == 1 & round == 1 
		assert c14_5!=. if (numchild > 0 | mi(numchild)) & call_status == 1 & round == 1 
		
	* Empowerment 
		cap noi assert h14!=. if call_status == 1 & round == 1 // 16 missing in h14 in R1 [recode as .u]
		assert h28!=. & h31!=. & h24!=. & h30!=. if call_status == 1 & round == 1 
		list field_hhid if h14 ==. & call_status == 1 & round == 1 
		assert n1!=. & n2!=. if call_status == 1 & round == 1 
		
		forval i = 1/13 {
			di "h`i'"
			cap noi assert h`i'!=. if call_status == 1 & round == 2 // 8 missing in each of the H variables in R2 [recode as .u]
		}
	
	* Psy well-being
		assert !mi(i5) if call_status == 1 & (inlist(round,1,2) | round == 4 & incomplete_hh == 1)
		assert !mi(i27) if call_status == 1 & (inlist(round,1,2) | round == 4 & incomplete_hh == 1)
		assert i5!=. & i27!=. & i7!=. & i10!=. & i11!=. & i12!=. & i16!=. & i23!=. & i25!=. if call_status == 1 & round == 2 
	
	* Loans & Savings 
		assert m5!=. if call_status == 1 & round == 1 
		assert m20!=. if call_status == 1 & round == 1 
		
	* Non-ag biz
		assert k23_a!=. if call_status == 1 & round == 1 
		assert !mi(k24_1) if  k23_a == 1 & round == 1 
		assert k32!=. if k23_a == 1 & round == 1 
		
	* Total income 
		assert k45_2!=. & k44!=. if call_status == 1 & round == 1 
		cap noi assert k45_1!=. if !inlist(k44,-99,-98,3) & call_status == 1 & round == 1  // 6 missing 
		cap noi assert k46!=. if call_status == 1 & round == 1 // 30 missing - we added this question a little later on 

	* Transfers 
		assert d8_1!=. if call_status == 1 & round == 1 
		assert d9!=. if d8_1 == 1 & round == 1 
		assert d9a!=. if d8_2 == 1 & round == 1 
	
	* IDPs
		assert t1!=. if call_status == 1 & round == 2 
		assert t2_1!=. if t1 == 1
		assert t3!=. if t2_1 == 1 
		assert t0_1!=. if !inlist(t3,0,-99,.)  
		
		foreach i in `c(alpha)' {
			  if "`i'"<="g" {
				di "assert t5`i'"
				assert t5`i'!=. if t2_1 == 1
			  }
		}
		
		assert t6!=. & t7!=. if t2_1 == 1
		
		assert t3_2!=. if t2_2 == 1
		assert t0_ret_1!=. if !inlist(t3_2,0,-99,.)
		
		foreach i in `c(alpha)' {
			  if "`i'"<="g" {
				di "assert t5`i'_2"
				assert t5`i'_2!=. if t2_2 == 1
			  }
		}
		
		assert t6_2!=. & t7_2!=. if t2_2 == 1
		assert t9_1!=. & t9_2!=. if t2_1 == 1
		assert t10_1!=. &  t10_2!=. if t2_2 == 1
		assert (t8!=. | t4_1!=. | t4!=. ) if call_status == 1 & round == 2 
		
	* Tazkira
		* ID HHs only surveyed ONLY in R1 or ONLY in R2 
		bys field_hhid: gen n_rounds = _N
		unique field_hhid if n_rounds == 1
		unique field_hhid if n_rounds == 2
		
		gen r1_only = (n_rounds == 1 & round == 1)
		gen r2_only = (n_rounds == 1 & round == 2)
		
		* R1
		assert z1!="" if round == 1 & call_status == 1
		assert z2!=. if round == 1 & call_status == 1 
		cap noi assert z3!=. if call_status == 1 & round == 1 & no_pm != 100 // 6 missing values for the PM 
		cap noi assert z4!="" if inlist(z2,1,2) & round == 1 & call_status == 1  // 13 missing values
		assert z5!="" if z2 == 0 & round == 1 & call_status == 1
		
		* R2
		assert z1!="" if round == 2 & call_status == 1 & r2_only == 1 
		assert z2!=. if round == 2 & call_status == 1 & r2_only == 1 
		assert z3!=. if call_status == 1 & round == 2 & no_pm != 100 & r2_only == 1
		assert z4!="" if inlist(z2,1,2) & round == 2 & call_status == 1 & r2_only == 1
		assert z5!="" if z2 == 0 & round == 2 & call_status == 1 & r2_only == 1 
		
		assert z6!=. if inlist(z2,1,2) & round == 2 & call_status == 1
		cap noi assert z7!=. if inlist(z3,1,2) & round == 2 & call_status == 1 // 2 missing values

	* Recode unexplained missing values with .u (=unexplained)
		
		* 16 missing values in h14 in R1
		recode h14 		(. = .u) if h14 == . & call_status == 1 & round == 1 

		* 8 missing values in each of the H variables in R2
		forval i = 1/13 {
			di "h`i'"
			recode h`i' (. = .u) if call_status == 1 & round == 2
		}
		
		* 6 missing values in k45_1 in R1
		recode k45_1 	(. = .u) if !inlist(k44,-99,-98,3) & call_status == 1 & round == 1
		
		* 30 missing values in k46 in R1
		recode k46 		(. = .u) if call_status == 1 & round == 1
		
		* 6 misisng values in z3 (R1)
		recode z3		(. = .u) if call_status == 1 & round == 1 & no_pm != 100
		
		* 13 missing values in z4 (R1)
		recode z4_* 	(. = .u) if inlist(z2,1,2) & round == 1 & call_status == 1
		
		* Missing values in z7 (R2)
		recode z7 		(. = .u) if inlist(z3,1,2) & round == 2 & call_status == 1
	
	
	* Drop variables used for checks we don't need anymore
	drop k24_1 k24_2 k24_3 z1 z4 z5
	
	* Recode partially complete interview missing values with .p	
	recode numchild 		 (. = .p) if call_status == 2 & round == 1 
	recode c14_1 c14_3 c14_7 (. = .p) if call_status == 2 & round == 1 
	recode c14_5 			 (. = .p) if call_status == 2 & round == 1 & numchild > 0
	recode d9 d9a			 (. = .p) if call_status == 2 & round == 1 & mi(d8_1)

	recode i5 i27 			 (. = .p) if call_status == 2
	recode h1 - h13 		 (. = .p) if call_status == 2 & round == 2
	recode h14 - h30 		 (. = .p) if call_status == 2 & round == 1
	recode i7 - i25 		 (. = .p) if call_status == 2 & round == 2
	recode k45_2 - d8_0 	 (. = .p) if call_status == 2 & round == 1

	recode k23_a k24_* k32	 (. = .p) if call_status == 2 & round == 1
	recode n1 n2 m5 m20		 (. = .p) if call_status == 2 & round == 1
	recode t1 - t4 			 (. = .p) if call_status == 2 & round == 2
	
	* Recode .99 and .98 as misisng in Total Loans and Savings, Total Income, Value of Transfers Received vars since this is a mistake
	recode m5 m20 k45_2 k45_1 d9 d9a (.99 = -99) (.98 = -98) (98 = -98) (99 = -99)
	
	* Decode all other extended missing values 
	mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n)	
	
	* Values very close to .99/.99 but not exaclty, so they don't get corrected above
	replace m5 = .r if hhid == 5822 & round == 1
	replace m5 = .d if hhid == 6560 & round == 1
		
	* Label
	label var 	round 	"Phone survey round"
	label var 	r1_only	"HH surveyed in R1 only"
	label var 	r2_only	"HH surveyed in R2 only"
	
	label var 	k32		"Combined businesses revenues in the last 4 weeks"
	
	label var d8_1 		"Type of support received (last 4 weeks): Monetary support"
	label var d8_2 		"Type of support received (last 4 weeks): Non-monetary (in-kind) support"
	label var d8__99 	"Type of support received (last 4 weeks): Don’t know"
	label var d8__98 	"Type of support received (last 4 weeks): Don't answer"
	label var d8_0 		"Type of support received (last 4 weeks): None"
	
	label var d9		"Total value of all monetary support"
	label var d9a		"Total value of all in-kind support"
	
	label var z5_7		"Main reason for not having Tazkira: I don’t want photo taken"
	
/******************************************************************************
					Gross outliers 
******************************************************************************/
	
	* Clean outliers for total savings and total loans
	do "${Phone_Survey}/Dofiles/Cleaning/savings_loans_outliers_clean.do"	
	
	* Clean outliers for total business revenues
	do "${Phone_Survey}/Dofiles/Cleaning/business_revenues_outliers_clean.do"	
	
	
	* Order vars 
	order field_hhid hhid treatment PRA_lottery round r1_only r2_only call_status no_pm, first
	order c14_* d* h1 - h13 h14 - h30 i* k* m* n1 n2 t1 - t4 z*, after(no_pm)
	
	* Sort 
	sort field_hhid round
	
	* Drop temp variables 
	drop n_rounds 
	
	* Save data 
		if	`c(stata_version)'>=14	{
			saveold "${all_hhlevel_phonesvy}", replace v(13)
		}
		else {
			save "${all_hhlevel_phonesvy}", replace
		}
	