/* Assets

	1. Round 2 roster prep
	2. Round 3 roster prep
	3. Round 4 roster prep
	4. Compile panel data
	5. Minor cleaning
	
	* In R2, we ask about DHS assets, l1, and "productive" assets, l1_a
	* In R3, we ask about "productive" assets, l1_a, for HHs NOT surveyed in R2
	* In R4, we ask about DHS assets only, l1
	
	NB: Focus on R2 which we can use for now 
	
*/

* Inputs 
global 	phone_svy_clean_r2			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Outputs
global 	assets						"${TUP_DB}\Phone_Survey\DataSets\Intermediate\assets_roster_phonesvy.dta"


*********************************************************************************
* Round 2: l1 l1_a l2 l2_o l3 l3_house l3_crop l4_1 l4_2 l4_3 l4__98
*********************************************************************************

	use "${phone_svy_clean_r2}", clear 
		
		* Reshape 
		keep field_hhid hhid call_status l1 - l4__98_19
		
		drop asset_repeat_count asset_id_* asset_name_*
		
		rename (*__98 *__99) (*_98 *_99)
		
		reshape long l1_ l1_a_ l2_ l2_o_ l3_ l3_house_ l3_crop_ l4_1_ l4_2_ l4_3_ l4__98_, i(hhid) j(asset)
		
		drop l1 l1_a l4_1 - l4_19 
		rename *_ *
		
		gen round = 2
		
		tempfile assets_r2
		save `assets_r2'
		
		
*********************************************************************************
* Round 3: l1_b l1_a 

* l1_a is only asked in this round if it was not asked in the previous round [129 HHs],
* so when we merge R1 with R3, these will be "using only" HHs
*********************************************************************************		
	
	use "${phone_svy_clean_r3}", clear 
		keep field_hhid hhid call_status l1_a - l1_b__99
		
		* All data we need is stored in the calculated variable l1_b
		drop l1_b_full* l1_b_preload*
		
		rename (*__98 *__99) (*_98 *_99)
		
		reshape long l1_a_ l1_b_, i(hhid) j(asset)
		
		drop l1_a l1_b
		rename *_ *
		
		unique hhid if !mi(l1_a) // 129 HHs
		
		gen round = 3
		
		tempfile assets_r3
		save `assets_r3'
		
		
*********************************************************************************
* Round 4: l1 l2 l2_o l3 l3_house [panel]
*********************************************************************************
		
	use "${phone_svy_clean_r4}", clear 
		keep field_hhid hhid call_status l1 - l3_house_19
		
		drop asset_repeat_count asset_id_* asset_name_*
		
		rename (*__98 *__99) (*_98 *_99)
		
		reshape long l1_ l1_a_ l2_ l2_o_ l3_ l3_house_, i(hhid) j(asset)
		
		drop l1 
		rename *_ *
		
		gen round = 4
		
		tempfile assets_r4
		save `assets_r4'
		

*********************************************************************************
* Merge and append rounds 
*********************************************************************************

		use "`assets_r2'"
			*merge 1:1 hhid asset using "`assets_r3'", update gen(merge_r3) // using only is 127, instead of 129 as expeted - not sure why, so use the update replace option to keep R3 observations where there is a conflict
			append using "`assets_r3'"
			append using "`assets_r4'"
			
		recode asset (99 = -99)	(98 = -98)	
			
		* Label
		label var 	round 		"Phone survey round"
		label var 	l1			"DHS asset ownership"
		label var 	l1_a		"Other productive asset ownership"
		label var 	l2_o		"Please specify the number of asset (if >10)."
		label var 	l3_house	"Total size of Land on which your home is built (jerib)"
		label var 	l3_crop		"Total size of Other land(s) (excluding land on which your home is built) (biswa)"
		label var 	l4_1 		"Owns asset: I own it"
		label var 	l4_2 		"Owns asset: A household member owns it"
		label var 	l4_3 		"Owns asset: Everyone in the household"
		label var 	l4__98 		"Owns asset: Don't answer"
		label var 	l1_b		"Does anyone in your household use these assets for a business / to generate income?"
		
		#delimit;
		label define asset_lab 
			1	"Radios/CDs/Cassettes"
			2	"Televisions"
			3	"Dish Antenna"
			4	"VCRs/DVD players"
			5	"Land on which your home is built"
			6	"Other land(s) (excluding land on which your home is built)"
			7	"Other houses/buildings"
			8	"Refrigerators "
			9	"Generators"
			10	"Mattresses"
			11	"Cell (mobile) phones"
			12	"Non-mobile phones"
			13	"Clothes irons"
			14	"Bed frames"
			15	"Pieces of jewelry (gold, silver, etc.)"
			16	"Mosquito nets"
			17	"Mosquito-repellant candles"
			18	"Fans"
			19	"Cameras"
			20	"Storage facility for crop"
			21	"Water tank"
			22	"Solar panels"
			23	"Gas cooker"
			24	"Bicycle"
			25	"Wheelbarrow"
			26	"Milking equipment"
			27	"Chaff cutter"
			28	"Sewing/knitting machine"
			29	"Borehole or well"
			30	"Sheller"
			31	"Other agro-processing equipment"
			32	"Weighing machine"
			33	"Saw"
			34	"Spray pump (back pack)"
			35	"Motorized water pump"
			36	"Mechanical water pump"
			37	"Drip irrigation equipment"
			38	"Other irrigation equipment"
			39	"Cart"
			40	"Plough"
			41	"Harrow, tiller, ridger, weeder"
			42	"Motorcycle"
			43	"Car/truck"
			44	"Tractor"
			45	"Watering can"
			46	"Axes"
			47	"Hoe"
			48	"Water Gallon"
			49	"Small gas cooker"
			0	"None"
			-98	"Don't answer"
			-99	"Don't know";
		#delimit cr
		
		label val asset asset_lab
		
		* Additional cleaning 
		tab l1 l1_a if inlist(asset,-98,-99) // no one selected these options 
		drop if inlist(asset,-98,-99)
		
		* Recode DK values 
		mvdecode _all, mv(-99 =.d \ -98=.r)
		
		* For 6 (Other land), use l3 for size, in a few instances we use l3_crop
		gen l3_land = l3 if asset == 6
			replace l3_land = l3_crop if mi(l3) & !mi(l3_crop)
			drop l3_crop l3
			order l3_land, after(l3_house)
			label var l3_land "Other land(s) (excluding land on which your home is built (biswa)"
			
		* Combine l2 and l2_o into one variable 
		replace l2 = l2_o if mi(l2) & !mi(l2_o)
			drop l2_o
	
	* Checks on missingness [errors in assertions are due to TPM corrections - i.e., when TPM selected an item correctly but surveyor did not]
	* think about this TPM thing a bit more; if that is the case, TPM must have answered follow-up questions on this asset, so we should be able to 
	* retrieve those answers from TPM data and fill in the missing values.
	
	cap noi asser l2!=. if l1==1 & !inlist(asset,5,6,0)
		br if l2==. & l1==1 & !inlist(asset,5,6,0) // T0425 is missing data on cells phones in R2; T2461 is missing data on gold in R4
	cap noi assert l3_house!=. if inlist(asset,5) & l1==1
		br if l3_house==. & inlist(asset,5) & l1==1 // T1386 is missing data on land house is built on in R2
	cap noi assert l4_1!=. if l1==1 & round == 2 
		unique hhid if l4_1!=. & l1==1 // we oly asked l4 of 34 HHs in the pilot, and then dropped the question; so, drop this variable 
		drop l4_*
		
	* Before we fix the quantities from TPM surveys, replace this missingness with ".u" (for unexplained)
		replace l2 = .u if field_hhid == "T0425" & asset == 11 & round == 2
		foreach var in "l2" "l3_house" {
			replace `var' = .u if field_hhid == "T1386" & asset == 5 & round == 2
		}
		
		* Separate DHS assets from other productive assets
		gen dhs = (asset <= 19 & asset!=. & asset !=0)
		label var dhs "DHS asset indicator"
		
		* Sort
		sort hhid round asset
		
		* Order
		order hhid round call_status asset dhs, first
		order l1_b, after(l1_a)
		
		* Drop the second ID
		drop field_hhid call_status

		* Save
		save "${assets}", replace 
			
			
			
		
		
		
