* Prepare Sayed corrections for non-food consumption rounds 3-4
* Inputs 
global nonfood_consumption				"${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfoodcons_roster_phonesvy.dta"
global phone_svy_profile   				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
global sayed_correction_r3_r4			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R3\Quality Checks/TUP_Audio_Sayed_extra_rounds.xlsx"

* Outputs 
global correction_consumption_r3_r4 	"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey\Quality Checks/correction_consumption_r3_r4.dta"
global discrepancy_consumption_r3_r4 	"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey\Quality Checks/sayed_dicrepancy_consumption_r3_r4.dta"



import excel using "${sayed_correction_r3_r4}", firstrow clear

rename A hhid 
rename G note
rename H note_detail
drop B I J
drop if c13_1 == "DO NOT FILL - issue with file"

destring c13_*, replace 

* Drop all missing (audio not available or cut off, so these were not checked)
drop if c13_1 == . & c13_16 == . & c13_17 == . & c13_18 == .

cap noi assert c13_1!=.
cap noi assert c13_16!=.
cap noi assert c13_17!=.
cap noi assert c13_18!=. // in 1692_3, health services was not asked, so do not do this replacement and replace this instance with -888
	replace c13_18 = -888 if c13_18 == .

* Cleaning (all)
mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n \ -888 = .b) // .b = bad quality audio

* Separate ID from round 
split hhid, p(_)
drop hhid 
rename hhid1 hhid
rename hhid2 round 
destring hhid round, replace 

reshape long c13_, i(hhid round) j(item)
rename *_ *
replace item = item + 20 

drop if c13 == .b // drop bad quality audios 

/* Checking with Sayed on the DKs in health services 

For these, he left a comment that surveyor was leading, but for others there is no note - 
checking with him whether this is for the audios that were first cut off and maybe 
he did not re-check those again: 

br if note == "Surveyor was leading the respondent" & mi(c13)
inlist(hhid,1483,1555,1600,2140) */

tempfile sayed_long
save `sayed_long'

* Temporarily recode back extended missings because otherwise the merge with update replace will not work 
tab c13, m
cou if mi(c13) // 54
assert c13 == .d if mi(c13) // all are DKs

gen c13_miss = c13
replace c13_miss = -99 if c13 == .d 

save "${correction_consumption_r3_r4}", replace 
stop

********************************************************************************
* CONSUMPTION 
********************************************************************************
use `sayed_long', clear 

replace item = item - 20 
rename c13 c13_
reshape wide c13_, i(hhid round) j(item)

merge m:1 hhid using "$phone_svy_profile", keepusing(treatment) keep(3) nogen
keep hhid c13_* round treatment 

tempfile sayed
save `sayed' 

* DISCREPANCY
use "${nonfood_consumption}", clear 
drop if item == 7 
keep hhid item round c13_with_outliers
rename c13_with_outliers c13_ 
reshape wide c13_, i(hhid round) j(item)
rename (*_21 *_36 *_37 *_38) (*_1 *_16 *_17 *_18)

tempfile consumption
save `consumption'


* Run bcstats
		cap noi bcstats, 	surveydata(`consumption') bcdata(`sayed') id(hhid round) ///
					t1vars(c13_1 c13_16 c13_17 c13_18) keepbc(treatment)  ///
					showall full replace /// 
					filename("${discrepancy_consumption_r3_r4}") dta nolab 
					
		use "${discrepancy_consumption_r3_r4}", clear 
		
		destring survey back_check, replace 
		
		gen actual_diff = .
			replace actual_diff = 0 if diff == 0 // 925
			* one is 0, one is missing (not outlier) - this is not a "real" difference (5 and 3 values)
			replace actual_diff = 1 if (diff == 1 & inlist(survey,.d,.r,.b,.) & back_check==0) | (diff == 1 & survey==0 &  inlist(back_check,.d,.r,.b,.)) 
			replace actual_diff = 1 if diff == 1 & survey>0 & !mi(survey) & back_check == . // same as above, poor quality audio was not checked, so do not count as a difference 
			* difference in values (37 values)
			replace actual_diff = 2 if diff==1 & !mi(survey) &!mi(back_check)
			* surveys is missing (DK, refuse) but Sayed gives a values (0 values)
			replace actual_diff = 3 if diff==1 & inlist(survey,.d,.r) & back_check>0 & !mi(back_check)
			* sayed is missing (DK, refuse) but but survey gives a value (14)
			replace actual_diff = 4 if diff==1 & inlist(back_check,.d,.r) & survey>0 & !mi(survey)
			
			sum diff 
			assert 925 + 5+3 + 37 + 0 + 14  == `r(N)'
			
		label define actual_diff_l 0 "No difference" 1 "Zero v. missing (no diff)" 2 "Difference in values" 3 "Missing survey (DK, refuse) with Sayed value"  4 "Missing Sayed (DK, refuse) with value in survey", modify
		lab val actual_diff actual_diff_l
		
		bys variable: tab actual_diff
		
		br if inlist(actual_diff,2,3,4)
		
		save, replace 
		
		export excel hhid variable round survey back_check diff bc_treatment actual_diff if inlist(actual_diff,2,3,4) using "${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey\Quality Checks/consumption_difference_extra_rounds.xlsx", firstrow(varl) replace 
		
			
			
			