/* Crops / Ag businesses 

	1. Round 2 roster prep:
		k15 k20_1 k20_2 ["panel" outcomes also asked in the "Long" survey in R4]
		k21_1 k21_2 [only asked in R1]
	
	2. Round 4 roster prep: 
		k15 k20_1 k20_2
	
	4. Compile cross-section/panel data
	5. Minor cleaning

*/

* Inputs 
global 	phone_svy_clean_r2 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Outputs
global 	crops				     	"${TUP_DB}\Phone_Survey\DataSets\Intermediate\crops_roster_phonesvy.dta"


*********************************************************************************
* Round 2: k15 k20_1 k20_2 [panel] k21_1 k21_2
*********************************************************************************

use "${phone_svy_clean_r2}", clear 
	keep field_hhid hhid call_status k15 - k21_2__99
	
	drop *warning *confirm* k20_1 k20_2
	rename *_corr *
	
	assert !mi(k20_1) if k15 == 1
	assert !mi(k20_2) if k15 == 1
	assert !mi(k21_1) if k20_1 > 0 & !mi(k20_1)
	
	rename *__99 *_99 
	
	* Reshape long 
	reshape long k21_1_ k21_2_, i(hhid) j(crop)
	
	drop k21_1 k21_2
	rename *_ *
	
	gen round = 2
	
	tempfile crops_r2
	save `crops_r2'
	

*********************************************************************************
* Round 4: k15 k20_1 k20_2 [panel]
*********************************************************************************

use "${phone_svy_clean_r4}", clear 
	keep field_hhid hhid call_status incomplete_hh k15 - k20_2_confirm_val
	
	drop *warning *confirm* k20_1 k20_2
	rename *_corr *
	
	assert !mi(k15) if incomplete_hh == 1 & call_status == 1 
	assert !mi(k20_1) if k15 == 1
	assert !mi(k20_2) if k15 == 1	
	
	gen round = 4
	
	tempfile crops_r4
	save `crops_r4'

	
*********************************************************************************
* Combine rounds
*********************************************************************************	
	use "`crops_r2'"
		append using "`crops_r4'"
		
	recode crop (99 = -99) (26 = -97)
	
	* Label
	label var 	round 			"Phone survey round"
	label var 	incomplete_hh 	"Type of R4 survey administered (Full or Short)"
	label var 	crop 			"Crop"
	label var 	k20_1			"How much did your household earn from selling crops in the last 12 months?"
	label var 	k20_2 			"Value of crops household stored or used for consumption in the past 12 months"
	label var 	k21_1			"Which crops did you cultivate for sale in the past 12 months?"
	label var 	k21_2 			"Which crops did you cultivate for own consumption in the past 12 months?"
	
	#delimit;
	lab define crop_lab
		1 "Wheat"
		2 "Vetch"
		3 "Maize"
		4 "Barley"
		5 "Rice"
		6 "Weed"
		7 "Sesame"
		8 "Clover"
		9 "Millet"
		10 "Sharsham"
		11 "Sugarcane"
		12 "Cotton"
		13 "Caraway-seed"
		14 "Potato"
		15 "Cereal"
		16 "Eggplant"
		17 "Tomato"
		18 "Onion"
		19 "Okra"
		20 "Fruits from a tree"
		21 "Grape"
		22 "Mellon"
		23 "Opium"
		24 "Zaghar"
		25 "Saffron"
		-97 "Other"
		-99 "Don’t know";
	#delimit cr
	lab val crop crop_lab
	
	label define incomplete_hh_lab 1 "Full survey" 0 "Short survey", modify
	label val incomplete_hh incomplete_hh_lab

	mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n)	 
	
	
	* Looking at outliers in crops sold (k20_1) and crops stored (k20_2) using both rounds as the fourth round is to add household that were previously missed 
	do "${Phone_Survey}/Dofiles/Cleaning/crops_outliers_clean.do"	
	
	* Order
	order field_hhid hhid round call_status incomplete_hh crop, first
	
	* Sort
	sort field_hhid round crop

	* Save data
	save "${crops}", replace 
	
	
