/* Food consumption [panel from 3 rounds]

	1. Round 1 roster prep
	2. Round 3 roster prep
	3. Round 4 roster prep
	4. Compile panel data
	5. Minor cleaning
	
	Questions & Issues:
		1. TBD 

*/

* Inputs 
global 	phone_svy_clean_r1			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_raw_r1_pilot		"${TUP_DB}\Phone_Survey\DataSets\Deidentified\phone_svy_raw_nopii_r1_pilot.dta" // consumption section from the 2 pilots 
global 	phone_svy_clean_r2 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Outputs
global 	food_consumption			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\foodcons_roster_phonesvy.dta" 


*********************************************************************************
* Round 1
*********************************************************************************

** First, pilot data 
use "${phone_svy_raw_r1_pilot}", clear 

	keep field_hhid hhid c3 - c8_a_o_5 key pilot1_flag pilot2_flag
		
		drop c3 bread_repeat_count bread_id_* bread_name_* c4 meat_repeat_count meat_id_* meat_name_* vegetables_repeat_count vegetables_id_* vegetables_name_* fruit_repeat_count fruit_id_* fruit_name_* c7 c8 c*__100 c5 dairy_repeat_count dairy_id_* dairy_name_*
		
		reshape long c3_ c3_i_ c3_a_kg_ c3_a_kg_o_ c3_a_pc_ c4_ c4_i_ c4_a_ c4_a_o_ c5_ c5_i_ c5_a_kg_ c5_a_kg_o_ c5_a_pc_ c7_ c7_i_ c7_a_ c7_a_o_ c8_ c8_i_ c8_a_ c8_a_o_, i(field_hhid) j(item)
			
		rename *_ *
		
		rename c3_* c_*_3
		rename c4_* c_*_4
		rename c5_* c_*_5
		rename c7_* c_*_7
		rename c8_* c_*_8
		rename (c3 c4 c5 c7 c8) (c_3 c_4 c_5 c_7 c_8) 
		
		gen n = _n
		
		reshape long c_ c_i_ c_a_ c_a_o_ c_a_kg_ c_a_kg_o_ c_a_pc_, i(n) j(item_type)
		
		drop n
		
		* dairy was added in the second pilot, so there is missingness for dairy for pilot 1 HHs 
		assert !mi(c_) if pilot1_flag == 0
		assert !mi(c_) if pilot2_flag == 1
		
		rename *_ *
		
		order field_hhid hhid item_type item, first
		
		destring c_i - c_a_pc, replace 
		mvdecode c_i - c_a_pc, mv(-99 = .d \ -98 = .r \ -97 = .n)	 

		* Fix "other" values [e.g., 16 in c_a means "other"; don't want to add '16' to an actual 'other' vaue below]
		local o_vars c_a c_a_kg
		foreach var of varlist `o_vars' {
			replace `var' = .n if !mi(`var'_o) // .n will stand for "other"
		}
		
		* Create flag variable
		gen flag_outlier = .
		lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
		lab val flag_outlier flag_outlier_l
		gen flag_outlier_why = ""
		
		* Replace 99/98 typos with .d
		foreach var in c_a c_a_o c_a_kg c_a_kg_o c_a_pc {
			forval i = 98/99 { 
				count if round(`var',0.01)==.`i'
				replace flag_outlier = 1 if round(`var',0.01)==.`i'
				replace flag_outlier_why = ".`i' typed instead of -`i'" if round(`var',0.01)==.`i'
				
				replace `var'=.d if round(`var',0.01)==.`i'
				replace flag_outlier = 1 if `var'== `i'
				replace flag_outlier_why = ".`i' typed instead of -`i'" if `var'== `i'
				replace `var'=.d if `var'== `i'
				}
		}
	
		destring c_a_pc, replace 
		replace c_a = c_a_kg if mi(c_a) & c_a_kg!=.
		replace c_a = c_a_o if mi(c_a) & c_a_o !=.
		replace c_a = c_a_kg_o if mi(c_a) & c_a_kg_o!=.
		
		* naan and egg collected in pieces in pilot 
		replace c_a = c_a_pc * 0.25 if !mi(c_a_pc) & item_type == 3 & item == 4 // 1 naan = 250 g
		replace c_a = c_a_pc * 0.05 if !mi(c_a_pc) & item_type == 5 & item == 5 // 1 egg = 50 g		
	
		replace c_a = .d if mi(c_a) & (c_a_kg == .d | c_a_o == .d | c_a_kg_o == .d | c_a_pc == .d)
	
		drop c_a_o c_a_kg c_a_kg_o c_a_pc
				
		* Create Roud var for appending data 
		gen round = 1
		
		* Drop a submission that was done again after the pilot 
		drop if key == "uuid:ee97affd-1c8c-4cd6-830f-a1a682c12555" // T2406 [post-pilot key uuid:c9684cec-a4b4-4260-a641-41997cc23982]
		drop if key == "uuid:145394d0-f1e4-4fd8-9936-4de361c03878" // T0009 [post-pilot key uuid:a64b6309-2723-4e73-bfc9-5cd0fd145fb1]
		
		* Save
		tempfile food_cons_r1_pilot
		save `food_cons_r1_pilot'
		
		
** Second, post-pilot data 
	use "${phone_svy_clean_r1}", clear 

		keep field_hhid hhid c3 - c8_a_pc_o_5 call_status

		destring *, replace 
		
		* Create Roud var for appending data 
		gen round = 1
	
		tempfile food_cons_r1
		save `food_cons_r1'
		
		
*********************************************************************************
* Round 3
*********************************************************************************	
use "${phone_svy_clean_r3}", clear 

	* Keep food consumption section
	keep field_hhid hhid c3 - c8_a_pc_o_5 call_status 
	
	* Create Roud var for appending data 
	gen round = 3
	
	tempfile food_cons_r3
	save `food_cons_r3'
		

*********************************************************************************
* Round 4 
*********************************************************************************	
use "${phone_svy_clean_r4}", clear 
	
	* Keep food consumption section
	keep field_hhid hhid c3 - c8_a_pc_o_5 call_status
	
	gen round = 4
				
	tempfile food_cons_r4
	save `food_cons_r4'
		
		
*********************************************************************************
* Compile panel and reshape 
*********************************************************************************/

use "`food_cons_r1'"
	append using "`food_cons_r3'"
	append using "`food_cons_r4'"

* Drop variables we don't need 	
	drop c3 bread_repeat_count bread_id_* bread_name_* c4 meat_repeat_count meat_id_* meat_name_* vegetables_repeat_count vegetables_id_* vegetables_name_* fruit_repeat_count fruit_id_* fruit_name_* c7 c8 c*__100 c5 dairy_repeat_count dairy_id_* dairy_name_* milk_unit_lab_* yogurt_unit_lab_*
		
* Reshape long
	reshape long c3_ c3_i_ c3_a_kg_ c3_a_kg_o_ c3_a_cup_ c3_a_cup_o_ c3_a_seer_ c3_a_seer_o_ c3_a_pc_ c3_a_pc_o_ c4_ c4_i_ c4_a_ c4_a_o_ c5_ c5_i_ c5_a_kg_ c5_a_kg_o_ c5_a_milk_unit_ c5_a_milk_ c5_a_milk_o_ c5_a_yogurt_unit_ c5_a_yogurt_ c5_a_yogurt_o_ c5_a_pc_ c5_a_pc_o_ c7_ c7_i_ c7_a_ c7_a_o_ c8_ c8_i_ c8_a_ c8_a_o_ c8_a_kg_ c8_a_kg_o_ c8_a_pc_ c8_a_pc_o_ c5_a_milk_jar_ c5_a_milk_kg_ c5_a_yogurt_bowl_ c5_a_yogurt_kg_, i(field_hhid round) j(item)
			
	rename *_ *
	
	rename c3_* c_*_3
	rename c4_* c_*_4
	rename c5_* c_*_5
	rename c7_* c_*_7
	rename c8_* c_*_8
	rename (c3 c4 c5 c7 c8) (c_3 c_4 c_5 c_7 c_8) 

	gen n = _n
		
	destring c_a_pc_8 c_a_pc_o_8, replace
	
	reshape long c_ c_i_ c_a_ c_a_o_ c_a_kg_ c_a_kg_o_ c_a_cup_ c_a_cup_o_ c_a_seer_ c_a_seer_o_ c_a_pc_ c_a_pc_o_ c_a_milk_unit_ c_a_milk_ c_a_milk_o_ c_a_yogurt_unit_ c_a_yogurt_ c_a_yogurt_o_ c_a_milk_jar_ c_a_milk_kg_ c_a_yogurt_bowl_ c_a_yogurt_kg_, i(n) j(item_type)
	
	drop n
	
	* Item 6, "Other meat", should only exist for the "meat" item type 
	drop if item == 6 & item_type != 4

	rename *_ *	
	
	destring c_i - c_a_yogurt_kg, replace 
	mvdecode c_i - c_a_yogurt_kg, mv(-99 = .d \ -98 = .r \ -97 = .n)	 

* Fix "other" values [e.g., 16 in c_a means "other"; don't want to add '16' to an actual 'other' vaue below]
	local o_vars c_a c_a_kg c_a_pc c_a_cup c_a_seer c_a_milk c_a_yogurt
	foreach var of varlist `o_vars' {
		replace `var' = .n if !mi(`var'_o) // .n will stand for "other"
	}
	
	* Create flag variable
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""
	
	* Replace 99/98 typos with .d
	foreach var in c_a c_a_o c_a_kg c_a_kg_o c_a_pc c_a_pc_o c_a_cup c_a_cup_o c_a_seer /// 
		c_a_seer_o c_a_milk c_a_milk_o c_a_yogurt c_a_yogurt_o c_a_milk_jar c_a_milk_kg c_a_yogurt_bowl c_a_yogurt_kg {
			forval i = 98/99 {
			count if round(`var',0.01)==.`i'
			replace flag_outlier = 1 if round(`var',0.01)==.`i'
			replace flag_outlier_why = ".`i' typed instead of -`i'" if round(`var',0.01)==.`i'
			
			replace `var'=.d if round(`var',0.01)==.`i'
			replace flag_outlier = 1 if `var'== `i'
			replace flag_outlier_why = ".`i' typed instead of -`i'" if `var'== `i'
			replace `var'=.d if `var'== `i'
			}
	}
	
	/* Unit issues identified in the Outlier fo-file 
		* Some fruits appear to have been collected in pieces instead of KGs in rounds 3, 4 
	* Apple 
	replace c_a = .o if item == 66 & inlist(hhid,hhid,5227,1010,1945,5775,5652) & round == 4 
	replace flag_outlier = 2 if item == 66 & c_a == .o & round == 4

	* Orange 
	replace c_a = .o if item == 72 & hhid == 6628 & round == 4 
	replace flag_outlier = 2 if item == 72 & c_a == .o & round == 4

	* Banana 
	replace c_a = .o if item == 76 & hhid == 5555 & round == 4 
	replace flag_outlier = 2 if item == 76 & c_a == .o & round == 4
	
	* Lettuce 
	replace c_a = .o if item == 84 & inlist(hhid,1692,5953) & round == 4 
	replace flag_outlier = 2 if item == 84 & c_a == .o & round == 4 */
	
	* KGs 
	egen kg_oth = rowtotal(c_a_kg c_a_kg_o c_a c_a_o) , missing
		* R3 - R4: Amount in KGs up to 1 SEER MAZAR -- so the question c3_a_seer is in KGs and c3_a_seer_o is in SEER (see below) 
		replace kg_oth = c_a_seer if inlist(round,3,4) & c_a_seer != . & c_a_seer != .n
		replace kg_oth = .d if (c_a_kg == .d | c_a_kg_o == .d | c_a == .d | c_a_o == .d | c_a_seer == .d)
		replace kg_oth = .r if (c_a_kg == .r | c_a_kg_o == .r | c_a == .r | c_a_o == .r | c_a_seer == .r)
		
	*cap noi assert c_a_milk == c_a_milk_kg if c_a_milk_unit == 1 // c_a_milk_kg is missing 
	egen kg_milk = rowtotal(c_a_milk c_a_milk_o) if c_a_milk_unit == 1, missing
		replace kg_milk = .d if (c_a_milk== .d | c_a_milk_o == .d | c_a_milk_kg == .d)
		replace kg_milk = .r if (c_a_milk== .r | c_a_milk_o == .r | c_a_milk_kg == .r)
	
	*cap noi assert c_a_yogurt == c_a_yogurt_kg if c_a_yogurt_unit == 1 // c_a_yogurt_kg is missing 
	egen kg_yogurt = rowtotal(c_a_yogurt c_a_yogurt_o) if c_a_yogurt_unit == 1, missing 
		replace kg_yogurt = .d if (c_a_yogurt== .d | c_a_yogurt_o == .d | c_a_yogurt_kg == .d)
		replace kg_yogurt = .r if (c_a_yogurt== .r | c_a_yogurt_o == .r | c_a_yogurt_kg == .r)
	
	egen kg = rowtotal(kg_oth kg_milk kg_yogurt), missing
		replace kg = .d if (kg_oth== .d | kg_milk == .d | kg_yogurt == .d)
		replace kg = .r if (kg_oth== .r | kg_milk == .r | kg_yogurt == .r)
	
	* Cups 
	egen cups = rowtotal(c_a_cup c_a_cup_o), missing
		replace cups = .d if (c_a_cup== .d | c_a_cup_o == .d)
		replace cups = .r if (c_a_cup== .r | c_a_cup_o == .r)

	* Pieces
	egen pc = rowtotal(c_a_pc c_a_pc_o), missing
		replace pc = .d if (c_a_pc == .d | c_a_pc_o == .d)
		replace pc = .r if (c_a_pc == .r | c_a_pc_o == .r)
	
	* Seer 
	* R1 is ONLY in SEER starting with version 345; before 345, it was in KGs 
	egen seer = rowtotal(c_a_seer c_a_seer_o) if round == 1, missing
		* R3 - R4: Amount in KGs up to 1 SEER MAZAR -- so the question c3_a_seer_o is in SEER and c3_a_seer is in KGs
		replace seer = c_a_seer_o if inlist(round,3,4)
		replace seer = .d if (c_a_seer== .d | c_a_seer_o == .d)
		replace seer = .r if (c_a_seer== .r | c_a_seer_o == .r)
			
	* Jar 
	*cap noi assert c_a_milk_jar == c_a_milk if c_a_milk_unit == 0
	egen jar = rowtotal(c_a_milk c_a_milk_o) if c_a_milk_unit == 0, missing
		replace jar = .d if (c_a_milk== .d | c_a_milk_o == .d)
		replace jar = .r if (c_a_milk== .r | c_a_milk_o == .r)
	
	* Bowl
	*cap noi assert c_a_yogurt_bowl == c_a_yogurt if c_a_yogurt_unit == 0
	egen bowl = rowtotal(c_a_yogurt c_a_yogurt_o) if c_a_yogurt_unit == 0, missing
		replace bowl = .d if (c_a_yogurt== .d | c_a_yogurt_o == .d)
		replace bowl = .r if (c_a_yogurt== .r | c_a_yogurt_o == .r)
		  
	* Convert everything to KGs
	drop c_a
	gen c_a = kg
		replace c_a = cups * 0.25 if !mi(cups)
		replace c_a = seer * 14 if !mi(seer)
		replace c_a = jar * 0.8 if !mi(jar)
		replace c_a = bowl * 0.3 if !mi(bowl)
		
		* pieces are a little trickier: naan, eggs, lettuce, banana are in pieces 
		replace c_a = pc * 0.25 if !mi(pc) & item_type == 3 & item == 4 // 1 naan = 250 g
		replace c_a = pc * 0.05 if !mi(pc) & item_type == 5 & item == 5 // 1 egg = 50 g
		replace c_a = pc * 0.45 if !mi(pc) & item_type == 8 & item == 5 // 1 lettuce = 450 g 
		replace c_a = pc * 0.21 if !mi(pc) & item_type == 8 & item == 3 // 1 banana = 210 g 
		
		* Fix extended missing values 
		replace c_a = cups if (cups == .d | cups == .r)
		replace c_a = seer if (seer == .d | seer == .r)
		replace c_a = jar if  (jar == .d | jar == .r)
		replace c_a = bowl if (bowl == .d | bowl == .r)
		replace c_a = pc if item_type == 3 & item == 4 & (pc == .d | pc == .r)
		replace c_a = pc if item_type == 5 & item == 5 & (pc == .d | pc == .r)
		replace c_a = pc if item_type == 8 & item == 5 & (pc == .d | pc == .r)
		replace c_a = pc if item_type == 8 & item == 3 & (pc == .d | pc == .r)
		
* Merge on pilot data 
	merge 1:1 hhid item_type item round using "`food_cons_r1_pilot'", update
	unique hhid if _merge==3 // 50 pilot HHs 

/*   Result                           # of obs.
-----------------------------------------
not matched                       151,060
	from master                   151,060  (_merge==1)
	from using                          0  (_merge==2)

matched                             1,250
	not updated                     1,250  (_merge==3)
	missing updated                     0  (_merge==4)
	nonmissing conflict                 0  (_merge==5)
*/

	/* Recode items to match follow up 
	
	1 Rice (high quality)
	2 Rice (low quality)
	3 Wheat flour
	4 Naan not made at home
	7 Beans
	   
	14 Beef
	15 Veal
	16 Mutton
	17 Goat
	18 Chicken

	24 Milk (fresh)
	26 Yogurt
	27 Curd (chaka)
	29 Dogh   
	33 Eggs */
	
	recode item (5=7) 									  if item_type == 3 // bread
	recode item (1=14) (2=15) (3=16) (4=17) (5=18) (6=22) if item_type == 4 // meet
	recode item (1=24) (2=26) (3=27) (4=29) (5=33) 		  if item_type == 5 // dairy
	recode item (1=41) (2=44) (3=45) (4=50) (5=64)		  if item_type == 7 // veg
	recode item (1=66) (2=72) (3=76) (4=80) (5=84) 		  if item_type == 8 // fruit
	
	order field_hhid hhid item_type item, first
	
	label define cat_lab 3 "Bread" 4 "Meat" 5 "Dairy" 7 "Vegetables" 8 "Fruits"
	label val item_type cat_lab

	#delimit ;
	label define item_lab
		1 "Rice (high quality)"
		2 "Rice (low quality)"
		3 "Wheat flour"
		4 "Naan not made at home"
		7 "Beans"
		14 "Beef"
		15 "Veal"
		16 "Mutton"
		17 "Goat"
		18 "Chicken"
		22 "Other meat"
		24 "Milk (fresh)"
		26 "Yogurt"
		27 "Curd (chaka)"
		29 "Dogh"
		33 "Eggs"
		41 "Potato"
		44 "Tomato"
		45 "Okra"
		50 "Pumpkin"
		64 "Other vegetables (green pepper)"
		66 "Apple"
		72 "Orange"
		76 "Banana"
		80 "Mango"
		84 "Other fruit (lettuce)", modify;
	#delimit cr
	
	* NB: check on Mandarin but keep as is for NARC comparison
	  
	label val item item_lab
	
	sort field_hhid item_type item

	drop c_a_o - c_a_yogurt_kg kg_oth - bowl
	
	* Item 22 (other meat) was only asked in subsequent rounds, not in R1 
	drop if item == 22 & round == 1 
					
	label var c_i			"On how many days did the household eat [item] in the last 7 days?"
	label var c_a			"How much [item] did your household eat in the last 7 days?"
	label var item_type		"Food item_type"
	label var item			"Food item"
	
	* Make sure there are no regular missing values (should be .r or .d if missing )
		* Missingness is fine for: some dairy in R1; meat when it is "other meat", when c_yn_4 = 0 or c_yn_4 = -99
	cap noi assert (call_status == 2) | (c_yn_4 == 0 & item_type == 4) | (c_yn_4 == -99 & item_type == 4) | item == 22 if mi(c)
	replace c =  0 	if c_yn_4 == 0 & item_type == 4
	replace c = .d 	if c_yn_4 == -99 & item_type == 4

	assert c_a != . if !mi(c_i)
	* Make sure there are no regular missing values (should be .r or .d if missing )
	cap noi assert c_a != . if c == 1
	br if c_a == . & c == 1
		* Missingess due to TPM corrections: 
			* T0362 is missing info on bell pepper they consumed in R3 (recode as .u)
			* T1095 is missing info on beans they consumed in R3 (recode as .u) 
			* T1688 is missing info on wheat flour consumed in R4 (recode as .u) 

	* Recode unexplained missing values with .u (=unexplained)
	recode c_i c_a (. = .u) if c_a == . & c == 1
	
	* Recode missing values in partial interviews with .p (=partial)
	recode c_i c_a   (. = .p) if c == 1 & call_status == 2
	recode c c_i c_a (. = .p) if c == . & call_status == 2
	recode c_yn_4	 (. = .p) if c == . & round != 1 & call_status == 2	

	* Drop partial interviews that do not have consumption 
	drop if c == .p
	
	* Misc labels 			
	label var round "Phone survey round"
	label drop c8_i_5
	
	* Merge Ramadan flag from profile data 
	preserve 
		use "${phone_svy_profile}", clear 
		keep hhid ramadan_r* 
		rename ramadan_r* ramadan_*
		reshape long ramadan_, i(hhid) j(round)
		rename *_ *
		tempfile ramadan
		save `ramadan'
	restore 
	
	cap drop  __000001 __000002
	merge m:1 hhid round using "`ramadan'", assert(2 3) keep(3) nogen
	label var ramadan "Data collected during Ramadan"
	
	* Drops vars we don't need 
	drop c_yn_4 key _merge
	
	* Run Outlier cleaning file
	do "${Phone_Survey_do}/Cleaning/foodcons_roster_outliers.do"
	
	* Order 
	order round pilot* ramadan call_status, after(item)
	
	* Sort 
	sort field_hhid round item
	
	* Save data 
	save "${food_consumption}", replace 

	