/*******************************************************************************	
Project:  		TUP - Afghanistan
Created on:  	
Last udpate on: 

Written by:  
Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans foood consumption from gross outliers
				Runs within "food_consumption_clean.do"

CONTENT:						
				Outlier "flags":
					- Method A (above p99 / below p1 in fl1 for UP/NUP)
							flag_fl1_hi flags 0.5% of values
							flag_fl1_lo flags  3% of values
							
					- Method B (winsorized pc median -/+ 3*winsorized pc SD)
							flag_p50plus3XSD_hi flags 1% high outliers based on "bounds" rule
							flag_p50minus3XSD_lo does not flag anything because after subtracting 3xSD from the median we get negative values,
								which are then replaced with 0 
							
				Replacements with ".o" are only made for HIGH outliers (flag_outlier_why = "Value unrealistically high") based on this rule:
					- All items except Wheat Flour and Naan: values > [winsorized pc median + 3*winsorized pc SD]
					- Wheat flour, flag as outlier if it is > 10 KGs per person per week [p99 at fl1]; there are lots of high values in 
						flour due to potential confusion between KGs and seer, and seer mazar (7 kgs) and seer kabuli (14 kgs) (though this
						seems unlikely).
					- > 10 KGs of naan per person is probably too high, there are only 4 such values replaced with .o
					
				A LOT of problems with wheat flour [values that are higher than 10 KGs per person per week];
					This happens when values are entered in KGs instead of Seer (which is 14 KGs)
					Divide the original c_a value by 14 assuming these are KGs 
						
				ISSUES WITH VERY SMALL VALUES (< 1 GRAM):
					Super low per capita values are tricky, because it is possible that one person of a HH of 5, for example, eats yogurt
						that week. In that case, a pc value of 10 grams may not be crazy if one person had one portion of 50 grams of yogurt 
						that week.
					Still, everything under 1 gram is pretty small...even for a HH of 30 people. 
					
				Note on Ramadan: in R1, 38 HHs or 2.18% (overall). For UP, it is 21 HHs. Control for Ramadan later, but drop these HHs for the 
					purposes of this summary.
					
						

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/
global 	food_consumption			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/foodcons_roster_phonesvy.dta"
global 	roster						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
global 	food_consumption_all		"${Dropbox}/DataWork_TUP_CodeReview/Followup_1/DataSets/Intermediate/food_consumption_all_fl1.dta"
global 	phone_svy_profile			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

********************************************************************************
	** Part 1: Food items
********************************************************************************
*use "${food_consumption}", clear 
* Cannot compare with AMMC rounds at this point since next consumption is collected in R3,
* so merge on fl1 per capita consumption values for benchmarking

preserve 
	use "${food_consumption_all}", clear
		merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor) keep(3) assert(2 3) nogen

	* Generate percentiles from fl1 
		bys item ultra_poor: egen fl1_p1  = pctile(consumed_qty_pc) if consumed == 1, p(1)
		bys item ultra_poor: egen fl1_p5  = pctile(consumed_qty_pc) if consumed == 1, p(5)
		bys item ultra_poor: egen fl1_p50 = pctile(consumed_qty_pc) if consumed == 1, p(50)
		bys item ultra_poor: egen fl1_p95 = pctile(consumed_qty_pc) if consumed == 1, p(95)
		bys item ultra_poor: egen fl1_p99 = pctile(consumed_qty_pc) if consumed == 1, p(99)
		bys item ultra_poor: egen fl1_min = min(consumed_qty_pc) 	  if consumed == 1
		bys item ultra_poor: egen fl1_max = max(consumed_qty_pc) 	  if consumed == 1
		
		egen nmiss = rowmiss(fl1_*)
		drop if nmiss == 7 	
		
		keep item ultra_poor fl1_*
		duplicates drop 
		
		tempfile food_pct_fl1
		save `food_pct_fl1'
restore

* Merge on 5th and 95th pct from fl1
	merge m:1 hhid using "${phone_svy_profile}", keepusing(enu_r1 treatment ultra_poor) keep(3) nogen
	merge m:1 ultra_poor item using "`food_pct_fl1'", keepusing(fl1_*) keep(1 3) nogen

* Get number of HH members from the HH roster
	preserve
		use "${roster}", clear
		cap drop __000000 __000001
	
		keep hhid hh_mem round
		duplicates drop hhid round, force
		tempfile hh_mem
		save	`hh_mem'
	restore
	
	merge m:1 hhid round using `hh_mem', assert(2 3) keep(3)
	assert round == 2 if _merge == 2
	drop _merge 
	order hh_mem, after(ramadan)

* Generate consumption pc 
	gen c_a_pc = c_a / hh_mem

* Generate percentiles from previous rounds 
	foreach round of numlist 1 3/4 {
		preserve
			keep if round == `round'
				bys item ultra_poor: egen r`round'_p1  = pctile(c_a_pc) if c == 1, p(1)
				bys item ultra_poor: egen r`round'_p5  = pctile(c_a_pc) if c == 1, p(5)
				bys item ultra_poor: egen r`round'_p50 = pctile(c_a_pc) if c == 1, p(50)
				bys item ultra_poor: egen r`round'_p95 = pctile(c_a_pc) if c == 1, p(95)
				bys item ultra_poor: egen r`round'_p99 = pctile(c_a_pc) if c == 1, p(99)
				bys item ultra_poor: egen r`round'_min = min(c_a_pc) 	if c == 1
				bys item ultra_poor: egen r`round'_max = max(c_a_pc) 	if c == 1	
				
				egen nmiss = rowmiss(r`round'_*)
				drop if nmiss == 7 
				
				keep item ultra_poor r`round'_* 
				
				duplicates drop
				tempfile r`round'_pct
				save `r`round'_pct' 
		restore	
	}
	
* Merge on 5th and 95th pct from R1, 3 and 4 of Phone survey
	merge m:1 ultra_poor item using "`r1_pct'", assert (1 3) nogen
	merge m:1 ultra_poor item using "`r3_pct'", assert (1 3) nogen
	merge m:1 ultra_poor item using "`r4_pct'", assert (1 3) nogen	

*--------------------------*
* Graph quantities by item *
*--------------------------*
		/*local value_label_item: value label item
		foreach item of numlist 1/84 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			*count 				if item == `item' & c_a_pc>0 & !mi(c_a_pc) & ultra_poor == 0
			*hist c_a_pc 		if item == `item' & c_a_pc>0 & !mi(c_a_pc) & ultra_poor == 0, percent name("nup_`item'") title("`l_`item'' - Non-poor") note(N=`r(N)')
			count 				if item == `item' & c_a_pc>0 & !mi(c_a_pc) & ultra_poor == 1
			hist c_a_pc 		if item == `item' & c_a_pc>0 & !mi(c_a_pc) & ultra_poor == 1, percent name("up_`item'")title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		}*/

*------------------------------------------------------------------------*
* Check big values to identify if they're gross outliers / typing errors *
*------------------------------------------------------------------------*
	
* A. Create hi/lo flags for pc consumption values that are: above 99pct / below 1pct in fl1  
	
	gen flag_fl1_hi = (c_a_pc > fl1_p99) & !mi(c_a_pc)
		* For wheat flour, flag if it is over 10 Kgs per person 
		replace flag_fl1_hi = 1 if item == 3 & c_a_pc > 10 & !mi(c_a_pc)
	gen flag_fl1_lo = (c_a_pc < fl1_p1) & !mi(c_a_pc)
	
	label var flag_fl1_hi "High outlier based on fl1 (>p99)"
	label var flag_fl1_lo "Low outlier based on fl1 (<p1)"
	
	tab flag_fl1_hi // 0.5% of values
	tab flag_fl1_lo // 3% of values
	
* B. Create hi/lo flags for pc consumption values that are: above / below [Median +/-3SD]of the winsorized value 
	
	* Winsorize pc consumption at 5pct
	winsor2 c_a_pc, cuts(5 95) by(item ultra_poor round)
	
	preserve 
		keep if c_a_pc_w>0
		collapse (p50) c_a_pc_w_p50 = c_a_pc_w (sd) c_a_pc_w_sd = c_a_pc_w, by(item ultra_poor round)
		
			gen upper_food = c_a_pc_w_p50 + 3*c_a_pc_w_sd
			gen lower_food = c_a_pc_w_p50 - 3*c_a_pc_w_sd
				replace lower_food = 0 if lower_food < 0
				
				tempfile bounds_food
				save `bounds_food'
	restore 
		
	merge m:1 item ultra_poor round using "`bounds_food'", keepusing(upper_food lower_food) nogen assert(3)
	
	gen flag_p50plus3XSD_hi = (c_a_pc > upper_food) & !mi(c_a_pc) & !mi(upper_food) & !mi(lower_food)
		//replace flag_p50plus3XSD_hi = 1 if item == 3 & c_a_pc > 10 & !mi(c_a_pc) // for wheat flour, flag if it is over 8 Kgs per person [p99 at fl1]
		*tabstat c_a if item == 3, by(hh_mem) stat(p5 mean med p95)
		*br item_type field_hhid item hh_mem c_a_pc fl1_* if item == 3 & c == 1 
	gen flag_p50minus3XSD_lo = (c_a_pc < lower_food) & !mi(c_a_pc) & !mi(upper_food) & !mi(lower_food)
	
	label var flag_p50plus3XSD_hi "High outlier based on R1 (winsorized p50+3*SD)"
	label var flag_p50minus3XSD_lo "Low outlier based on R1 (winsorized p50-3*SD)"
	
	tab flag_p50plus3XSD_hi // 1% high outliers based on "bounds" rule
	tab flag_p50minus3XSD_lo // no "low" gross outliers based on "bounds"
		* this is because after subtracting 3xSD from the median we get negative values, which are then replaced with 0 
	
* C. Create hi/lo flags for pc consumption values that are: above 99pct / below 1pct in R3, R4
	
	foreach round of numlist 1 3/4 {
		gen flag_r`round'_hi = (c_a_pc > r`round'_p99) & !mi(c_a_pc)
			* For wheat flour, flag if it is over 10 Kgs per person 
			replace flag_r`round'_hi = 1 if item == 3 & c_a_pc > 10 & !mi(c_a_pc)
		gen flag_r`round'_lo = (c_a_pc < r`round'_p1) & !mi(c_a_pc)
		
		label var flag_r`round'_hi "High outlier based on Round `round' (>p99)"
		label var flag_r`round'_lo "Low outlier based on Round `round' (<p1)"
	}
	
* Browse potential outliers 
	tab item if flag_p50plus3XSD_hi == 1 // mostly in: low quality rice, whear flour, yogurt and potato
	gsort item -c_a_pc
	
	* LOW outliers based on med+3SD
		* there are none
	* HIGH outliers based on med+3SD
	br round field_hhid hhid item c_a c_a_pc hh_mem upper_food if flag_p50plus3XSD_hi == 1 & round == 1

	* LOW outliers based on fl1 p1
	gsort item enu_r1 -c_a_pc
	br hhid item enu_r1 hh_mem c_a_pc fl1_p1 if flag_fl1_lo == 1 
	* HIGH outliers based on fl1 p99
	br hhid item enu_r1 hh_mem c_a_pc fl1_p99 if flag_fl1_hi == 1
	
	/*preserve 
		collapse (sum) flag_fl1_lo, by(enu_r1 item )
		keep if flag_fl1_lo > 0
		gsort enu_r1 -flag_fl1_lo
		br if flag_fl1_lo > 10
		
		
		collapse (sum) flag_fl1_lo, by(enu_r1)
		keep if flag_fl1_lo > 0
		gsort -flag_fl1_lo
		list
	
	restore*/
	
	
* Replace identified outliers with .o -- HIGH values only fow now

	* Replace c_a, not c_a_pc, since this variable will be constructed in a construction do-file

	** ALL ROUNDS 
	* A LOT of problems with wheat flour [values that are higher than 10 KGs per person per week];
		* This happens when values are entered in KGs instead of Seer (which is 14 KGs)
		* Could divide the original c_a value by 14 assuming these are KGs, but replaceing with .o for now 
	replace c_a = .o if item == 3 & c_a_pc > 10 & !mi(c_a_pc)
	replace flag_outlier = 1 if item == 3 & c_a_pc > 10 & !mi(c_a_pc)
	replace flag_outlier_why = "Unit issues" if item == 3 & c_a_pc > 10 & !mi(c_a_pc)
	
	bys round: tab flag_outlier_why if item == 3 & c == 1 & ultra_poor == 1, m 
	
	tab enu_r1 if !mi(flag_outlier_why) & item == 3 & c == 1 & ultra_poor == 1 // enu 7 and 15 
	
	merge m:1 hhid using "${phone_svy_profile}", keepusing(date_r1) keep(3)
	
	tab date_r1 if !mi(flag_outlier_why) & item == 3 & c == 1 & ultra_poor == 1 & inlist(enu_r1,7,15)

	* Mostly issues in R1 - entered KG instead of seer in the "other" field 
	
/*------------------------------------------------------------------------------------------------------------------------
-> round = 1

        flag_outlier_why |      Freq.     Percent        Cum.
-------------------------+-----------------------------------
                         |        627       94.86       94.86
             Unit issues |         34        5.14      100.00
-------------------------+-----------------------------------
                   Total |        661      100.00

------------------------------------------------------------------------------------------------------------------------
-> round = 3

        flag_outlier_why |      Freq.     Percent        Cum.
-------------------------+-----------------------------------
                         |        643       99.08       99.08
             Unit issues |          6        0.92      100.00
-------------------------+-----------------------------------
                   Total |        649      100.00

------------------------------------------------------------------------------------------------------------------------
-> round = 4

        flag_outlier_why |      Freq.     Percent        Cum.
-------------------------+-----------------------------------
                         |        653       99.09       99.09
             Unit issues |          6        0.91      100.00
-------------------------+-----------------------------------
                   Total |        659      100.00 */

	drop c_a_pc
	gen c_a_pc = c_a / hh_mem
	br round field_hhid hhid item c_a c_a_pc hh_mem upper_food if flag_p50plus3XSD_hi == 1 & item == 3 

	* Even so there are 8 HHs that consumed > 10 KGs pp of Wheat Flour - flag these as outliers 
	* 7 kgs of low quality rice for hhid = 1036
	replace c_a = .o if item == 3 & c_a_pc >= 10 & !mi(c_a_pc)
	replace flag_outlier = 1 if item == 3 & c_a == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 3 & c_a == .o
	
	** Round 1 

	* 7 kgs of low quality rice for hhid = 1036
	replace c_a = .o if item == 2 & hhid == 1036 & round == 1
	replace flag_outlier = 1 if item == 2 & c_a == .o & round == 1
	replace flag_outlier_why = "Value unrealistically high" if item == 2 & c_a == .o & round == 1
	* > 10 KGs of naan per person is probably too high (6000, 5661, 6319, 1115)
	replace c_a = .o if item == 4 & c_a_pc >= 10 & !mi(c_a_pc) & round == 1
	replace flag_outlier = 1 if item == 4 & c_a == .o & round == 1
	replace flag_outlier_why = "Value unrealistically high" if item == 4 & c_a == .o & round == 1
	
	** Round 3 
	
	* 7 kgs of potato for hhid == 6132
	replace c_a = .o if item == 41 & hhid == 6132 & round == 3
	replace flag_outlier = 1 if item == 41 & c_a == .o & round == 3
	replace flag_outlier_why = "Value unrealistically high" if item == 41 & c_a == .o & round == 3
	
	/* Some fruits look collected in pieces - - this will be needed to be fixed in the Cleaning do-file before doing the piece to KG conversion,
		but have not touched it yet (these are few values anyway)
	
	field_hhid	hhid	item	round	hh_mem	c_a	c_a_pc	upper_food
	T1341	6132	Apple	3	2	2	1	.8919902
	T0905	6650	Apple	3	9	9	1	.8919902
	T0905	6650	Orange	3	9	9	1	.5247967
	T1341	6132	Other fruit (lettuce)	3	2	3.15	1.575	.6324641
	T0908	5872	Other fruit (lettuce)	3	3	4.5	1.5	.6324641
	T1262	5953	Other fruit (lettuce)	3	2	2.7	1.35	.6324641
	T0363	5580	Other fruit (lettuce)	3	6	6.3	1.05	.6324641
	T1519	2055	Other fruit (lettuce)	3	9	9	1	.6747592
	T1036	1593	Other fruit (lettuce)	3	4	2.7	.675	.6747592 */

	** Round 4 
	
	/* Some fruits look collected in pieces - this will be needed to be fixed in the Cleaning do-file before doing the piece to KG conversion
		but have not touched it yet (these are few values anyway)
		
	hhid	item	c_a	c_a_pc	hh_mem
	5227	Apple	14	2.333333	6
	1010	Apple	14	2	7
	1945	Apple	5	1.666667	3
	5775	Apple	4	1	4
	5652	Apple	7	1	7
	6628	Orange	7	1.4	5
	5555	Banana	30.24	2.749091	11
	1692	Other fruit (lettuce)	3.15	1.575	2
	5953	Other fruit (lettuce)	2.7	1.35	2 */
	
	
* Drop variables we do not need 
	drop c_a_pc /*fl1_* flag_*/ c_a_pc_w upper_food lower_food 
	

/*------------------------------------------------------------------------*
* Check big values to identify if they're gross outliers / typing errors *
*------------------------------------------------------------------------*		

* I. Bread		
* 1) Rice (high quality)
	
	local i = 1
	bys ultra_poor: sum c_a_pc if item == `i' & c_a_pc>0 & !mi(c_a_pc), d
	sort item ultra_poor c_a_pc
	br item ultra_poor c_a_pc hh_mem /*enum_id*/ if item == `i' & c_a_pc>0 & !mi(c_a_pc)
	
	* Two clear outliers: We send to missing
		loc check_hhmem "9,10"
		bys hh_mem ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a) & inlist(hh_mem,`check_hhmem'), d // clearly outliers even comparing to households of the same size
		replace flag_outlier = 1 if item == 1 & inlist(hhid, 5128, 5105)
		replace c_a = .o if item == 1 & hhid == 5128
		replace c_a = .o if item == 1 & hhid == 5105
	
* 2) Rice (low quality)
	
	local i = 2
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id hh_mem if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		loc check_hhmem "2,4,7,25"
		bys hh_mem ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a) & inlist(hh_mem,`check_hhmem'), d // clearly outliers even comparing to households of the same size
	
	
* 3) Wheat flour
	
	local i = 3
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers

* 4) Naan not made at home
	
	local i = 4
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id hh_mem if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
	
* 7) Beans

	local i = 7
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id hh_mem if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 7 & hhid == 1880 
		replace flag_outlier = 3 if item == 7 & c_a == 250 & enum_id == 56
		replace flag_outlier_why = "Zuhra Beeg, beans: same value for 6 households" if item == 7 & c_a == 250 & enum_id == 56
		
		replace c_a = .o if item == 7 & c_a == 250 & enum_id == 56 // 6 surveys by Zuhra Beeg with a value of 250 kgs for households of 3-6 members. Clear outliers
		replace c_a = .o if item == 7 & hhid == 1880 // 300 Kgs for 1 household member
	
* II. Meat	
* 14) Beef

	local i = 14
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers
	
* 15) Veal

	local i = 15
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 15 & hhid == 5643 
		replace flag_outlier_why = "99 typed instead of -99" if item == 15 & hhid == 5643
		replace flag_outlier = 1 if item == 15 & hhid == 1816 

		replace c_a = .d if item == 15 & hhid == 5643 // looks like a -99	
		replace c_a = .o if item == 15 & hhid == 1816 // Clear outlier of 2000
		
* 16) Mutton

	local i = 16
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers
	
* 17) Goat

	local i = 17
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers
	
* 18) Chicken

	local i = 18
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing
		replace flag_outlier = 1 if item == 18 & inlist(hhid, 5574, 6209)
		
		replace c_a = .o if item == 18 & hhid == 5574 // Clear outlier of 600
		replace c_a = .o if item == 18 & hhid == 6209 // Clear outlier of 1000
		
* xxxx Other meat???? stop		
		
* III. Milk		
* 24) Milk (fresh)

	local i = 24
	bys ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
	* Clear outliers: We send to missing
		loc check_hhmem "9, 7, 12, 8, 10"
		bys hh_mem ultra_poor: sum c_a if item == `i' & c_a>0 & !mi(c_a) & inlist(hh_mem,`check_hhmem'), d // clearly outliers even comparing to households of the same size
		replace flag_outlier = 1 if item == 24 & inlist(hhid, 1633, 1836, 6006)	

		replace c_a = .o if item == 24 & hhid == 1633 // 150 Kgs for a 7-member household
		replace c_a = .o if item == 24 & hhid == 1836 // 72 Kgs for a 9-member household
		replace c_a = .o if item == 24 & hhid == 6006 // 100 Kgs for a 10-member household		
	
* 26) Yogurt

	local i = 26
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 27) Curd (chaka)

	local i = 27
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 29) Dogh

	local i = 29
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.
	
* 33) Eggs

	local i = 33
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.

* IV. Vegetables	
* 41) Potato

	local i = 41
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 41 & hhid == 5643
		replace flag_outlier_why = "99 typed instead of -99" if item == 41 & hhid == 5643
		replace flag_outlier = 1 if item == 41 & hhid == 1614

		replace c_a = .d if item == 41 & hhid == 5643 // looks like a -99	
		replace c_a = .o if item == 41 & hhid == 1614 // clear outlier of 1000 Kgs for a 5-member household
	
* 44) Tomato

	local i = 44
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 44 & inlist(hhid, 5954, 1503)
		replace flag_outlier_why = "99 typed instead of -99" if item == 44 & inlist(hhid, 5954, 1503)
		replace flag_outlier = 1 if item == 44 & inlist(hhid, 5783, 6177, 1101)
		
		replace c_a = .d if item == 44 & hhid == 5954 // looks like a -99		
		replace c_a = .o if item == 44 & hhid == 5783 // clear outlier of 105 Kgs for a 8-member household	
		replace c_a = .o if item == 44 & hhid == 6177 // clear outlier of 350 Kgs for a 12-member household	
		replace c_a = .d if item == 44 & hhid == 1503 // looks like a -99		
		replace c_a = .o if item == 44 & hhid == 1101 // clear outlier of 200 Kgs for a 4-member household	
		
* 45) Okra

	local i = 45
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 45 & inlist(hhid, 1171, 2131)
		replace flag_outlier_why = "99 typed instead of -99" if item == 45 & inlist(hhid, 1171, 2131)
		replace flag_outlier = 1 if item == 45 & inlist(hhid, 6015, 6209)
		
		replace c_a = .o if item == 45 & hhid == 6015 // clear outlier of 90 Kgs for a 8-member household	
		replace c_a = .o if item == 45 & hhid == 6209 // clear outlier of 1500 Kgs for a 8-member household	
		replace c_a = .d if item == 45 & hhid == 1171 // looks like a -99		
		replace c_a = .d if item == 45 & hhid == 2131 // looks like a -99					
	
* 50) Pumpkin, squash

	local i = 50
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.		
	
* 56) Hot pepper

	local i = 56
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* Clear outliers: We send to missing	
		replace flag_outlier = 1 if item == 56 & hhid == 1383
		replace flag_outlier_why = "99 typed instead of -99" if item == 56 & hhid == 1383
		replace c_a = .d if item == 56 & hhid == 1383 // looks like a -99	
		
		replace flag_outlier = 1 if item == 56 & inlist(hhid, 5272, 6150, 1152)
		replace c_a = .o if item == 56 & hhid == 5272 // clear outlier of 100 Kgs for a 9-member household	
		replace c_a = .o if item == 56 & hhid == 6150 // clear outlier of 100 Kgs for a 7-member household	
		replace c_a = .o if item == 56 & hhid == 1152 // clear outlier of 100 Kgs for a 9-member household	
		
		replace flag_outlier = 3 if item == 56 & c_a >= 50 & !mi(c_a) & enum_id == 48
		replace flag_outlier_why = "Zahra Amin Husain, hot pepper: 5 surveys with outliers" if item == 56 & c_a >= 50 & !mi(c_a) & enum_id == 48
		replace c_a = .o if item == 56 & c_a >= 50 & !mi(c_a) & enum_id == 48 // 5 surveys by Zahra Amin Husain who apparenterely misinterpreted the unit		
	
* 64) Other vegetables

	local i = 64
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* V. Fruits	
* 66) Apple

	local i = 66
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			

* 72) Orange/citrus

	local i = 72
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.			
	
* 76) Banana

	local i = 76
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)

	* No clear outliers.					
	
* 84) Other fruit and/or nuts

	local i = 84
	bys ultra_poor: sum c_a hh_mem if item == `i' & c_a>0 & !mi(c_a), d
	sort item ultra_poor c_a
	br item ultra_poor c_a hh_mem enum_id if item == `i' & c_a>0 & !mi(c_a)
	
	* No clear outliers.				
	
* Graph with cleaned variables
	/*
		local value_label_item: value label item
		foreach item of numlist 1(1)105 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			count 				if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1
			hist c_a 	if item == `item' & c_a>0 & !mi(c_a) & ultra_poor == 1, percent name("up_`item'", replace)title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		}
	*/
	
* Deleting irrelevant variables
	drop ultra_poor enum_id hh_mem	
	
