* Figure out a reliabel no_pm flag // HH confirmation

* Inputs (raw PII data)
global 	phone_svy_raw_pii_r1 		"${mounted_r1}/EncryptedData/Phone_Survey_R1/Raw Identified Data/LHH_Phone_Survey_R1_raw.dta"
global 	phone_svy_raw_pii_r2		"${mounted_r2}/EncryptedData/Phone_Survey_R2/Raw Identified Data/LHH_Phone_Survey_AMMC_R1_raw.dta"
global 	phone_svy_raw_pii_r3		"${mounted_r3}/EncryptedData/Phone_Survey_R3/Raw Identified Data/LHH_Phone_Survey_AMMC_R2_raw.dta"
global 	phone_svy_raw_pii_r4		"${mounted_r4}/EncryptedData/Phone_Survey_R4/Raw Identified Data/LHH_Phone_Survey_AMMC_R3_raw.dta"
global	roster    					"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/preload.dta" // preloaded data for R1

* Outputs (PII data)	
global 	hhconfirm_pii_r1 	 		"${mounted_r1}/EncryptedData/Phone_Survey_R1/Raw Identified Data/hhconfirm_pii_r1.dta"
global  hhconfirm_pii_r2 			"${mounted_r2}/EncryptedData/Phone_Survey_R2/Raw Identified Data/hhconfirm_pii_r2.dta"
global 	hhconfirm_pii_r3 			"${mounted_r3}/EncryptedData/Phone_Survey_R3/Raw Identified Data/hhconfirm_pii_r3.dta"
global 	hhconfirm_pii_r4 	"		 ${mounted_r4}/EncryptedData/Phone_Survey_R4/Raw Identified Data/hhconfirm_pii_r4.dta"

global 	hhconfirm_interm_pii_r1 	"${mounted_r1}/EncryptedData/Phone_Survey_R1/Raw Identified Data/hhconfirm_interm_pii_r1.dta"
global 	hhconfirm_interm_pii_r2 	"${mounted_r2}/EncryptedData/Phone_Survey_R2/Raw Identified Data/hhconfirm_interm_pii_r2.dta"
global 	hhconfirm_interm_pii_r3 	"${mounted_r3}/EncryptedData/Phone_Survey_R3/Raw Identified Data/hhconfirm_interm_pii_r3.dta"
global 	hhconfirm_interm_pii_r4 	"${mounted_r4}/EncryptedData/Phone_Survey_R4/Raw Identified Data/hhconfirm_interm_pii_r4.dta"

* Change these based on how you mount Veracrypt 
global mounted_r1 "H:"
global mounted_r2 "I:"
global mounted_r3 "J:"
global mounted_r4 "K:"
  
  
*********************************************************************************
* Clean rounds 
*********************************************************************************	
cap program drop hh_confirm
program define hh_confirm  
	
	set trace on
	use "${phone_svy_raw_pii_r`0'}", clear

		keep hh_id call_status lady_hh pm_hh pm_pos pw_pos_old corr_respondent - hh_confirm no_pm key
			
		* Keep IDs in the final sample
		rename hh_id field_hhid 
		merge m:1 field_hhid using "${phone_svy_clean_r`0'}", keep(3) keepusing(key) nogen
		
		merge 1:1 key using "${phone_svy_clean_r`0'}", keepusing(key) keep(3) nogen
		
			tempfile confirm
			save `confirm'
		
		* HHs that are missing confirmation info 
		keep if mi(know_pm)
		keep field_hhid 
		rename field_hhid hh_id
		duplicates drop
		
		* Keep only the problem IDs with missing confirmation info
		merge 1:m hh_id using "${phone_svy_raw_pii_r`0'}", keep(3) keepusing(date hh_id call_status corr_respondent - hh_confirm no_pm key) nogen
		
		* Keep the last non-misisng know_pm observation (by survey date)
		gsort hh_id -know_pm date
		
		by hh_id: gen n = _n
		keep if n == 1
		
		* PM info is still missing for XX HHs
		cap noi assert no_pm == "100" if mi(know_pm)

		* Quick check for missingness 
		assert !mi(name2) if know_pm == "-97"
		assert !mi(know_pm_age) if !mi(know_pm) & know_pm != "0"
		
		rename hh_id field_hhid
		merge 1:1 field_hhid using "`confirm'", nogen update replace
		drop date 
			
		* Destring 
		destring *, replace 
		
		* Clean ages of LHH, PM, third HH member
		rename (know_pm_age_warning know_lhh_age_warning know_mem_age_warning) (know_pm_age_99_warning know_lhh_age_99_warning know_mem_age_99_warning)

		local 99vars know_pm_age know_lhh_age know_mem_age
		
		destring `99vars', replace 

		foreach 99var in `99vars' {
			replace `99var' = `99var'_99_warning if inlist(`99var'_99_warning,-99,-98) // 0 = value entered
			drop `99var'_99_warning
		}

		* Create a clean variable for the name of the third HH member
		tostring know_mem_oldroster_label, replace 
		gen knowmem_name = know_mem_oldroster_label
			replace knowmem_name = know_mem_o if !mi(know_mem_o)
		
		* Drop vars we will not use 
		drop name2 fname2 full_name2 no_pm_flag pm_name_new pm_pos_new b8_pm pm_confirmed know_lhh_age_1 ///
			know_lhh_age_2 b8_pw lhh_confirmed know_mem_oldroster_label know_mem_name ///
			know_mem_fname know_mem_o know_mem_b8 know_mem_confirmed hh_confirm ///
			lhh_name lhh_fname lhhname_o lhhname_oldroster_label n key checkmem_name
		
		* Order 
		order field_hhid call_status lady_hh pm_hh, first
		
		* Save data 
		save "${phone_svy_hhconfirm_pii_r`0'}", replace	  
	
	set trace off
end

hh_confirm 1
hh_confirm 2
hh_confirm 3 
hh_confirm 4
	  
*********************************************************************************
* Merge rounds 
*********************************************************************************	
	
	* Start with Round 1 
	use "${phone_svy_hhconfirm_pii_r1}", clear 
	
	* Fix LHH and PM positions in roster (from fl1)
	tostring pm_pos, replace 
	replace know_pm = pm_pos if know_pm == "1" // in the pilot I think at some point it was a yes/no 0/1 question, so 1 here means Yes, not a position in roster
	replace know_lhh = substr(know_lhh,6,.) if strlen(know_lhh) > 5
	replace know_pm = substr(know_pm,6,.) if strlen(know_pm) > 5
	destring know_*, replace 
	
	replace know_lhh = pw_pos_old if mi(know_lhh)
		replace know_lhh = pw_pos_old if mi(know_lhh)
	destring pm_pos, replace 
	replace know_pm = pm_pos if mi(know_pm) & no_pm != 100

	* Rename vars for reshape 
	rename (lady_hh pm_hh knowmem_name) 			(hh_name_calc_1 hh_name_calc_2 hh_name_calc_3)
	rename (know_lhh know_pm know_mem) 				(member_1 member_2 member_3)
	rename (know_lhh_age know_pm_age know_mem_age) 	(age_1 age_2 age_3)
	
	drop pm_pos pw_pos_old
	
	* Reshape long 
	reshape long hh_name_calc_ member_ age_, i(field_hhid) j(mem)
	
	rename *_ *
	
	* Drop empty obs created by reshape
	replace hh_name_calc = "" if hh_name_calc == "."
	drop if mi(member) & mi(hh_name_calc) & mi(age)
	
	label define mem_lab 1 "LHH" 2 "PM" 3 "Other member"
	label val mem mem_lab
	label val member .
	
	/** NB: there are a few issues where in some HHs position for PM and PW is the same (cannot be), or is 0 for both (also cannot be)
	
	Leaving unresolved for now as it's not a ton of HHs
	
	duplicates tag field_hhid member, gen(tag)
	tab tag
	br if tag > 0 // 50 HHS???
	br if tag & member != -97 > 0 */
	
	* Merge on gender and age from the fl1 data 
	merge m:1 field_hhid member using "${roster}", keep(1 3) keepusing(b6 b8)

	tab member if _merge==1, m

	
/*      member |      Freq.     Percent        Cum.
------------+-----------------------------------
        -97 |        280       80.69       80.69 // "Other", new members that were not there at fl1
          0 |         67       19.31      100.00 // "None" means there is no LHH / PM / other member in HH
------------+-----------------------------------
      Total |        347      100.00 */
	
	tab mem no_pm if member == 0, m
	list field_hhid if member == 0 & mem == 1 // T1989 there is no LHH? AND no PM?
		
	* Merge on b3 (HH members) [doing this separately since merging on field_hhid]
	merge m:m field_hhid using "${roster}", keepusing(b3) assert (2 3) keep(3) nogen
	
	* Create member positions for "Other" -97 members (number of HH members at fl1 + number of -97 members added)
		* If both PM and LHH are -97, LHH is first, PM is second 
	gen member_neg = -member
	bys field_hhid member_neg: gen n97 = _n if member == -97
	drop member_neg
	
	replace member = b3 + n97 if member == -97
	
	* Save 
	save "${hhconfirm_interm_pii_r1}", replace 
	
	
	STIO
	* Round 2
	
	use "${hhconfirm_pii_r2}", clear 
	
	* Fix LHH and PM positions in roster (from fl1)
	tostring pm_pos, replace 
	replace know_pm = pm_pos if know_pm == "1" // in the pilot I think at some point it was a yes/no 0/1 question, so 1 here means Yes, not a position in roster
	replace know_lhh = substr(know_lhh,6,.) if strlen(know_lhh) > 5
	replace know_pm = substr(know_pm,6,.) if strlen(know_pm) > 5
	destring know_*, replace 
	
	replace know_lhh = pw_pos_old if mi(know_lhh)
		replace know_lhh = pw_pos_old if mi(know_lhh)
	destring pm_pos, replace 
	replace know_pm = pm_pos if mi(know_pm) & no_pm != 100

	* Rename vars for reshape 
	rename (lady_hh pm_hh knowmem_name) 			(hh_name_calc_1 hh_name_calc_2 hh_name_calc_3)
	rename (know_lhh know_pm know_mem) 				(member_1 member_2 member_3)
	rename (know_lhh_age know_pm_age know_mem_age) 	(age_1 age_2 age_3)
	
	drop pm_pos pw_pos_old
	
	* Reshape long 
	reshape long hh_name_calc_ member_ age_, i(field_hhid) j(mem)
	
	rename *_ *
	
	* Drop empty obs created by reshape
	replace hh_name_calc = "" if hh_name_calc == "."
	drop if mi(member) & mi(hh_name_calc) & mi(age)
	
	label define mem_lab 1 "LHH" 2 "PM" 3 "Other member"
	label val mem mem_lab
	label val member .
	
	* Merge on gender and age from R1 data 
	STOP - not quite what we want - we want to merge on other ages, yes?
	
	merge m:1 field_hhid member using "${hhconfirm_interm_pii_r1}", keep(1 3) keepusing(b6 b8)

	tab member if _merge==1, m

	
	
	
	
	
	
	
	* LHH names first
	* Then PM names 
	
field_hhid	mem	call_status	no_pm	corr_respondent	member	age	hh_name_calc
T0003	LHH	Complete	0	Yes	2	65	زلیخا - حضرت دین // this is unchanged (not -97)
T0003	PM	Complete	0	Yes	9	42	میرویس - محمد هاشم // this is -97, check if in fl1 roster we have 8 HH members (yes)

	
	use "${roster}", clear 
	sort field_hhid member
	
	br if field_hhid == "T0003"
	
	T2369 -- there is no member 1 in the roster???
	
	
	  	use "${phone_svy_raw_pii_r1}", clear

		keep hh_id call_status lady_hh pm_hh pm_pos pw_pos_old corr_respondent - hh_confirm no_pm key
			
	br if hh_id == "T0003"
	
field_hhid	mem	call_status	no_pm	corr_respondent	member	age
T0002	PM	Complete	0	Yes	1	35
T0002	LHH	Complete	0	Yes	2	25
T0003	LHH	Complete	0	Yes	2	65
T0003	PM	Complete	0	Yes	9	42

	
	field_hhid

T0053
T0093
T0278




















