/* Livestock

	1. Round 1 roster prep:
		k7  (How many of the following livestock does your household own?)
		k36 (Did your household sell any livestock since April (Hamal)?)
		k36_type
		k37
		k38 (Approximately, what is the total value your household earned from livestock sales since April (Hamal)?)
		k44_4
		k39 (Why did you sell the following livestock since April (Hamal)?)
		 
	2. Round 3 roster prep:
		k6
		k7 (has a different meaning from k7 in R1 or R4: do you still own X? After asking whether the HH owned this type of livestock over the past 3 years)
		k35_a
		k35
		r44
		k39 (has a different meaning from k39 in R1: Why did you sell ${livestock_name}? Refers to sales over the past 3 years, as opposed to "since April")
		
	3. Round 4 roster prep:
		k36 (same as R1, except in the past 4 weeks, as opposed to "since April")
		k38 (same as R1, except in the past 4 weeks, as opposed to "since April") k38_dk
		k7  (same as R1)
		k8  If your household had to sell one of the ${livestock_name} today, how much would your household earn on average? 
	
	4. Compile cross-section/panel data
		The only real "panel" variabe in this section is k7 (in R1 and R4). It is appended (i.e., long). All other variables in the 3 rounds are merged.

	5. Minor cleaning
	
		Notes / TO DO:
			Did not really check for missingness in detail yet.

*/

* Inputs 
global 	phone_svy_clean_r1			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Outputs
global 	livestock					"${TUP_DB}\Phone_Survey\DataSets\Intermediate\livestock_roster_phonesvy.dta"


*********************************************************************************
* Round 1: k7 k36 k36_type k37 k38 k44_4 k39
*********************************************************************************

use "${phone_svy_clean_r1}", clear
	keep hhid call_status k7_1 - k39_4__97
	
	* Combine "other" number of livestock vars
	local othervars k7_1 k7_2 k7_3 k7_4 k37_1 k37_2 k37_3 k37_4
	
	foreach var of local othervars {
	    replace `var' = `var'_o if !mi(`var'_o)
		drop `var'_o
	}
	
	* Drop vars we don't need 
	drop k37_error *_warning k44_*_13
	
	/* k39 appears in R1 and R3, but is coded slightly differently.
		1- 4 is fine; 5 - 9 needs recoding.
	
	R1: 
		1	For household consumption
		2	For household medical treatment/expenses
		3	To repay household debt
		4	For other household emergency expenses (excluding medical expenses)
		5	To invest in another business/livestock
		6	To buy household assets
		8	The livestock was sick

	R3: 
		1	For household food consumption
		2	For household medical treatment/expenses
		3	To repay household debt
		4	For other household emergency expenses (excluding medical expenses)
		5	To invest in another business (not related to livestock)
		6	To buy other livestock
		7	To buy household assets
		8	The livestock was sick
		9	Livestock too expensive to keep */

	rename (k39_*_5 k39_*_6) (k39_*_10 k39_*_7)
	
	* Reshape long (unit of obs will be cow/goat/sheep/chicken)
	rename (k44_1_* k44_2_* k44_3_* k44_4_*) (k44_*_1 k44_*_2 k44_*_3 k44_*_4)
	rename (k39_1_* k39_2_* k39_3_* k39_4_*) (k39_*_1 k39_*_2 k39_*_3 k39_*_4)
	rename k39__97_* k39_97_*
	
	reshape long k7_ k36_type_ k37_ k38_ k44_1_ k44_2_ k44_3_ k44_4_ k44_5_ k44_6_ k44_7_ k44_8_ k44_9_ k44_10_ k44_11_ k44_12_ ///
		k39_1_ k39_2_ k39_3_ k39_4_ k39_5_ k39_6_ k39_7_ k39_8_ k39_9_ k39_10_ k39_97_, i(hhid) j(livestock)
	
	drop k36_type k44_1 k44_2 k44_3 k44_4 k39_1 k39_2 k39_3 k39_4
	rename *_ *
	rename k39_97 k39__97
	
	gen round = 1 
	
	tempfile livestock_r1
	save `livestock_r1'
	
	
*********************************************************************************
* Round 3: k6 k7 (has a different meaning from k7 in R1) k35_a k35 r44 k39
*********************************************************************************	
use "${phone_svy_clean_r3}", clear
	keep hhid call_status k6 - r44__99_4 
	
	* Drop vars we don't need 
	drop livestock_repeat_count livestock_id_* livestock_name_*

	* Reshape long (unit of obs will be cow/goat/sheep/chicken)
	rename (*__97* *__99*) (*_97* *_99*)
	tostring k35_4, replace 
	
	reshape long k6_ k7_ k35_a_ k35_ k35_1_ k35_2_ k35_3_ k35_97_ k35_99_ k35_4_ ///
		k39_1_ k39_2_ k39_3_ k39_4_ k39_5_ k39_6_ k39_7_ k39_8_ k39_9_ k39_97_ ///
		r44_1_ r44_2_ r44_3_ r44_4_ r44_97_ r44_99_, i(hhid) j(livestock)
	
	drop k6 k39_1 r44_1 k39_2 r44_2 k39_3 r44_3 k39_4 r44_4
	rename *_ *
	rename (*_97 *_99) (*__97 *__99)
	drop k35
	
	recode livestock (99=-99)
	assert k6 == 0 if livestock == -99
	drop if inlist(livestock,0,-99) // 0 = None, -99 was never selected, so there is no data in these obs 
	replace k6 = 0 if mi(k6)
	
	* k7 in R3 has a different meaning from k7 in R1 or R4: do you still own X?
	* After asking whether the HH owned this type of livestock over the past 3 years
	* Keep it separate
	rename k7 k7_r3
	
	* Also for k39: Why did you sell ${livestock_name}? in the past 3 years 
	* As opposed to the livestock sold in the last 12 months 
	rename k39_* k39_*_r3
	
	gen round = 3 
	
	tempfile livestock_r3
	save `livestock_r3'

	
*********************************************************************************
* Round 4: k36 k38 k38_dk k7 k8
*********************************************************************************	
use "${phone_svy_clean_r4}", clear
	keep hhid call_status k36 - k8_4_confirm_val
	
	* Combine "other" number of livestock vars
	local othervars k7_1 k7_2 k7_3 k7_4
	
	foreach var of local othervars {
	    replace `var' = `var'_o if !mi(`var'_o)
		drop `var'_o
	}
	
	* Drop vars we don't need 
	drop *warning *confirm *confirm_val k8_1 k8_2 k8_3 k8_4 k38
	rename *_corr *
	
	* Reshape long (unit of obs will be cow/goat/sheep/chicken)
	reshape long k7_ k8_, i(hhid) j(livestock)
	
	rename *_ *
	* These variables are asked for different recall periods in R1 (since April) and R4 (in the last 4 weeks)
	* so keep them separate at this stage
	rename (k36 k38) (k36_r4 k38_r4)
	
	gen round = 4
	
	* Clean outliers for livestock self valuation
	do "${Phone_Survey}/Dofiles/Cleaning/livestock_valuation_outliers_clean.do"	
	
	tempfile livestock_r4
	save `livestock_r4'
	
		
*********************************************************************************
* Compile panel 
*********************************************************************************

	use "`livestock_r1'"
		append using "`livestock_r3'"
		append using "`livestock_r4'"

	
	
	* Label
	label var k6 		"Over the past 3 years, did your household own any of the following livestock?"
	label var k7 		"Number of livestock owned"
	label var k7_r3 	"Do you still own this type of livestock?"
	label var k8 		"If you had to sell one of the livestock today, how much would you earn?"	
	label var k36_type 	"Livestock sold since April"
	label var k36_r4 	"Livestock sold in the last 4 weeks"
	label var k37 		"Number of livestock sold since April"
	label var k38 		"Total value earned from sale of livestock since April"
	label var k38_r4 	"Total value earned from sale of livestock in the last 4 weeks"
	label var round 	"Phone survey round"
	
	label var k44_1 	"Livestock sold since April: sold in January"
	label var k44_2 	"Livestock sold since April: sold in February"
	label var k44_3 	"Livestock sold since April: sold in March"
	label var k44_4 	"Livestock sold since April: sold in April"
	label var k44_5 	"Livestock sold since April: sold in May"
	label var k44_6 	"Livestock sold since April: sold in June"
	label var k44_7 	"Livestock sold since April: sold in July"
	label var k44_8 	"Livestock sold since April: sold in August"
	label var k44_9 	"Livestock sold since April: sold in September"
	label var k44_10 	"Livestock sold since April: sold in October"
	label var k44_11 	"Livestock sold since April: sold in November"
	label var k44_12 	"Livestock sold since April: sold in December"
	
	label var k39_1 	"Reason sold livestock since April: household consumption"
	label var k39_2 	"Reason sold livestock since April: household medical treatment/expenses"
	label var k39_3 	"Reason sold livestock since April: repay household debt"
	label var k39_4 	"Reason sold livestock since April: other emergency expenses (not medical)"
	label var k39_5 	"Reason sold livestock since April: invest in another business"
	label var k39_6 	"Reason sold livestock since April: to buy other livestock"
	label var k39_7 	"Reason sold livestock since April: to buy household assets"
	label var k39_8 	"Reason sold livestock since April: livestock was sick"
	label var k39_9 	"Reason sold livestock since April: livestock too expensive to keep"
	label var k39_10 	"Reason sold livestock since April: invest in another business/livestock"
	label var k39__97 	"Reason sold livestock since April: other"
	
	label var k39_1_r3 		"Reason sold livestock last 3 yrs: household consumption"
	label var k39_2_r3 		"Reason sold livestock last 3 yrs: household medical treatment/expenses"
	label var k39_3_r3 		"Reason sold livestock last 3 yrs: repay household debt"
	label var k39_4_r3 		"Reason sold livestock last 3 yrs: other emergency expenses (not medical)"
	label var k39_5_r3 		"Reason sold livestock last 3 yrs: invest in another business"
	label var k39_6_r3 		"Reason sold livestock last 3 yrs: to buy other livestock"
	label var k39_7_r3 		"Reason sold livestock last 3 yrs: to buy household assets"
	label var k39_8_r3 		"Reason sold livestock last 3 yrs: livestock was sick"
	label var k39_9_r3 		"Reason sold livestock last 3 yrs: livestock too expensive to keep"
	label var k39__97_r3 	"Reason sold livestock last 3 yrs: other"
	
	label var k35_a 	"Compared to how many livestock you had then, do you own more or less now?"
	label var k35_1 	"Reason no longer own (or own less) livestock: Died"
	label var k35_2 	"Reason no longer own (or own less) livestock: Sold"
	label var k35_3 	"Reason no longer own (or own less) livestock: Gifted"
	label var k35__97 	"Reason no longer own (or own less) livestock: Other"
	label var k35__99 	"Reason no longer own (or own less) livestock: Don't know"
	label var k35_4 	"Reason no longer own (or own less) livestock: Consumed (ate)"

	label var r44_1 	"If sold livestock to buy other livestock, bought: Cows"
	label var r44_2 	"If sold livestock to buy other livestock, bought: Goats"
	label var r44_3 	"If sold livestock to buy other livestock, bought: Sheep"
	label var r44_4 	"If sold livestock to buy other livestock, bought: Chickens"
	label var r44__97 	"If sold livestock to buy other livestock, bought: Other"
	label var r44__99 	"If sold livestock to buy other livestock, bought: Don't know"
	
	label define livestock_lab 0 "None" 1 "Cow" 2 "Goat" 3 "Sheep" 4 "Chicken"
	label val livestock livestock_lab
	
	mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n)	 
	
	
	* Check and clean outliers and inconsistencies for the value of livestock sales
	do "${Phone_Survey}/Dofiles/Cleaning/livestock_sales_outliers_clean.do"	
	
	
	
	* Order
	order hhid round call_status livestock, first
	order k39_5 k39_6 k39_7 k39_8 k39_9, after(k39_4)
	order k35_4, after(k35_3)
	
	* Sort
	sort hhid round livestock

	* Save data
	save "${livestock}", replace 
	
	
	