/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	January 4, 2023
Last udpate on: 
Written by:  	Thomas Escande	

Revision: 		

********************************************************************************	

THIS DO FILE: 	Cleans outliers for the value of total sales of livestock (k38)
				Do-file runs within "livestock_roster_clear.do".

*/

global  all_HH_nopii_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
global  current_roster_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1.dta"

	* Add UP and treatment variables for correct comparisons 
	merge m:1 hhid using "${all_HH_nopii_fl1}", keepusing(ultra_poor treatment) keep(3) nogen

					/*******************************************************
						Looking at outliers in R1 
					*********************************************************/

	* Check on the value of livestock sales vs. number of livestock sold in R1 (since April - so about 6-8 months depending on survey date for a HH)
	gen sales_per_head_r1 = k38 / k37 
	tabstat sales_per_head_r1 if sales_per_head_r1 > 0, by(livestock) stat(min p5 p50 mean p75 p95 max)
	
	bys livestock: tab sales_per_head_r1
	* All resuslts are very consistent apart from :690 for Goat is probably a mistake - likely 6,900 since the avg is 5,000
	replace k38 = .o if sales_per_head_r1 == 690 & livestock == 2
	drop sales_per_head_r1
	
	
					/*******************************************************
						Looking at outliers in R4
					*********************************************************/	
					
	* In R4, we do not ask for sales value (past 4 weeks) separately by livestock type. We ask for totals for all types of livestock, so it is 
	* a bit hard to check, but it does not look crazy. 
	* Some of the top values above 100,000 Afs (1,100 USD) are high, but not crazy if sold a couple of cows.
	* Looks comparable to R1, although the recall period is way different - past 6-8 months v. past 4 weeks 
	tabstat k38 if k38 > 0, stat(min p5 p50 mean p75 p95 max)
	
		preserve
			keep if round == 1 
			collapse (sum) k38, by(hhid)
			* Rough approximation of what it would look like over 4 weeks, construction is done better in the construction files
			replace k38 = k38/8 /*approximating the recall period as 8 periods of 4 weeks */
			tabstat k38 if k38 > 0, stat(min p5 p50 mean p75 p95 max)	
		restore
		
	tabstat k38_r4 if k38_r4 > 0, stat(min p5 p50 mean p75 p95 max)

	* Compare this to fl1 [this is part 4 weeks sales, but total, not per luivestock type]: 
	preserve 
		global fl1_data  "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"

		use "${fl1_data}", clear 
			gen sales_per_head_fl1 = k38 / k37 
			tabstat sales_per_head_fl1 if sales_per_head_fl1 > 0, stat(min p5 p50 mean p75 p95 max)
			tabstat k38 if k38 > 0, stat(min p5 p50 mean p75 p95 max) // looks pretty comparable to what we see in R4 
			gen k38_6mo = k38*6 // 6 months?
			tabstat k38_6mo if k38_6mo > 0, stat(min p5 p50 mean p75 p95 max)

	restore 
					
* In r4, we don't have a lot of information on the type or number of livestock sold, so we can look for extreme values and compare to what we have in R1 
* Comparing to the previous recall period, it looks like some of the values are quite high. Using the previous max over the whole period as the maximum here (110 000)
*tw (hist k38_r4 if livestock == 1 & ultra_poor == 1 , freq) || (hist k38_r4 if livestock == 1 & ultra_poor == 0 , freq color(red%30))

	replace k38_r4 = .o if k38_r4 >= 110000  & ultra_poor == 1 & !mi(k38_r4 ) /*1 household out of 58*/					
	replace k38_r4 = .o if k38_r4 >= 110000  & ultra_poor == 0 & !mi(k38_r4 ) /*2 households out of 82*/	


drop ultra_poor treatment

