/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	January 4, 2023
Last udpate on: 
Written by:  	Thomas Escande	

Revision: 		

********************************************************************************	

THIS DO FILE: 	Cleans outliers for the value of livestock (k8) for both UP and NUP at the same time as livestock valuation should not change so much between UP and NUP 
				Do-file runs within "livestock_roster_clear.do".

*/

global  all_HH_nopii_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
global  current_roster_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1.dta"

	* Code missings for k8, it is treated later for the other variables but makes sense here to do it for that
	mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n)	

	* Add UP and treatment variables for correct comparisons 
	merge m:1 hhid using "${all_HH_nopii_fl1}", keepusing(ultra_poor treatment) keep(3) nogen
	
	* Look at the data to identify potential outliers (NB Asset cost for the program was estimated as 37 000  AFN (2016)) and included pregnant cow or with calf
	* Transfer equivalence: 1 cow = 3 Sheep = 4 Goats . For chicken, international comparison would be 0.017 cow so 1 cow = 59 chicken 
	
	*tw (hist k8 if livestock == 1 & ultra_poor == 1, freq) || (hist k8 if livestock == 1 & ultra_poor == 0, freq color(red%30))	

*1 Cows	
	* Taking 100000 as an upper limit based on the transfer price, inflation and data distribution - 11 changes, 3 for the UP and 8 for the NUP 
	replace k8 = .o if livestock == 1 & k8 > 100000 & !mi(k8)


*2 "Goat" 
	*tw (hist k8 if livestock == 2 & ultra_poor == 1, freq) || (hist k8 if livestock == 2 & ultra_poor == 0, freq color(red%30))
	* No obvious outliers 	

*3 "Sheep"
	*tw (hist k8 if livestock == 3 & ultra_poor == 1, freq) || (hist k8 if livestock == 3 & ultra_poor == 0, freq color(red%30)) - 4 changes, 2 UP and 2 NUP 
	replace k8 = .o if livestock == 3 & k8 > 60000 & !mi(k8)
	
	
*4 "Chicken"	
	*tw (hist k8 if livestock == 4 & ultra_poor == 1, freq) || (hist k8 if livestock == 4 & ultra_poor == 0, freq color(red%30)) - 22 changes, 9 UP and 13 NUP 
	replace k8 = .o if livestock == 4 & k8 >= 3000 & !mi(k8)
*3000 is still extremly high for a chicken but that should be taken care of in the winsorization 

drop ultra_poor treatment







