set graphics off

global 	phone_svy_clean_r4 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r2.dta" 
global 	village_svy_raw  			"${TUP_DB}/Phone_Survey/DataSets/Deidentified/village_svy_raw_r1.dta" 
global  phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"


use "${phone_svy_clean_r2}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) keepusing(PRA_lottery) nogen
	keep hhid t1 - t4 treatment call_status PRA_lottery
	drop t0_2_1 - t0_2__99 // empty vars 
	
	* Keep UP only 
	keep if !mi(treatment)
	
	* Keep complete interviews only 
	tab call_status if mi(t1) // 1 missing value from a partial interview
	keep if call_status == 1 
	
	* Encode missing values 
	mvdecode *, mv(-99 = .d \ -98 = .r) 

	
	** OVERALL 
		* Are you aware of ... ?
	tabstat t1 t2_*, stat(mean N) by(treatment)
	
		* How many? Most people don't know 
	tab t3 if t2_1 == 1 & treatment == 0, m
	tab t3 if t2_1 == 1 & treatment == 1, m
	
	tab t3_2 if t2_2 == 1 & treatment == 0, m
	tab t3_2 if t2_2 == 1 & treatment == 1, m
	
		* Why did they move? (conditional on having answered How many, so N is quite small)
	tabstat t0_? t0__?? if treatment == 0, stat(mean N)
	tabstat t0_? t0__?? if treatment == 1, stat(mean N)
	tabstat t0_ret_? t0_ret__?? if treatment == 0, stat(mean N)
	tabstat t0_ret_? t0_ret__?? if treatment == 1, stat(mean N)
	
	* ALL UP
	tabstat t0_? t0__??, stat(mean N)
	tabstat t0_ret_? t0_ret__??, stat(mean N)
		
		
	** BY TREATMENT STATUS 
		* Preceptions / attitudes: how likeli are IDPs to...
		
	unab t5_list: t5?
	unab t5_2_list: t5?_2
	
	* Fix labels for Returnees 
	foreach var in `t5_2_list' {
		lab val `var' t5a
		
	}	
		
	tabm t5? if treatment == 1 & !mi(t3), r m 
	tabm t5? if treatment == 0 & !mi(t3), r m 

	label define c_lab 1 "(Very) unlikely" 3 "No effect" 4 "(Very) Likely"
	
	* I would graph this - STOP come back 
	foreach var in t5a t5b t5c t5d t5e t5f t5g {
		
		* combine very likely, likely etc
	gen `var'_c = `var'
		replace `var'_c = 1 if inlist(`var',1,2)
		replace `var'_c = 4 if inlist(`var',4,5)
		label val `var'_c c_lab
		
	gen `var'_c_2 = `var'_2
		replace `var'_c_2 = 1 if inlist(`var'_2,1,2)
		replace `var'_c_2 = 4 if inlist(`var'_2,4,5)
		label val `var'_c_2 c_lab	
		
		local `var'_lab : var lab `var'
		tabplot `var'_c treatment, horizontal percent(treatment) xtitle("treatment group") ytitle("") subtitle("IDPs: ``var'_lab'")  showval(format(%2.0f)) 
			graph export "`var'_graph.png", replace
		
		tabplot `var'_c_2 treatment, horizontal percent(treatment) xtitle("treatment group") ytitle("") subtitle("Returnees: ``var'_lab'") showval(format(%2.0f)) 	
			graph export "`var'_2_graph.png", replace 
	}
		
		* Should IDPs be supported or helped to move back?
	tab t6 if t2_1 == 1, m
	tab t6 if t2_1 == 1 & treatment == 0, m
	tab t6 if t2_1 == 1 & treatment == 1, m
	
	tab t6_2 if t2_2 == 1, m
	tab t6_2 if t2_2 == 1 & treatment == 0, m
	tab t6_2 if t2_2 == 1 & treatment == 1, m
	
	reg t6 treatment , r 
	
		* How many IDPs do you think are there in Afg? 
		* Idea was that if you think there are many / few your attitudes may change
	tab t7 if t2_1 == 1, m // most people don't know 
	tab t7 if t2_1 == 1 & treatment == 0, m // most people don't know 
	tab t7 if t2_1 == 1 & treatment == 1, m // most people don't know 
	tabstat t7 if t2_1 == 1, stat(min p25 p50 mean p75 max N)

	tab t7_2 if t2_2 == 1, m // most people don't know 
	tab t7_2 if t2_2 == 1 & treatment == 0, m // most people don't know 
	tab t7_2 if t2_2 == 1 & treatment == 1, m // most people don't know 
	
		histogram t7 if t2_1 == 1 & t7>0 & !mi(t7)
		histogram t7_2 if t2_2 == 1 & t7>0 & !mi(t7_2)
	
		tabstat t7 if t2_1 == 1, by(treatment) stat(min p25 p50 mean p75 max N)
		tabstat t7_2 if t2_2 == 1, by(treatment) stat(min p25 p50 mean p75 max N)
	
	
	* Preference - IDPs [only those who knew any IDPs answer]
	tabstat t9_1 t9_2, stat(p25 mean p50 p75 N) by(treatment)
	
	* Preference - Returnees [only those who knew any returnees answer]
	tabstat t10_1 t10_2, stat(p25 mean p50 p75 N) by(treatment)
	
	* Returnee access to gov services [everyone answers this]
	tab t8, m

	tab t8 if treatment == 0, m
	tab t8 if treatment == 1, m
	
	ttest t8, by(treatment) uneq
	reg t8 treatment, r
	
	* Attitude to gov policies [everyone answers this]
	tab t4_1, m
	
	tab t4_1 if treatment == 0, m
	tab t4_1 if treatment == 1, m
	
	ttest t4_1, by(treatment) uneq
	

	tab t4, m 
	
	tab t4 if treatment == 0, m
	tab t4 if treatment == 1, m
	
	ttest t4, by(treatment) uneq

	
	
** Migration in and out of the HH - R4 	and Covid 
use "${phone_svy_clean_r4}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) keepusing(PRA_lottery) nogen 
	keep hhid in_migration - migrant_remit_amt_99_warning treatment PRA_lottery call_status x1 - x5 incomplete_hh
	
		* Keep UP only 
	keep if !mi(treatment)
	
	* Encode missing values 
	mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .o) 
	
	
	** In-migration 
		
		* Moved?
		tab in_migration, m
		
		tab in_migration if treatment == 0, m
		tab in_migration if treatment == 1, m
		
		ttest in_migration, by(treatment) uneq
		
		* How many? By location 
		tabstat in_migration_num_afg_calc if in_migration_num_afg_calc>0, by(treatment) stat(mean N)
		tabstat in_migration_num_oth_calc if in_migration_num_oth_calc>0, by(treatment) stat(mean N)
		
	** Out migration
	
		* Push factor migration
		tabstat out_migration_push_? out_migration_push__??, by(treatment) stat(mean N)
		
		* Push factor migration destination
		tabstat out_migration_push_loc_*, by(treatment) stat(mean N)
		
		* Pull factor migration
		tabstat out_migration_? out_migration__??, by(treatment) stat(mean N)
		
		* Pull factor migration numbers? By location 
		tabstat out_migration_num_afg_calc if out_migration_num_afg_calc>0, by(treatment) stat(mean N)
		tabstat out_migration_num_oth_calc if out_migration_num_oth_calc>0, by(treatment) stat(mean N)
		
		* Destination of out migration to another country
		tabstat out_migration_location_afg_*, by(treatment) stat(mean N)
		
	** Remittance 
		* Yes/no
		tab migrant_remittance if (out_migration_1 ==1 | out_migration_2 == 1 | out_migration__97 == 1), m

		tab migrant_remittance if (out_migration_1 ==1 | out_migration_2 == 1 | out_migration__97 == 1) & treatment == 0, m
		tab migrant_remittance if (out_migration_1 ==1 | out_migration_2 == 1 | out_migration__97 == 1) & treatment == 1, m

		ttest migrant_remittance, by(treatment) uneq
		
		* Value of remittance 
		tabstat migrant_remit_amt, by(treatment) stat(mean p50 sd N)
		
		tab migrant_remit_amt if inlist(migrant_remittance,1,2), m
		
		tab migrant_remit_amt_99_warning // no obs 
		drop migrant_remit_amt_99_warning

		ttest migrant_remit_amt, by(treatment) uneq
	
	STOP
** Anything in the Village survey about migration? 
	use "${village_svy_raw}", clear 
	
	
	
** Covid [only asked in the "short" survey, so N is a bit smaller]
	* Have you heard of covid?
	tab x1 if incomplete_hh == 0, m
	tabstat x1, by(treatment) stat(mean N)
	
	ttest x1, by(treatment) uneq
	
	* Have you taken measures?
	gen anymeasure = (x2!="0" & !mi(x2))
	
	tabstat anymeasure x2_0 - x2_6 if incomplete_hh == 0 & x1 == 1, by(treatment) stat(mean N)
	
	ttest anymeasure if incomplete_hh == 0 & x1 == 1, by(treatment) uneq

	* would you take the vaccine?
		* combine Yes, voluntarily and Yes if it were mandatory
	gen vaccine_yes = (inlist(x5,1,2))
	
	tabstat vaccine_yes if incomplete_hh == 0 & x1 == 1, by(treatment) stat(mean N) 
	ttest vaccine_yes if incomplete_hh == 0 & x1 == 1, by(treatment) uneq
	
	tab x5 if incomplete_hh == 0 & x1 == 1 & treatment ==0, m
	tab x5 if incomplete_hh == 0 & x1 == 1 & treatment ==1, m
	tab x5 if incomplete_hh == 0 & x1 == 1, m
	