/* Migration [cross-section, keeping latest observation when we have a panel]

NB: this do-files runs from within ""${Phone_Survey_do}/Cleaning/cross_section_merge.do"

	NOTE: Have not done any checks for missingness / consistency yet. 
	
	Quesitons & issues:
		1. Migration section was cut after a few surveys, so there is a not a lot of data in this round (N = 79). 
		We end up having R3 and R4 data for these 79 HHs, but it's not a "panel".
		
		2. Two cases of unexplained missingness in T0096 and T0465, recoded as ".r", in R4, in variables:
			T0096: in_migration_num_afg - in_migration_num_oth_o
			T0465: out_migration_num_afg - out_migration_rel__99
		
*/

* Inputs
global 	phone_svy_clean_r3 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Outputs
global 	migration_clean				"${TUP_DB}\Phone_Survey\DataSets\Intermediate\migration_clean_phonesvy.dta"


*********************************************************************************
* Round 3 [we cut this section after a few surveys, so there is a not a lot of data in this round, but there is some]
*********************************************************************************

use "${phone_svy_clean_r3}", clear 
		keep field_hhid hhid call_status in_migration - migrant_remit_amt_99_warning
		
		drop *_99_warning *calc 
		
		gen round = 3
		
		tempfile migration_r3
		save `migration_r3'
		
*********************************************************************************
* Round 4 
*********************************************************************************		
		
use "${phone_svy_clean_r4}", clear 
		keep field_hhid hhid call_status in_migration -  migrant_remit_amt_99_warning
		
		drop *_99_warning *calc 
				
		gen round = 4 

		tempfile migration_r4
		save `migration_r4'
		
		
*********************************************************************************
* Append rounds (append for now)
*********************************************************************************	
		
		use "`migration_r3'"
			append using "`migration_r4'"

		* Of 79 HHs with migration info in R3, 75 were also survyed in R4; so, we drop R3 and use R4 data  
		duplicates report hhid 
		
		keep if round == 4 
			
		* Drop HHs without this information 	
		drop if in_migration == .
		
		* Label 
		label var 	out_migration_1 	"Member left HH ('pull'): Work opportunities"
		label var 	out_migration_2 	"Member left HH ('pull'): Education opportunities"
		label var 	out_migration__97 	"Member left HH ('pull'): Other"
		label var 	out_migration_0 	"Member left HH ('pull'): None"
		label var 	out_migration__98 	"Member left HH ('pull'): Don't answer"
		label var 	out_migration__99 	"Member left HH ('pull'): Don't know"
		
		label var 	out_migration_location_afg_1 	"Moved to: Iran"
		label var 	out_migration_location_afg_2 	"Moved to: Pakistan"
		label var 	out_migration_location_afg__97 	"Moved to: Other"
		label var 	out_migration_location_afg__98 	"Moved to: Don't answer"
		label var 	out_migration_location_afg__99 	"Moved to: Don't know'"
		
		label var 	out_migration_push_0 	"Member left HH ('push'): No one"
		label var 	out_migration_push_1 	"Member left HH ('push'): Conict/violence/security"
		label var 	out_migration_push_2 	"Member left HH ('push'): Lack of local economic opportunities"
		label var 	out_migration_push__97	"Member left HH ('push'): Other"
		label var 	out_migration_push__98 	"Member left HH ('push'): Don't answer"
		label var 	out_migration_push__99 	"Member left HH ('push'): Don't know"
		
		label var 	out_migration_push_loc_0 	"Moved to ('push'): Another part of Afghanistan"
		label var 	out_migration_push_loc_1 	"Moved to ('push'): Abroad to another country"
		label var 	out_migration_push_loc__98 	"Moved to ('push'): Don't answer"
		label var	out_migration_push_loc__99 	"Moved to ('push'): Don’t know"
		
		label var	out_migration_rel_1		"Relationship with migrant: Spouse"
		label var	out_migration_rel_2		"Relationship with migrant: Son/daughter"
		label var	out_migration_rel_3		"Relationship with migrant: Stepson/stepdaughter/adopted/foster"
		label var	out_migration_rel_4		"Relationship with migrant: Son-in-law/daughter-in-law"
		label var	out_migration_rel_5		"Relationship with migrant: Grandchild"
		label var	out_migration_rel_6		"Relationship with migrant: Brother/sister"
		label var	out_migration_rel_7		"Relationship with migrant: Brother-in-law/sister-in-law"
		label var	out_migration_rel_8		"Relationship with migrant: Father/mother"
		label var	out_migration_rel_9		"Relationship with migrant: Father-in-law/mother-in-law"
		label var	out_migration_rel_10	"Relationship with migrant: Grandparent"
		label var	out_migration_rel_11	"Relationship with migrant: Great-grandchild"
		label var	out_migration_rel_12	"Relationship with migrant: Cousin"
		label var	out_migration_rel_13	"Relationship with migrant: Nephew/niece"
		label var	out_migration_rel_14	"Relationship with migrant: Co-wife"
		label var	out_migration_rel_15	"Relationship with migrant: Aunt/uncle"
		label var	out_migration_rel_16	"Relationship with migrant: Other relative"
		label var	out_migration_rel__97	"Relationship with migrant: Other unrelated"
		label var	out_migration_rel__98	"Relationship with migrant: Don't answer"
		label var	out_migration_rel__99	"Relationship with migrant: Don't know"

		
		** Missingness checks and recording of randomly missing values 
		
		* In-migration / out-migration / out-push migration screening questions 
		assert !mi(in_migration) & !mi(out_migration) & !mi(out_migration_push) if round == 4 
		
		* Number of in-migrants 
		* One case in round 4 (T0096) with a randomly missing value (to be coded as .r)
		cap noi assert !mi(in_migration_num_afg) & !mi(in_migration_num_oth) if in_migration == 1 
		list field_hhid if mi(in_migration_num_afg) & in_migration == 1 
		
		* "Other" number of in-migrants 
		assert !mi(in_migration_num_afg_o) if in_migration_num_afg == -97
		assert !mi(in_migration_num_oth_o) if in_migration_num_oth == -97
		
		* Number of out-migrants 
		* One case in round 4 (T0465) with a randomly missing value (to be coded as .r)
		cap noi assert !mi(out_migration_num_afg) & !mi(out_migration_num_oth) if out_migration == "1" 
		list field_hhid if mi(out_migration_num_afg) & out_migration == "1" 
		*br if !inlist(out_migration,"0","-97","-98","-99","") & mi(out_migration_num_afg) & mi(out_migration_num_oth)
		
		* "Other" number of out-migrants 
		assert !mi(out_migration_num_afg_o) if out_migration_num_afg == -97
		assert !mi(out_migration_num_oth_o) if out_migration_num_oth == -97
		
		* Location for out-migration
		assert !mi(out_migration_location_afg) if inlist(out_migration_num_oth,1,2) 		

		* Relationship [only asked in R3]
		assert !mi(out_migration_rel) if !inlist(out_migration,"0","-98","-99","") & round == 3

		* Remittance [y/n]
		* One case in round 4 (T0465) with a randomly missing value (to be coded as .r)
		cap noi assert !mi(migrant_remittance) if !inlist(out_migration,"0","-98","-99","")
		list field_hhid if mi(migrant_remittance) & !inlist(out_migration,"0","-98","-99","")
		
		* Remittance [amount]
		assert !mi(migrant_remit_amt) if inlist(migrant_remittance,1,2)
		
		* Drop string multiple_select vars we don't need before recoding 
		drop out_migration out_migration_location_afg out_migration_rel out_migration_push /// 
		out_migration_push_loc out_migration_num out_migration_location_afg
		
		* Recode randomly missing value (as .r)
		recode in_migration_num_afg - in_migration_num_oth_o (. = .r) if field_hhid == "T0096" & round == 4 
		recode out_migration_num_afg - out_migration_rel__99 (. = .r) if field_hhid == "T0465" & round == 4 
		
		* Encode all other missing values 
		mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .o) 
		
		* Order 
		order field_hhid hhid call_status, first
		order out_migration_push_0 - out_migration_push_loc__99, after(out_migration_rel__99)
		
		* Save data 
		save "${migration_clean}", replace 
		
		
		
		
		
		