/* Mobile data roster [cross-section, keeping latest observation when we have a panel]

NB: this dataset does not have PII. It excludes actual phone numbers. At some point,
	important to check those for duplication as I am sure there will be some (i.e., HH 
	listing the same number twice).
	
Questions and issues:

	1. Mobile data was not collected for some HHs in Round 1 early on because we (I) were 
		going to rely on the data from the MISFA exercise. See if we can fill it in more or less
		using the data from MISFA verification.	
	2. In theory this section should only be asked once of each HH and we should have a dataset uique at the hhid-phone level.
		But, in 27 cases it got asked twice. In this case, for now, keep the earlier data point since we will most likely be able to use,
		assuming it is from R1 or R2.
	3. There are 59 HH where the number of phones they report owning does not match the number of phones they provide detailed data for.
		This is weird, not really sure how it would happen. Could be if section is asked more than once (i.e., problem (2)).
		
		Check if some of the phone numbers recorded were duplicates, but for now assume that the number of phones detail is provided for 
		is correct / takes precedence over the answer in v1.

*/

* Inputs 
global 	phone_svy_clean_r1			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Outputs
global 	mobile						"${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_roster_phonesvy.dta"
	
	
*********************************************************************************
* Cleaning rounds 1, 2, 3, 4
*********************************************************************************	
cap program drop mobile_clean
program define mobile_clean
 
 set trace on
 
	use "${phone_svy_clean_r`0'}", clear 
	
	if `0' == 4 {
		keep field_hhid hhid call_status no_pm a12_mobile_short v1 - v4_crisis_3
		
	}
	else {
		keep field_hhid hhid call_status no_pm a12_mobile_short v1 - v4_crisis_4
	}
	
		destring *, replace 
		*replace no_pm = . if no_pm == 0
		
		drop phone_roster_count phone_num_* lady_line_*
		
		* Reshape 
		rename *_current *_0
		reshape long v3_ v4_ v2_network_time_ v2_sim_ v2_tazkira_1_ v2_tazkira_2_ v4_crisis_, i(hhid) j(phone)
		
		rename *_ *
		* So that current phone is 1, not 0
		replace phone = phone + 1 
		
		gen round = `0'
		
		 * Drop extra obs created with reshape 
		egen miss = rmiss(v3 - v4_crisis)
			drop if miss == 7
			drop miss
		
		save "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r`0'.dta", replace 
		
		set trace off
 end
 
	mobile_clean 1
	mobile_clean 2
	mobile_clean 3
	mobile_clean 4
	
			
*********************************************************************************
* Merge datasets and Cleaning
*********************************************************************************		
	
	use "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r1.dta", clear 
		append using "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r2.dta"
		append using "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r3.dta"
		append using "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r4.dta"
		
	* In theory this section should only be asked once of each HH and at this point we should 
	* have a dataset uique at the hhid-phone level. But, in 27 cases it got asked tiwce.
	* In this case, for now, keep the earlier data point since we will most likely be able to use 
	* it (assuming it is coming from R1-2).
	duplicates tag hhid phone, gen(tag)
	bys hhid phone: egen min_round = min(round)
	drop if tag>0 & round != min_round
	drop tag min_round 
	
	isid hhid phone 
	label drop asset_l
	
	* Keep only HHs that consented 
	keep if a12_mobile_short == 1 
		
	* Encode missing values 	
	mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n)	
	
	* Check for missingness 
	assert v1 != .
	
	* In 4 cases, v1 = -99 / DK, but follow-up questions are asked. This should not be the case. Follow-up questions hould be missing.
	foreach var in v3 v4 v2_network_time v2_sim v2_tazkira_1 v2_tazkira_2 v4_crisis {
		replace `var' = . if mi(v1)
		
	}
	
	* Checking if the number of phones reported in v1 == number of phones detailed data is collected for (it does not...)
	bys field_hhid: egen v3_nonmiss = total(!missing(v3))
	cap noi assert v3_nonmiss == v1 if !mi(v1)
	br if v3_nonmiss != v1 & !mi(v1)
	unique field_hhid if v3_nonmiss != v1 & !mi(v1)
	cou if v3_nonmiss != v1 & !mi(v1)
	* Check if some of the phone numbers recorded were duplicates, but for now assume that the number of phones detail is provided for 
	* is correct / takes precedence over the answer in v1
	replace v1 = v3_nonmiss if v1!=v3_nonmiss &!mi(v1)

	* Drop variables we don't need 
	drop call_status no_pm v3_nonmiss
	
	* Label 
	label var round "Phone survey round"
	label var v3 "The relationship of the primary owner of this number to the LHH"
	label var v4 "What network carrier is this phone number on?"
	label var v2_network_time "Roughly how long has this phone number been used by the household?"
	label var v2_sim "Did you obtain this SIM card yourself or did someone help you get it?"
	label var v2_tazkira_1 "Did you use your tazkira to obtain this SIM card?"
	label var v2_tazkira_2 "Did you use someone else’s tazkira to obtain this SIM card?"
	label var v4_crisis "What network carrier was this phone number on?"
	 
	* Sort
	sort hhid round phone 
	
	* Order 
	order hhid phone round, first

	* Erase temp datasets 
	erase "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r1.dta"
	erase "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r2.dta"
	erase "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r3.dta"
	erase "${TUP_DB}\Phone_Survey\DataSets\Intermediate\mobile_r4.dta"
	
	* Save
	save "${mobile}", replace
	