/*******************************************************************************	
Project:  		
Created on:  	
Last udpate on: 

Written by:  	
Revision: 		

********************************************************************************			

THIS DO FILE: 	Cleans non-food consumption from gross outliers

	flag_fl1_hi // <7% of values
	flag_fl1_lo // <1% of values
	flag_p50plus3XSD_hi // 2.5% high outliers based on "bounds" rule

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
global 	nonfood_consumption			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/nonfoodcons_roster_phonesvy.dta"
global 	phone_svy_clean_r1			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r1.dta" 
global 	all_hhlevel_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
global 	roster						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
global 	assets						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/hhassets_roster_phonesvy.dta"
global 	phone_svy_profile			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta" 
global  profile_info 				"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"

global  all_HH_interm_nopii_fl1 	"${Dropbox}/DataWork_TUP_CodeReview\Followup_1\DataSets/Intermediate/all_HH_interm_nopii_fl1.dta"
global  data_for_analysis_fl1		"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
*global  nonfood_consumption_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/nonfood_consumption_fl1.dta" // not syncing on plane 
global  nonfood_consumption_fl1		"${Dropbox}\DataWork_MDC\Followup_1\DataSets\Intermediate\submit\c_c_nonfoodconsumption_fl1.dta"
global  roster_fl1					"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"


********************************************************************************
	** Part 1: Non-food items
********************************************************************************
*use "${nonfood_consumption}", clear 
	
* Get ultra-poor variable 
	merge m:1 hhid using "${phone_svy_profile}", assert(2 3) keep(3) nogen keepus(ultra_poor enu_r*)

* Get number of HH members
	preserve
		use "${roster}", clear
		*keep if round == 1 
		keep hhid hh_mem round
		duplicates drop hhid round, force
		tempfile hh_mem
		save	`hh_mem'
	restore
	merge m:1 hhid round using `hh_mem', assert(2 3) keep(3) nogen	

* Create flag variables
	gen flag_outlier = .
	lab def flag_outlier_l 1 "Typing error" 2 "Unit issues" 3 "Enumerator issues" 4 "Inconsistent values"
	lab val flag_outlier flag_outlier_l
	gen flag_outlier_why = ""	
	
* Replace .98 and .99 as extended missing .d (don't know)
	foreach var in c12 c13 {
		forval i = 98/99 {
			count if round(`var',0.01)==.`i'
			
			replace flag_outlier = 1 if round(`var',0.01)==.`i'
			replace flag_outlier_why = ".`i' typed instead of -`i'" if round(`var',0.01)==.`i'				
			replace `var'=.d if round(`var',0.01)==.`i'
		}
	}
	
*-------------------------------------------------------------------------------*
* Check 99 and 98 to identify if they're coding mistakes
*-------------------------------------------------------------------------------*
	tab enu_r1 if (inlist(c12, .d, .r) | inlist(c13, .d, .r)) & round == 1 // Zahra Salik, Fatima Salik, Roh Afza have a lot
	tab enu_r1 if (inlist(c12, 99, 98) | inlist(c13, 99, 98)) & round == 1 // Zahra Mohammadi has 5. We assume they're extended missing
	
	tab enu_r3 if (inlist(c12, 99, 98) | inlist(c13, 99, 98)) & round == 3 // none in R3
	tab enu_r4 if (inlist(c12, 99, 98) | inlist(c13, 99, 98)) & round == 4 // none in R4 
	
	/*
			   Interviewer ID |      Freq.     Percent        Cum.
		----------------------+-----------------------------------
				  Taibah Nori |         35       39.77       39.77
		 BiBi Qamer Khaleqyar |          1        1.14       40.91
			   Yalda Mansoury |         12       13.64       54.55
			   Nahida Alizada |          2        2.27       56.82
			 Dr. Faruqa Sahab |         28       31.82       88.64
				Freshtah Noor |          1        1.14       89.77
				Muhaya Habibi |          2        2.27       92.05
				   Noria Neda |          2        2.27       94.32
			 Eng Najla Akbari |          5        5.68      100.00
		----------------------+-----------------------------------
						Total |         88      100.00
	*/
	
* We assume that Zahra Mohammadi meant to introduce -99 and -98 
	replace flag_outlier = 1 if c12 == 99 & enu_r1 == 11 & round == 1 
	replace flag_outlier = 1 if c13 == 99 & enu_r1 == 11 & round == 1 
	replace flag_outlier_why = "99 typed instead of -99" if (c12 == 99 | c13 == 99) & enu_r1 == 11 & round == 1 
	replace c12 = .d if c12 == 99 & enu_r1 == 11 & round == 1 
	replace c13 = .d if c13 == 99 & enu_r1 == 11 & round == 1 

	replace flag_outlier = 1 if c12 == 98 & enu_r1 == 11 & round == 1 
	replace flag_outlier = 1 if c13 == 98 & enu_r1 == 11 & round == 1 
	replace flag_outlier_why = "98 typed instead of -98" if (c12 == 98 | c13 == 98) & enu_r1 == 11 & round == 1 
	replace c12 = .r if c12 == 98 & enu_r1 == 11 & round == 1 
	replace c13 = .r if c13 == 98 & enu_r1 == 11 & round == 1 

* Create one variable for c12 and c13: we're analyzing by item so it doesn't matter c12 is monthly and c13 yearly
	br hhid hhid item c12 c13
	gen 	non_food = c12
	replace non_food = c13 if item >= 21
	
* Generate non-food consumption pc 
	gen nonfood_exp_pc = non_food/hh_mem
	lab var nonfood_exp_pc "Non-food expsnditure per capita (Afs)" 
	
* Drop partial interviews with no values so that the merge on hhid-item below works 
	drop if mi(item)

*-------------------------------------------------------------------------------*
* Comparisons with fl1 and other phone survey rounds
*-------------------------------------------------------------------------------*	
	* Cannot compare with AMMC rounds at this point since next consumption is collected in R3,
	* so merge on fl1 per capita consumption values for benchmarking

* Get number of HH members from the HH roster from fl1
	preserve
		use "${roster_fl1}", clear
		keep hhid b3
		rename b3 hh_mem
		duplicates drop hhid, force
		tempfile hh_mem
		save	`hh_mem'
	restore
	
	merge m:1 hhid using `hh_mem', assert(2 3) keep(3) nogen

	preserve 
		use "${nonfood_consumption_fl1}", clear
			merge m:1 hhid using "${profile_info}", keepusing(ultra_poor) keep(3) assert(2 3) nogen
			merge m:1 hhid using "`hh_mem'", assert(3) nogen
			
			* Keep only the relevant items
			keep if inlist(item,7,21,36,37,38)
			
			gen 	non_food = c12
			replace non_food = c13 if item >= 21
			
			* Generate non-food consumption pc 
			gen nonfood_exp_pc = non_food/hh_mem
			lab var nonfood_exp_pc "Non-food expsnditure per capita (Afs)" 

		* Generate percentiles from fl1 
			bys item ultra_poor: egen fl1_p1  = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(1)
			bys item ultra_poor: egen fl1_p5  = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(5)
			bys item ultra_poor: egen fl1_p50 = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(50)
			bys item ultra_poor: egen fl1_p95 = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(95)
			bys item ultra_poor: egen fl1_p99 = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(99)
			bys item ultra_poor: egen fl1_min = min(nonfood_exp_pc)    if nonfood_exp_pc>0 & !mi(nonfood_exp_pc)
			bys item ultra_poor: egen fl1_max = max(nonfood_exp_pc)    if nonfood_exp_pc>0 & !mi(nonfood_exp_pc)
			
			egen nmiss = rowmiss(fl1_*)
			drop if nmiss == 7 	
			
			keep item ultra_poor fl1_*
			duplicates drop 
			
			tempfile nonfood_pct_fl1
			save `nonfood_pct_fl1'
	restore

* Generate percentiles from previous rounds 
	foreach round of numlist 1 3/4 {
		preserve
			keep if round == `round'
				bys item ultra_poor: egen r`round'_p1  = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(1)
				bys item ultra_poor: egen r`round'_p5  = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(5)
				bys item ultra_poor: egen r`round'_p50 = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(50)
				bys item ultra_poor: egen r`round'_p95 = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(95)
				bys item ultra_poor: egen r`round'_p99 = pctile(nonfood_exp_pc) if nonfood_exp_pc>0 & !mi(nonfood_exp_pc), p(99)
				bys item ultra_poor: egen r`round'_min = min(nonfood_exp_pc) 	if nonfood_exp_pc>0 & !mi(nonfood_exp_pc)
				bys item ultra_poor: egen r`round'_max = max(nonfood_exp_pc) 	if nonfood_exp_pc>0 & !mi(nonfood_exp_pc)	
				
				egen nmiss = rowmiss(r`round'_*)
				drop if nmiss == 7 
				
				keep item ultra_poor r`round'_* 
				
				duplicates drop
				tempfile r`round'_pct
				save `r`round'_pct' 
		restore	
	}
	
* Merge on 5th and 95th pct from R1, 3 and 4 of Phone survey
	merge m:1 ultra_poor item using "`r1_pct'", nogen
	merge m:1 ultra_poor item using "`r3_pct'", nogen
	merge m:1 ultra_poor item using "`r4_pct'", nogen	

* Merge on 5th and 95th pct from fl1
	merge m:1 ultra_poor item using "`nonfood_pct_fl1'", keepusing(fl1_*) keep(1 3) nogen

	tabstat nonfood_exp_pc if ultra_poor == 1, by(item) stat(min p5 p25 p50 mean p75 p95 max) // do no exclude Ramadan 
	
	
*-------------------------------------------------------------------------------*
* Check big values to identify if they're gross outliers / typing errors 
*-------------------------------------------------------------------------------*
	
* A. Create hi/lo flags for pc consumption values that are: above 99pct / below 1pct in fl1  
	
	gen flag_fl1_hi = (nonfood_exp_pc > fl1_p99) & !mi(nonfood_exp_pc) & nonfood_exp_pc>0
	gen flag_fl1_lo = (nonfood_exp_pc < fl1_p1) & !mi(nonfood_exp_pc) & nonfood_exp_pc>0
	
	label var flag_fl1_hi "High outlier based on fl1 (>p99)"
	label var flag_fl1_lo "Low outlier based on fl1 (<p1)"
	
	tab flag_fl1_hi // <7% of values
	tab flag_fl1_lo // <1% of values
	
* B. Create hi/lo flags for pc consumption values that are: above / below [Median +/-3SD]of the winsorized value 
	
	* Winsorize pc consumption at 5pct
	winsor2 nonfood_exp_pc if !mi(nonfood_exp_pc) & nonfood_exp_pc>0, cuts(5 95) by(item ultra_poor)
	
	preserve 
		keep if nonfood_exp_pc_w>0 & !mi(nonfood_exp_pc_w)
		collapse (p50) nonfood_exp_pc_w_p50 = nonfood_exp_pc_w (sd) nonfood_exp_pc_w_sd = nonfood_exp_pc_w, by(item ultra_poor)
		
			gen upper_nonfood = nonfood_exp_pc_w_p50 + 3*nonfood_exp_pc_w_sd
			gen lower_nonfood = nonfood_exp_pc_w_p50 - 3*nonfood_exp_pc_w_sd
				replace lower_nonfood = 0 if lower_nonfood < 0
				
				tempfile bounds_nonfood
				save `bounds_nonfood'
	restore 
		
	merge m:1 item ultra_poor using "`bounds_nonfood'", keepusing(upper_nonfood lower_nonfood) //nogen assert(3)
	
	gen flag_p50plus3XSD_hi  = (nonfood_exp_pc > upper_nonfood) & !mi(nonfood_exp_pc) & nonfood_exp_pc>0 & !mi(upper_nonfood) & !mi(lower_nonfood)
	gen flag_p50minus3XSD_lo = (nonfood_exp_pc < lower_nonfood) & !mi(nonfood_exp_pc) & nonfood_exp_pc>0 & !mi(upper_nonfood) & !mi(lower_nonfood)
	
	label var flag_p50plus3XSD_hi  "High outlier based on R1 (winsorized p50+3*SD)"
	label var flag_p50minus3XSD_lo "Low outlier based on R1 (winsorized p50-3*SD)"
	
	tab flag_p50plus3XSD_hi // 2.5% high outliers based on "bounds" rule
	tab flag_p50minus3XSD_lo // no "low" gross outliers based on "bounds"
		* this is because after subtracting 3xSD from the median we get negative values, which are then replaced with 0 

	
*-------------------------------------------------------------------------------*
* Get variables we need for analysis
*-------------------------------------------------------------------------------*	
	
*Most important is to check for all the UP first. Let's check their loans, whether they say they have a house, value of food consumption and savings, as well as the fl1 values for these. 
*It's about 15 HHs but with very high values. Check all above AFG 100K. The median for UP is AFG 7K

	preserve
		* HH-level follow-up
			use "${all_hhlevel_phonesvy}", clear
			keep if round == 1 
			keep hhid m20 m5
			tempfile hh_level_bars
			save	`hh_level_bars'
		
		* HH-level follow-up
			use "${all_HH_interm_nopii_fl1}", clear
			keep hhid e1 e1_o m19 m20 m1_a m5
			rename * fl1_*
			rename fl1_hhid hhid 
			tempfile hh_level_bars_fl1
			save	`hh_level_bars_fl1'
		
		* Assets
			use "${assets}", clear
			keep if inlist(asset,5,6,7) 
			keep if round == 2 
			keep hhid asset l1
			gen 	asset_l = "_house_land" if asset == 5
			replace asset_l = "_other_land" if asset == 6
			replace asset_l = "_other_house" if asset == 7
			drop asset
			reshape wide l1, i(hhid) j(asset_l) s
			egen owns_anything = rowtotal(l1_house_land l1_other_house l1_other_land)
			tempfile assets
			save	`assets'
			
		* Consumption baseline
			use "${data_for_analysis_fl1}", clear
			keep hhid exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc_ALCS exp_nf_tot_m_pc
			rename * fl1_*
			rename fl1_hhid hhid
			tempfile consump_fl1
			save 	`consump_fl1'
			
		* Non-food consumption baseline
			use "${nonfood_consumption_fl1}", clear
			rename (c12 c13) (fl1_c12 fl1_c13)
			tempfile nonfood_fl1
			save	`nonfood_fl1'
	restore
	
* Merge
	merge m:1 hhid using `hh_level_bars', keep(1 3) nogen
	merge m:1 hhid using `hh_level_bars_fl1', keep(1 3) nogen
	merge m:1 hhid using `assets', keep(1 3) nogen // assets are from R2, so not a 1:1 merge 
	merge m:1 hhid using `consump_fl1', keep(1 3) nogen
	merge m:1 hhid item using `nonfood_fl1', keep(1 3) nogen
	
*----------------------------*
* Graph and do summary stats *
*----------------------------*
	/*
		local value_label_item: value label item
		foreach item of numlist 1(1)38 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			count if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 0
			hist non_food if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 0, percent name("nup_`item'", replace) title("`l_`item'' - Non-poor") note(N=`r(N)')
			count if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 1
			hist non_food if item == `item' & non_food>0 & !mi(non_food) & ultra_poor == 1, percent name("up_`item'", replace)title("`l_`item'' - Ultra-poor") note(N=`r(N)')
		}
	*/
	
* Browse potential outliers 

	tab item if flag_p50plus3XSD_hi == 1 // mostly in: soap and health services 
	gsort item ultra_poor -nonfood_exp_pc round
	
	* LOW outliers based on med+3SD
		* there are none
	* HIGH outliers based on med+3SD
	br hhid item ultra_poor round hh_mem non_food nonfood_exp_pc c12 c13 upper_nonfood fl1_c13 fl1_exp_nf_tot_m_pc owns_anything fl1_e1 fl1_m5 m5 fl1_m19 fl1_m20 m20  if flag_p50plus3XSD_hi == 1 & ultra_poor == 1 & round == 1
		* for Soap, p99 at fl1 is 157 Afs, which is about 1.77

	* HIGH outliers based on fl1 p99
	br hhid item ultra_poor hh_mem non_food nonfood_exp_pc fl1_p99 fl1_c13 fl1_exp_nf_tot_m_pc owns_anything fl1_e1 fl1_m5 m5 fl1_m19 fl1_m20 m20  if flag_fl1_hi == 1 
	* LOW outliers based on fl1 p1
		* Values of < 1 Afs pc are certainly very low, although not in per capita terms we don't see anything <1. Values of 1 Afs are weird.
	gsort item ultra_poor -nonfood_exp_pc
	br hhid item ultra_poor hh_mem non_food nonfood_exp_pc fl1_p1 fl1_c13 fl1_exp_nf_tot_m_pc owns_anything fl1_e1 fl1_m5 m5 fl1_m19 fl1_m20 m20  if flag_fl1_lo == 1 

	* Commenting out gross outlier replacement since this is taken care of by the Sayed and Hossain check:
	
		
	* Replace identified outliers with .o -- HIGH values only fow now
		gen c13_with_outliers = c13
		gen c12_with_outliers = c12
		
	* Replace c_a, not nonfood_exp_pc, since this variable will be constructed in a construction do-file

	* Ultra-poor
	* Soap: replace value of >= 200 Afs pp/per moonth (~11 USD) for ultra-poor HH that did not have a loan
	replace c12 = .o if item == 7 & nonfood_exp_pc >= 220 & !mi(c12) & ultra_poor == 1 & m5 == 0 // 16 changes
	replace flag_outlier = 1 if item == 7 & c12 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 7 & c12 == .o
	
	* House construction:
		* Both UP and NUP HHs generally have loans large enough to cover high construction spending, although some values of loans 
		* are in themselves questionable, like one 51K USD loan for a UP HH.... they all do also own a house.
		* Similar picture for hajj/annual celebrations
		
	* 400000 (USD 4K) in HH construction is probably an outlier, even if with loans 
	replace c13 = .o if item == 21 & hhid == 1374  & round == 1 
	replace flag_outlier = 1 if item == 21 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 21 & c13 == .o
	
	*  200000 in health services with a small loan is likely an outlier 
	* replace c13 = .o if item == 38 & hhid == 1627 & round == 1 // 50000 is a big number, but they also have a large loan 
	replace c13 = .o if item == 38 & hhid == 1929 & round == 1
	replace flag_outlier = 1 if item == 38 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 38 & c13 == .o
	
	* For weddings, consider PC expense above 27500 Afs (285 USD) as outlier [based on the 3*SD value]
	* replace c13 = .o if item == 36 & hhid == 1115 & round == 1 // 112000 is a high value, but they also have a huge loan  
	replace c13 = .o if item == 36 & nonfood_exp_pc >= 27500 & !mi(c13) & ultra_poor == 1 & m5 == 0 // no changes, because all of them have loans! 
	replace flag_outlier = 1 if item == 36 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 36 & c13 == .o

	**** UP AND NUP --- > NEW 
	* Clean values above 1000 AFN regardless of whether they have a loan 
	replace c12 = .o if item == 7 & nonfood_exp_pc >= 1000 & !mi(c12) // 19 changes (10 in UP and 9 in NUP, but none of the UP are in R1)
	replace flag_outlier = 1 if item == 7 & c12 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 7 & c12 == .o
	
	* Non-UP 
	* Soap: replace value of >= 220 Afs pp/per moonth (~11 USD) for ultra-poor HH that did not have a loan
	* leave the same rule as for UP, because the upper bound value for NUP is 200 which is a little less than UP (which is weird)
	replace c12 = .o if item == 7 & nonfood_exp_pc >= 220 & !mi(c12) & ultra_poor == 0 & m5 == 0 // 18 changes
	replace flag_outlier = 1 if item == 7 & c12 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 7 & c12 == .o
	
	* House construction:
		* Both UP and NUP HHs generally have loans large enough to cover high construction spending, although some values of loans 
		* are in themselves questionable, like one 51K USD loan for a UP HH.... they all do also own a house.
		* Similar picture for hajj/annual celebrations
		
	* 545,454 (USD 5.6K) in HH construction is probably an outlier, even if with loans, even for the NUP 
	* 312500 and 200000 as well 
	replace c13 = .o if item == 21 & inlist(hhid,5507,5548,5171)  & round == 1 
	replace flag_outlier = 1 if item == 21 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 21 & c13 == .o
	
	* 2000000 in health services with a small loan is likely an outlier 
	replace c13 = .o if item == 38 & hhid == 5508 & round == 1
	replace flag_outlier = 1 if item == 38 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 38 & c13 == .o
	
	* above 83333 in health for NUP HHs
	replace c13 = .o if item == 38 & inlist(hhid,5508,6250,6411) & !mi(c13) & round == 1 
	replace flag_outlier = 1 if item == 38 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 38 & c13 == .o

	* For weddings, consider PC expense above 500000 Afs as outlier [based on the 3*SD value - which is probably still too high]
	replace c13 = .o if item == 36 & inlist(hhid,5010,6037,5430) & !mi(c13) & round == 1  // they all have loans but loans are outliers 
	replace flag_outlier = 1 if item == 36 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 36 & c13 == .o
	
	* For annual celebrations, 75000 is way above the next highest value of 33333
	replace c13 = .o if item == 37 & hhid == 6415 & !mi(c13) & round == 4
	replace flag_outlier = 1 if item == 37 & c13 == .o
	replace flag_outlier_why = "Value unrealistically high" if item == 37 & c13 == .o
	

* Drop variables
	drop hh_mem non_food /*fl1_*/ m5 m20 l1_house_land l1_other_house l1_other_land owns_anything nonfood_exp_pc upper_nonfood lower_nonfood nonfood_exp_pc_w
	
