/* Non-food consumption

	1. Round 1 roster prep
	2. Round 3 roster prep
	3. Round 4 roster prep
	4. Compile panel data
	5. Minor cleaning

*/

* Inputs 
global 	phone_svy_clean_r1			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Sayed and Hossain's corrections for non-food consumption 
global correction_consumption_r1 	"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey\Quality Checks/correction_consumption_r1.dta" //
global correction_consumption_r3_r4 "${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey\Quality Checks/correction_consumption_r3_r4.dta"

* Outputs
global 	nonfood_consumption			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfoodcons_roster_phonesvy.dta"


*********************************************************************************
* Cleaning rounds 1, 3, 4
*********************************************************************************
cap program drop nonfood_clean
program define nonfood_clean
 
 set trace on
 
	use "${phone_svy_clean_r`0'}", clear 
	keep field_hhid hhid c12_7 - c13_18_99_warning call_status
	drop *confirm* *warning
	drop c12_7 c13_1 c13_16 c13_17 c13_18
	rename *_corr *
	
	reshape long c12_ c13_, i(hhid) j(item)
		rename *_ * 
		mvdecode c13 c12, mv(-99 = .d \ -98 = .r \ -97 = .n)
		assert call_status == 2 if c13 == . & item != 7 // partial (incomplete) surveys have regular missing values
		assert call_status == 2 if c12 == . & item == 7 // partial (incomplete) surveys have regular missing values

	gen round = `0'
	
	save "${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfood_r`0'.dta", replace 
	
	set trace off
 end
 
	* Run cleaning on all rounds 
	nonfood_clean 1
	nonfood_clean 3
	nonfood_clean 4

	* Append rounds 
	 use "${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfood_r1.dta"
		append using "${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfood_r3.dta"
		append using "${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfood_r4.dta"
	
	* Erase temp datasets 
	erase "${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfood_r1.dta"
	erase "${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfood_r3.dta"
	erase "${TUP_DB}\Phone_Survey\DataSets\Intermediate\nonfood_r4.dta"
	
	* Label
	lab var c12 "What did your household spend in the last month on the following (value in Afghanis):"
	lab var c13 "What did your household spend in the last 12 months on the following (value in Afghanis):"
	lab var item "Item"
	lab var round "Phone survey round"
	
	replace item = item + 20 if inlist(item,1,16,17,18)
		
	lab def item_l 	1 "Food consumed at home" 2 "Food consumed outside the home" ///
							3 "Cigarettes" 4 "Tobacco/snuff" 5 "Matches" ///
							6 "Laundry powder/detergents, cleaning supplies" ///
							7 "Soap (hand, toiletry)" 8 "Shampoo" 9 "Toothpaste" ///
							10 "Personal grooming (haircuts, etc.) for males" ///
							11 "Fee for public bath" 12 "Laundry charges"  ///
							13 "Fee for baking bread" 14 "Fixed phone line and use (including PCO booths)"  ///
							15 "Mobile phone charges (minutes and prepaid)" ///
							16 "Internet service/Internet café, fax, mail"  ///
							17 "Transportation fare - bus and taxis" ///
							18 "Fuel for car/motor bike (do not include business vehicles)" ///
							19 "Taxes (formal and informal)"  ///
							20 "Other miscellaneous expenses in last month" ///
							21 "House construction and repair (materials and labor)" ///
							22 "Education fees (tuition for school, college, university)" ///
							23 "School uniforms" 24 "Textbooks" 25 "Pens, pencils and notebooks (school supplies)" ///
							26 "Other stationery" 27 "Repair, maintenance and tires for motor vehicles" ///
							28 "Airfares" 29 "Men's clothing (excluding shoes)"  ///
							30 "Women's clothing (excluding shoes)" ///
							31 "Children's clothing (excluding shoes and school uniforms)" ///
							32 "Men's shoes" 33 "Women's shoes" 34 "Children's shoes" ///
							35 "Fines" 36 "Weddings and funerals, haj"  ///
							37 "Annual celebrations and charitable donations (khair-o-khairat)" ///
							38 "Health services"
		lab val item item_l
	
	* Merge Ramadan flag from profile data 
	preserve 
		use "${phone_svy_profile}", clear 
		keep hhid ramadan_r* 
		rename ramadan_r* ramadan_*
		reshape long ramadan_, i(hhid) j(round)
		rename *_ *
		tempfile ramadan
		save `ramadan'
	restore 
	
	cap drop  __000001 __000002
	merge m:1 hhid round using "`ramadan'", assert(2 3) keep(3) nogen
	label var ramadan "Data collected during Ramadan"
	
	* Recode missing values in partial interviews as .p
	*replace item = .p if c12 == . & c13 == . & call_status == 2 
	recode c12 (. = .p) if call_status == 2 & inlist(item,7)
	recode c13 (. = .p) if call_status == 2 & !inlist(item,7)

	assert c12 !=. if call_status == 1 & inlist(item,7)
	assert c13 !=. if call_status == 1 & !inlist(item,7)

	drop if (c12 == .p | c13 == .p)
	
	* Run Outlier cleaning file (replacements are commente out, but we also do not need to run this now)
	*do "${Phone_Survey_do}/Cleaning/nonfood_consumption_outliers.do"
	
	* Before applying corrections, save original values with potential outliers 
	gen c13_with_outliers = c13
	gen c12_with_outliers = c12 

	* c13_miss is the variable with missing values (DKs)
	merge 1:1 hhid round item using "${correction_consumption_r1}", keepusing(c13 c13_miss) update replace force nogen
	merge 1:1 hhid round item using "${correction_consumption_r3_r4}", keepusing(c13 c13_miss) update replace force nogen
		
	* Recode Sayed missing values back  
	replace c13 = c13_miss if c13_miss !=.   

	mvdecode *, mv(-99 = .d)
	
	* Order
	order field_hhid hhid round ramadan call_status item, first 
	
	* Sort 
	sort field_hhid round item
	
	merge m:1 hhid using "${phone_svy_profile}", keep(3) nogen keepus(treatment)

	
	* Save data
	save "${nonfood_consumption}", replace  
