/*



*/



* Inputs
global 	phone_svy_raw_r2 			"${TUP_DB}/Phone_Survey/DataSets/Deidentified/phone_svy_raw_nopii_r2.dta" 
global 	profile_info 				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
global 	id_map						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
global 	tpm_correction_r2			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R2/Quality Checks/Cross checked feedback/AMMC Enumerator TPM Correction_R1.xlsx"
global  discrepancy_latest_r2		"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R2/Quality Checks/Spotchecks/discrepancy_latest.dta"

* Outputs
global 	phone_svy_clean_r2 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r2.dta" 


use "${phone_svy_raw_r2}", clear 

drop if date >= date("01may2021", "DMY") // 39 observations collected AFTER May 1 which we cannot use per IRB ruling 
	
	
*********************************************************************************
* 1. Merge on fl1 hhid and other profile data 
*********************************************************************************	
	* Merge hhid mapping to get the follow-up ID   
	cap drop _m
	merge m:1 field_hhid using "${id_map}", keepusing(hhid) assert(2 3) keep(3) nogen   
	  
	* Merge with treatment status vars using follow-up ID   
	merge m:1 hhid using "${profile_info}", keepusing(treatment ultra_poor PRA_lottery) assert(2 3) keep(3) nogen   

*********************************************************************************
* 2. Drop SCTO variables not pertaining to the survey --- UPDATE
*********************************************************************************	

	/* Keep previous survey completion flags just in case (incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete)
	
	keep date - a3_v incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete hh_id hh_id_confirm corr_respondent - q7 date_a field_hhid village a5 hhid - tpm_correction */
	
	
*********************************************************************************
* 3. Apply 99/-99 corrections and high value corrections
*********************************************************************************	

	* For partial interveiws, compile the complete interview from 2 (or more) submissions  
	tab field_hhid if call_status == 2
	
	* 99 flags etc : k20_1_99_warning k20_2_99_warning i4_d_99_warning i4_s_99_warning
	rename (know_pm_age_warning know_lhh_age_warning know_mem_age_warning) (know_pm_age_99_warning know_lhh_age_99_warning know_mem_age_99_warning)

	local 99vars know_pm_age know_lhh_age know_mem_age k20_1 k20_2 i4_d i4_s
	
	destring `99vars', replace 

	foreach 99var in `99vars' {
		replace `99var' = `99var'_99_warning if inlist(`99var'_99_warning,-99,-98,1) // 0 = value entered; 1 = issues from pilot when everyone confirmed a mistake to move on 
	}
	
	*value confirmation: k20_1_confirm k20_1_confirm_val k20_2_confirm k20_2_confirm_val
	local confirm_var k20_1 k20_2
	 
	foreach confirm_var in `confirm_var' { 
		gen `confirm_var'_corr = `confirm_var'
			replace `confirm_var'_corr = `confirm_var'_confirm if `confirm_var'_confirm_val == 2 // if Value 2 is correct  
			label var `confirm_var'_corr "Var with correction for potentially high value" 
			order `confirm_var'_corr, after(`confirm_var') 
	} 


*********************************************************************************
* 4. TPM corrections from the Google Sheet
*********************************************************************************	

	preserve 

		* Import and reshape data with TPM corrections cross-checked by Abobaker for this round
		import excel using "${tpm_correction_r2}", firstrow clear 
			tostring hhid - other_8, replace 
			drop if mi(hhid)
			drop AA
			reshape long var_ tpm_correct_ other_, i(hhid) j(num)
			rename *_ *
			rename hhid field_hhid
			drop if mi(var)
			keep if tpm_correct == "yes" | mi(tpm_correct)
			replace var = strtrim(var)
			
			* fix var name for "_calc" vars and child sex issue with labels
			replace var = var + "_calc" if regexm(var,"schoolchild_") & !regexm(var,"_calc")
			
		* Merge on TPM values for variables where replacements will be made
			merge 1:1 field_hhid var using "${discrepancy_latest_r2}", keepusing(tpm_val) assert(2 3) keep(3) nogen
		
			local confirm_var c12_7 c13_1 c13_16 c13_17 c13_18 m5 m20 k38 k8_1 k8_2 k8_3 k8_4 k32 k20_1 k20_2

			foreach var in `confirm_var' {
				replace var = "`var'_corr" if var == "`var'"
			}
			
			* Create values for replacement 
			gen val = other
				replace val = tpm_val if tpm_correct == "yes"
				assert !mi(val)
				
			keep field_hhid var val
			
			reshape wide val, i(field_hhid) j(var) string
			rename val* *
			
			* select_multiple and other strings in master data need to be a string, otherwise destring variables
				qui ds
				local allvars `r(varlist)'
				local string_vars "field_hhid l1 l1_a k21_2"
				local numeric : list allvars - string_vars
			
				destring `numeric', replace 
			
			tempfile corrections
			save `corrections'

	restore

* Apply TPM corrections to the data 

	destring *, replace 
	* Make some multiple_select vars strings so the merge works well with the TPM corrections 
	tostring l1 l1_a k21_2, replace 
	
		merge 1:1 field_hhid using "`corrections'", update replace assert(1 5) gen (tpm_correction) // replace with non-missing values from TPM file

* For the select_multiple variables, we need to transfer the TPM corrections from the select_multiple string variables to the associated dummy variables
	* Approach for this is described in the first example (c3)
	* One thing to think about in the future is that if, e.g., surveyor missed a type of item consumed (as in c3), then all follow up questions on the 
		* item will be missing as well. Keep in mind.
	* Variables this is done for: k21_2 l1 l1_a 
		
		*** k21_2
		* drop original dummies 
		drop k21_2_1 - k21_2__99
		* split the updated select_mutliple variable 
		split k21_2, destring gen(k21_2_)
		* recode negative codes to positive value so it also works as an index in the loop below 
		recode k21_2_1 - k21_2_25 (-99 = 99)
		
		foreach index of numlist 1/26 99 {
			* create dummies from the updated select_mutliple variable 
			egen 	k21_2_`index'_temp = anymatch(k21_2_?), values(`index')
				* correct for missing select_multiple variable (dummies created above have "0" instead of "." when k21_2 == ""; switch is back to ".")
			replace k21_2_`index'_temp = . if mi(k21_2)
		}
			* drop variables created by the split command and fix var names 
			drop k21_2_1 - k21_2_25
			rename *_temp *
			
			rename k21_2_99 k21_2__99
			
			* order 
			order k21_2_1 - k21_2__99, after(k21_2)
	
		*** l1
		drop l1_1 - l1__99
		split l1, destring gen(l1_)
		recode l1_1 - l1_16 (-99 = 99) (-98 = 98)
		
		foreach index of numlist 0/19 98 99 {
			egen	l1_`index'_temp = anymatch(l1_1 l1_2 l1_3 l1_4 l1_5 l1_6 l1_7 l1_8 l1_9 l1_10 l1_11 l1_12 l1_13 l1_14 l1_15 l1_16), values(`index')
			replace l1_`index'_temp = . if mi(l1)
		}
	
			drop l1_1 - l1_16
			rename *_temp *
		
			rename (l1_98 l1_99) (l1__98 l1__99) 
			
			order l1_0 - l1__99, after(l1)
			
		*** l1_a
			* Due to a rename conflict, l1_1 was later renamed l1_a. These vars need to be combined into 1. 
		tabmiss l1_1_20 - l1_1__99 // these are all missing, can drop and not worry about it 
		drop l1_1_20 - l1_1__99
			
		drop l1_a_20 - l1_a__99
		split l1_a, destring gen(l1_a_)
		recode l1_a_1 - l1_a_23 (-99 = 99) (-98 = 98)
		
		foreach index of numlist 0 20/49 98 99 {
			egen	l1_a_`index'_temp = anymatch(l1_a_?), values(`index')
			replace l1_a_`index'_temp = . if mi(l1_a)
		}
	
			drop l1_a_1 - l1_a_23
			rename *_temp *
		
			rename (l1_a_98 l1_a_99) (l1_a__98 l1_a__99) 
			
			order l1_a_0 - l1_a__99, after(l1_a)
			
			
*********************************************************************************
* 5. Other cleaning
*********************************************************************************	
** k15: there is a lot of missingness in k15; this is because we had it first as a multiple select question and then changed it to yes/no. 
	replace k15 = 1 if !mi(k20_1)
	replace k15 = 0 if mi(k20_1)

	* Replace missings and Other  
	*mvdecode *, mv(-99 = .d / -98 = .r / -97 = .o / -96 = .n) 
	
	forval i = 1/4  {
		label val v3_`i' v3_current
	}
	
	lab var consent_phone "Consented to mobile date module"
	label var v3_1 "Lady of the Household (Self)"
	label var v3_2 "Primary Man"
	label var v3_3 "Other household member"
	label var v3_4 "Someone outside the household"
	
	label var i2_d_0 "This level of education will help daughter: Will not help"
	label var i2_d_1 "This level of education will help daughter: Get job/earn money"
	label var i2_d_2 "This level of education will help daughter: Make him/her wiser"
	label var i2_d_3 "This level of education will help daughter: Enhance marriage prospects"
	label var i2_d__97 "This level of education will help daughter: Other"
	label var i2_d__98 "This level of education will help daughter: DA"
	label var i2_d__99 "This level of education will help daughter: DK"	
	
	label var 	t2_1 	"Includes: IDPs"
	label var 	t2_2 	"Includes: Returnees"
	label var 	t2__99 	"Includes: Don't know"
	
	label var	t0_1	"Migration reason: To escape conflict, persecution, or repression"
	label var	t0_2	"Migration reason: Covid-related reason (border closure, seeking treatment)"
	label var	t0_3	"Migration reason: To seek better economic opportunities"
	label var	t0_4	"Migration reason: Deported "
	label var	t0__97	"Migration reason: Other"
	label var	t0__99	"Migration reason: Don’t know"
	
	label var	t0_ret_1	"Migration reason: To escape conflict, persecution, or repression"
	label var	t0_ret_2	"Migration reason: Covid-related reason (border closure, seeking treatment)"
	label var	t0_ret_3	"Migration reason: To seek better economic opportunities"
	label var	t0_ret_4	"Migration reason: Deported "
	label var	t0_ret__97	"Migration reason: Other"
	label var	t0_ret__99	"Migration reason: Don’t know"
		
	* Order 
	order phone_num_2 - v4_crisis_2, after(v4_crisis_1)
	order phone_num_3 - v4_crisis_4, after(v4_crisis_2)
	
	* NB: this is coming from the TPM correction file, while phone variables with PII have been deleted from these data;
	* temporarily remove it here as well until we are ready to analyze phone numbers.
	drop v2_1
	
	/**** ROSTERS 
	
	 * HH roster - only asking for # of HH members in R2
	 hh_mem hh_mem_calc
	 
	 * crops 
	 k15 - k21_2__99
	 
	 * assets 
	 l1 - l4__98_19
	 
	 * shocks 
	 g1 - g3
	 
	 * phones (this excludes phone numbers for now)
	 v1 - v4_crisis_4
	
*********************************************************************************
* 5. Drop roster variables 
*********************************************************************************/	
	
	
	* Save data 
	save "${phone_svy_clean_r2}", replace 