* Inputs 
global 	phone_svy_raw_r3 			"${TUP_DB}/Phone_Survey/DataSets/Deidentified/phone_svy_raw_nopii_r3.dta"
global 	profile_info 				"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
global 	id_map						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
global 	tpm_correction_r3			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R3/Quality Checks/Cross checked feedback/AMMC Enumerator TPM Correction_R2.xlsx"
global  discrepancy_latest_r3		"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R3/Quality Checks/Spotchecks/discrepancy_latest.dta"

* Outputs
global  phone_svy_clean_r3			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r3.dta"


use "${phone_svy_raw_r3}", clear	

*********************************************************************************
* 1. Merge on fl1 hhid and other profile data 
*********************************************************************************	
	* Merge hhid mapping to get the follow-up ID   
	cap drop _m
	merge m:1 field_hhid using "${id_map}", keepusing(hhid) assert(2 3) keep(3) nogen   
	  
	* Merge with treatment status vars using follow-up ID   
	merge m:1 hhid using "${profile_info}", keepusing(treatment ultra_poor PRA_lottery) assert(2 3) keep(3) nogen   
	
	* Drop weird HHs with 0 consumption 
	drop if inlist(hhid,1100,1146,1206,1582,1592,1612,1617,1630,1639,2053,2184,5264,6611) // this is in Ramadan
	
*********************************************************************************
* 2. Drop SCTO variables not pertaining to the survey --- UPDATE
*********************************************************************************	

	/* Keep previous survey completion flags just in case (incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete)
	
	keep date - a3_v incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete hh_id hh_id_confirm corr_respondent - q7 date_a field_hhid village a5 hhid - tpm_correction */
	
		
		
*********************************************************************************
* 3. Apply 99/-99 corrections and high value corrections and save in Intermediate folder  
*********************************************************************************	

/* 99 flags etc
c12_7_99_warning c13_1_99_warning c13_16_99_warning c13_17_99_warning c13_18_99_warning k30_1_99_warning k30_1_m_99_warning migrant_remit_amt_99_warning m5_1_99_warning m5_2_99_warning m5_3_99_warning m20_1_99_warning m20_2_99_warning m20_3_99_warning i4_d_99_warning i4_s_99_warning */

	
	rename (know_pm_age_warning know_lhh_age_warning know_mem_age_warning k30_1_99_warning ) (know_pm_age_99_warning know_lhh_age_99_warning know_mem_age_99_warning k30_1_earn_99_warning)

	local 99vars know_pm_age know_lhh_age know_mem_age c12_7 c13_1 c13_16 c13_17 c13_18 k30_1_earn k30_1_m migrant_remit_amt m5_1 m5_2 m5_3 m20_1 m20_2 m20_3 i4_d i4_s
	
	destring `99vars', replace 

	foreach 99var in `99vars' {
		replace `99var' = `99var'_99_warning if inlist(`99var'_99_warning,-99,-98,1) // 0 = value entered; 1 = issues from pilot when everyone confirmed a mistake to move on 
	}
	
	* Sum 3-field variables again after 99/.99 correction is appleid to individual values [need to fix in pilot 1 since 99/.99 warnings were not implemented there] 
	 
	foreach var in m5 m20 { 
		egen `var'_tot = rsum(`var'_1 `var'_2 `var'_3) 
		replace `var'_tot = . if mi(`var') 
		drop `var' 
		rename `var'_tot `var' 
	} 
	
	order m5, after(m5_3)
	order m20, after(m20_3)
	
	local confirm_var c12_7 c13_1 c13_16 c13_17 c13_18 m5 m20
	 
	foreach confirm_var in `confirm_var' { 
		gen `confirm_var'_corr = `confirm_var'
			replace `confirm_var'_corr = `confirm_var'_confirm if `confirm_var'_confirm_val == 2 // if Value 2 is correct  
			label var `confirm_var'_corr "Var with correction for potentially high value" 
			order `confirm_var'_corr, after(`confirm_var') 
	} 
	
	* Fix K30_1_earn 
	foreach var in v14187 v11397 v8607 v7131 v6105 v5661 v4328 v4314 v2871 v2857 v1603 v1575 v1561 {
		replace k30_1_earn = `var' if mi(k30_1_earn) & !mi(`var')
			drop `var'
	}

	order k30_1_earn, after(k30_in_7)


*********************************************************************************
* 4. TPM corrections from the Google Sheet
*********************************************************************************	

	preserve 

		* Import and reshape data with TPM corrections cross-checked by Abobaker for this round
		import excel using "${tpm_correction_r3}", firstrow clear 
			tostring hhid - other_9, replace 
			reshape long var_ tpm_correct_ other_, i(hhid) j(num)
			rename *_ *
			rename hhid field_hhid
			drop if mi(var)
			keep if tpm_correct == "yes" | mi(tpm_correct)
			replace var = strtrim(var)
			drop if var == "no"
			
			* fix var name for "_calc" vars and child sex issue with labels
			replace var = var + "_calc" if regexm(var,"schoolchild_") & !regexm(var,"_calc")
			
			* Make corrections to variable names so the merge with TPM values works 
			replace	var	=	"c3_a_cup_2"	if other ==	"13"			&	field_hhid	==	"T0357"
			replace	var	=	"e7"		  	if other == "5"			    &	field_hhid	==	"T0186"
			replace	var	=	"c3_a_seer_3"	if var ==	"c3_a_seer"		&	field_hhid	==	"T0200"
			replace	var	=	"c7_a_1"		if tpm_correct == "yes" 	&	field_hhid	==	"T0386"

		* Merge on TPM values for variables where replacements will be made
			merge 1:1 field_hhid var using "${discrepancy_latest_r3}", keepusing(tpm_val) assert(2 3) keep(3) nogen
		
			local confirm_var c12_7 c13_1 c13_16 c13_17 c13_18 m5 m20 k38 k8_1 k8_2 k8_3 k8_4 k32 k20_1 k20_2

			foreach var in `confirm_var' {
				replace var = "`var'_corr" if var == "`var'"
			}
			
			* Create values for replacement 
			gen val = other
				replace val = tpm_val if tpm_correct == "yes"
				assert !mi(val)
				
			keep field_hhid var val
			
			reshape wide val, i(field_hhid) j(var) string
			rename val* *
			
			* select_multiple and other strings in master data need to be a string, otherwise destring variables
				qui ds
				local allvars `r(varlist)'
				local string_vars "field_hhid i2_d k30 k6 e7 k30_m l1_b c7 c3 k39_1 k39_2"
				local numeric : list allvars - string_vars
			
				destring `numeric', replace 
			
			* Correct TPM typo
			replace k30_m = "2 8 9" if k30_m == "22289"
			
			tempfile corrections
			save `corrections'

	restore

* Apply TPM corrections to the data 

	destring *, replace 
	* Make some multiple_select vars strings so the merge works well with the TPM corrections 
	tostring i2_d k30 k6 e7 k30_m l1_b c7 c3 k39_1 k39_2, replace 
	
		merge 1:1 field_hhid using "`corrections'", update replace assert(1 5) gen (tpm_correction) // replace with non-missing values from TPM file

* For the select_multiple variables, we need to transfer the TPM corrections from the select_multiple string variables to the associated dummy variables
	* Approach for this is described in the first example (c3)
	* One thing to think about in the future is that if, e.g., surveyor missed a type of item consumed (as in c3), then all follow up questions on the 
		* item will be missing as well. Keep in mind.
	* Variables this is done for: c3 c7 k30_m k30 i2_d k6 e7 k39_1 k39_2 l1_b
		
		*** c3 
		* drop original dummies 
		drop c3_1 - c3__100
		* split the updated select_mutliple variable 
		split c3, destring gen(c3_)
		* recode negative codes to positive value so it also works as an index in the loop below 
		recode c3_1 - c3_5 (-100 = 100)
		
		foreach index of numlist 1/5 100 {
			* create dummies from the updated select_mutliple variable 
			egen 	c3_`index'_temp = anymatch(c3_?), values(`index')
				* correct for missing select_multiple variable (dummies created above have "0" instead of "." when c3 == ""; switch is back to ".")
			replace c3_`index'_temp = . if mi(c3)
		}
			* drop variables created by the split command and fix var names 
			drop c3_1 - c3_5
			rename *_temp *
			
			rename c3_100 c3__100
			
			* order 
			order c3_1 - c3__100, after(c3)
			
		drop c7_1 - c7__100
		split c7, destring gen(c7_)
		recode c7_1 - c7_5 (-100 = 100)
		
		foreach index of numlist 1/5 100 {
			egen 	c7_`index'_temp = anymatch(c7_?), values(`index')
			replace c7_`index'_temp = . if mi(c7)
		}
			drop c7_1 - c7_5
			rename *_temp *
			
			rename c7_100 c7__100
			
			* order 
			order c7_1 - c7__100, after(c7)
				
		*** k30_m 
		drop k30_m_1 - k30_m__98
		
		split k30_m, destring gen(k30_m_)
		recode k30_m_1 - k30_m_8 (-98 = 98)

		foreach index of numlist 0/9 98 {
			egen 	k30_m_`index'_temp = anymatch(k30_m_?), values(`index')
			replace k30_m_`index'_temp = . if mi(k30_m)
		}
		
			drop k30_m_1 - k30_m_8
			rename *_temp *
			
			rename k30_m_98 k30_m__98
			
			order k30_m_0 - k30_m__98, after(k30_m)
			
		*** k30
		drop k30_1 - k30__98
		split k30, destring gen(k30_)
		recode k30_1 - k30_7 (-98 = 98)

		foreach index of numlist 0/9 98 {
			egen 	k30_`index'_temp = anymatch(k30_1 k30_2 k30_3 k30_4 k30_5 k30_6 k30_7), values(`index')
			replace k30_`index'_temp = . if mi(k30)
		}
		
			drop k30_1 - k30_7
			rename *_temp *
			
			rename k30_98 k30__98
			
			order k30_0 - k30__98, after(k30)

		*** i2_d
		drop i2_d_1 - i2_d__99
		split i2_d, destring gen(i2_d_)
		recode i2_d_1 - i2_d_3 (-97 = 97) (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/3 97 98 99 {
			egen	i2_d_`index'_temp = anymatch(i2_d_?), values(`index')
			replace i2_d_`index'_temp = . if mi(i2_d)
		}
	
			drop i2_d_1 - i2_d_3
			rename *_temp *
		
			rename (i2_d_97 i2_d_98 i2_d_99) (i2_d__97 i2_d__98 i2_d__99)
			
			order i2_d_0 - i2_d__99, after(i2_d)
				
		*** k6
		drop k6_1 - k6__99
		split k6, destring gen(k6_)
		recode k6_1 - k6_3  (-99 = 99)
		
		foreach index of numlist 0/3 99 {
			egen	k6_`index'_temp = anymatch(k6_?), values(`index')
			replace k6_`index'_temp = . if mi(k6)
		}
	
			drop k6_1 - k6_3
			rename *_temp *
		
			rename k6_99 k6__99
			
			order k6_0 - k6__99, after(k6)
		
		*** e7
		drop e7_1 - e7__98
		split e7, destring gen(e7_)
		recode e7_1 - e7_6 (-98 = 98) (-99 = 99)
		
		foreach index of numlist 1/7 98 99 {
			egen	e7_`index'_temp = anymatch(e7_?), values(`index')
			replace e7_`index'_temp = . if mi(e7)
		}
	
			drop e7_1 - e7_6
			rename *_temp *
		
			rename (e7_98 e7_99) (e7__98 e7__99)
			
			order e7_1 - e7__99, after(e7)

		*** k39_1
		drop k39_1_1 - k39__97_1
		split k39_1, destring gen(k39_1__)
		recode k39_1__1 - k39_1__7 (-97 = 97)
		
		foreach index of numlist 1/9 97 {
			egen	k39_1_`index'_temp = anymatch(k39_1__?), values(`index')
			replace k39_1_`index'_temp = . if mi(k39_1)
		}
	
			drop k39_1__1 - k39_1__7
			rename k39_1_*_temp k39_*_1
		
			rename k39_97_1 k39__97_1
			
			order k39_1_1 - k39__97_1, after(k39_1)
			
		*** k39_2
		drop k39_1_2 - k39__97_2
		split k39_2, destring gen(k39_2__)
		recode k39_2__1 - k39_2__7 (-97 = 97)
		
		foreach index of numlist 1/9 97 {
			egen	k39_2_`index'_temp = anymatch(k39_2__?), values(`index')
			replace k39_2_`index'_temp = . if mi(k39_2)
		}
	
			drop k39_2__1 - k39_2__7
			rename k39_2_*_temp k39_*_2
		
			rename k39_97_2 k39__97_2
			
			order k39_1_2 - k39__97_2, after(k39_2)
		
		*** l1_b
		split l1_b, destring gen(l1_b_)
		tostring l1_b_14, replace 
		replace l1_b_14 = "" if l1_b_14 == "."
		
			forval i=1/14 {
				replace l1_b_`i' = substr(l1_b_`i',-2,2) if strlen(l1_b_`i')>5
				replace l1_b_`i' = subinstr(l1_b_`i',"_","",.)
				destring l1_b_`i', replace 
			}
		
		recode l1_b_1 - l1_b_14 (-99 = 99) (-98 = 98)
		
		foreach index of numlist 0 20/49 98 99 {
			egen	l1_b_`index'_temp = anymatch(l1_b_?), values(`index')
			replace l1_b_`index'_temp = . if mi(l1_b)
		}
	
			drop l1_b_1 - l1_b_14
			rename *_temp *
		
			rename (l1_b_98 l1_b_99) (l1_b__98 l1_b__99) 
			
			order l1_b_0 - l1_b__99, after(l1_b)
		
*********************************************************************************
* 5. Other cleaning 
*********************************************************************************
	* Rename 
	rename k27_13 k27__97
	
	* Label
	forval i = 1/4  {
			label val v3_`i' v3_current
		}
	
	lab var consent_phone "Consented to mobile date module"
	label var v3_1 "Lady of the Household (Self)"
	label var v3_2 "Primary Man"
	label var v3_3 "Other household member"
	label var v3_4 "Someone outside the household"

	label var k30_1 "Activity: Tend any animals owned or leased by the household"
	label var k30_2 "Activity: Farm land owned or sharecropped by the household"
	label var k30_3 "Activity: Work on business owned by household other than farm/animals"
	label var k30_9 "Activity: Work on household chores"
	label var k30_4 "Activity: Work as an agricultural laborer outside household"
	label var k30_5 "Activity: Do housework in someone else's home"
	label var k30_6 "Activity: Work as a non-agricultural laborer outside the household"
	label var k30_7 "Activity: Work in salaried/formal employment"
	label var k30_8 "Activity: Do any other work for pay"
	label var k30_0 "Activity: None"
	label var k30__98 "Activity: DA"
	
	label var i2_d_0 "This level of education will help daughter: Will not help"
	label var i2_d_1 "This level of education will help daughter: Get job/earn money"
	label var i2_d_2 "This level of education will help daughter: Make him/her wiser"
	label var i2_d_3 "This level of education will help daughter: Enhance marriage prospects"
	label var i2_d__97 "This level of education will help daughter: Other"
	label var i2_d__98 "This level of education will help daughter: DA"
	label var i2_d__99 "This level of education will help daughter: DK"	
	
	label var e1 "Allowed to buy things in the market without asking the permission"
	label var e2 "Listened to when decuiding on buying an expensive item"
	label var e3 "Have to ask permission to buy clothing for yourself"
	label var e4 "Permitted to visit women in other parts of the village to talk with them"
	label var e5 "Permitted to visit any place riding on public transport"
	label var e7 "Who do you consult with for decisions regarding your children's health care?"
	label var e8 "Who decides whether to pay for expenses related to education"

	label var e7_1	"LHH consults: No one, I decide on my own"
	label var e7_2	"LHH consults: My husband"
	label var e7_3	"LHH consults: Mother-in-law"
	label var e7_4	"LHH consults: Father-in-law"
	label var e7_5	"LHH consults: Relatives from my husband's side"
	label var e7_6	"LHH consults: Son / daughter"
	label var e7_7	"LHH consults: Relative from my side of the family (like mom, dad, sister, brother)"
	label var e7__99	"LHH consults: Don’t know"
	label var e7__98	"LHH consults: Don’t answer"
	
	label var 	k27_1	"Reason for biz closure: Shortage of funds to operate the business"
	label var 	k27_2	"Reason for biz closure: Shortage of workers to operate the business"
	label var 	k27_3	"Reason for biz closure: Too few customers"
	label var 	k27_4	"Reason for biz closure: Shortage of materials/ inputs for the business"
	label var 	k27_5	"Reason for biz closure: Too many competitors"
	label var 	k27_6	"Reason for biz closure: Got another job"
	label var 	k27_7	"Reason for biz closure: Theft / insecurity"
	label var 	k27_8	"Reason for biz closure: Legal or regulatory problems"
	label var 	k27_9	"Reason for biz closure: Started another business"
	label var 	k27_10	"Reason for biz closure: Could not get a loan to cover a loss or to expand"
	label var 	k27_11	"Reason for biz closure: HH member operating the business got sick or passed away"
	label var 	k27_12	"Reason for biz closure: Because of COVID (lockdown, border closure, etc.)"
	label var 	k27__97	"Reason for biz closure: Other" 
	label var 	k27__99	"Reason for biz closure: Don't know"
	
	label var 	out_migration_1 	"Member left HH ('pull'): Work opportunities"
	label var 	out_migration_2 	"Member left HH ('pull'): Education opportunities"
	label var 	out_migration__97 	"Member left HH ('pull'): Other"
	label var 	out_migration_0 	"Member left HH ('pull'): None"
	label var 	out_migration__98 	"Member left HH ('pull'): Don't answer"
	label var 	out_migration__99 	"Member left HH ('pull'): Don't know"
	
	label var 	out_migration_location_afg_1 	"Moved to: Iran"
	label var 	out_migration_location_afg_2 	"Moved to: Pakistan"
	label var 	out_migration_location_afg__97 	"Moved to: Other"
	label var 	out_migration_location_afg__98 	"Moved to: Don't answer"
	label var 	out_migration_location_afg__99 	"Moved to: Don't know'"
	
	label var	out_migration_rel_1		"Relationship with migrant: Spouse"
	label var	out_migration_rel_2		"Relationship with migrant: Son/daughter"
	label var	out_migration_rel_3		"Relationship with migrant: Stepson/stepdaughter/adopted/foster"
	label var	out_migration_rel_4		"Relationship with migrant: Son-in-law/daughter-in-law"
	label var	out_migration_rel_5		"Relationship with migrant: Grandchild"
	label var	out_migration_rel_6		"Relationship with migrant: Brother/sister"
	label var	out_migration_rel_7		"Relationship with migrant: Brother-in-law/sister-in-law"
	label var	out_migration_rel_8		"Relationship with migrant: Father/mother"
	label var	out_migration_rel_9		"Relationship with migrant: Father-in-law/mother-in-law"
	label var	out_migration_rel_10	"Relationship with migrant: Grandparent"
	label var	out_migration_rel_11	"Relationship with migrant: Great-grandchild"
	label var	out_migration_rel_12	"Relationship with migrant: Cousin"
	label var	out_migration_rel_13	"Relationship with migrant: Nephew/niece"
	label var	out_migration_rel_14	"Relationship with migrant: Co-wife"
	label var	out_migration_rel_15	"Relationship with migrant: Aunt/uncle"
	label var	out_migration_rel_16	"Relationship with migrant: Other relative"
	label var	out_migration_rel__97	"Relationship with migrant: Other unrelated"
	label var	out_migration_rel__98	"Relationship with migrant: Don't answer"
	label var	out_migration_rel__99	"Relationship with migrant: Don't know"
	
	label var	m3_1	"Reason for loan: For health emergency"
	label var	m3_2	"Reason for loan: To purchase food or other essential items for the household"
	label var	m3_3	"Reason for loan: To purchase durable good such as television, refrigerator, etc"
	label var	m3_4	"Reason for loan: To buy seeds/fertilizer or other farm inputs"
	label var	m3_5	"Reason for loan: To start a business"
	label var	m3_6	"Reason for loan: To invest in current business"
	label var	m3_7	"Reason for loan: To provide working capital for current business"
	label var	m3_8	"Reason for loan: To pay for wedding/religious celebration"
	label var	m3_9	"Reason for loan: To pay dowry"
	label var	m3_10	"Reason for loan: To invest in exiting livestock"
	label var	m3_11	"Reason for loan: To purchase livestock"
	label var	m3__98	"Reason for loan: Don't answer"
	label var	m3__97	"Reason for loan: Other"
	
	label var 	violence_ask "HH selected for Violence Module"
	label var	o1_b_1	"Source of conflict: Attacks by insurgents"
	label var	o1_b_2	"Source of conflict: Military operations"
	label var	o1_b_3	"Source of conflict: Violence instigated by local militias"
	label var	o1_b_4	"Source of conflict: Suicide attacks"
	label var	o1_b_5	"Source of conflict: Armed robbery"
	label var	o1_b__97	"Source of conflict: Other"
	label var	o1_b__98	"Source of conflict: Don't answer"
	label var	o1_b__99	"Source of conflict: Don't know"
	
	
/*********************************************************************************
* 6. Create raw roster datasets 
*********************************************************************************		
	
	**** ROSTERS 
	
	 * HH roster - only asking for # of HH members, male and female, children in R3 
	 hh_mem - numadult_m_calc
	 
	 * consumption 
	 c3 - c13_18_99_warning
	 
	 * labor / time use - not a roster really 
	 k5_1 - k30_1_m_99_warning
	
	* biz closure follow ups 
	k25 - k27__99
	
	* Livestock - over the past 3 years
	k6 - r44__99_4
	
	
	* credit - will be a panel
	m5_1 - m20_confirm_val
	
	* assets - mmm not sure if panel
	l1_a - l1_b

	* EMPOWERMENT QUESTIONS IN THIS ROUND!

*********************************************************************************
* 5. Drop roster variables 
*********************************************************************************/	
	
	

	
	* Save cleaned data  
	save "${phone_svy_clean_r3}", replace 
	
	
	 
	* Replace missings and Other  
	*mvdecode *, mv(-99 = .d / -98 = .r / -97 = .o / -96 = .n) */
	

	
	
	



