/*

UPDATE DESCRIPTION


	* Next stepts:
		- drop scto variables
		- drop roster variables that will be in separate datasets 
	


TPM corrections file (https://docs.google.com/spreadsheets/d/1lbZIIrRgJSY28fF4r3jh6fcwFitAoWkUoXhKxaxQhCw/edit?usp=sharing) for each round is saved here:
	Dropbox/TUP_Afghanistan/Data Collection/COVID survey ROUND/Quality Checks/Feedback Notes Cross Checked/AMMC Enumerator TPM Correction_ROUND#.xlsx

*/


* Inputs
global 	phone_svy_raw_r4 		"${TUP_DB}/Phone_Survey/DataSets/Deidentified/phone_svy_raw_nopii_r4.dta"
global 	profile_info 			"${TUP_DB}/Profile_and_merging/DataSets/Final/profile_info_nopii.dta"
global 	id_map					"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
global 	tpm_correction_r4		"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Quality Checks/Feedback Notes Cross Checked/AMMC Enumerator TPM Correction_R3.xlsx"
global  discrepancy_latest_r4	"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Quality Checks/Spotchecks/discrepancy_latest.dta"

* Outputs 
global  phone_svy_clean_r4		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r4.dta"


use "${phone_svy_raw_r4}", clear 

*********************************************************************************
* 1. Merge on fl1 hhid and other profile data 
*********************************************************************************	
	* Merge hhid mapping to get the follow-up ID   
	cap drop _m
	merge m:1 field_hhid using "${id_map}", keepusing(hhid) assert(2 3) keep(3) nogen   
	  
	* Merge with treatment status vars using follow-up ID   
	merge m:1 hhid using "${profile_info}", keepusing(treatment ultra_poor PRA_lottery) assert(2 3) keep(3) nogen   
	
	* Drop weird HHs with 0 consumption 
	drop if inlist(hhid,1412,5891)

	* Drop HHIDs with 0 consumption (weird)
	drop if inlist(hhid,1185,1637,1639,1412,5891,6405)
	
*********************************************************************************
* 2. Drop SCTO variables not pertaining to the survey --- UPDATE
*********************************************************************************	

	/* Keep previous survey completion flags just in case (incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete)
	
	keep date - a3_v incomplete_hh narc_complete ammc_r1_complete ammc_r2_complete hh_id hh_id_confirm corr_respondent - q7 date_a field_hhid village a5 hhid - tpm_correction */
	
	
	
	
*********************************************************************************
* 3. Apply 99/-99 corrections and high value corrections and save in Deidentified folder  
*********************************************************************************	

* For partial interveiws, compile the complete interview from 2 (or more) submissions  
	tab field_hhid if call_status == 2 
	
/* 99 flags 
c12_7_99_warning c13_1_99_warning c13_16_99_warning c13_17_99_warning c13_18_99_warning k38_99_warning k8_1_99_warning k8_2_99_warning k8_3_99_warning k8_4_99_warning k30_1_99_warning k30_1_m_99_warning earn_1_99_warning earn_2_99_warning earn_3_99_warning k32_1_99_warning k20_1_99_warning k20_2_99_warning migrant_remit_amt_99_warning m5_1_99_warning m5_2_99_warning m5_3_99_warning m20_1_99_warning m20_2_99_warning m20_3_99_warning m19_99_warning i4_d_99_warning */

	rename (know_pm_age_warning know_lhh_age_warning know_mem_age_warning k30_1_99_warning) (know_pm_age_99_warning know_lhh_age_99_warning know_mem_age_99_warning k30_1_earn_99_warning)

	local 99vars know_pm_age know_lhh_age know_mem_age c12_7 c13_1 c13_16 c13_17 c13_18 k38 k8_1 k8_2 k8_3 k8_4 k30_1_earn k30_1_m earn_1 earn_2 earn_3 k32_1 k20_1 k20_2 migrant_remit_amt m5_1 m5_2 m5_3 m20_1 m20_2 m20_3 i4_d
	
	destring `99vars', replace 

	foreach 99var in `99vars' {
		replace `99var' = `99var'_99_warning if inlist(`99var'_99_warning,-99,-98,1) // 0 = value entered; 1 = issues from pilot when everyone confirmed a mistake to move on 
	}
	
	* Sum 3-field variables again after 99/.99 correction is appleid to individual values [need to fix in pilot 1 since 99/.99 warnings were not implemented there] 
	 
	foreach var in m5 m20 k32 { 
		cap drop `var'_tot
		egen `var'_tot = rsum(`var'_1 `var'_2 `var'_3) 
		replace `var'_tot = . if mi(`var'_1) 
		drop `var' 
		rename `var'_tot `var' 
	} 
	
		order m5, after(m5_3)
		order m20, after(m20_3)
		order k32, after(k32_3)
		
	egen earn = rowtotal(earn_1 earn_2 earn_3), missing
	order earn, after(earn_3)
	
	local confirm_var c12_7 c13_1 c13_16 c13_17 c13_18 m5 m20 k38 k8_1 k8_2 k8_3 k8_4 k32 k20_1 k20_2
	 
	foreach confirm_var in `confirm_var' { 
		gen `confirm_var'_corr = `confirm_var'
			replace `confirm_var'_corr = `confirm_var'_confirm if `confirm_var'_confirm_val == 2 // if Value 2 is correct  
			label var `confirm_var'_corr "Var with correction for potentially high value" 
			order `confirm_var'_corr, after(`confirm_var') 
	} 
	
	
*********************************************************************************
* 4. TPM corrections from the Google Sheet
*********************************************************************************	

	preserve 

		* Import and reshape data with TPM corrections cross-checked by Abobaker for this round
		import excel using "${tpm_correction_r4}", firstrow clear 
			tostring hhid - other_8, replace 
			reshape long var_ tpm_correct_ other_, i(hhid) j(num)
			rename *_ *
			rename hhid field_hhid
			drop if mi(var)
			keep if tpm_correct == "yes" | mi(tpm_correct)
			replace var = strtrim(var)
			
			* fix var name for "_calc" vars and child sex issue with labels
			replace var = var + "_calc" if regexm(var,"schoolchild_") & !regexm(var,"_calc")
			
			local confirm_var c12_7 c13_1 c13_16 c13_17 c13_18 m5 m20 k38 k8_1 k8_2 k8_3 k8_4 k32 k20_1 k20_2

			foreach var in `confirm_var' {
				replace var = "`var'_corr" if var == "`var'"
			}

			* Make corrections to variable names so the merge with TPM values works 
			replace	var	=	"c3_a_seer_3"	if var ==	"c3_a_seer"		&	field_hhid	==	"T0026"
			replace	var	=	"m22"			if var ==	"m21"			&	field_hhid	==	"T0119"
			replace	var	=	"c3_a_seer_3"	if var ==	"c3_a_seer"		&	field_hhid	==	"T0167"
			replace	var	=	"c3_a_seer_3"	if var ==	"c3_a_seer"		&	field_hhid	==	"T0781"
			replace	var	=	"c3_a_seer_o_3"	if var ==	"c3_a_seer_o"	&	field_hhid	==	"T1002"
			replace	var	=	"l3_house_5"	if var ==	"l3_house"		&	field_hhid	==	"T1858"
			replace	var	=	"c5_a_milk_1"	if var ==	"c5_a_milk"		&	field_hhid	==	"T2430"

		* Merge on TPM values for variables where replacements will be made
			merge 1:1 field_hhid var using "${discrepancy_latest_r4}", keepusing(tpm_val) assert(2 3) keep(3) nogen
			
			* Create values for replacement 
			gen val = other
				replace val = tpm_val if tpm_correct == "yes"
				assert !mi(val)
				
			keep field_hhid var val
			
			reshape wide val, i(field_hhid) j(var) string
			rename val* *
			
			/* select_multiple and other strings in master data need to be a string, otherwise destring variables
					c3
					k30_m
					l1
					out_migration_push
					out_migration_push_loc
					out_migration
					m22
					g1_a
					i2_d
					f23
					x2 */
				qui ds
				local allvars `r(varlist)'
				local string_vars "field_hhid schoolchild_age_1_calc schoolchild_age_2_calc c3 k30_m l1	out_migration_push out_migration_push_loc out_migration m22	g1_a i2_d f23 x2"
				local numeric : list allvars - string_vars
				
				* Correct TPM typo
				replace x2 = "1 2 3 4" if x2 == "22314" 
			
				destring `numeric', replace 
			
			tempfile corrections
			save `corrections'

	restore

* Apply TPM corrections to the data 

	destring *, replace 
		merge 1:1 field_hhid using "`corrections'", update replace assert(1 5) gen (tpm_correction) // replace with non-missing values from TPM file

* For the select_multiple variables, we need to transfer the TPM corrections from the select_multiple string variables to the associated dummy variables
	* Approach for this is described in the first example (c3)
	* One thing to think about in the future is that if, e.g., surveyor missed a type of item consumed (as in c3), then all follow up questions on the 
		* item will be missing as well. Keep in mind.
	* Variables this is done for: c3 k30_m l1 out_migration_push out_migration_push_loc out_migration m22 g1_a i2_d f23 x2
		
		*** c3 
		* drop original dummies 
		drop c3_1 - c3__100
		* split the updated select_mutliple variable 
		split c3, destring gen(c3_)
		* recode negative codes to positive value so it also works as an index in the loop below 
		recode c3_1 - c3_5 (-100 = 100)
		
		foreach index of numlist 1/5 100 {
			* create dummies from the updated select_mutliple variable 
			egen 	c3_`index'_temp = anymatch(c3_?), values(`index')
				* correct for missing select_multiple variable (dummies created above have "0" instead of "." when c3 == ""; switch is back to ".")
			replace c3_`index'_temp = . if mi(c3)
		}
			* drop variables created by the split command and fix var names 
			drop c3_1 - c3_5
			rename *_temp *
			
			rename c3_100 c3__100
			
			* order 
			order c3_1 - c3__100, after(c3)
					
		*** k30_m 
		drop k30_m_1 - k30_m__98
		split k30_m, destring gen(k30_m_)
		recode k30_m_1 - k30_m_9 (-98 = 98)

		foreach index of numlist 0/9 98 {
			egen 	k30_m_`index'_temp = anymatch(k30_m_?), values(`index')
			replace k30_m_`index'_temp = . if mi(k30_m)
		}
		
			drop k30_m_1 - k30_m_9
			rename *_temp *
			
			rename k30_m_98 k30_m__98
			
			order k30_m_0 - k30_m__98, after(k30_m)
		
		*** l1
		drop l1_1 - l1__99
		split l1, destring gen(l1_)
		recode l1_1 - l1_18 (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/19 98 99 {
			egen	l1_`index'_temp = anymatch(l1_?), values(`index')
			replace l1_`index'_temp = . if mi(l1)
		}
	
			drop l1_1 - l1_18
			rename *_temp *
		
			rename (l1_98 l1_99) (l1__98 l1__99) 
			
			order l1_0 - l1__99, after(l1)
	
		*** out_migration_push
		drop out_migration_push_1 - out_migration_push__99
		split out_migration_push, destring gen(out_migration_push_)
		recode out_migration_push_1 out_migration_push_2 (-97 = 97) (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/2 97 98 99 {
			egen	out_migration_push_`index'_temp = anymatch(out_migration_push_?), values(`index')
			replace out_migration_push_`index'_temp = . if mi(out_migration_push)
		}
	
			drop out_migration_push_1 out_migration_push_2
			rename *_temp *
		
			rename (out_migration_push_97 out_migration_push_98 out_migration_push_99) ///
				(out_migration_push__97 out_migration_push__98 out_migration_push__99) 
				
			order out_migration_push_0 - out_migration_push__99, after(out_migration_push)
	
		*** out_migration_push_loc
		drop out_migration_push_loc_0 - out_migration_push_loc__98
		split out_migration_push_loc, destring gen(out_migration_push_loc_)
		recode out_migration_push_loc_1 out_migration_push_loc_2 (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/1 98 99 {
			egen	out_migration_push_loc_`index'_temp = anymatch(out_migration_push_loc_?), values(`index')
			replace out_migration_push_loc_`index'_temp = . if mi(out_migration_push_loc)
		}
	
			drop out_migration_push_loc_1 out_migration_push_loc_2
			rename *_temp *
		
			rename (out_migration_push_loc_98 out_migration_push_loc_99) ///
				(out_migration_push_loc__98 out_migration_push_loc__99) 
				
			order out_migration_push_loc_0 - out_migration_push_loc__99, after(out_migration_push_loc)
		
		*** out_migration
		drop out_migration_1 - out_migration__99
		split out_migration, destring gen(out_migration_)
		recode out_migration_1 out_migration_2 (-97 = 97) (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/2 97 98 99 {
			egen	out_migration_`index'_temp = anymatch(out_migration_?), values(`index')
			replace out_migration_`index'_temp = . if mi(out_migration)
		}
	
			drop out_migration_1 out_migration_2
			rename *_temp *
		
			rename (out_migration_97 out_migration_98 out_migration_99) ///
				(out_migration__97 out_migration__98 out_migration__99) 
			
			order out_migration_0 - out_migration__99, after(out_migration)
				
		*** m22
		drop m22_0 - m22__99
		split m22, destring gen(m22_)
		recode m22_1 m22_2 m22_3 (-97 = 97) (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/10 97 98 99 {
			egen	m22_`index'_temp = anymatch(m22_?), values(`index')
			replace m22_`index'_temp = . if mi(m22)
		}
	
			drop m22_1 m22_2 m22_3
			rename *_temp *
		
			rename (m22_97 m22_98 m22_99) (m22__97 m22__98 m22__99) 
			
			order m22_0 - m22__99, after(m22)
				
		*** g1_a
		drop g1_a_1 - g1_a_0
		split g1_a, destring gen(g1_a_)
		recode g1_a_1 - g1_a_14 (-97 = 97)
		
		foreach index of numlist 0/16 97 {
			egen	g1_a_`index'_temp = anymatch(g1_a_?), values(`index')
			replace g1_a_`index'_temp = . if mi(g1_a)
		}
	
			drop g1_a_1 - g1_a_14
			rename *_temp *
		
			rename g1_a_97 g1_a__97
			
			order g1_a_0 - g1_a__97, after(g1_a)
		
		*** i2_d
		drop i2_d_1 - i2_d__99
		split i2_d, destring gen(i2_d_)
		recode i2_d_1 - i2_d_4 (-97 = 97) (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/3 97 98 99 {
			egen	i2_d_`index'_temp = anymatch(i2_d_?), values(`index')
			replace i2_d_`index'_temp = . if mi(i2_d)
		}
	
			drop i2_d_1 - i2_d_4
			rename *_temp *
		
			rename (i2_d_97 i2_d_98 i2_d_99) (i2_d__97 i2_d__98 i2_d__99)
			
			order i2_d_0 - i2_d__99, after(i2_d)
		
		*** f23
		drop f23_1 - f23__99
		split f23, destring gen(f23_)
		recode f23_1 - f23_4 (-98 = 98) (-99 = 99)
		
		foreach index of numlist 0/4 98 99 {
			egen	f23_`index'_temp = anymatch(f23_?), values(`index')
			replace f23_`index'_temp = . if mi(f23)
		}
	
			drop f23_1 - f23_4
			rename *_temp *
		
			rename (f23_98 f23_99) (f23__98 f23__99)
			
			foreach index of numlist 0/4 {
				replace f23_`index' = .r if f23__98 == 1
				replace f23_`index' = .d if f23__99 == 1
			}
				
			order f23_0 - f23__99, after(f23)
		
		*** x2
		drop x2_1 - x2_0
		split x2, destring gen(x2_)
		
		foreach index of numlist 0/6 {
			egen	x2_`index'_temp = anymatch(x2_?), values(`index')
			replace x2_`index'_temp = . if mi(x2)
		}
	
			drop x2_1 - x2_5
			rename *_temp *
			
			order x2_0 - x2_6, after(x2)
			
		
*********************************************************************************
* 5. Other cleaning 
*********************************************************************************
forval i = 1/3  {
		label val v3_`i' v3_current
	}
	
	label var 	no_pm	"100 = No PM in HH [var needs to be looked at]"
	lab var consent_phone "Consented to mobile date module"
	label var v3_1 "Lady of the Household (Self)"
	label var v3_2 "Primary Man"
	label var v3_3 "Other household member"
	
	forval i = 1/3  {
		label var k24_`i'_3 "Primary female is Owner of a HH non-agricultural bussiness"
		label var k24_`i'_2 "Primary female is Manager of a HH non-agricultural bussiness"
		label var k24_`i'_1 "Primary female is Worker of a HH non-agricultural bussiness"
		label var k24_`i'_4 "Primary female Helps Occasionally in a HH non-agricultural bussiness"
		label var k24_`i'_0 "Primary female Do not participate in a HH non-agricultural bussiness"
	}
	
	label var k30_1 "Activity: Tend any animals owned or leased by the household"
	label var k30_2 "Activity: Farm land owned or sharecropped by the household"
	label var k30_3 "Activity: Work on business owned by household other than farm/animals"
	label var k30_9 "Activity: Work on household chores"
	label var k30_4 "Activity: Work as an agricultural laborer outside household"
	label var k30_5 "Activity: Do housework in someone else's home"
	label var k30_6 "Activity: Work as a non-agricultural laborer outside the household"
	label var k30_7 "Activity: Work in salaried/formal employment"
	label var k30_8 "Activity: Do any other work for pay"
	label var k30_0 "Activity: None"
	label var k30__98 "Activity: DA"
	
	label var k32	"Combined businesses revenues in the last 4 weeks"
	
	label var i2_d_0 "This level of education will help daughter: Will not help"
	label var i2_d_1 "This level of education will help daughter: Get job/earn money"
	label var i2_d_2 "This level of education will help daughter: Make him/her wiser"
	label var i2_d_3 "This level of education will help daughter: Enhance marriage prospects"
	label var i2_d__97 "This level of education will help daughter: Other"
	label var i2_d__98 "This level of education will help daughter: DA"
	label var i2_d__99 "This level of education will help daughter: DK"

	label var e6 "Allowed to go alone to meet friends or relatives in the village"
	
	label var 	out_migration_push_0 	"Member left HH ('push'): No one"
	label var 	out_migration_push_1 	"Member left HH ('push'): Conict/violence/security"
	label var 	out_migration_push_2 	"Member left HH ('push'): Lack of local economic opportunities"
	label var 	out_migration_push__97	"Member left HH ('push'): Other"
	label var 	out_migration_push__98 	"Member left HH ('push'): Don't answer"
	label var 	out_migration_push__99 	"Member left HH ('push'): Don't know"
	
	label var 	out_migration_push_loc_0 	"Moved to ('push'): Another part of Afghanistan"
	label var 	out_migration_push_loc_1 	"Moved to ('push'): Abroad to another country"
	label var 	out_migration_push_loc__98 	"Moved to ('push'): Don't answer"
	label var	out_migration_push_loc__99 	"Moved to ('push'): Don’t know"
	
	label var 	out_migration_1 	"Member left HH ('pull'): Work opportunities"
	label var 	out_migration_2 	"Member left HH ('pull'): Education opportunities"
	label var 	out_migration__97 	"Member left HH ('pull'): Other"
	label var 	out_migration_0 	"Member left HH ('pull'): None"
	label var 	out_migration__98 	"Member left HH ('pull'): Don't answer"
	label var 	out_migration__99 	"Member left HH ('pull'): Don't know"
	
	label var 	out_migration_location_afg_1 	"Moved to: Iran"
	label var 	out_migration_location_afg_2 	"Moved to: Pakistan"
	label var 	out_migration_location_afg__97 	"Moved to: Other"
	label var 	out_migration_location_afg__98 	"Moved to: Don't answer"
	label var 	out_migration_location_afg__99 	"Moved to: Don't know'"
	
	label var	z1_1	"LHH done activity: Open an account in a bank, a microfinance institution or join VSLA"
	label var	z1_2	"LHH done activity: Buy or register a SIM card"
	label var	z1_3	"LHH done activity: Vote in the last presidential election"
	label var	z1_4	"LHH done activity: Register land or property"
	label var	z1_5	"LHH done activity: Access health services"
	label var	z1_6	"LHH done activity: Receive assistance from the government "
	label var	z1_0	"LHH done activity: None of the above"

	label var	z4_1	"LHH used Tazkira for activity: Open an account in a bank, a microfinance institution or join VSLA"
	label var	z4_2	"LHH used Tazkira for activity: Buy or register a SIM card"
	label var	z4_3	"LHH used Tazkira for activity: Vote in the last presidential election"
	label var	z4_4	"LHH used Tazkira for activity: Register land or property"
	label var	z4_5	"LHH used Tazkira for activity: Access health services"
	label var	z4_6	"LHH used Tazkira for activity: Receive assistance from the government "
	label var	z4_0	"LHH used Tazkira for activity: Did not use my tazkira card"
	
	label var	z5_1	"Main reason for not having Tazkira: I applied but haven’t received it"
	label var	z5_2	"Main reason for not having Tazkira: I do not know how to apply"
	label var	z5_3	"Main reason for not having Tazkira: It costs too much to apply"
	label var	z5_4	"Main reason for not having Tazkira: I would need to travel too far to apply "
	label var	z5_5	"Main reason for not having Tazkira: The application process is too complicated"
	label var	z5_6	"Main reason for not having Tazkira: I need someone to go with me to apply"
	label var	z5_7	"Main reason for not having Tazkira: I don’t want to take or someone taking a picture of my face"
	label var	z5_0	"Main reason for not having Tazkira: I don’t need an ID"
	
	label var 	z6		"LHH Tazkira a paper card or the electronic Tazkira (e Tazkira)"
	label var 	z7		"PM Tazkira a paper card or the electronic Tazkira (e Tazkira)"
	
	label var 	am1		"Compared to the previous year, this year was your household able to save:"
	label var 	am2		"Difficulty getting a loan this year, compared to the previous year:"
	
	label var	m22_0	"Emergency loan source: I would not be able to get a loan"
	label var	m22_1	"Emergency loan source: Formal banks"
	label var	m22_2	"Emergency loan source: Microfinance institution"
	label var	m22_3	"Emergency loan source: Landlord"
	label var	m22_4	"Emergency loan source: Employer"
	label var	m22_5	"Emergency loan source: Relative"
	label var	m22_6	"Emergency loan source: Friend or neighbor"
	label var	m22_10	"Emergency loan source: Shopkeeper"
	label var	m22_7	"Emergency loan source: Khan, arbab, village or qawm leader "
	label var	m22_8	"Emergency loan source: ROSCA/chit fund/merry-go-round"
	label var	m22_9	"Emergency loan source: don't need a loan as I would use savings/sell an asset"
	label var	m22__97	"Emergency loan source: Other"
	label var	m22__98	"Emergency loan source: Don't answer"
	label var	m22__99	"Emergency loan source: Don’t know"

	label var	f23_1	"Sick HH member: You (LHH)"
	label var	f23_2	"Sick HH member: Primary Man"
	label var	f23_3	"Sick HH member: Other adults of the household"
	label var	f23_4	"Sick HH member: Children of the household"
	label var	f23_0	"Sick HH member: No one"
	label var	f23__98	"Sick HH member: Don't answer"
	label var	f23__99	"Sick HH member: Don’t know"
	
	label var	f25_1	"Reason did not seek care: Did not have permission to go"
	label var	f25_2	"Reason did not seek care: Could not find someone to accompany me"
	label var	f25_3	"Reason did not seek care: It was not serious enough"
	label var	f25_4	"Reason did not seek care: Could not afford the cost of visit"
	label var	f25_5	"Reason did not seek care: Did not find transport"
	label var	f25_6	"Reason did not seek care: The quality of the health care provider is poor"
	label var	f25_7	"Reason did not seek care: Were previously badly treated"
	label var	f25_8	"Reason did not seek care: Could not take time off work or had other commitments"
	label var	f25_9	"Reason did not seek care: Did not know where to go"
	label var	f25_10	"Reason did not seek care: Thought the facility was full"
	label var	f25_11	"Reason did not seek care: Were concerned about coronavirus exposure"
	label var	f25_12	"Reason did not seek care: Concerned about safety/security"
	label var	f25__97	"Reason did not seek care: Other"
	label var	f25__98	"Reason did not seek care: Don't answer"
	label var	f25__99	"Reason did not seek care: Don’t know"
	
	label var	x2_1	"Covid measure taken: Frequent hand washing"
	label var	x2_2	"Covid measure taken: Wearing a face mask"
	label var	x2_3	"Covid measure taken: Physical distancing (avoiding large gatherings, close contact)"
	label var	x2_4	"Covid measure taken: Staying home when you were sick or when you had a cold"
	label var	x2_5	"Covid measure taken: Reduce the number of times you go out"
	label var	x2_6	"Covid measure taken: Cancel travel plans"
	label var	x2_0	"Covid measure taken: None"

	label var	f6		"Has oldest child under 5 had diarrhea in the last 2 weeks?"
	label var 	x5		"Would you take the Covid vaccine is it were available?"
	
	label var has_daughter "HH has a daughter under 12 y/o"
	label var 	incomplete_hh "Type of R4 survey administered (Full or Short)"
	
	label define incomplete_hh_lab 1 "Full survey" 0 "Short survey"
	label val incomplete_hh incomplete_hh_lab
	
			
/*********************************************************************************
* 6. Create raw roster datasets 
*********************************************************************************		
	
	* HH roster - includes age and gender for children like R1
	hh_mem - numadult_calc
	
	* consumption 
	c3 - c13_18_99_warning
	
	* livestock -- some of this will be a panel
	k36 - k8_4_confirm_val
	
	* time use / labor - some of it is panel
	k5_1 - earn_3_99_warning
	
	* non ag biz - and role in biz -- this is a panel like in R1
	k23_a - k24_3_0
	
	* short crop income 
	k15 - k20_2_confirm_val
	
	* assets panel
	l1 - l3_house_19
	
	* migration
	in_migration - migrant_remit_amt_99_warning
	
	* loans - panel
	m5_1 - m20_confirm_val
	
	* shocks 
	g1_a - g3
	
	* schooling 
	age_learning_count - b15b_14
	
	* health...covid....tazkira...phone 

*********************************************************************************
* 5. Drop roster variables 
*********************************************************************************/	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	* Save cleaned data  
	save "${phone_svy_clean_r4}", replace 