/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	September 7, 2021
Last udpate on: November 1, 2021

Written by:  	Yulia Belyakova			

Revision: 		

********************************************************************************	

THIS DO FILE: 	This do-file creates a "profile" dataset for the phone survey.

It inlcudes all HHs surveyed in fl1 (2,495) and corresponding status from phone survey rounds if the HH was surveyed.
There are 2 status vars for each round:

	- call_status_r*: simplified call status with 4 categories
	       1 Complete
           2 Partial
           3 Refused
           4 Other (not surveyed)

	- detail_call_status_r*: detailed call status with 15 categories that can be referenced if detail on "other (not surveyed)" 
		from the simplified status is needed; the categories include
		
		   1 Complete interview
           2 Respondent does not know LHH
           3 Phone is permanently off
           4 Arabic / Turkmani / Uzbik-speaking HH
           5 HH moved form the area
           6 LHH is not available and cannot be replaced
           7 No answer
           8 No response after 7 contact attempts / Closed
           9 Partially complete interview (to follow-up)
          10 Partially complete interview (refused to continue)
          11 HH temporarily out of the area (can reach later)
          12 Refusal (no consent, picks up but refuses to talk)
          13 Rescheduled interview
          14 Number identified as valid - awaiting callback
          15 Same HH presumably listed under 2 IDs

Additionally, dataset includes flags for HHs that:
	
	- fl1_sample: HH in follow-up 1 analysis sample [2,495]
	- phone_fl1: reported having a phone at fl1 [2,022]
	- phone_anytime: reported ever having a phone [2,398]
	- phone_initial_sample: were verified by MISFA and were the starting point of the phone svy sample [2,150]
	- phone_verified: had a working phone number and verified household in at least one of the rounds [2,065];
		verified = complete, partial, refused, language, temporarily away
	- attrited HH (anyone who (1) reported having a phone at fl1 and (2) does not have a complete interview in either of R1/R2 (or both))
	
Other identifiers include:
	- pilot_r1: identifies HHs surveyed by NARC in pilot rounds (this is because the first pilot was done by them w/o Mohammad and was messy)
	- ramadan_r#: identifies HHs surveyed during Ramadan [mostly Round 3, with a handful in R1]
	- rand_treatment: is a random binary 0/1 indicator for UP HHs to use in lieau of the treatment indicator before the PAP is finalized 

		INPUTS:      	"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/phones_wide.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/all_phones_wide.dta" // 2150
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"
										
		OUTPUT: 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		

*******************************************************************************/

* Inputs

* TUP_Afghanistan Dropbox files
global  status_all_rounds 			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"
global	phones_wide     			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/phones_wide.dta"
global  all_phones_wide				"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/all_phones_wide.dta" // 2150
global 	id_map						"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey/Questionnaires/Electronic/Preloaded/hhid_mapping.dta"
global  status_all_rounds 			"${Dropbox}/TUP_Afghanistan/Data Collection/COVID survey R4/Inputs/LHH_hh_status_all_rounds.dta"

global 	profile_info 				"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"

global  data_for_analysis_fl1		"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
global  data_for_analysis_bl		"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"

global 	phone_svy_clean_r1			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_raw_r4 			"${TUP_DB}/Phone_Survey/DataSets/Deidentified/phone_svy_raw_nopii_r4.dta"

* Outputs 
global 	phone_svy_profile			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"


	use "${phones_wide}", clear  // 2,022 - report having a phone at fl1
		keep field_hhid 
		gen phone_fl1 = 1  
		label var phone_fl1 "Reported having a phone at fl1 (2022)" 
		merge 1:1 field_hhid using "${all_phones_wide}", force // merge on 2,150 - initial MISFA verification / collection; 376 of these are new (did not have a phone at fl1)
		tab _merge
		
		/*       _merge |      Freq.     Percent        Cum.
------------------------+-----------------------------------
        master only (1) |        248       10.34       10.34 - fl1 phones not verified by MISFA
         using only (2) |        376       15.68       26.02 - new phones collected by MISFA 
            matched (3) |      1,774       73.98      100.00 - fl1 phones verified by MISFA 
------------------------+-----------------------------------
                  Total |      2,398      100.00 
				  
		 (3) 1774 + (2) 376 = 2150 HHs that constitute initial NARC sample */
		 
		 gen phone_initial_sample = (_merge == 2 | _merge == 3) 
			label var phone_initial_sample "HH in initial R1 sample verified by MISFA (2150)"
			drop _merge

		keep field_hhid phone_fl1 phone_initial_sample
		gen phone_anytime = 1 // 2,398
		label var phone_anytime "Reported having a phone at any time (2398)"
	
	* Merge on fl1 HHID and fl1 data 
		merge m:1 field_hhid using 	"${id_map}", keepusing(hhid) assert(2 3) keep(3) nogen
		merge 1:1 hhid using 		"${profile_info}", keepusing(hhid PRA_lottery treatment ultra_poor pweight WealthRankingCategory_v pweight_CWR) nogen
		merge 1:1 hhid using 		"${data_for_analysis_fl1}", keep(1 3) gen(fl1_sample) keepusing(hhid)
		merge 1:1 hhid using 		"${data_for_analysis_bl}", keep(1 3) gen(bl_sample) keepusing(hhid)
		
		replace bl_sample = 0 if bl_sample == 1
		replace bl_sample = 1 if bl_sample == 3 
		label val bl_sample .
		label var bl_sample "Baseline analysis sample (2852)"
		
		replace fl1_sample = 0 if fl1_sample == 1
		replace fl1_sample = 1 if fl1_sample == 3 
		label val fl1_sample .
		label var fl1_sample "Follow-up 1 analysis sample (2495)"
		
		replace phone_fl1 = 			0 if mi(phone_fl1)
		replace phone_anytime = 		0 if mi(phone_anytime)
		replace phone_initial_sample = 	0 if mi(phone_initial_sample)
	
	* Merge on call status from all rounds [including non-Complete interviews, refusals, etc.]
	merge 1:1 hhid using "${status_all_rounds}", keepusing(narc - ammc_r3) nogen
	
	* Merge on Phone svy rounds [this is to check final call status for Complete and Partial interviews agianst that in the status_all_rounds data]
	merge 1:1 hhid using "${phone_svy_clean_r1}", keepusing(call_status pilot1_flag pilot2_flag date a2 a11 a11_o) nogen
		rename (call_status date a2 a11 a11_o) (call_status_r1 date_r1 enu_r1 a11_r1 a11_o_r1)
	merge 1:1 hhid using "${phone_svy_clean_r2}", keepusing(call_status date a2 a11 a11_o) nogen
		rename (call_status date a2 a11 a11_o) (call_status_r2 date_r2 enu_r2 a11_r2 a11_o_r2)
	merge 1:1 hhid using "${phone_svy_clean_r3}", keepusing(call_status date a2 a11 a11_o) nogen
		rename (call_status date a2 a11 a11_o) (call_status_r3 date_r3 enu_r3 a11_r3 a11_o_r3)
	merge 1:1 hhid using "${phone_svy_clean_r4}", keepusing(call_status date a2 a11 a11_o incomplete_hh) nogen
		rename (call_status date a2 a11 a11_o incomplete_hh) (call_status_r4 date_r4 enu_r4 a11_r4 a11_o_r4 survey_type_r4)

	tab narc 	call_status_r1, m // 1,736 + 7 partial = 1,743
	tab ammc_r1 call_status_r2, m // 1,671 + 2 partial = 1,672	
	tab ammc_r2 call_status_r3, m // 1,652
	tab ammc_r3 call_status_r4, m // 1,676 + 6 partial = 1,682
	
	* Simplify call status into 4 categories: Complete, Partial, Refused, Other (not surveyed)
	label define call_status 4 "Other (not surveyed)", modify 
	
	replace call_status_r1 = 3 if inlist(narc,12)
	replace call_status_r1 = 4 if !inlist(narc,1,9,10,12,.) 
	
	replace call_status_r2 = 3 if inlist(ammc_r1,12)
	replace call_status_r2 = 4 if !inlist(ammc_r1,1,9,10,12,.) 
		br if mi(call_status_r2) & ammc_r1 == 10 // T1711 has been IDed as partial, refused to continue in lastcall data, but it was really a language issue so categorize it as "Other"
	replace call_status_r2 = 4 if field_hhid == "T1711"
	
	replace call_status_r3 = 3 if inlist(ammc_r2,12)
	replace call_status_r3 = 4 if !inlist(ammc_r2,1,9,10,12,.) 

	replace call_status_r4 = 3 if inlist(ammc_r3,12)
	replace call_status_r4 = 4 if !inlist(ammc_r3,1,9,10,12,.) 
	
	* These variables have a "detailed" call tatus for the "Other (not surveyed)" call status category
	rename (narc ammc_r1 ammc_r2 ammc_r3) (detail_call_status_r1 detail_call_status_r2 detail_call_status_r3 detail_call_status_r4)
	order detail_call_status_r1 - detail_call_status_r4, after(call_status_r4)
	
	forval i = 1/4 {
		label var call_status_r`i'		  "Round `i' call status"
		label var detail_call_status_r`i' "Round `i' call status detail for 'Other (not surveyed)' category"
		label var enu_r`i' 				  "Round `i' enumerator"
		label val enu_r`i' .
		label var date_r`i'				 "Round `i' survey date"
	}
	
	* Generate HH with "verified" phone flag [verified = complete, partial, refused, language, temporarily away]
	egen phone_verified = anymatch(call_status_r*), values(1 2 3)
		tab phone_verified // 2063, not 2065; the discrepancy is due to T1711 being re-categorized from partial to not surveyed, and one other
		tempvar phone_verified_temp
		egen `phone_verified_temp' = anymatch(detail_call_status_r*), values(4 11)
		replace phone_verified = `phone_verified_temp' if `phone_verified_temp' == 1 & phone_verified != 1
		assert !mi(phone_verified)
		tab phone_verified
		label var phone_verified "HH with a verified phone in at least one round (2065)"
		
	* Recreate the variable for just R1 / R2; it is used to calculate respose (consent) rate response_r1_r2
		egen phone_verified_r1_r2 = anymatch(call_status_r1 call_status_r2), values(1 2 3)
		tab phone_verified_r1_r2
		tempvar phone_verified_temp
		egen `phone_verified_temp' = anymatch(detail_call_status_r1 detail_call_status_r2), values(4 11)
		replace phone_verified_r1_r2 = `phone_verified_temp' if `phone_verified_temp' == 1 & phone_verified_r1_r2 != 1
		assert !mi(phone_verified_r1_r2)
		tab phone_verified_r1_r2
		label var phone_verified_r1_r2 "HH with a verified phone in round 1 or 2 (1977)"
		
	* Create this variable for each individual round 	
	forval i = 1/4 {	
		egen phone_verified_r`i' = anymatch(call_status_r`i'), values(1 2 3)
		tab phone_verified_r`i'
		tempvar phone_verified_temp_r`i'
		egen `phone_verified_temp_r`i'' = anymatch(detail_call_status_r`i'), values(4 11)
		replace phone_verified_r`i' = `phone_verified_temp_r`i'' if `phone_verified_temp_r`i'' == 1 & phone_verified_r`i' != 1
		assert !mi(phone_verified_r`i')
		tab phone_verified_r`i'
		label var phone_verified_r`i' "HH with a verified phone in round `i'"
	}
	
	* Clean pilot flags for NARC round
	gen pilot_r1 = 1 if pilot1_flag == 1 
		replace pilot_r1 = 2 if pilot2_flag == 1
		label define pilot 1 "NARC pilot 1" 2 "NARC pilot 2"
		label val pilot_r1 pilot 
		label var pilot_r1 "HH surveyed in R1 (NARC) pilot"
		drop pilot1_flag pilot2_flag
	
	** Attrition
	
	egen round_1_or_2 = anymatch(call_status_r1 call_status_r2), values(1 2)
	replace round_1_or_2 = 0 if inlist(hhid,5196,1637,1662,2184,6119) // HHs dropped in cleaning files due to 0 total consumption, which is a quality issue 
	label var round_1_or_2 "HH surveyed in R1 or R2"
	
	* Define attrited HHs [counting Complete AND Partial interviews]
	* Follow-up 1 and baseline attrition 
	
	foreach round in "fl1" "bl" {
	
		forval i = 1/4 {
			gen attrition_`round'_r`i' = .
		}
		
		forval i = 1/4 {
			replace attrition_`round'_r`i' = 0 if `round'_sample == 1
			replace attrition_`round'_r`i' = 1 if `round'_sample == 1 & !inlist(call_status_r`i',1,2)
		}
		
		gen attrition_`round'_r1_or_r2 = .
			replace attrition_`round'_r1_or_r2 = 0 if `round'_sample == 1
			replace attrition_`round'_r1_or_r2 = 1 if round_1_or_2 == 0 & `round'_sample == 1
			
		* Drop bad quality HHs in R1, R3, R4
		replace attrition_`round'_r1 = 1 if inlist(hhid,5196,1637,1662,2184,6119)
		replace attrition_`round'_r1_or_r2 = 1 if inlist(hhid,5196,1637,1662,2184,6119)
		replace attrition_`round'_r3 = 1 if inlist(hhid,1100,1146,1206,1582,1592,1612,1617,1630,1639,2053,2184,5264,6611)
		replace attrition_`round'_r4 = 1 if inlist(hhid,1185,1637,1639,1412,5891,6405)
	}

	forval i = 1/4 {
		label var attrition_fl1_r`i' "Round `i' attrition (from endline 1,147 UP)"	
		label var attrition_bl_r`i' "Round `i' attrition (from baseline 1,173 UP)"	
	}
		
		label var attrition_fl1_r1_or_r2 "Round 1 or 2 attrition (from endline 1,147 UP)"	
		label var attrition_bl_r1_or_r2 "Round 1 or 2 attrition (from baseline 1,173 UP)"	

	* Anyround 
	egen anyround = anymatch(call_status_r*), values(1 2) 
	replace anyround = 0 if inlist(hhid,5196,1637,1662,2184,6119) /// 
			| inlist(hhid,1100,1146,1206,1582,1592,1612,1617,1630,1639,2053,2184,5264,6611) /// 
			| inlist(hhid,1185,1637,1639,1412,5891,6405) // HHs dropped in cleaning files due to 0 total consumption, which is a quality issue  
		label var anyround "HH surveyed in at least 1 phone survey round" 
		
	egen anyround_test = rowtotal(attrition_fl1_r1 attrition_fl1_r2 attrition_fl1_r3 attrition_fl1_r4), missing 
		tab anyround_test
		tab anyround anyround_test
		
		* If a HH is only missing in 1 or 2 of the 4 rounds, put it back (except 3 HHs that we remove in more than 1 round)
		replace anyround = 1 if inlist(anyround_test,1,2) //& !inlist(hhid,1637,1639,2184) - do not overcomplicate 
		drop anyround_test
		
		tab anyround, m
		
	gen no_round = -(anyround - 1)
		label var no_round "HH not surveyed in ANY round (overall, 1,147 UP)"
				
		
	* Attrition in ANY round 
	foreach round in "fl1" "bl" {
		gen attrition_`round'_anyround = .
		
		replace attrition_`round'_anyround = 0 if `round'_sample == 1
		replace attrition_`round'_anyround = 1 if `round'_sample == 1 & anyround == 0
		}
		
	* Rename fl1 attition variables so they don't need to be changed in all the do-files	
	rename 	attrition_fl1_* attrition_*
		
	tab attrition_r1 // 752 of 2495
	tab attrition_r2 // 861 of 2495
	tab attrition_r1_or_r2 // 646 of 2495
	
	* HHs surveyed in ALL rounds 
	gen all_rounds = (attrition_r1 == 0 & attrition_r2 == 0 &  attrition_r3 == 0 &  attrition_r4 == 0)
		lab var all_rounds "HH surveyed in all rounds"
		
	* Response (consent) rate in R1/R2 
	gen response_r1_r2 = (1-attrition_r1_or_r2)/phone_verified_r1_r2
		sum response_r1_r2 if ultra_poor == 1 
		lab var response_r1_r2 "Response rate in round 1 or 2 (out of verified phones in those rounds)"

	* Response (consent) rate in any (at least one) round 
	gen response_anyround = (anyround)/phone_verified
		sum response_anyround if ultra_poor == 1 
		lab var response_anyround "Response rate in any round (out of verified phones in all rounds)"
		
	* Response (consent) rate in ALL rounds 
	gen response_allrounds = (all_rounds)/phone_verified
		sum response_allrounds if ultra_poor == 1 
		lab var response_allrounds "Response rate in ALL rounds (out of verified phones in all rounds)"		
	
	* Response rates for R1/R2:
		* Out of the in-person fl1 sample 
	gen response_overfl1_r1_r2 = round_1_or_2/fl1_sample
		lab var response_overfl1_r1_r2 "R1/R2 response rate over fl1 sample"
		* Out of the 2150 phones verified and added by MISFA in the initial round 
	gen response_overmisfa_r1_r2 = round_1_or_2/phone_initial_sample
		lab var response_overmisfa_r1_r2 "R1/R2 response rate over MISFA verified numbers"
		
	* Response rates for any round:
		* Out of the in-person fl1 sample 
	gen response_overfl1_anyround = anyround/fl1_sample
		lab var response_overfl1_anyround "Any round response rate over fl1 sample"
		* Out of the 2150 phones verified and added by MISFA in the initial round 
	gen response_overmisfa_anyround = anyround/phone_initial_sample
		lab var response_overmisfa_anyround"Any round response rate over MISFA verified numbers"
	
	* Response (consent) rates for each round 
	forval i = 1/4 {
	    gen response_r`i' = (1-attrition_r`i')/phone_verified_r`i'
		sum response_r`i' if ultra_poor == 1 
		lab var response_r`i' "Response rate in round `i' (out of verified phones in those rounds)"
	}
	
	* Response (consent) rate among the "extra" (= Full Survey) and the rest ("Short survey) HHs in R4
	* It's weird that we are missing survey_type_r4 for a few HHs, so quickly calculate it here:
	replace survey_type_r4 = 1 if phone_verified_r4 == 1 & mi(survey_type_r4) &  (attrition_r1 == 1 | attrition_r2 == 1 | attrition_r3 == 1) // 17 changes
	replace survey_type_r4 = 0 if phone_verified_r4 == 1 & mi(survey_type_r4) &  (attrition_r1 == 0 & attrition_r2 == 0 & attrition_r3 == 0) // 9 changes

	
	foreach suffix in "short" "full" {
	    if "`suffix'" == "short" {
			local i 0    
			local j 1
		}
		if "`suffix'" == "full" {
			local i 1
			local j 0
		} 
		
	    gen response_r4_`suffix' = response_r4 if survey_type_r4 == `i'
		sum response_r4_`suffix' if ultra_poor == 1 
		lab var response_r4_`suffix' "Response rate in round 4 (`suffix' survey) (out of verified phones in those rounds)"
	}

	* Ramadan flag [this is mostly for R3, but there are a handful of HHs in R1 that fell in Ramadan]
		tempvar ramadan_begin
		gen `ramadan_begin' = date("12apr2021", "DMY")
		
		tempvar ramadan_end
		gen `ramadan_end' = date("12may2021", "DMY")
		
		forval i = 1/4 {
			gen ramadan_r`i' = 0
			replace ramadan_r`i' = 1 if inrange(date_r`i',`ramadan_begin',`ramadan_end') 
			label var ramadan_r`i' "Round `i' collected during Ramadan (Apr 12 - May 12)"
		}
		
	* Get district and village vars
	preserve 
		forval round = 1/4 {
			use "${phone_svy_clean_r`round'}", clear 
				keep hhid a5 village
				rename village a6
				label drop a5_lab
				tempfile loc_`round'
				save `loc_`round''
		}
			append using "`loc_2'"
			append using "`loc_3'"
			append using "`loc_1'"
			
			duplicates drop
			
			tempfile loc_all
			save `loc_all'
	restore 
	
	merge 1:1 hhid using "`loc_all'", assert(1 3)
		cap noi assert _merge == 1 if no_round == 1 // 2 HHs partially complete (refused to contunie) - so not counted as surveyed 
		drop _merge 
		
	* Create a random variable in lieau of the treatment indicator to use before finalizing the PAP
	set seed 1234567
	gen rand_treatment = uniform() < .5 if ultra_poor == 1 
	label var rand_treatment "Random binary variable in lieau of the treatment indicator"
	
	* Order vars 
	order PRA_lottery - pweight_CWR, last
	order field_hhid hhid fl1_sample attrition* phone_anytime phone_fl1 phone_initial_sample phone_verified anyround no_round pilot_r1 date_r*, first
	order enu*, after(detail_call_status_r4)
	
	gsort -field_hhid 
	cap drop __00000*
	stop
	
	* Save data
	save "${phone_svy_profile}", replace
	
	