/* HH roster and child schooling 

	1. Round 1 roster prep
		For pilot 1, we only have the total number of HH members (hh_mem) and number of school-aged children (schoolchild)
		For pilot 2, we have detailed info on sex (child_sex) for up to 5 children [we did not ask for child age detail in the pilot]
		
		At some point post-pilot, we have: 
			Number of HH members (hh_mem)
			Number of children under 18 (numchild)
			Age of children (child_age)
			Sex of children (child_sex)
			
		Schooling qestions include:
			Enrollment (x6)
			Main reason for no enrollemnt (b15b)
			Missing exams (x7a)

	2. Round 2 roster prep
			Number of HH members (hh_mem)
		
	3. Round 3 roster prep
			Number of HH members (hh_mem)
			Number of children under 18 (numchild)
			Number of adults over 18 (numadult)
			Number of female adults over 18 (numadult_f)
		
	4. Round 4 roster prep
			Number of HH members (hh_mem)
			Number of children under 18 (numchild)
			Age of children (child_age)
			Sex of children (child_sex)		
			
		Schooling qestions include:
			Enrollment (x6)
			Main reason for no enrollemnt (b15b)
	
	5. Compile panel data
		Data are appended as a panel, although it is a panel mostly for consistency checks across rounds.
		
	6. Minor cleaning
	
	
	Questions & Issues: 
	
		1. Issue with number of children in Round 4. It appears that in a few instanes (27 HHs) there is an extra repeat group for child sex and age.
		This likely happened when the number of children in numchild question was revised down, though it is weird that there is almost always info
		for exactly one more extra child (sometimes 2).
		
		Potention solution [TBD]:
			(1) rely on numchild question and remove the last child extra info was entered for OR
			(2) revise numchild and hh_mem based on the info entered in the child age/sex roster 
			
		2. A note on schooling questions:
			x6 in R1 is asked about enrollment when schools were open in October 2020 ("was child enrolled in school when schools reopened
				in October (Meezaan)?") since schools were closed at the time of R1
			x6 in R4 is asking for current enrollment ("is child currently enrolled?), since schools were open at the time of R4 
			
		3. In Round 1, 6 HHs are missing "no_pm" flag (likely a SCTO issue). We get it from Rescheduled attempts in the raw data.
			
*/

* Inputs 
global 	phone_svy_raw_r1_pilot		"${TUP_DB}/Phone_Survey/DataSets/Deidentified/phone_svy_raw_nopii_r1_pilot.dta" // roster was collected differently in the pilot
global 	phone_svy_clean_r1			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r3 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"      		
global 	roster_final_fl1            "${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1"		
global 	all_HH_nopii_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
global  phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* Outputs
global 	roster						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"


*********************************************************************************
* Round 1 [pilot and rest of data]
*********************************************************************************
* First, pilot:
*	For pilot 1, we only have the total number of HH members and number of school-aged children
* 	For pilot 2, we have detailed info on sex for up to 5 children [we did not ask for child age detail in the pilot]

use "${phone_svy_raw_r1_pilot}", clear 

	keep field_hhid hhid pilot1_flag pilot2_flag hh_mem - child_sex_5 no_pm
	
	destring *_calc no_pm, replace 
	replace hh_mem_calc = hh_mem if mi(hh_mem_calc)
	replace schoolchild_calc = schoolchild if mi(schoolchild_calc)
	
	drop hh_mem hh_mem_o numchild numchild_o numchild_girls_o numchild_girls schoolchild schoolchild_o child_sex_gr_count child_sex_id_*
	
	preserve 
		keep field_hhid hhid child_sex_1 - child_sex_5
		
		reshape long child_sex_, i(hhid) j(childnum)
		rename *_ *
		
		drop if mi(child_sex)
		
		* child_sex is 0 = Male, 1 = Female; record to match rest of data where 1 = Male, 2 = Female
		recode child_sex (1=2) (0=1)
		
		tempfile child_deetail_r1_pilot
		save `child_deetail_r1_pilot'
	restore 
	
	merge 1:m field_hhid using "`child_deetail_r1_pilot'", nogen
	
	* we collected child sex for up to 5 kids in pilot 2
	assert !mi(child_sex) if pilot2_flag == 1 & schoolchild_calc > 0
	
	drop child_sex_*
	
	rename *_calc *

	gen round = 1
	 
	tempfile roster_r1_pilot
	save `roster_r1_pilot'

* Now, the main R1 data 

use "${phone_svy_clean_r1}", clear 

* HH roster - for children's age
	keep field_hhid hhid call_status pilot1_flag pilot2_flag hh_mem - child_sex_15 no_pm
	 
	destring *_calc no_pm, replace 
	replace hh_mem_calc = hh_mem if mi(hh_mem_calc)
	*tabmiss numchild_calc // 34 missing 
	
	drop child_sex_gr_count child_sex_id_* child_sex_id_* hh_mem hh_mem_o numchild numchild_o numchild_girls_o schoolchild_o
	 
	rename *_calc *
	
	preserve 
		keep field_hhid hhid child_age_1 - child_sex_15
		
		reshape long child_sex_ child_age_, i(hhid) j(childnum)
		rename *_ *
		
		drop if mi(child_age) & mi(child_sex)
		
		* child_sex is 0 = Male, 1 = Female; record to match rest of data where 1 = Male, 2 = Female
		recode child_sex (1=2) (0=1)
		
		tempfile child_deetail_r1
		save `child_deetail_r1'
	restore 
	
	merge 1:m field_hhid using "`child_deetail_r1'", nogen
	
	drop child_age_* child_sex_*
	
	gen round = 1
	
	* Drop pilot1 observations since these will be merged on from the pilot data (procesed above)
	drop if pilot1_flag == 1
	
	* In Round 1, 6 HHs are missing "no_pm" flag. We get it from Rescheduled attempts in the raw data where this info was recorded.
	* From "${mounted}/EncryptedData/Phone_Survey_R1/Raw Identified Data/LHH_Phone_Survey_R1_raw.dta"
	replace no_pm = 0 if inlist(field_hhid,"T1580","T0300","T0728","T1780","T0384","T1886")

	tempfile roster_r1
	save `roster_r1'

	 
*********************************************************************************
* Round 2: Asking for # of HH members
*********************************************************************************	
	
use "${phone_svy_clean_r2}", clear 
	
	 keep field_hhid hhid call_status hh_mem_calc no_pm
	 rename *_calc * 
	 
	 destring no_pm, replace 
	
	 * For 6 HHs, roster is inexplicably missing and data starts with consumption [checked in raw data]
	 list field_hhid if mi(hh_mem)
	  
	 gen round = 2
	 
	 tempfile roster_r2
	 save `roster_r2'
	 
	 
*********************************************************************************
* Round 3: Asking for # of HH members, male and female, and # of children
*********************************************************************************	 
	 
use "${phone_svy_clean_r3}", clear 

	 keep field_hhid hhid call_status hh_mem_calc numchild_calc numadult_calc numadult_f_calc numadult_m_calc no_pm
	 rename *_calc * 
	 
	 destring no_pm, replace
	 
	 assert hh_mem == numchild + numadult
	 assert numadult == numadult_f + numadult_m
	 
	 * For 6 HHs, roster is inexplicably missing and data starts with consumption [checked in raw data]
	 list field_hhid if mi(hh_mem) 
	 
	 gen round = 3
	 
	 tempfile roster_r3
	 save `roster_r3'
	 
		
*********************************************************************************
* Round 4: includes age and gender for children like R1
*********************************************************************************	 
	 
use "${phone_svy_clean_r4}", clear 	 
	 
	 keep field_hhid hhid call_status hh_mem - numadult_calc no_pm
	 
	 * hhh_head is missing (not asked) when there was only one adult HH member (by default, the HHH)
	 * T0186 is missing all roster data, so hhh_head is also missing 
	 replace hhh_head = 1 if mi(hhh_head) & numadult == 1 
	 
	 * T0186 is missing roster section for some inexplicable reason (checked in raw data too)
	 cap noi assert !mi(numadult)
	 list field_hhid if mi(numadult)
	 
	  * We will work with the labels (_calc) because these are the ones with TPM corrections
	 rename (schoolchild_sex_*_calc schoolchild_age_*_calc) (schoolchild_sex_calc_* schoolchild_age_calc_*)
	 destring schoolchild_age_calc_* no_pm, replace 
	 
	 forval i=1/20 {
	     * Child age
		cap noi replace schoolchild_age_calc_`i' = "0" if schoolchild_age_calc_`i' == "کمتر از یک سال" | schoolchild_age_calc_`i' == "یو کال څخه لږ" // under a year 
		cap noi replace schoolchild_age_calc_`i' = "-99" if schoolchild_age_calc_`i' == "نمی داند" | schoolchild_age_calc_`i' == "نه پوهیږم" // DK 
		destring schoolchild_age_calc_`i', replace 
		
		* Child sex
		cap noi replace schoolchild_sex_calc_`i' = "1" if schoolchild_sex_calc_`i' == "مرد" | schoolchild_sex_calc_`i' == "نارینه" // male
		cap noi replace schoolchild_sex_calc_`i' = "2" if schoolchild_sex_calc_`i' == "زن" | schoolchild_sex_calc_`i' == "ښځینه" // female 
		destring schoolchild_sex_calc_`i', replace 
	 }
	 
	 drop child_sex_gr_count - has_daughter hh_mem hh_mem_o numchild numchild_o numadult numadult_o
	 rename schoolchild_sex_calc_* child_sex_*
	 rename schoolchild_age_calc_* child_age_*
	 rename *_calc *
	 
	 order numadult, after(numchild)
	 assert hh_mem == numchild + numadult
	 
	 cap noi assert !mi(hh_mem) // still T0186, inexplicably missing all roster data 
	 
	 reshape long child_sex_ child_age_, i(hhid) j(childnum)
	 rename *_ *
	 
	 drop if mi(child_sex) & numchild > 0 & !mi(numchild)
	 
	 * Check that we have information on sex and gender of the reported number of children in the HH 
	 tempvar child
	 bys hhid: gen `child' = _N
	 cap noi assert `child' == numchild
	 unique hhid if `child' != numchild
	 * It appears that in a few instanes (27 HHs) there is an extra repeat group for child sex and age. This likely happened when the number of
		* children in numchild question was revised down, though it is weird that there is almost always info for exactly one more extra child (sometimes 2).
	 tempvar childiff
	 gen `childiff' = `child' - numchild
	 tab `childiff'

	 * Potention solution [TBD]: (1) rely on numchild question and remove the last child extra info was entered for OR
		*(2) revise numchild and hh_mem based on the info entered in the child age/sex roster 
		
	 gen round = 4
	 
	 tempfile roster_r4
	 save `roster_r4'
	 

*********************************************************************************
* Child schooling in R1 and R4 [this is only asked of school-aged children]
*********************************************************************************
	use "${phone_svy_clean_r1}", clear 
	
		keep field_hhid hhid call_status pilot1_flag pilot2_flag age_learning_count - x7a_18
		
		drop age_learning_count child_id_* schoolchild_sex_lab_* schoolchild_age_lab_*
		
		reshape long x6_ b15b_ x7a_, i(hhid) j(childnum)
		rename *_ *
			
		* A little unexplained missingness in x6, it should be 0 when b15b is asked 
		replace x6 = 0 if !mi(b15b)
		drop if mi(x6)
		
		gen round = 1 
		
		tempfile schooling_r1
		save `schooling_r1'
		
	use "${phone_svy_clean_r4}", clear 
		keep field_hhid hhid call_status age_learning_count - b15b_14
		
		drop age_learning_count child_id_* schoolchild_sex_lab_* schoolchild_age_lab_*
		
		reshape long x6_ b15b_, i(hhid) j(childnum)
		rename *_ *
		
		* A little unexplained missingness in x6, it should be 0 when b15b is asked 
		replace x6 = 0 if !mi(b15b)
		drop if mi(x6)
		
		gen round = 4
		
		tempfile schooling_r4
		save `schooling_r4'
	

*********************************************************************************
* Merge and append rounds 
*********************************************************************************	
	
* Start with R1 pilot data  
use "`roster_r1_pilot'"
	
	* Work out issues with merging on schooling details for R1 pilot 1:
	
	* We have the number of school children, but no sex and gender. We need to expand the data 
	* based on the number of school children for the merge on HHID childnum to work.
	
	expand schoolchild if pilot1_flag == 1
	
	* Get childnum variable from the R1 schooling data 
	preserve 
		use "`schooling_r1'", clear
			keep field_hhid pilot1_flag childnum
			keep if pilot1_flag == 1
				
			tempfile schooling_pilot
			save `schooling_pilot'
	restore
	
	* Merge childnum from R1 schooling data onto pilot roster (should be master only (_m=1) and missing updated (_m=4))
	merge m:m field_hhid using "`schooling_pilot'", assert(1 4) update nogen

	* Now we are ready to proceed with the rest of the merging 
	* Merge on the rest of R1 (post-pilot data)
	merge 1:1 hhid childnum using "`roster_r1'", update replace nogen

	* Merge child schooling for R1
	merge 1:1 hhid childnum round using "`schooling_r1'", update replace nogen
	
	* Append R2, R3 and R4
	append using "`roster_r2'"
	append using "`roster_r3'"
	append using "`roster_r4'"
	
	* Merge child schooling for R4
	* We cannot really be sure that the children are in the same order... in fact, they 
	* most likely are not. So we should never treat this as a panel.
	merge 1:1 hhid childnum round using "`schooling_r4'", keepusing(x6 b15b) update assert(1 4)  nogen 

	* Label
	label var childnum 			"Child #"
	label var hh_mem 			"Including yourself, how many members are there in your household?"
	label var numchild 			"How many of these are children (18 years old or less)?"
	label var numadult 			"How many of these are adults (18 years old or more)?"
	label var numadult_f 		"How many of these adults are women?"
	label var numadult_m 		"How many of these adults are men?"
	label var child_sex 		"Is the child male or female?"
	label var numchild_girls 	"How many of these children are girls?"
	label var child_age 		"How old is the child? In years."
	label var x6 				"Is the child currently enrolled in school?"
	label var b15b 				"Main reason child is not enrolled in school"
	label var x7a 				"When students had to sit for exams, did the child miss any exams?"
	label var round 			"Phone survey round"
	label var no_pm				"100 if no PM in HH"
	
	label define sex 1 "Male" 2 "Female"
	label val child_sex sex
	label drop asset_l
	
	* Drop weird variables
	cap drop drop __000000 __000001
	
	* Drop variables we don't need
	drop field_hhid
	
	* Sort
	sort hhid round childnum
	
	* Order 
	order hhid pilot1_flag pilot2_flag round call_status, first
	order hhh_head hhh_head_lhh hh_mem numadult numadult_f numadult_m numchild numchild_girls schoolchild childnum child_sex child_age, after(call_status)
	
	* Checking for (in)consistency between rounds and fl1 in HH size and whether there is a PM or not
	preserve 
		use "${roster_final_fl1}", clear 
		* Keep only HHs surveyed in the phone survey 
		merge m:1 hhid using "${phone_svy_profile}", keep(3)
		keep if anyround == 1 
		
		keep hhid b3 hh_only_pf
		rename b3 hh_mem
		duplicates drop
		gen round = 0
				
		tempfile fl1_hhsize
		save `fl1_hhsize'
	restore 
	
preserve	
	append using "`fl1_hhsize'"
		
	keep hhid round hh_mem no_pm hh_only_pf
	duplicates drop 
	
	* Calculate HH size "round-over-round (ROR) variance" across rounds 
	bys hhid (round): gen hh_mem_var = hh_mem[_n]/hh_mem[_n - 1] - 1
	* For HHs surveyed only once, we cannot calculate the "ROR variance"
	bys hhid: gen n = _N
	replace hh_mem_var = 0 if n == 1 
	sum hh_mem_var, d
	
/*                          hh_mem_var
-------------------------------------------------------------
      Percentiles      Smallest
 1%       -.5625      -.9090909
 5%         -.25            -.9
10%    -.1428571      -.8095238       Obs               6,686
25%            0            -.8       Sum of Wgt.       6,686

50%            0                      Mean            .095924
                        Largest       Std. Dev.      .5880437
75%     .0714286              9
90%          .25             10       Variance       .3457953
95%           .6             10       Skewness       10.73372
99%     2.333333             17       Kurtosis       188.2914 */

	
	* Check what happens with the Primary Man	
	recode no_pm (100 = 1)
	replace no_pm = hh_only_pf if round == 0

	bys hhid (round): gen no_pm_var = no_pm[_n]/no_pm[_n - 1] - 1
	* For HHs surveyed only once, we cannot calculate the "ROR variance"
	bys hhid (round): gen n_round = _n
	replace no_pm_var = 0 if (n == 1 | n_round > 1) & mi(no_pm_var)
	sum no_pm_var, d
	
	br if inlist(hhid,1129,1186,1238,1003,1009,1010,1019)

	collapse (sum) no_pm_var, by(hhid)
	tab no_pm_var // 19% or 359 of HHs switched PM status in one of the 5 surveys (incl. fl1)
restore
	
	* Save data 
	save "${roster}", replace 
	 	
		
		
		
		
		
		
		
		
		

	 
	 
	 
	 