/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	October 15, 2021
Last udpate on: 
Written by:  	Yulia Belyakova		

Revision: 		

********************************************************************************	

THIS DO FILE: 	Cleans outliers for Total savings (m20) and Total loans (m5) variables.
				Do-file runs within "all_hhlevel_phonesvy.do".

*/

global  all_HH_nopii_fl1			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
global  current_roster_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"

* 0. Prepare the dataset by adding missing variables 
	* Get number of HH members to calculate per capita loans for phone survey R1
	preserve
		use "${roster_phonesvy}", clear
		keep if round == 1 
		keep hhid hh_mem numchild schoolchild round
		gen numadult = hh_mem - numchild // in R1, we do not ask for the number of children in the pilot but for the number of school children 
			replace numadult = hh_mem - schoolchild if mi(numadult)
		replace numchild = schoolchild if mi(numchild)
		duplicates drop hhid round, force
		
		tempfile hh_mem
		save	`hh_mem'
	restore
	
	merge m:1 hhid using `hh_mem', keepusing(hh_mem numadult numchild) nogen
	
	* Gen HHsize - per adult equivaleng
		gen HHsize = 0.5*numchild + numadult
		* replace with total HH size in case missing the child / adult split 
		replace HHsize = hh_mem if mi(HHsize)

	* Add UP and treatment variables for correct comparisons 
	merge m:1 hhid using "${all_HH_nopii_fl1}", keepusing(ultra_poor treatment) keep(3) nogen
	
	

* I. Savings - follow simple rules from fl1 [5 values are flagged as outliers]

* Defining as outlier any value that is more than 100 000, 4 observations in total
	replace m20 = .o if m20 > 100000 & !mi(m20) 
	
	
* II. Loans - compare with per capita loan amount at fl1 [11 values replaced as outliers -- above 160000 per capita for UP and above 272727.3 pc for NUP]
	
	gen m5_pc = m5 / HHsize 
	
	rename (m5 HHsize) (m5_phonesvy HHsize_phonesvy)

	* Merge on m5 and HH size from fl1 for comparison
	merge m:1 hhid using "${all_HH_nopii_fl1}", keepusing(m5 ultra_poor) keep(3) nogen
	
	preserve 
		use "${current_roster_fl1}", clear 
		keep hhid HHsize
		
		duplicates drop
		tempfile fl1_size
		save `fl1_size'
	restore 
	
	merge m:1 hhid using "`fl1_size'", keepusing(HHsize) keep(3) nogen
	
	gen m5_pc_fl1 = m5 / HHsize 
	sum m5_pc_fl1 m5_pc
	
	* Create max per capita loan amount at fl1 by UP
	bys ultra_poor: egen m5_pc_fl1_max = max(m5_pc_fl1) 
	
	* Flag per capita loan amounts at phone survey R1 that are above max per capita amounts at fl1 by UP/NUP
	gen flag_outlier = 1 if (m5_pc > m5_pc_fl1_max) & !mi(m5_pc) // 17 values are flagged 
	
	replace m5_phonesvy = .o if flag_outlier == 1 
	
	* Excluding a couple more values specifically for ultra_poor (only 2 UP values were dropped) - dropping 7 more observations 
	replace m5_phonesvy = .o if	ultra_poor == 1 & m5_pc >= 100000  & !mi(m5_pc)  
	
	drop flag_outlier m5 HHsize* numadult numchild
	rename m5_phonesvy m5