/* Shocks roster panel [unit of observation is hh-round-shock]

	1. Round 1 roster prep
	2. Round 2 roster prep
	3. Round 4 roster prep
	4. Compile panel data
	5. Minor cleaning
	
	Questions & issues:
	1. The data are appended as a panel, although recall periods differ, so this will need to be taken into
		consideration in further cleaning:
			R1 is asked since April 2020
			R2 is asked since date of R1 survey or since April 2020 (if there is no R1 survey)
			R4 is asked about last 4 weeks 
	2. We add more shocks in R2 and R4, such that we have 12 items (including "other") in R1 and 17 items in R2 and R4 (just FYI)
	3. TBD

*/

* Inputs 
global 	phone_svy_clean_r1			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r1.dta" 
global 	phone_svy_clean_r2 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r2.dta" 
global 	phone_svy_clean_r4 			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_clean_nopii_r4.dta" 
global 	phone_svy_profile			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\phone_svy_profile.dta"

* Outputs
global 	shocks						"${TUP_DB}\Phone_Survey\DataSets\Intermediate\shocks_roster_phonesvy.dta"


*********************************************************************************
* Round 1: g1 g1_a g4_a g4 g5 g2 g3; recall: since April 2020
*********************************************************************************

use "${phone_svy_clean_r1}", clear 
	keep hhid call_status g1 - g3 formdef_version
	
	drop shocks_timing_count event_id_* event_name_*

	drop g1_a__97 // this was from an earlier form version and is empty	
	* Rename since -97 always means "other"
	rename g1_a_13 g1_a_97
	rename g4_a_*_13 g4_a_*_97
	
	* Reshape long 
	reshape long g1_a_ g4_a_1_ g4_a_2_ g4_a_3_ g4_a_4_ g4_a_5_ g4_a_6_ g4_a_7_ g4_a_8_ g4_a_9_ g4_a_10_ g4_a_11_ g4_a_12_ g4_a_13_, i(hhid) j(shock)
	
	drop g1_a g4_a_1 g4_a_2 g4_a_3 g4_a_4 g4_a_5 g4_a_6 g4_a_7 g4_a_8 g4_a_9 g4_a_10 g4_a_11 g4_a_12 g4_a_13
	rename *_ *
	
	/* Recode months so that they match R2
	
		R1:
			4	April / Hamal 2020
			5	May / Sawour 2020
			6	June / Jowza 2020
			7	July / Sarataan 2020
			8	August / Asad 2020
			9	September / Saunbola 2020
			10	October / Mizān 2020
			11	November / Aqrab 2020
			12	December / Qaws 2020
			1	January / Jadi 2021
			2	February 2021
			3	March 2021
			13	Lasted all year

		
		R2: 
			1	April / Hamal 2020
			2	May / Sawour 2020
			3	June / Jowza 2020
			4	July / Sarataan 2020
			5	August / Asad 2020
			6	September / Saunbola 2020
			7	October / Mizān 2020
			8	November / Aqrab 2020
			9	December / Qaws 2020
			10	January / Jadi 2021
			11	Feb-21
			12	Mar-21
			13	April / Hamal 2021
			14	May / Sawour 2021
			15	June / Jowza 2021
			16	Lasted for all months listed */
	
	forval i=1/13 {
		if `i' >= 4 & `i' <= 12 {
			local j = `i' - 3 
		}
		if `i' < 4 | `i' > 12 {
			local j = `i' + 9
		}
		if `i' == 13 {
			local j = 16
		}
		
		di "This is i `i'"
		di "This is j `j'"
		
		rename g4_a_`i' g4_a_`j'_temp
	}
	
	rename *_temp *
	destring g4_a_*, replace 
	
	/* In the firat NARC pilot and a few HHs in the second NARC pilot, we asked g5 as a pebble quesiton:
	
	"Imagine that a pile of 10 pebbles represents combined income from <u>all</u> income streams of your household
	<i>prior to the severe shock</i>. How many pebbles represent your LOSS in income from <u>all</u> sources <i>after
	the severe shock</i>?" 
	
	We will either not use this, or need to change it to match the sale we used after the pilot and in the subsequent rounds:
	
		1	Increased a lot
		2	Increased a little
		3	Remained the same
		4	Decreased a little
		5	Decreased a lot
		-99	Don’t know
		-98	Don’t answer */
	
		merge m:1 hhid using "${phone_svy_profile}", keep(3) nogen keepusing(pilot_r1)
		
		* There are only 6 HHs in the NARC pilots that reported any shock and answered g5.
		unique hhid if g1 == 1 & inlist(pilot_r1,1,2)
		tab g5 formdef_version if g1 == 1 & inlist(pilot_r1,1,2), m nol

	 /*  Think |
	 about the |
		  same |
		severe |
	   adverse |
	event. How |
	 would you |
	  describe |
	  the loss |   Form version used on device
		 in th |       323        325        332 |     Total
	-----------+---------------------------------+----------
		   -99 |        13          0          0 |        13 
			 1 |        13          0          0 |        13 
			 2 |        13          0          0 |        13 
			 4 |         0          0         13 |        13 
			 6 |         0          0         13 |        13 
			 8 |         0         13          0 |        13 
	-----------+---------------------------------+----------
		 Total |        39         13         26 |        78 

				  
		For the 3 HHs that answered something other than DK/refuse, we can assume that:
			- 10-20% reduction is "decreased a little"
			- 40-80% reduction is "decreased a lot" */	
			
		replace g5 = 4 if inlist(g5,1,2) & g1 == 1 & inlist(pilot_r1,1,2)
		replace g5 = 5 if inlist(g5,4,6,8) & g1 == 1 & inlist(pilot_r1,1,2)
		
		tab g5, nol
		drop formdef_version

	gen round = 1
	
	tempfile shocks_r1
	save `shocks_r1'
	
	
*********************************************************************************
* Round 2: g1 g1_a g4 g4_a g5 g2 g3; recall: since R1 OR since April 2020
*********************************************************************************

use "${phone_svy_clean_r2}", clear 
	keep hhid call_status g1 - g3 g4_a_1 g4_a_2 g4_a_3 g4_a_4 g4_a_5 g4_a_6 g4_a_7 g4_a_8 g4_a_9 g4_a_10 ///
		g4_a_11 g4_a_12 g4_a_13 g4_a_14 g4_a_15 g4_a_16 g4_a_17
	
	drop shocks_timing_count
	
		/* Rename variables since the coding in R4 was a bit different than in R1 
	
	R1:
		1	Lost a job (outside of HH)
		2	Household livestock got sick or died 
		3	Household business had to close
		4	Household business had a loss
		5	Severe illness of a HH member
		6	Death of a HH member
		7	Weather or natural disaster shock (e.g., drought, flood, storm, earthquake)
		8	Theft
		9	Other violence/crime event
		10	Rise in food prices
		11	Lower crop yield
		12	Loss of household asset
		13	Other

	R2/R4:
		1	Lost a job or cannot find work (outside of HH)
		2	Household livestock got sick or died 
		3	Household business had to close
		4	Household business had a loss
		6	Severe illness or injury of a HH member (including accidents)
		7	Death of a HH member
		9	Weather or natural disaster shock (e.g., drought, flood, storm, earthquake)
		10	Theft
		13	Other violence/crime event
		14	Rise in food prices
		15	Lower crop yield
		16	Loss of household asset
		17	Other
		5	Household forced to move
		8	Imprisonment of a HH member
		11	Destruction of house / other property (due to conflict or accident)
		12	HH member had to pay compensation */

	/*rename g1_a_17 g1_a__97
	rename (g1_a_5 g1_a_8 g1_a_11 g1_a_12) (g1_a_17 g1_a_18 g1_a_19 g1_a_20)
	rename (g1_a_6 g1_a_7 g1_a_9 g1_a_10 g1_a_13 g1_a_14 g1_a_15 g1_a_16) (g1_a_5 g1_a_6 g1_a_7 g1_a_8 g1_a_9 g1_a_10 g1_a_11 g1_a_12)
	rename (g1_a_17 g1_a_18 g1_a_19 g1_a_20) (g1_a_13 g1_a_14 g1_a_15 g1_a_16) */
	
	foreach var of varlist g1 g4 {
		rename `var'_a_17 `var'_a__97
		rename (`var'_a_5 `var'_a_8 `var'_a_11 `var'_a_12) (`var'_a_17 `var'_a_18 `var'_a_19 `var'_a_20)
		rename (`var'_a_6 `var'_a_7 `var'_a_9 `var'_a_10 `var'_a_13 `var'_a_14 `var'_a_15 `var'_a_16) (`var'_a_5 `var'_a_6 `var'_a_7 `var'_a_8 `var'_a_9 `var'_a_10 `var'_a_11 `var'_a_12)
		rename (`var'_a_17 `var'_a_18 `var'_a_19 `var'_a_20) (`var'_a_13 `var'_a_14 `var'_a_15 `var'_a_16)
	}
	
	* Similarly recode g4 
	gen g4_temp = .
		replace g4_temp = -97 if g4 == 17
		replace g4_temp = 13  if g4 == 5
		replace g4_temp = 5   if g4 == 6
		replace g4_temp = 6   if g4 == 7
		replace g4_temp = 14  if g4 == 8
		replace g4_temp = 7   if g4 == 9
		replace g4_temp = 8   if g4 == 10
		replace g4_temp = 9   if g4 == 13
		replace g4_temp = 10  if g4 == 14
		replace g4_temp = 11  if g4 == 15
		replace g4_temp = 12  if g4 == 16
		replace g4_temp = 15  if g4 == 11
		replace g4_temp = 16  if g4 == 12
		
		drop g4 
		rename g4_temp g4
		
	* Reshape long
	rename (g1_a__97 g4_a__97) (g1_a_97 g4_a_97)
	tostring g4_a_*, replace 
	
	reshape long g1_a_ g4_a_, i(hhid) j(shock)
	drop g1_a
	rename *_ *
	
	* Split g4_a into dummies for each month in the choice list 
	split g4_a, gen(g4_a_)
	destring g4_a_*, replace 
	
	forval i = 1/16 {
		egen g4_a_`i'_temp = anymatch(g4_a_?), values(`i')
	}
	
	* Anymatch in the loop above sets all missing values to 0, which is confusing. Fix this.
	egen g4_a_tot = rsum(g4_a_*_temp)
	forval i = 1/16 {
		replace g4_a_`i'_temp = . if g4_a_tot == 0
	}
	drop g4_a_tot

	drop  g4_a_1 g4_a_2 g4_a_3 g4_a_4 g4_a_5 g2
	rename *_temp *

	gen round = 2
	
	tempfile shocks_r2
	save `shocks_r2'	

	
*********************************************************************************
* Round 4: g1_a g3; recall: last 4 weeks
*********************************************************************************

use "${phone_svy_clean_r4}", clear 
	keep hhid call_status g1_a - g3
	
	* Rename variables since the coding in R4 was a bit different than in R1 
	rename (g1_a_5 g1_a_8 g1_a_11 g1_a_12) (g1_a_17 g1_a_18 g1_a_19 g1_a_20)
	rename (g1_a_6 g1_a_7 g1_a_9 g1_a_10 g1_a_13 g1_a_14 g1_a_15 g1_a_16) (g1_a_5 g1_a_6 g1_a_7 g1_a_8 g1_a_9 g1_a_10 g1_a_11 g1_a_12)
	rename (g1_a_17 g1_a_18 g1_a_19 g1_a_20) (g1_a_13 g1_a_14 g1_a_15 g1_a_16)
	
	rename *__97 *_97
	reshape long g1_a_, i(hhid) j(shock)
	drop g1_a
	rename *_ *
	
	* Rename to be consistent with R1 where this question was called g1
	gen g1_temp = (g1_a == 1 & shock != 0)
	bys hhid: egen g1 = max(g1_temp)
	drop g1_temp
	
	gen round = 4
	
	tempfile shocks_r4
	save `shocks_r4'	
	
	
*********************************************************************************
* Combine rounds [append for now]
*********************************************************************************	
	use "`shocks_r1'"
		append using "`shocks_r2'"
		append using "`shocks_r4'"
		
	recode shock (97 = -97)

	drop g2 g2 g4_a
	
	** Extra cleaning 

	* You cannot have "no shock" and a shock selected, but there are a few instances where this happens in R4 due to
	* a coding mistake most likely clean this to remove the "no shock" option since there was a shock 
	
	* Old form was used for 1 HH in R4 - correct this 
	replace g1_a = 0 if hhid == 1475 & round == 4 
		replace g1_a = 1 if shock == 0 & hhid == 1475 & round == 4 
	
	bys hhid round: egen numshock = total(g1_a)
	
	replace g1_a = 0 if g1_a != 0 & shock == 0 & numshock > 1  // 7 weird cases
 
	* In the question on which event was the most severe, it is not asked if only one 
	* shock was selected. Mark this shock selection here just so it's clear.
	cap noi assert mi(g4) if numshock==1 & round !=4 
		unique hhid if !mi(g4) & numshock==1 & round !=4 // 4 weird HHs select a worst shock even though they report only 1 - this is weird but fine 
	
	* 12 HHs did not select the worst shock even though they selected 2 or more shocks - likely due to TPM corrections 
	unique hhid if mi(g4) & numshock>1 & round != 4
	
	gen worst_shock = .
	replace worst_shock = shock if numshock == 1 & g1_a == 1
	bys hhid round (worst_shock) : egen worstest_shock = max(worst_shock)
	
	replace g4 = worstest_shock if numshock == 1 & round != 4 & mi(g4)
	drop worst* numshock
	
	* Label
	label var 	shock 	"Type of shock"
	label var 	round 	"Phone survey round"
	label var 	g1_a	"Nature of the adverse event(s)"
	
	label var	g2_0	"Coping strategy: Nothing"
	label var	g2_1	"Coping strategy: Decreased expenses"
	label var	g2_2	"Coping strategy: Borrowed "
	label var	g2_3	"Coping strategy: Received gift / support"
	label var	g2_4	"Coping strategy: Used savings (including dowry)"
	label var	g2_5	"Coping strategy: Sold assets"
	label var	g2_6	"Coping strategy: Increased workload of adult member(s)"
	label var	g2_7	"Coping strategy: Children started working"
	label var	g2_8	"Coping strategy: Started begging"
	label var	g2__97	"Coping strategy: Other"
	label var	g2__99	"Coping strategy: Don't know"
	label var	g2__98	"Coping strategy: Don't answer"

	label var	g4_a_1	"Shock occurred in: April / Hamal 2020"
	label var	g4_a_2	"Shock occurred in: May / Sawour 2020"
	label var	g4_a_3	"Shock occurred in: June / Jowza 2020"
	label var	g4_a_4	"Shock occurred in: July / Sarataan 2020"
	label var	g4_a_5	"Shock occurred in: August / Asad 2020"
	label var	g4_a_6	"Shock occurred in: September / Saunbola 2020"
	label var	g4_a_7	"Shock occurred in: October / Mizān 2020"
	label var	g4_a_8	"Shock occurred in: November / Aqrab 2020"
	label var	g4_a_9	"Shock occurred in: December / Qaws 2020"
	label var	g4_a_10	"Shock occurred in: January / Jadi 2021"
	label var	g4_a_11	"Shock occurred in: February 2021"
	label var	g4_a_12	"Shock occurred in: March 2021"
	label var	g4_a_13	"Shock occurred in: April / Hamal 2021"
	label var	g4_a_14	"Shock occurred in: May / Sawour 2021"
	label var	g4_a_15	"Shock occurred in: June / Jowza 2021"
	label var	g4_a_16	"Shock occurred in: Lasted all year/All months listed"
	
	#delimit;
	label define shock_lab 
		0   "No shock"
		1	"Lost a job or cannot find work (outside of HH)"
		2	"Household livestock got sick or died "
		3	"Household business had to close"
		4	"Household business had a loss"
		5	"Severe illness or injury of a HH member (including accidents)"
		6	"Death of a HH member"
		7	"Weather or natural disaster shock (e.g., drought, flood, storm, earthquake)"
		8	"Theft"
		9	"Other violence/crime event"
		10	"Rise in food prices"
		11	"Lower crop yield"
		12	"Loss of household asset"
		-97 "Other"
		13	"Household forced to move"
		14	"Imprisonment of a HH member"
		15	"Destruction of house / other property (due to conflict or accident)"
		16	"HH member had to pay compensation";
	#delimit cr
	
	lab val shock shock_lab
	lab val g4 shock_lab
	
	destring *, replace 

	mvdecode *, mv(-99 = .d \ -98 = .r )	 
	
	* Order
	order hhid round call_status shock, first
	order g2_* g3, after(g1_a)
	order g4_a_1 - g4_a_9 g4_a_10 - g4_a_12 g4_a_13 - g4_a_15, after(g3)
	order g5, last
	
	* Sort
	sort hhid round shock

	* Save data
	save "${shocks}", replace 
	
	