/* Days and hours worked in paid or unpaid productive activity in the past 7 days roster [unit of observation hh-day]
		
		OUT is for activities 	4, 5, 6, 7, 8
		IN is for activities 	1, 2, 3
			--> everyting other than HH chores 
		
	Questions & issues:
		1. Unexplained missingnes in days/hours likely due to TPM corrections; very small (3 hh) but look into it at some point.
		2. Hours is a multiple choice question, that goes from 0-14 and 15 means "More than 14 hours". So, 15 is not really 15 hours,
			but could be more. Since the questions were constrained by this multiple choice, we will not really have outliers in hours.
			There are a few PMs that worked 105 hour weeks, but it is in theory possible.
		
*/

* Inputs 
global 	phone_svy_clean_r3 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_clean_nopii_r3.dta" 
global 	phone_svy_profile			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* Outputs
global 	timeuse_hours				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/timeuse_hours_roster_phonesvy.dta"


	use "${phone_svy_clean_r3}", clear 
		keep field_hhid hhid call_status k30a_out - k30_in_7 k30a_out_m - k30_in_m_7  ///
			k30_1 k30_2 k30_3 k30_4 k30_5 k30_6 k30_7 k30_8 k30_m_1 k30_m_2 k30_m_3 k30_m_4 k30_m_5 k30_m_6 k30_m_7 k30_m_8 no_pm
		
		* Check for unexplained missingness 
		cap noi assert k30a_out!= . if (k30_4 == 1 | k30_5 == 1 | k30_6 == 1 | k30_7 == 1 | k30_8 == 1) // activity 8 not inluded for 1 HH 
		assert k30a_out_m!= . if (k30_m_4 == 1 | k30_m_5 == 1 | k30_m_6 == 1 | k30_m_7 == 1 | k30_m_8 == 1)
		
		cap noi assert k30a_in!= . if (k30_1 == 1 | k30_2 == 1 | k30_3 == 1) 
		cap noi assert k30a_in_m!= . if (k30_m_1 == 1 | k30_m_2 == 1 | k30_m_3 == 1)

		* This must be TPM corrections 
		br if k30a_out== . & (k30_4 == 1 | k30_5 == 1 | k30_6 == 1 | k30_7 == 1 | k30_8 == 1) // 6360
		br if k30a_in== . & (k30_1 == 1 | k30_2 == 1 | k30_3 == 1) // 6295
		br if k30a_in_m== . & (k30_m_1 == 1 | k30_m_2 == 1 | k30_m_3 == 1) // 1514

		* Reshape long 
		reshape long k30_out_ k30_in_ k30_out_m_ k30_in_m_, i(hhid) j(day)
		 
		rename *_ *_hrs
		
		* Create round flag (this is only R4)
		gen round = 3
		
		* Label 
		label var round 		"Phone survey round"
		label var day 			"Day (of 7)"
		label var k30a_out 		"LHH Days worked (w or w/o pay) outside the HH in past 7 days"
		label var k30_out_hrs 	"LHH Hours worked for each day worked (w or w/o pay) outside the HH"
		label var k30a_in		"LHH Days worked (w or w/o pay) inside the HH in past 7 days"
		label var k30_in_hrs 	"LHH Hours worked for each day worked (w or w/o pay) inside the HH"
		label var k30a_out_m 	"PM Days worked (w or w/o pay) outside the HH in past 7 days"
		label var k30_out_m_hrs "PM Hours worked for each day worked (w or w/o pay) outside the HH"
		label var k30a_in_m 	"PM Days worked (w or w/o pay) inside the HH in past 7 days"
		label var k30_in_m_hrs 	"PM Hours worked for each day worked (w or w/o pay) inside the HH"
		
		mvdecode *, mv(-99 = .d \ -98 = .r \ -97 = .n)	 

		* Sort
		sort hhid day
		
		* Order 
		order field_hhid hhid call_status day, first
		
		label drop asset_l
		
		* Save
		save "${timeuse_hours}", replace 

			
		