clear all
set more off
set maxvar 20000

	* Input files
		global assets_data        		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/assets_roster_phonesvy.dta"
		global phone_svy_profile  		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		global inputdata 	       		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"

		* Output files: 
		* Wide data
		global all_assets 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_assets_phonesvy.dta"
		
		* Long data for panel regressions 
		global all_assets_long 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_assets_phonesvy_long.dta"
		
********************************************************************************
	** Part 1: Basic cleaning and preparation of the dataset [R2 and R4]
********************************************************************************
	
	use "${assets_data}", clear
	
	*Merging to get ultrapoor id
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment PRA_lottery attrition_r2 attrition_r4) assert(2 3) keep(3) nogen
	
	* Keep DHS assets only for now (and "none", asset == 0)
	keep if dhs == 1 | asset == 0 
	drop dhs l1_a l1_b // these variables is for non-DHS asset quantities
	drop if round == 3
		
	* Standardize land values to hectares
	gen l3 	   = l3_house * $jerib
	replace l3 = l3_land  * $biswa if mi(l3)
	replace l3 = .u if (l3_land == .u | l3_house == .u)
	replace l3 = .d if (l3_land == .d | l3_house == .d)
	replace l3 = .r if (l3_land == .r | l3_house == .r)
	label var l3 "Total size of land (hectares)"
	drop l3_house l3_land
		
	* Winsorize land size (ask Mohammad about this)
	winsor2 l3, cuts(1 99) suffix(_win) by(ultra_poor)
	lab var l3_win "Total size of land (hectares) - 1-99 pct winsorized"
	
	*Reshape to get one variable per asset
	
	* Rename suffix for each item
	rename (l1 l2 l3 l3_win) (l1_ l2_ l3_ l3_win_)

	reshape wide l1_ l2_ l3_ l3_win_, i(hhid round) j(asset)
 	
	
	*Creating local per type of asset
		loc	asset1	radio_CD
		loc	asset2	TV
		loc	asset3	DishTV
		loc	asset4	VCR_DVD
		loc	asset5	house_Land
		loc	asset6	nonHouse_Land
		loc	asset7	othHouse
		loc	asset8	fridge
		loc	asset9	generator
		loc	asset10	matress
		loc	asset11	mobile_phone
		loc	asset12	non_mobilephone
		loc	asset13	iron
		loc	asset14	bedframe
		loc	asset15	jewelry
		loc	asset16	mosquitonet
		loc	asset17	mosq_repel_candle
		loc	asset18	fan
		loc	asset19	camera

	*Creating dummy for ownership and a variable for the number owned of each asset
	forval	assetnum=1/19	{
		gen	own_`asset`assetnum''		= 0
		replace own_`asset`assetnum'' 	= 1 if l1_`assetnum' == 1 
		lab	var	own_`asset`assetnum''	"Household owns any `asset`assetnum''"

		gen num_`asset`assetnum'' 		= 0
		replace num_`asset`assetnum''   = l1_`assetnum' * l2_`assetnum' if !mi(l2_`assetnum')
		replace num_`asset`assetnum'' 	= l2_`assetnum' if l2_`assetnum'!=. & num_`asset`assetnum'' == 0 // add back extended missing 
		lab	var	num_`asset`assetnum''	"Number of `asset`assetnum'' owned by the household"
	}

	replace num_house_Land 		= l1_5 * l3_5
		replace num_house_Land = l3_5 if mi(num_house_Land) & l3_5!=. // add back missing - there are a lot of DKs , probably need to impute this 
		replace num_house_Land = 0 if l1_5 == 0 // make this question unconditional
	
	replace num_nonHouse_Land 	= l1_6 * l3_6 
		replace num_nonHouse_Land = l3_6 if mi(num_nonHouse_Land) & l3_6!=. // add back missing
		replace num_nonHouse_Land = 0 if l1_6 == 0 // make this question unconditional
	lab	var	num_house_Land		"Size of land on which the dwelling is"
	lab	var	num_nonHouse_Land	"Size of land owned by household, excluding land on which the house is"
	
	* Winsorized land 
	gen num_house_Land_win 		= l1_5 * l3_win_5
		replace num_house_Land_win = l3_5 if mi(num_house_Land_win) & l3_5!=. // add back missing
		replace num_house_Land_win = 0 if l1_5 == 0 // make this question unconditional	
	
	gen num_nonHouse_Land_win 	= l1_6 * l3_win_6 
		replace num_nonHouse_Land_win = l1_6 if mi(num_house_Land_win) & l1_6!=. // add back missing
		replace num_nonHouse_Land_win = 0 if l1_6 == 0 // make this question unconditional
	lab	var	num_house_Land_win		"Size of land on which the dwelling is - 1/95% winsorized"
	lab	var	num_nonHouse_Land_win	"Size of land owned by household, excluding land on which the house is - 1/95% winsorized"
	
	* Save long data 
	save $all_assets_long, replace 

	* Reshape wide 
	
	keep hhid round attrition_r2 attrition_r4 PRA_lottery treatment ultra_poor num*

	* Reshape wide 
	unab varlist: num_radio_CD - num_nonHouse_Land_win
	
	foreach var in `varlist' { 
		local l`var' : variable label `var' 
	}	
	
	rename (num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  ///			
		num_mobile_phone  num_non_mobilephone num_iron  num_bedframe  num_jewelry  num_mosquitonet  /// 
		num_mosq_repel_candle  num_fan  num_camera num_othHouse ///
		num_house_Land num_house_Land_win num_nonHouse_Land num_nonHouse_Land_win) ///
		(num_radio_CD_  num_TV_  num_DishTV_  num_VCR_DVD_  num_fridge_  num_generator_  num_matress_  ///			
		num_mobile_phone_  num_non_mobilephone_ num_iron_  num_bedframe_  num_jewelry_  num_mosquitonet_  /// 
		num_mosq_repel_candle_  num_fan_  num_camera_ num_othHouse_ ///
		num_house_Land_ num_house_Land_win_ num_nonHouse_Land_ num_nonHouse_Land_win_)
		
	reshape wide num_radio_CD_  num_TV_  num_DishTV_  num_VCR_DVD_  num_fridge_  num_generator_  num_matress_  ///			
		num_mobile_phone_  num_non_mobilephone_ num_iron_  num_bedframe_  num_jewelry_  num_mosquitonet_  /// 
		num_mosq_repel_candle_  num_fan_  num_camera_ num_othHouse_ ///
		num_house_Land_ num_house_Land_win_ num_nonHouse_Land_ num_nonHouse_Land_win_, i(hhid) j(round)
		
	foreach var in num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  ///			
		num_mobile_phone  num_non_mobilephone num_iron  num_bedframe  num_jewelry  num_mosquitonet  /// 
		num_mosq_repel_candle  num_fan  num_camera num_othHouse ///
		num_house_Land num_house_Land_win num_nonHouse_Land num_nonHouse_Land_win { 
		label var `var'_2 "`l`var''" 
		label var `var'_4 "`l`var''" 
	}	 	
	
	* Save wide data 
	save $all_assets, replace 