/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 6, 2023
Last udpate on: 

Written by:  	Yulia Belyakova (ybelyakova@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates consumption indices by dividing the values in constant 2018 AFN by the endline control mean
				(round 1 of phone survey for individual rounds, and overal for panel data.)
					

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
* Inputs
	gl phone_svy_profile   				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	gl total_expenditure_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_phonesvy.dta"
	gl total_expenditure_long			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_long_phonesvy.dta"  

* Outputs 	
	gl total_expenditure_index_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_index_phonesvy.dta"
	gl total_expenditure_index_long			    "${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_index_long_phonesvy.dta"  

***************************************************************************************
	** Part 1: Create indices for different rouds (standardize to round 1 control mean)
***************************************************************************************
use "${total_expenditure_phonesvy}", clear 

	keep hhid exp_tot_m_pc_?_ca18 exp_tot_m_pc_noh_?_ca18 exp_f_tot_m_pc_?_ca18 exp_nf_tot_m_pc_?_ca18 ///
		exp_nf_tot_m_pc_noh_?_ca18 

	merge 1:1 hhid using "${phone_svy_profile}", keepusing(treatment ultra_poor PRA_lottery all_rounds) keep(3) nogen

* Total consumption (with health)
	foreach var in exp_tot_m_pc_1 exp_tot_m_pc_3 exp_tot_m_pc_4 { 
		qui reg exp_tot_m_pc_1_ca18 treatment i.PRA_lottery, r
		sum exp_tot_m_pc_1_ca18 if treatment == 0 & e(sample) == 1 
		global exp_tot_m_pc_1_ca18_cmean `r(mean)'
		
		gen `var'_ca21 = `var'_ca18 / ${exp_tot_m_pc_1_ca18_cmean}
	}

* Total consumption (NO health)
	foreach var in exp_tot_m_pc_noh_1 exp_tot_m_pc_noh_3 exp_tot_m_pc_noh_4 { 
		qui reg exp_tot_m_pc_noh_1_ca18 treatment i.PRA_lottery, r
		sum exp_tot_m_pc_noh_1_ca18 if treatment == 0 & e(sample) == 1 
		global exp_tot_m_pc_noh_1_ca18_cmean `r(mean)'
		
		gen `var'_ca21 = `var'_ca18 / ${exp_tot_m_pc_noh_1_ca18_cmean}
	}	
	
* Food consumption
	foreach var in exp_f_tot_m_pc_1 exp_f_tot_m_pc_3 exp_f_tot_m_pc_4 {
		qui reg exp_f_tot_m_pc_1_ca18 treatment i.PRA_lottery, r
		sum exp_f_tot_m_pc_1_ca18 if treatment == 0 & e(sample) == 1 
		global exp_f_tot_m_pc_1_ca18_cmean `r(mean)'
		
		gen `var'_ca21 = `var'_ca18 / ${exp_f_tot_m_pc_1_ca18_cmean}
	}
	
* Non-Food consumption (with health)
	foreach var in exp_nf_tot_m_pc_1 exp_nf_tot_m_pc_3  exp_nf_tot_m_pc_4  { 
		qui reg exp_nf_tot_m_pc_1_ca18 treatment i.PRA_lottery, r
		sum exp_nf_tot_m_pc_1_ca18 if treatment == 0 & e(sample) == 1 
		global exp_nf_tot_m_pc_1_ca18_cmean `r(mean)'
		
		gen `var'_ca21 = `var'_ca18 / ${exp_nf_tot_m_pc_1_ca18_cmean}
	}
	
* Non-Food consumption (NO health)
	foreach var in exp_nf_tot_m_pc_noh_1 exp_nf_tot_m_pc_noh_3  exp_nf_tot_m_pc_noh_4  { 
		qui reg exp_nf_tot_m_pc_noh_1_ca18 treatment i.PRA_lottery, r
		sum exp_nf_tot_m_pc_noh_1_ca18 if treatment == 0 & e(sample) == 1 
		global exp_nf_tot_m_pc_noh_1_ca18_cmean `r(mean)'
		
		gen `var'_ca21 = `var'_ca18 / ${exp_nf_tot_m_pc_noh_1_ca18_cmean}
	}	
	
	
	* Do the same but for a subset of HHs which were surveyed in all rounds (for robustness check)
	preserve 
	
		keep if all_rounds == 1
		
		* Total consumption (with health)
		foreach var in exp_tot_m_pc_1 exp_tot_m_pc_3 exp_tot_m_pc_4 { 
			qui reg exp_tot_m_pc_1_ca18 treatment i.PRA_lottery, r
			sum exp_tot_m_pc_1_ca18 if treatment == 0 & e(sample) == 1 
			global exp_tot_m_pc_1_ca18_allcm `r(mean)'
			
			gen `var'_ca21_all = `var'_ca18 / ${exp_tot_m_pc_1_ca18_allcm}
		}

	* Total consumption (NO health)
		foreach var in exp_tot_m_pc_noh_1 exp_tot_m_pc_noh_3 exp_tot_m_pc_noh_4 { 
			qui reg exp_tot_m_pc_noh_1_ca18 treatment i.PRA_lottery, r
			sum exp_tot_m_pc_noh_1_ca18 if treatment == 0 & e(sample) == 1 
			global exp_tot_m_pc_noh_1_ca18_allcm `r(mean)'
			
			gen `var'_ca21_all = `var'_ca18 / ${exp_tot_m_pc_noh_1_ca18_allcm}
		}	
		
	* Food consumption
		foreach var in exp_f_tot_m_pc_1 exp_f_tot_m_pc_3 exp_f_tot_m_pc_4 {
			qui reg exp_f_tot_m_pc_1_ca18 treatment i.PRA_lottery, r
			sum exp_f_tot_m_pc_1_ca18 if treatment == 0 & e(sample) == 1 
			global exp_f_tot_m_pc_1_ca18_allcm `r(mean)'
			
			gen `var'_ca21_all = `var'_ca18 / ${exp_f_tot_m_pc_1_ca18_allcm}
		}
		
	* Non-Food consumption (with health)
		foreach var in exp_nf_tot_m_pc_1 exp_nf_tot_m_pc_3  exp_nf_tot_m_pc_4  { 
			qui reg exp_nf_tot_m_pc_1_ca18 treatment i.PRA_lottery, r
			sum exp_nf_tot_m_pc_1_ca18 if treatment == 0 & e(sample) == 1 
			global exp_nf_tot_m_pc_1_ca18_allcm `r(mean)'
			
			gen `var'_ca21_all = `var'_ca18 / ${exp_nf_tot_m_pc_1_ca18_allcm}
		}
		
	* Non-Food consumption (NO health)
		foreach var in exp_nf_tot_m_pc_noh_1 exp_nf_tot_m_pc_noh_3  exp_nf_tot_m_pc_noh_4  { 
			qui reg exp_nf_tot_m_pc_noh_1_ca18 treatment i.PRA_lottery, r
			sum exp_nf_tot_m_pc_noh_1_ca18 if treatment == 0 & e(sample) == 1 
			global exp_nf_tot_m_pc_noh_1_ca18_allcm `r(mean)'
			
			gen `var'_ca21_all = `var'_ca18 / ${exp_nf_tot_m_pc_noh_1_ca18_allcm}
		}	
			
		keep hhid *_all
		
		tempfile consump_allr
		save `consump_allr'
	
	restore 
	
	merge 1:1 hhid using `consump_allr', assert(1 3) nogen 
	
	keep hhid *_ca21*
	
	* Labels 
	foreach round in 1 3 4 {
		lab var exp_tot_m_pc_`round'_ca21 "Total Consumption Index (round `round')"
		lab var exp_tot_m_pc_noh_`round'_ca21 "Total Consumption Index - No Health (round `round')"
		lab var exp_f_tot_m_pc_`round'_ca21 "Food Consumption Index (round `round')"
		lab var exp_nf_tot_m_pc_`round'_ca21 "Non-Food Consumption Index (round `round')"
		lab var exp_nf_tot_m_pc_noh_`round'_ca21 "Non-Food Consumption Index - No Health (round `round')"
		
		lab var exp_tot_m_pc_`round'_ca21_all "Total Consumption Index (round `round') - all rounds subsample"
		lab var exp_tot_m_pc_noh_`round'_ca21_all "Total Consumption Index - No Health (round `round') - all rounds subsample"
		lab var exp_f_tot_m_pc_`round'_ca21_all "Food Consumption Index (round `round') - all rounds subsample"
		lab var exp_nf_tot_m_pc_`round'_ca21_all "Non-Food Consumption Index (round `round') - all rounds subsample"
		lab var exp_nf_tot_m_pc_noh_`round'_ca21_all "Non-Food Consumption Index - No Health (round `round') - all rounds subsample"
	}
	
	* Save dataset 
	save "${total_expenditure_index_phonesvy}", replace 
	
*******************************************************************************************
	** Part 2: Create indices for panel data (standardize to overall endline control mean)
*******************************************************************************************	
	
use "${total_expenditure_long}", clear 

	keep hhid round exp_tot_m_pc_ca18 exp_tot_m_pc_noh_ca18 exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc_ca18 ///
		exp_nf_tot_m_pc_noh_ca18 exp_tot_m_pc_noh ///
		exp_tot_m_pc_noh_w95_ca18 exp_tot_m_pc_noh_w97_ca18 exp_tot_m_pc_noh_w99_ca18 ///
		exp_tot_m_pc_noh_w95t_ca18 exp_tot_m_pc_noh_w97t_ca18 exp_tot_m_pc_noh_w99t_ca18 

	merge m:1 hhid using "${phone_svy_profile}", keepusing(treatment ultra_poor PRA_lottery all_rounds) keep(3) nogen
	
	foreach var in exp_tot_m_pc_noh {
		gen `var'_ppp18 = `var' / ${ppp_2018}
		gen `var'_ppp21 = `var' / ${ppp_2021}
	
	}
	
	* Additional construction (move this eventually) 
	* Constant 2018 AFN divided by endline control mean (consumption only) -- standardize all to overall control mean   
	foreach var in exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc exp_nf_tot_m_pc_noh exp_tot_m_pc_noh exp_tot_m_pc_noh_w95 exp_tot_m_pc_noh_w97 exp_tot_m_pc_noh_w99 exp_tot_m_pc_noh_w95t exp_tot_m_pc_noh_w97t exp_tot_m_pc_noh_w99t {  
		qui reg `var'_ca18 treatment ${controls}, r  
		sum `var'_ca18 if treatment == 0 & e(sample) == 1   
		global `var'_cmean `r(mean)'  
		  
		gen `var'_ca21 = `var'_ca18 / ${`var'_cmean}  
	} 
	
		* Constant 2018 AFN divided by endline control mean (consumption only) -- standardize all to overall control mean   
	foreach var in exp_tot_m_pc_noh {  
		qui reg `var'_ppp18 treatment ${controls}, r  
		sum `var'_ppp18 if treatment == 0 & e(sample) == 1   
		global `var'_ppp_cmean `r(mean)'  
		  
		gen `var'_indppp = `var'_ppp18 / ${`var'_ppp_cmean}  
	} 
	
	
	
	lab var exp_tot_m_pc_ca21 "Total Consumption Index (pooled)"
	lab var exp_tot_m_pc_noh_ca21 "Total Consumption Index (pooled) - no health"
	lab var exp_f_tot_m_pc_ca21 "Food Consumption Index (pooled)" 
	lab var exp_nf_tot_m_pc_ca21 "Non-Food Consumption Index (pooled)"
	lab var exp_nf_tot_m_pc_noh_ca21 "Non-Food Consumption Index (pooled) - no health"
	
	* The same for the robustness chcek subsample (HHs surveyed in all rounds)
	preserve 
		keep if all_rounds == 1 
	
		foreach var in exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc exp_nf_tot_m_pc_noh exp_tot_m_pc_noh {  
			qui reg `var'_ca18 treatment ${controls}, r 
			sum `var'_ca18 if treatment == 0 & e(sample) == 1   
			global `var'_allcm `r(mean)'  
			  
			gen `var'_ca21_all = `var'_ca18 / ${`var'_allcm}  
		} 
		
		keep hhid round *_ca21_all
		
		lab var exp_tot_m_pc_ca21_all "Total Consumption Index (pooled) - all rounds subsample"
		lab var exp_tot_m_pc_noh_ca21_all "Total Consumption Index (pooled) - no health - all rounds subsample"
		lab var exp_f_tot_m_pc_ca21_all "Food Consumption Index (pooled) - all rounds subsample" 
		lab var exp_nf_tot_m_pc_ca21_all "Non-Food Consumption Index (pooled) - all rounds subsample"
		lab var exp_nf_tot_m_pc_noh_ca21_all "Non-Food Consumption Index (pooled) - no health - all rounds subsample"
		
		tempfile consump_allrounds
		save `consump_allrounds'
	restore 
 
	merge 1:1 hhid round using "`consump_allrounds'", assert(1 3) nogen
 
	keep hhid round *_ca21*
 
	* Save dataset 
	save "${total_expenditure_index_long}", replace 
	
	