/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 13, 2019
Last udpate on: November 1, 2021

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		Yulia Belyakova

********************************************************************************			

THIS DO FILE: 	Merges the constructed variables to the household dataset and creates the dataset for data analysis.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off
set maxvar 20000
* Inputs
	gl all_hhlevel_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
	gl phone_svy_profile   				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	gl total_expenditure_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_phonesvy.dta"
	gl total_expenditure_index_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_index_phonesvy.dta"	
	gl foodsecurity_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_security_index_phonesvy.dta"
	gl finance_index_up_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_up_phonesvy.dta"
	gl timeuse_up_phonesvy 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_up_phonesvy.dta"
	gl wellbeing_index_up_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_up_phonesvy.dta"
	gl wellbeing_index_nup_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_nup_phonesvy.dta"
	gl asset_index_up_phonesvy 			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_up_phonesvy.dta"
	gl total_expenditure_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/total_expenditure_bl.dta"
	gl livestock_assets_index_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_index_phonesvy.dta"
	gl f_empowerment_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/f_empowerment_phonesvy.dta"
	gl f_empowerment_nup_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/f_empowerment_nup_phonesvy.dta"	
	gl polinvolvement_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/political_involvement_index_phonesvy.dta"
	gl timeuse_up_phonesvy 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_up_phonesvy.dta"
	gl data_for_analysis_bl				"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	gl timeuse_hh_phonesvy 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_hh_phonesvy.dta"
	gl entrepreneur_index_up_bl 		"${TUP_DB}/Baseline/DataSets/Intermediate/entrepreneur_index_up_bl.dta"	
	gl shocks_interm					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/shocks_interm_phonesvy.dta"
	gl livestock_roster 		 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_roster_phonesvy.dta"
	gl migration						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/migration_phonesvy.dta"
	gl non_assets_data    		    	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/other_assets_phonesvy.dta"
	gl health_phonesvy  				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/health_phonesvy.dta"
	gl other_vars_phonesvy 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/other_vars_phonesvy.dta"
	gl revenues_income_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/revenues_income_phonesvy.dta" 
	gl wellbeing_index_ses_bl_phonesvy	"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/wellbeing_index_ses_bl.dta"	 
	
	* Baseline control standardized well-being index 
	*gl wellbeing_index_ses_bl_phonesvy	"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/wellbeing_index_ses_bl_phonesvy.dta"	
	gl  hh_composition					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/hh_composition_phonesvy.dta"

	* Baseline controls 
	gl covars_bl_phonesvy				"${TUP_DB}/Baseline_Phone/DataSets/Final/covars_bl_phonesvy.dta"
	gl data_for_analysis_bl_phonesvy	"${TUP_DB}/Baseline_Phone/DataSets/Final/data_for_analysis_bl_phonesvy.dta" 
	
	* Add NUP indicators for comparison
	gl finance_index_ses 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/finance_index_ses_phonesvy.dta"
	gl asset_index_nup 					"${TUP_DB}/Phone_Survey/DataSets/Intermediate/asset_index_nup_phonesvy.dta"
	
	gl wellbeing_index_ses_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_ses_phonesvy.dta"
	gl f_empowerment_ses_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/f_empowerment_ses_phonesvy.dta"

	gl schooling_phonesvy				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/schooling_phonesvy.dta"

	* Extras (to review and delete if needed)
	gl food_consumption_all_detail		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_consumption_all_detail_phonesvy.dta"
	
* Outputs
	* Data for analysis
		gl data_for_analysis_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Final/data_for_analysis_phonesvy.dta"

	* Data for analysis: IE Main paper
		gl data_for_analysis_phonesvy_IE	"${TUP_DB}/IE_Phone_paper/DataSets/Final/data_for_analysis_phonesvy_IE.dta"
	
********************************************************************************
	** Part 1: Merge dataset with indices
********************************************************************************


*----------------------------*
* Prepare baseline for merge *
*----------------------------*

use "${data_for_analysis_bl_phonesvy}", clear
	keep 	hhid  exp_tot_m_pc_noh_ca21 index_sdC_f_emp_3c_phone psy_indexC_sdC_bl_phone wealth_score_sdC_phone
	
	rename index_sdC_f_emp_3c_phone empower
	rename exp_tot_m_pc_noh_ca21 cons
	rename psy_indexC_sdC_bl_phone psy
	rename wealth_score_sdC_phone wealth
	
	rename * *_bl
	rename hhid_bl hhid
	tempfile baseline
	save 	`baseline'

*---------------*
* Merge variables *
*---------------*

* Start with HHID and merge on all variables needed for analysis 
use "${all_hhlevel_phonesvy}", clear
	keep hhid
	duplicates drop
	cou // 1932 HH ever surveyed in any of the 4 rounds 
	
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(treatment ultra_poor PRA_lottery call_status* attrition_r* all_rounds) keep(3) nogen force update 

* Consumption (rounds 1, 3, 4)
	merge 1:m hhid using "${total_expenditure_phonesvy}", assert(1 3) nogen // 12 master-only are R2-only HHs
		
* Consumption Index	(rounds 1, 3, 4)	
	merge 1:m hhid using "${total_expenditure_index_phonesvy}", assert(1 3) nogen

* Adding entrepreneur_index from Baseline
	loc entrep_bl "impuls_index_sdC_bl passion_work_index_sdC_bl tenacity_index_sdC_bl polychronicity_index_sdC_bl locus_control_index_sdC_bl achievement_index_sdC_bl power_motivation_index_sdC_bl  work_central_index_sdC_bl organized_index_sdC_bl entrep_index_pca_bl entrep_index_sdC_bl"
	merge m:1 hhid using "${entrepreneur_index_up_bl}", keepus(`entrep_bl') keep(1 3) nogen	
	
* Food Security (rounds 1, 4)
	loc foodsec_vars "c14_7_1 c14_3_ac_1 c14_5_ac_1 c14_1_ac_1 index_sdC_food_sec_1 index_sdC_food_sec2_1 index_sdUP_food_sec_1 index_sdUP_food_sec2_1 c14_7_4 c14_3_ac_4 c14_5_ac_4 c14_1_ac_4 index_sdC_food_sec_4 index_sdC_food_sec2_4 index_sdUP_food_sec_4 index_sdUP_food_sec2_4  index_sdUP_C_food_sec_1 index_sdUP_C_food_sec2_1 index_sdUP_C_food_sec_4 index_sdC_NUP_food_sec_1 index_sdC_NUP_food_sec2_1"
	merge 1:1 hhid using "${foodsecurity_phonesvy}", keepus(`foodsec_vars') assert(1 3) nogen

* Female empowerment
	loc empowerment_vars "h1_ac h2_ac h3_ac h4_ac h5_ac h6_ac h7_ac h8_ac h9_ac h10_ac h11_ac h12_ac h13_ac h14_ac_all h28_ac_all h31_ac_all h24_ac_all h30_all h14_ac_1 h28_ac_1 h31_ac_1 h24_ac_1 h30_1 h14_ac_4 h28_ac_4 h31_ac_4 h24_ac_4 h30_4 mobile_yes_pf did_labor_nohh_1 did_labor_nohh_3 did_labor_nohh_4 did_labor_nohh_1_all did_labor_nohh_3_all did_labor_nohh_1_Z did_labor_nohh_3_Z owner_manager_pf ed_level_d ed_help_d age_marriage_d z2_all n1_1 n2_1 n1_4 n2_4 n1_all n2_all index_sdC_all_decisions index_sdC_role_prod_1 index_sdC_role_prod_3 index_sdC_social_capital index_sdC_f_emp_3c_1 index_sdC_f_emp_3c_3 index_Z_all_decisions index_Z_role_prod_act_1 index_Z_role_prod_act_3 index_Z_social_capital index_Z_decisions_eco_1 index_Z_decisions_eco_3 index_Z_f_emp_3c_1 index_Z_f_emp_3c_3 index_sdC_all_decisions_r index_sdC_role_prod_r_1 index_sdC_role_prod_r_3 index_sdC_social_capital_r index_sdC_f_emp_3c_r_1 index_sdC_f_emp_3c_r_3 index_sdC_all_decisions_m index_sdC_role_prod_m_1 index_sdC_role_prod_m_3 index_sdC_social_capital_m index_sdC_f_emp_3c_m_1 index_sdC_f_emp_3c_m_3 hh_head_gender foodexp otherexp chischool chimarr z1_3_all index_sdC_all_decisions_dau index_sdC_role_prod_dau_1 index_sdC_role_prod_dau_3 index_sdC_social_capital_dau index_sdC_social_norms_dau index_sdC_f_emp_dau_3 index_sdC_f_emp_dau_1 has_daughter 	index_sdC_all_decisions_all index_sdC_role_prod_1_all index_sdC_role_prod_3_all index_sdC_social_capital_all index_sdC_f_emp_3c_1_all index_sdC_f_emp_3c_3_all *nomkt" // s21 is z2	
	
	merge 1:1 hhid using "${f_empowerment_phonesvy}", keepus(`empowerment_vars') assert(1 3) nogen
	
* NUP female empowerment 	
	loc empowerment_vars "*sdC_NUP* *sdT_NUP*"
	merge 1:1 hhid using "${f_empowerment_nup_phonesvy}", keepus(`empowerment_vars') assert(1 3) nogen
	
* SES female empowerment 	
	loc empowerment_vars "*sdUP_C*"
	merge 1:1 hhid using "${f_empowerment_ses_phonesvy}", keepus(`empowerment_vars') assert(1 3) nogen
	
* Psy well being
	loc wellbeing_vars "*sdC* cesd_md cesd_ts happy* satisf_score* cesd_md"
	merge 1:1 hhid using "${wellbeing_index_up_phonesvy}", keepus(`wellbeing_vars') assert(1 3) nogen
	
* NUP Psy well being	
loc wellbeing_vars "*sdC_NUP* *sdT_NUP*"
	merge 1:1 hhid using "${wellbeing_index_nup_phonesvy}", keepus(`wellbeing_vars') assert(1 3) nogen	
		
* SES Well-being 		
	loc wellbeing_vars "*sdUP_C*"
	merge 1:1 hhid using "${wellbeing_index_ses_phonesvy}", keepus(`wellbeing_vars') assert(1 3) nogen		
	
* Household assets
	loc hhassets_vars "wealth_score_? *sdC* property_score_?"
	merge 1:1 hhid using "${asset_index_up_phonesvy}", keepus(`hhassets_vars') assert(1 3) nogen	
	
* NUP HH assets 
	loc nup_hhassets_vars "wealth_score_? *sdNUP* property_score_? num_house_Land_? num_house_Land_win_? num_nonHouse_Land_? num_nonHouse_Land_win_?"
	merge 1:1 hhid using "${asset_index_nup}", keepus(`nup_hhassets_vars') assert(1 3) nogen	

* Value of assets
	loc assets_vars "tot_lstock_value* tot_lstock_value_med* lstock_value_med* tot_lstock_value_cow* lstock_value_cow* lstock_value_goat* lstock_value_sheep* lstock_value_chicken* lstock_yes_cow* lstock_yes_goat* lstock_yes_sheep* lstock_yes_chicken*  lstock_num_cow* lstock_num_goat* lstock_num_sheep* lstock_num_chicken*  lstock_value_goat*  tot_lstock_unit* tot_lstock_unit_cow* tup_lstock_yes*"
	merge 1:1 hhid using "${livestock_assets_index_phonesvy}", keepus(`assets_vars') assert(1 3) nogen	

* Finance (savings and loans from R1 and R3; index from R4)
	loc fin_vars "fin_index_sdC* access_credit saving_dummy* saving* saving_win* loan_dummy* loan* loan_win*"
	merge 1:1 hhid using "${finance_index_up_phonesvy}", keepus(`fin_vars') keep(1 3) nogen
	
* NUP Finance (savings and loans from R1 and R3; index from R4)
	loc nup_fin_vars "fin_index_sdUP* access_credit saving_dummy_? saving_* saving_win_* loan_dummy_? loan_* loan_win_* prod_loan"
	merge 1:1 hhid using "${finance_index_ses}", keepus(`nup_fin_vars') nogen update
			
* Political involvement
	loc polinvolvement_vars "z2_index_all z1_3_index_all n1_all n2_all *sdUP* *sdC*"
	merge m:1 hhid using "${polinvolvement_phonesvy}", keepus(`polinvolvement_vars') assert(1 3) nogen // s21 is z2						
				
* Migration (select variables only)
	loc migration_vars in_migration out_migration_push_1 out_migration_push_2 out_migration_num migrant_remittance migrant_remit_amt_afn
	merge 1:1 hhid using "${migration}", keepus(`migration_vars') assert(1 3) nogen
		
	merge 1:1 hhid using "${health_phonesvy}", assert(1 3) nogen

* Income and Revenues
	merge 1:1 hhid using "${revenues_income_phonesvy}", assert(1 3) nogen
	
* Time use
	merge 1:1 hhid using "${timeuse_hh_phonesvy}", assert(1 3) nogen					
					
* Shocks 
	merge 1:1 hhid using "${shocks_interm}", assert(1 3) nogen		
		
* Schooling (shares)
preserve 
	use "${schooling_phonesvy}", clear 
		keep hhid share_inschool_1 share_inschool_4 n
		keep if n == 1 
		isid hhid 
	
	tempfile schooling 
	save `schooling'
restore 	
	
	merge 1:1 hhid using "`schooling'", keepusing(share_inschool_1 share_inschool_4) assert(1 3) nogen
	
* HH Composition
	merge 1:1 hhid using "${hh_composition}", assert(2 3) keep(3) nogen		

* Non-DHS productive assets 
	merge 1:1 hhid using "${non_assets_data}", keepusing(asset_num asset_yes num_asset_produse asset_yes_produse) assert(1 3) nogen		

* Merge transfers, other vars  	
	merge 1:1 hhid using "${other_vars_phonesvy}", keepusing(trans_rec trans_value trans_value_win trans_value_shock_12mo trans_value_shock_4wk trans_value_shock_win_12mo trans_value_shock_win_4wk trans_value_ill_12mo trans_value_ill_4wk trans_value_ill_win_12mo trans_value_ill_win_4wk trans_rec_shock* trans_rec_ill* k36_shock*) assert(1 3) nogen		


	
/* Basline control standardized psy well-being index 	
	merge 1:1 hhid round using "${wellbeing_index_ses_bl_phonesvy}", keepusing(satisf_score_f_phonesvy hap_score_phonesvy cesd_score_phonesvy satisf_z_sdCbl_phonesvy hap_z_sdCbl_phonesvy cesd_z_sdCbl_phonesvy psy_indexC_sdCbl_phonesvy cesd_f_md_phonesvy happy_i27_f_phonesvy) nogen*/
	

*-------------------------*
* Additional construction *
*-------------------------*
unique hhid if ultra_poor == 1
	assert `r(N)' == 845 // N = 845 UP HHs were surveyed in at least one round
	
* Merge on profile vars  
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(treatment ultra_poor PRA_lottery) update replace force keep(3) nogen	 	
	
* Merge baseline
	merge m:1 hhid using `baseline', keep(1 3) gen(merge_bl)

* Merging on 2 covariates unbalanced at baseline 
	merge m:1 hhid using "${covars_bl_phonesvy}", keep(1 3) nogen
* Merging on NUP psy well-being index from baseline to use as covariate in the NUP comparison analysis 	
	merge 1:1 hhid using "${wellbeing_index_ses_bl_phonesvy}", assert(1 3) nogen keepusing(psy_indexC_sdC_NUP_bl)
* Impute missing values in psy_indexC_sdC_NUP_bl
		foreach var in psy_indexC_sdC_NUP {
				
				* Create a missingness indicator 
				gen `var'_bl_mi = mi(`var'_bl) & !mi(`var')
					label var `var'_bl_mi "Baseline covariate missing dummy"
				
				* Calculate % missingness (this is out of total obs) 
				qui tabmiss `var'_bl
					local pct_miss `r(mean)'
			
				* Less than 10% missing obs 
				bys ultra_poor: egen `var'_mean = mean(`var'_bl) 
				replace `var'_bl = `var'_mean if mi(`var'_bl) & `pct_miss' <= 0.1
					drop `var'_mean
				
				* More than 10% missing obs
				replace `var'_bl = 0 if mi(`var'_bl) & `pct_miss' > 0.1
			}
			
			* Categorical vars - do not take the mean
			foreach var in $covariate_vars_cat {
				
				* Create a missingness indicator 
				gen `var'_bl_mi = mi(`var'_bl)
					label var `var'_bl_mi "Baseline covariate missing dummy"
			
				* Recode missing variable as 0
				replace `var'_bl = 0 if mi(`var'_bl)
			}
			

* Create thirds for heterogeneous analysis
	loc consump_var 	"cons_bl"
	loc asset_var 		"wealth_bl"
	loc psych_var 		"psy_bl"
	loc empower_var 	"empower_bl"
	
	loc consump_l 		"Consumption Index"
	loc assets_l 		"Asset levels (PCA)"
	loc psych_l 		"Psych Well-being"
	loc empower_l 		"Women's Empowerment Index"
	
	foreach var in consump asset psych empower { //
		xtile bl_`var'_thirds = ``var'_var', nq(3)
		tab bl_`var'_thirds, gen(bl_`var'_)
		lab var bl_`var'_1 "Bottom third - Baseline ``var'_l'"
		lab var bl_`var'_2 "Middle third - Baseline ``var'_l'"
		lab var bl_`var'_3 "Top third - Baseline ``var'_l'"
		
		foreach third in 1 2 3 {
			local l_`third' : variable label bl_`var'_`third'
			gen treatXbl_`var'_`third' = treatment*bl_`var'_`third' // treatment is replace with treatment here 
			lab var treatXbl_`var'_`third' "Treatment X `l_`third''"
		}
	}
	

* Create winsorization for robustness check
foreach var in exp_tot_m_pc_1 exp_tot_m_pc_1_ca18 exp_tot_m_pc_3 exp_tot_m_pc_3_ca18 exp_tot_m_pc_4 exp_tot_m_pc_4_ca18 loan_1 loan_3 loan_4 saving_1 saving_3 saving_4 tot_lstock_value_4 lstock_value_cow_4 lstock_value_goat_4 lstock_value_sheep_4 lstock_value_chicken_4 tot_hh_income_1 tot_hh_income_noag_1 tot_hh_income_4 tot_lstock_rev_1 tot_lstock_rev_4 tot_crop_rev_2 tot_crop_rev_imp_2 tot_crop_rev_4 tot_biz_rev_1 tot_biz_rev_imp_1 tot_biz_rev_4 tot_biz_rev_imp_4 tot_hh_pay_imp_1 tot_hh_pay_imp_3 tot_hh_pay_imp_4 earn_4 tot_lstock_value_med_4 lstock_value_med_cow_4 lstock_value_med_goat_4 lstock_value_med_sheep_4 lstock_value_med_chicken_4 tot_pmpw_pay_imp_1 tot_pmpw_pay_imp_3 tot_pmpw_pay_imp_4 num_house_Land_2 num_house_Land_4 num_nonHouse_Land_2 num_nonHouse_Land_4 {
		
		winsor2 `var', by(ultra_poor) cuts(0 95) suff(_w95)
		replace `var'_w95 = `var' if mi(`var'_w95)
		local l_`var' : variable label `var'
		lab var `var'_w95 "`l_`var'' - UP Winsorized (95%)"
		
		winsor2 `var', by(ultra_poor) cuts(0 97) suff(_w97)
		replace `var'_w97 = `var' if mi(`var'_w97)
		local l_`var' : variable label `var'
		lab var `var'_w97 "`l_`var'' - UP Winsorized (97%)"
		
		winsor2 `var', by(ultra_poor) cuts(0 99) suff(_w99)
		replace `var'_w99 = `var' if mi(`var'_w99)
		local l_`var' : variable label `var'
		lab var `var'_w99 "`l_`var'' - UP Winsorized (99%)"
		
		* By treatment 
		winsor2 `var', by(treatment) cuts(0 95) suff(_w95t)
		replace `var'_w95t = `var' if mi(`var'_w95t)
		local l_`var' : variable label `var'
		lab var `var'_w95t "`l_`var'' - Treatment Winsorized (95%)"
		
		winsor2 `var', by(treatment) cuts(0 97) suff(_w97t)
		replace `var'_w97t = `var' if mi(`var'_w97t)
		local l_`var' : variable label `var'
		lab var `var'_w97t "`l_`var'' - Treatment Winsorized (97%)"
		
		winsor2 `var', by(treatment) cuts(0 99) suff(_w99t)
		replace `var'_w99t = `var' if mi(`var'_w99t)
		local l_`var' : variable label `var'
		lab var `var'_w99t "`l_`var'' - Treatment Winsorized (99%)"
	}	

* Overall Economy CPI variables 
local econ_cpi_vars "saving_1 saving_all_1 saving_3 saving_all_3 saving_4 saving_win_1 saving_win_all_1 saving_win_3 saving_win_all_3 saving_win_4 loan_1 loan_3 loan_4 loan_win_1 loan_win_3 loan_win_4 loan_all_1 loan_all_3 loan_win_all_1 loan_win_all_3 tot_hh_income_1 tot_hh_income_noag_1 tot_hh_income_4 tot_lstock_rev_1 tot_lstock_rev_win_1 tot_lstock_rev_4 tot_lstock_rev_win_4 tot_crop_rev_2 tot_crop_rev_imp_2 tot_crop_rev_win_2 tot_crop_rev_4 tot_crop_rev_win_4 tot_crop_rev_all tot_crop_rev_win_all tot_biz_rev_1 tot_biz_rev_imp_1 tot_biz_rev_win_1 tot_biz_rev_4 tot_biz_rev_imp_4 tot_biz_rev_win_4 tot_hh_pay_1 tot_hh_pay_imp_1 tot_hh_pay_all_1 tot_hh_pay_imp_all_1 tot_hh_pay_3 tot_hh_pay_imp_3 tot_hh_pay_all_3 tot_hh_pay_all_4 tot_hh_pay_imp_all_3 tot_hh_pay_4 tot_hh_pay_imp_4 tot_hh_pay_imp_all_4 tot_lstock_value_4 trans_value trans_value_win trans_value_shock_12mo trans_value_shock_4wk trans_value_shock_win_12mo trans_value_shock_win_4wk trans_value_ill_12mo trans_value_ill_4wk trans_value_ill_win_12mo trans_value_ill_win_4wk tot_pf_pay_1 tot_pf_pay_all_1 tot_pf_pay_imp_1 tot_pf_pay_imp_all_1 tot_pf_pay_3 tot_pf_pay_all_3 tot_pf_pay_imp_3 tot_pf_pay_imp_all_3 tot_pf_pay_4 tot_pf_pay_all_4 tot_pf_pay_imp_4 tot_pf_pay_imp_all_4 tot_pm_pay_1 tot_pm_pay_all_1 tot_pm_pay_imp_1 tot_pm_pay_imp_all_1 tot_pm_pay_3 tot_pm_pay_all_3 tot_pm_pay_imp_3 tot_pm_pay_imp_all_3 tot_pm_pay_4 tot_pm_pay_all_4 tot_pm_pay_imp_4 tot_pm_pay_imp_all_4 lstock_value_cow_4 lstock_value_cow_cow_4 lstock_value_goat_4 lstock_value_cow_goat_4 lstock_value_sheep_4 lstock_value_cow_sheep_4 lstock_value_chicken_4 lstock_value_cow_chicken_4 tot_lstock_value_cow_4 earn_4 earn_win_4 *_w95* *_w97* *_w99* tot_lstock_value_med_4 lstock_value_med_cow_4 lstock_value_med_goat_4 lstock_value_med_sheep_4 lstock_value_med_chicken_4 tot_pmpw_pay_imp_1 tot_pmpw_pay_imp_3 tot_pmpw_pay_imp_4"
		
	foreach var in `econ_cpi_vars' {
		cap confirm var `var'
		if !_rc { // if the variable exists 
			local l_`var' : variable label `var'
			gen `var'_ca18 = `var' * ($cpi_econ_fl1 / $cpi_econ_phone)
			lab var `var'_ca18 "`l_`var''"
		}
	}	

		
*------------*
* iecodebook *
*------------*
	
	local list 1 3/4
		
	foreach x in pc {	
		foreach i of numlist `list' {
			lab var exp_f_m_`x'_grain_`i'  		"Grains/legumes/breads (round `i')"
			lab var exp_f_m_`x'_dairy_`i'		"Dairy products (round `i')"
			lab var exp_f_m_`x'_fruit_`i' 		"Fruits and nuts (round `i')"
			lab var exp_f_m_`x'_meat_fish_`i'  	"Meat and fish (round `i')"
			lab var exp_f_m_`x'_veg_`i' 		"Vegetables (round `i')"
		}
	}

	foreach i of numlist `list' {	
		* Multiple rounds of consumption
		lab var exp_f_tot_m_pc_`i' 		"Total food consumption (round `i')"
		lab var exp_nf_tot_m_pc_`i'	 	"Total non-food consumption (round `i')"
		lab var exp_tot_m_pc_`i' 		"Consumption per Capita (AFN), Month (round `i')"
		lab var exp_tot_m_pc_`i'_ca18 	"Consumption per Capita (2018 AFN), Month (round `i')"
		lab var exp_f_tot_m_pc_`i'_ca18  "Food Consumption per Capita (2018 AFN), Month (round `i')"
		lab var exp_nf_tot_m_pc_`i'_ca18 "Non-Food Consumption per Capita (2018 AFN), Month (round `i')"
		
		* Multiple rounds of financials
		lab var loan_`i'	 			"HH Total Outstanding Cash Loans (AFN) (round `i')"
		lab var loan_win_`i' 			"HH Total Outstanding Cash Loans (AFN) - Winsorized (round `i')"
		lab var loan_`i'_ca18 			"HH Total Outstanding Cash Loans (2018 AFN) (round `i')"
		lab var loan_win_`i'_ca18		"HH Total Outstanding Cash Loans (2018 AFN) - Winsorized (round `i')"

		lab var saving_`i'				"HH Total Savings (AFN) (round `i')"
		lab var saving_win_`i' 			"HH Total Savings (AFN) - Winsorized (round `i')"
		lab var saving_`i'_ca18 		"HH Total Savings (2018 AFN) (round `i')"
		lab var saving_win_`i'_ca18 	"HH Total Savings (2018 AFN) - Winsorized (round `i')"
		
		lab var tot_hh_pay_`i'					"PM + PW Paid Labor Income (AFN) (round `i')"
		lab var tot_hh_pay_`i'_ca18				"PM + PW Paid Labor Income (2018 AFN) (round `i')"
		lab var tot_hh_pay_imp_`i'				"PM and PW Paid Labor Income" // imputed (round `i')
		lab var tot_hh_pay_imp_`i'_ca18			"PM + PW Paid Labor Income (2018 AFN) - imputed (round `i')"
		lab var tot_hh_pay_all_`i'				"PM + PW Paid Labor Income (AFN) (round `i', all)"
		lab var tot_hh_pay_all_`i'_ca18			"PM + PW Paid Labor Income (2018 AFN) (round `i', all)"
		lab var tot_hh_pay_imp_all_`i'			"PM + PW Paid Labor Income (AFN) - imputed (round `i', all)"
		lab var tot_hh_pay_imp_all_`i'_ca18		"PM + PW Paid Labor Income (2018 AFN) - imputed (round `i', all)"
		lab var tot_hh_pay_imp_`i'_w95			"PM + PW Paid Labor Income (AFN) - imputed (round `i') - UP Winsorized (95%)"
		lab var tot_hh_pay_imp_`i'_w97			"PM + PW Paid Labor Income (AFN) - imputed (round `i') - UP Winsorized (97%)"
		lab var tot_hh_pay_imp_`i'_w99			"PM + PW Paid Labor Income (AFN) - imputed (round `i') - UP Winsorized (99%)"
		lab var tot_hh_pay_imp_`i'_w95t			"PM + PW Paid Labor Income (AFN) - imputed (round `i') - Treatment Winsorized (95%)"
		lab var tot_hh_pay_imp_`i'_w97t			"PM + PW Paid Labor Income (AFN) - imputed (round `i') - Treatment Winsorized (97%)"
		lab var tot_hh_pay_imp_`i'_w99t			"PM + PW Paid Labor Income (AFN) - imputed (round `i') - Treatment Winsorized (99%)"
	}
	
	foreach round in 2 4 {
		lab var tot_crop_rev_`round' 	 "Agricultural Revenue (AFN) (round `round')"
		lab var tot_crop_rev_`round'_w95 "Agricultural Revenue (AFN) (round `round') - UP Winsorized (95%)"
		lab var tot_crop_rev_`round'_w97 "Agricultural Revenue (AFN) (round `round') - UP Winsorized (97%)"
		lab var tot_crop_rev_`round'_w99 "Agricultural Revenue (AFN) (round `round') - UP Winsorized (99%)"
		lab var tot_crop_rev_`round'_w95t "Agricultural Revenue (AFN) (round `round') - Treatment Winsorized (95%)"
		lab var tot_crop_rev_`round'_w97t "Agricultural Revenue (AFN) (round `round') - Treatment Winsorized (97%)"
		lab var tot_crop_rev_`round'_w99t "Agricultural Revenue (AFN) (round `round') - Treatment Winsorized (99%)"
		if `round' == 2 {
			lab var tot_crop_rev_imp_`round'  "Own Agriculture Revenue"
		}
	}
	
	foreach round in 1 4 {
		lab var tot_biz_rev_`round' 	"Non-Agricultural Business Revenue (AFN) (round `round')"
		lab var tot_biz_rev_`round'_w95 "Non-Agricultural Business Revenue (AFN) (round `round') - UP Winsorized (95%)"
		lab var tot_biz_rev_`round'_w97 "Non-Agricultural Business Revenue (AFN) (round `round') - UP Winsorized (97%)"
		lab var tot_biz_rev_`round'_w99 "Non-Agricultural Business Revenue (AFN) (round `round') - UP Winsorized (99%)"
		lab var tot_biz_rev_`round'_w95t "Non-Agricultural Business Revenue (AFN) (round `round') - Treatment Winsorized (95%)"
		lab var tot_biz_rev_`round'_w97t "Non-Agricultural Business Revenue (AFN) (round `round') - TreatmentUP Winsorized (97%)"
		lab var tot_biz_rev_`round'_w99t "Non-Agricultural Business Revenue (AFN) (round `round') - TreatmentUP Winsorized (99%)"	
		lab var tot_biz_rev_imp_`round' "Own Non-Agricultural Revenue"
	}

	lab var earn_4	   "Other Adults Paid Labor Income (USD) - (round 4)"
	lab var earn_4_w95 "Other Adults Paid Labor Income (USD) - (round 4) - UP Winsorized (95%)"
	lab var earn_4_w97 "Other Adults Paid Labor Income (USD) - (round 4) - UP Winsorized (97%)"
	lab var earn_4_w99 "Other Adults Paid Labor Income (USD) - (round 4) - UP Winsorized (99%)"
	lab var earn_4_w95t "Other Adults Paid Labor Income (USD) - (round 4) - Treatment Winsorized (95%)"
	lab var earn_4_w97t "Other Adults Paid Labor Income (USD) - (round 4) - Treatment Winsorized (97%)"
	lab var earn_4_w99t "Other Adults Paid Labor Income (USD) - (round 4) - Treatment Winsorized (99%)"	
			
	foreach i of numlist 1 3 {	
		lab var loan_all_`i'	 		"HH Total Outstanding Cash Loans (AFN) (round `i', all)"
		lab var loan_win_all_`i' 		"HH Total Outstanding Cash Loans (AFN) - Winsorized (round `i', all)"
		lab var loan_all_`i'_ca18 		"HH Total Outstanding Cash Loans (2018 AFN) (round `i', all)"
		lab var loan_win_all_`i'_ca18	"HH Total Outstanding Cash Loans (2018 AFN) - Winsorized (round `i', all)"

		lab var saving_all_`i'			"HH Total Savings (AFN) (round `i', all)"
		lab var saving_win_all_`i' 		"HH Total Savings (AFN) - Winsorized (round `i', all)"
		lab var saving_all_`i'_ca18 	"HH Total Savings (2018 AFN) (round `i', all)"
		lab var saving_win_all_`i'_ca18 "HH Total Savings (2018 AFN) - Winsorized (round `i', all)"
		
		lab var fin_index_sdC_`i' 		"Financial Inclusion Index (2 components) (round `i')"
		lab var fin_index_sdC_all_`i' 	"Financial Inclusion Index (2 components) (round `i', all)"
		lab var fin_index_sdC_win_`i' 	"Financial Inclusion Index (2 components) - winsorized savings (round `i')"
		lab var fin_index_sdC_win_all_`i' "Financial Inclusion Index (2 components) - winsorized savings (round `i', all)"
		
		lab var tot_pf_pay_`i'			"Paid Labor Income - PW (AFN) (round `i')"
		lab var tot_pf_pay_`i'_ca18		"Paid Labor Income - PW (2018 AFN) (round `i')"
		lab var tot_pf_pay_imp_`i'		"Paid Labor Income - PW (AFN) - imputed (round `i')"
		lab var tot_pf_pay_imp_`i'_ca18	"Paid Labor Income - PW (2018 AFN) - imputed (round `i')"
		lab var tot_pf_pay_all_`i'		"Paid Labor Income - PW (AFN) (round `i', all)"
		lab var tot_pf_pay_all_`i'_ca18	"Paid Labor Income - PW (2018 AFN) (round `i', all)"
		lab var tot_pf_pay_imp_all_1	"Paid Labor Income - PW (AFN) - imputed (round `i', all)"
		lab var tot_pf_pay_imp_all_1_ca18 "Paid Labor Income - PW (2018 AFN) - imputed (round `i', all)"
	}
	
	lab var access_credit 	"Can Access Formal Credit if Needed"

	lab var index_sdC_all_decisions "Decision-Making Index"
	lab var index_sdC_role_prod_1 "Economic Opportunities Index, R1 mkt work participation"
	lab var index_sdC_role_prod_3 "Economic Opportunities Index, R3 mkt work participation"
	lab var index_sdC_social_capital "Social Involvement Index"
	lab var index_sdC_f_emp_3c_1 "Women's Empowerment Index (3 Dimensions), R1 mkt work participation"
	lab var index_sdC_f_emp_3c_3 "Women's Empowerment Index (3 Dimensions), R3 mkt work participation"

	lab var index_sdC_all_decisions_m "Decision-Making Index"
	lab var index_sdC_role_prod_m_1 "Economic Opportunities Index"
	lab var index_sdC_role_prod_m_3 "Economic Opportunities Index"
	lab var index_sdC_social_capital_m "Social Involvement Index"
	lab var index_sdC_f_emp_3c_m_1 "Women's Empowerment Index (3 Dimensions)"
	lab var index_sdC_f_emp_3c_m_3 "Women's Empowerment Index (3 Dimensions)"
	
	lab var index_sdC_all_decisions_dau "Decision-Making Index (daughter)"
	lab var index_sdC_role_prod_dau_1 "Economic Opportunities Index, R1 mkt work participation (daughter)"
	lab var index_sdC_role_prod_dau_3 "Economic Opportunities Index, R3 mkt work participation (daughter)"
	lab var index_sdC_social_capital_dau "Social Involvement Index (daughter)"
	lab var index_sdC_social_norms_dau "Aspirations for Daughters Index (daughter)"
	lab var index_sdC_f_emp_dau_1 "Women's Empowerment Index (4 Dimensions), R1 mkt work participation (daughter)"
	lab var index_sdC_f_emp_dau_3 "Women's Empowerment Index (4 Dimensions), R3 mkt work participation (daughter)"
	
	foreach round in 1 4 {
		lab var lstock_yes_cow_`round' "Household Owns Cows (round `round')"
		lab var lstock_yes_goat_`round' "Household Owns Goats (round `round')"
		lab var lstock_yes_sheep_`round' "Household Owns Sheep (round `round')"
		lab var lstock_yes_chicken_`round' "Household Owns Chickens (round `round')"
		lab var tup_lstock_yes_`round' "Household Owns Any TUP Livestock (round `round')"
	}
	
	lab var tot_lstock_value_4 			"Total Value of TUP Livestock (AFN)"
	label var tot_lstock_value_4_ca18 	"Total Value of TUP Livestock (2018 AFN)"	
	
	lab var index_sdC_food_sec_1 "Food Security Index (round 1)"
	lab var index_sdC_food_sec_4 "Food Security Index (round 4)"
	lab var index_sdUP_C_food_sec_1 "Food Security Index (round 1)"
	lab var index_sdUP_C_food_sec_4 "Food Security Index (round 4)"	

	lab var wealth_score_2 "HH Asset Ownership Index (PCA) (round 2)"
	lab var wealth_score_4 "HH Asset Ownership Index (PCA) (round 4)"
	lab var property_score_2 "Land & Dwelling Ownership Index (PCA) (round 2)" 
	lab var property_score_4 "Land & Dwelling Ownership Index (PCA) (round 4)" 
	lab var wealth_score_sdC_2 "HH Asset Ownership Index (round 2)"
	lab var wealth_score_sdC_4 "HH Asset Ownership Index (round 4)"
	
	label var tot_hh_income_1 			"Proxy Total Income and Revenues (AFN)" //  (round 1,2)
	label var tot_hh_income_4 			"Proxy Total Household Income and Revenues (AFN) (round 3,4) - no Ag"
	label var tot_hh_income_noag_1		"Proxy Total Household Income and Revenues (AFN) (round 1) - no Ag"
	
	label var tot_hh_income_1_ca18 		"Total Household Income and Revenues (2018 AFN) (round 1,2)"
	label var tot_hh_income_4_ca18 		"Total Household Income and Revenues (2018 AFN) (round 3,4) - no Ag"

	label var tot_lstock_rev_1 		"Own Livestock Sales Revenue (AFN)" // (round 1)
	label var tot_lstock_rev_1_ca18	"Livestock Revenue (excl. animal products) (2018 AFN) (round 1)"
	label var tot_lstock_rev_4 		"Livestock Revenue (excl. animal products) (AFN) (round 4)"
	label var tot_lstock_rev_4_ca18 "Livestock Revenue (excl. animal products) (2018 AFN) (round 4)"

	label var tot_crop_rev_2  		"Own Agricultural Revenue (AFN)"
	label var tot_crop_rev_all  	"Own Agricultural Revenue (AFN)"
	label var tot_crop_rev_2_ca18 	"Own Agriculture Revenue (2018 AFN)"
	label var tot_crop_rev_all_ca18 "Own Agriculture Revenue (2018 AFN)"
	
	label var tot_biz_rev_1  		"Non-Agricultural Business Revenue (AFN) (round 1)"
	label var tot_biz_rev_4			"Non-Agricultural Business Revenue (AFN) (round 4)"
	label var tot_biz_rev_1_ca18	"HH Non-Agricultural Business Revenue (2018 AFN) (round 1)"
	label var tot_biz_rev_4_ca18	 "HH Non-Agricultural Business Revenue (2018 AFN) (round 4)"

	lab var employment_pf_1  "Primary Woman Participates in Income-generating Activities (round 1)"
	lab var employment_pf_3  "Primary Woman Participates in Income-generating Activities (round 3)"
	
	lab var biz_yes_1 "Household Has Other Non-Agricultural Business (round 1)"
	lab var biz_yes_4 "Household Has Other Non-Agricultural Business (round 4)"
	lab var crop_yes_2 "Household Has an Agriculture Activity"	
	lab var crop_yes_all "Household Has an Agriculture Activity (all)"	
	
	foreach round in 1 3 4 {
		foreach group in pf pm {
			
			if "`group'" == "pf" {
				local member "PF"
			}
			if "`group'" == "pm" {
				local member "PM"
			}
			foreach suffix in "" "_all" {
				label var did_labor_nohh`suffix'_`group'_`round'  	"`member' Did any type of revenue generating activity (4 weeks) (round `round', `suffix')"
				label var did_livestock`suffix'_`group'_`round' 	"`member' Worked in HH Livestock (4 weeks) (round `round')"
				label var did_ownFarming`suffix'_`group'_`round'  	"`member' Worked in HH Agriculture (4 weeks) (round `round')"
				label var did_ownBiz`suffix'_`group'_`round'  		"`member' Worked in HH Non-Agricultural Business (4 weeks) (round `round')"
				label var did_oFarm`suffix'_`group'_`round'  		"`member' Worked in Casual Labor: Agricultural (4 weeks) (round `round')"
				label var did_maid`suffix'_`group'_`round' 			"`member' Worked in Casual Labor: Maid Services (4 weeks) (round `round')"
				label var did_outWork`suffix'_`group'_`round' 		"`member' Worked in Casual Labor: Non-Agricultural (4 weeks) (round `round')"
				label var did_salEmp`suffix'_`group'_`round' 		"`member' Worked in Salaried or Formal Employment (4 weeks) (round `round')"
				label var did_oPaidWork`suffix'_`group'_`round'  	"`member' Worked in Other Paid Work (4 weeks) (round `round')"
				label var labor_particip`suffix'_`group'_`round' 	"`member' Labor Participation (round `round')"
				label var employment`suffix'_`group'_`round' 		"`member' Market Work Participation (round `round')"
				label var k5_1`suffix'_`group'_`round'				"`member' Looked for work (past 2 weeks) (round `round')"
				label var did_oWork`suffix'_`group'_`round'			"`member' Did Any Other Work (4 weeks) (round `round')"
			}
		}
	}

	foreach suffix in "" "_allr" {
		lab var psy_indexC_sdC_1`suffix' "Psychological Well-Being Index (3 Dimensions) (round 1)"
		lab var psy_indexC_sdC_2`suffix' "Psychological Well-Being Index (3 Dimensions) (round 2)"
		lab var psy_indexC_sdC`suffix' "Psychological Well-being Index (3 items)" // (R1 and R2 average)
	}
	
	foreach suffix in "" "_all" {
		lab var satisf_z_sdC_1`suffix' "Life Satisfaction (WVS) Index (round 1)"
		lab var satisf_z_sdC_2`suffix' "Life Satisfaction (WVS) Index (round 2)"
		lab var satisf_z_sdC`suffix' "Life Satisfaction (WVS) Index (R1 and R2 average)"
		lab var hap_z_sdC_1`suffix' "Happiness (WVS) Index (round 1)"
		lab var hap_z_sdC_2`suffix' "Happiness (WVS) Index (round 2)"
		lab var hap_z_sdC`suffix' "Happiness (WVS) Index (R1 and R2 average)"
		
		* These are both from Round 2 
		lab var cesd_z_sdC_1`suffix' "Depression (CESD) Index (Negatively Coded) (round 2)"
		lab var cesd_z_sdC_2`suffix' "Depression (CESD) Index (Negatively Coded) (round 2)"
	}
	
	lab var happy "PW is Very Happy or Quite Happy"
	lab var satisf_score "PW Life Satisfaction Rating (1-10)"
	lab var cesd_md "PW is Depressed (7-CESD $\geq$ 8)"
	
	label var c14_7_1 	 "Everyone in the Household Regularly Eats at Least Two Meals a Day (round 1)"
	label var c14_3_ac_1 "No Adult Skips or Cuts the Size of Meals (round 1)"
	label var c14_5_ac_1 "No Child Skips or Cuts the Size of Meals (round 1)"
	label var c14_7_4 	 "Everyone in the Household Regularly Eats at Least Two Meals a Day (round 4)"
	label var c14_3_ac_4 "No Adult Skips or Cuts the Size of Meals (round 4)"
	label var c14_5_ac_4 "No Child Skips or Cuts the Size of Meals (round 4)"
	
	lab var index_sdC_f_emp_3c_1 "Women's Empowerment Index (3 dimensions)"
	lab var index_sdC_f_emp_3c_1_all "Women's Empowerment Index (3 dimensions)"
	lab var foodexp "Food Expenditures and What to Cook"
	lab var h8_ac "Home Improvements/Repairs"
	lab var h7_ac "Managing Household Finances"
	lab var chischool "Children's School Attendance"
	lab var h13_ac "Children's Health Seeking"
	lab var chimarr "Children's Marriage"
	lab var h6_ac "Buying or Selling Land or Property"
	lab var otherexp "Other Non-food Expenditures"
	lab var h14_ac_1 "Her Fertility"
	lab var h24_ac_1 "Her Opening a Business"
	lab var h31_ac_1 "Her Working Outside of Home"
	lab var h28_ac_1 "Her Taking a Loan"
	lab var index_sdC_role_prod_1 "Economic Opportunities Index"
	lab var owner_manager_pf "PW is Owner or Manager of a HH Non-Agricultural Business"
	lab var h30_1 "PW Has Financial Assets in Her Own Name"
	lab var did_labor_nohh_1 "PW Did Market Work" 
	lab var mobile_yes_pf "PW Has a Mobile Phone"
	lab var index_sdC_social_capital "Political and Social Involvement Index"
	lab var z2_all "PW Has a Tazkira (National ID Card)"
	lab var z1_3_all "PW Voted in an Election (Presidential or Provincial)"
	lab var n1_1 "PW Attended Village Meetings "
	lab var n2_1 "PW Approached Village Leaders  About Issues"
	
	lab var prod_loan "HH Has Taken Out a Loan for Productive Purposes"
	lab var num_inc_source_1 "Income Sources (Out of 4)"
	lab var asset_num "Productive Assets Owned (Out of 30)"
	lab var num_asset_produse "Productive Assets Owned and Used for Production (Out of 30)"
	lab var num_crop_type "Types of Crop Cultivated (Out of 25)"
		
	* Note this is only "all"
	lab var z2_index_all "Primary Woman Has a Tazkira ID Card"
	lab var z1_3_index_all "Primary Woman Voted in the Presidential Election"
	
	lab var diarrhea_yes "Diarrhea Rate in Oldest Under-5 Child, Past 2 Weeks"

	lab var trans_rec 			"Received Transfers (Monetary or In-Kind)"
	lab var trans_value		 	"Value of Transfers Received"
	lab var trans_value_win		"Value of Transfers Received"
		
	foreach suffix in "_12mo" "_4wk" {
		lab var trans_rec_shock`suffix'  "Received Support, Any Shock"
		lab var trans_rec_ill`suffix'  	 "Received Support, Illness or Death"
		
		lab var trans_value_shock`suffix'_ca18 "Value of Support, Any Shock (2018 AFN)"
		lab var trans_value_shock_win`suffix'_ca18 "Value of Support, Any Shock (2018 AFN)"
		lab var trans_value_ill`suffix'_ca18 "Value of Support, Illness or Death (2018 AFN)"
		lab var trans_value_ill_win`suffix'_ca18 "Value of Support, Illness or Death (2018 AFN)"
		
		lab var recover`suffix' 		"HH Somewhat, Mostly or Fully Recovered"
		
		lab var g2_7`suffix'			"Children Working"
		lab var g2_6`suffix'			"Increase Adult Workload"
		
		lab var k36_shock`suffix' "Did your household sell any livestock since April (Hamal)? - Shocked HHs"
	}
	
	* In 2021 USD 
	foreach suffix in w95 w95t w97 w97t w99 w99t {
		rename lstock_value_med_chicken_4_`suffix' lstock_value_m_chic_4_`suffix'
		rename lstock_value_med_sheep_4_`suffix' lstock_value_m_sheep_4_`suffix'
	} 	
	
	unab winsor: *_w95 *_w97 *_w99 *_w95t *_w97t *_w99t
	
	foreach var in exp_tot_m_pc_1 exp_f_tot_m_pc_1 exp_f_tot_m_pc_3 exp_f_tot_m_pc_4 exp_nf_tot_m_pc_1 exp_nf_tot_m_pc_3 exp_nf_tot_m_pc_4 tot_hh_income_1 tot_hh_income_noag_1 tot_hh_income_4 tot_lstock_rev_1 tot_lstock_rev_4 tot_lstock_rev_win_1 tot_lstock_rev_win_4 tot_crop_rev_2 tot_crop_rev_imp_2 tot_crop_rev_win_2 tot_crop_rev_4 tot_crop_rev_win_4 tot_crop_rev_all tot_crop_rev_win_all tot_biz_rev_1 tot_biz_rev_imp_1 tot_biz_rev_win_1 tot_biz_rev_4 tot_biz_rev_imp_4 tot_biz_rev_win_4 tot_hh_pay_imp_1 tot_hh_pay_imp_all_1 tot_hh_pay_imp_3 tot_hh_pay_imp_all_3 tot_hh_pay_imp_4 tot_hh_pay_imp_all_4 saving_1 saving_win_1 saving_win_t_1 saving_3 saving_win_3 saving_win_t_3 saving_4 saving_win_4 saving_win_t_4 saving_all_1 saving_win_all_1 saving_win_t_all_1 saving_all_3 saving_win_all_3 saving_win_t_all_3 loan_1 loan_win_1 loan_win_t_1 loan_3 loan_win_3 loan_win_t_3 loan_4 loan_win_4 loan_win_t_4 loan_all_1 loan_win_all_1 loan_win_t_all_1 loan_all_3 loan_win_all_3 loan_win_t_all_3 trans_value trans_value_win trans_value_shock_12mo trans_value_shock_4wk trans_value_shock_win_12mo trans_value_shock_win_4wk trans_value_ill_12mo trans_value_ill_4wk trans_value_ill_win_12mo trans_value_ill_win_4wk migrant_remit_amt_afn tot_pf_pay_1 tot_pf_pay_all_1 tot_pf_pay_imp_1 tot_pf_pay_imp_all_1 tot_pf_pay_3 tot_pf_pay_all_3 tot_pf_pay_imp_3 tot_pf_pay_imp_all_3 tot_pf_pay_4 tot_pf_pay_all_4 tot_pf_pay_imp_4 tot_pf_pay_imp_all_4 tot_pm_pay_1 tot_pm_pay_all_1 tot_pm_pay_imp_1 tot_pm_pay_imp_all_1 tot_pm_pay_3 tot_pm_pay_all_3 tot_pm_pay_imp_3 tot_pm_pay_imp_all_3 tot_pm_pay_4 tot_pm_pay_all_4 tot_pm_pay_imp_4 tot_pm_pay_imp_all_4 tot_pmpw_pay_1 tot_pmpw_pay_imp_1 tot_pmpw_pay_all_1 tot_pmpw_pay_imp_all_1 tot_pmpw_pay_3 tot_pmpw_pay_imp_3 tot_pmpw_pay_all_3 tot_pmpw_pay_imp_all_3 tot_pmpw_pay_4 tot_pmpw_pay_imp_4 tot_pmpw_pay_all_4 tot_pmpw_pay_imp_all_4 tot_lstock_value_4 lstock_value_cow_4 lstock_value_goat_4 lstock_value_sheep_4 lstock_value_chicken_4 earn_4 `winsor' tot_lstock_value_med_4 lstock_value_med_cow_4 lstock_value_med_goat_4 lstock_value_med_sheep_4 lstock_value_med_chicken_4 {
		local `var'l : var lab `var'
		local `var'l: subinstr local `var'l "(AFN)" "(2021 USD)", all
		gen `var'_usd = `var' / $exchange_rate_2021
		lab var `var'_usd "``var'l'"
	}
	
* Constant 2018 USD
	foreach var in exp_tot_m_pc_1 exp_f_tot_m_pc_1 exp_f_tot_m_pc_3 exp_f_tot_m_pc_4 exp_nf_tot_m_pc_1 exp_nf_tot_m_pc_3 exp_nf_tot_m_pc_4 tot_hh_income_1 tot_hh_income_noag_1 tot_hh_income_4 tot_lstock_rev_1 tot_lstock_rev_4 tot_lstock_rev_win_1 tot_lstock_rev_win_4 tot_crop_rev_2 tot_crop_rev_imp_2 tot_crop_rev_win_2 tot_crop_rev_4 tot_crop_rev_win_4 tot_crop_rev_all tot_crop_rev_win_all tot_biz_rev_1 tot_biz_rev_imp_1 tot_biz_rev_win_1 tot_biz_rev_4 tot_biz_rev_imp_4 tot_biz_rev_win_4 tot_hh_pay_imp_1 tot_hh_pay_imp_3 tot_hh_pay_imp_4 tot_hh_pay_imp_all_4 saving_1 saving_win_1 saving_3 saving_win_3 saving_4 saving_win_4 loan_1 loan_win_1 loan_3 loan_win_3 loan_4 loan_win_4 trans_value trans_value_win trans_value_shock_12mo trans_value_shock_4wk trans_value_shock_win_12mo trans_value_shock_win_4wk trans_value_ill_12mo trans_value_ill_4wk trans_value_ill_win_12mo trans_value_ill_win_4wk tot_pf_pay_1 tot_pf_pay_imp_1 tot_pf_pay_3 tot_pf_pay_imp_3 tot_pf_pay_4 tot_pf_pay_imp_4 tot_pm_pay_1 tot_pm_pay_imp_1 tot_pm_pay_3 tot_pm_pay_imp_3 tot_pm_pay_4 tot_pm_pay_imp_4 tot_pmpw_pay_imp_1 tot_pmpw_pay_imp_3 tot_pmpw_pay_imp_4 tot_lstock_value_4 lstock_value_cow_4 lstock_value_goat_4 lstock_value_sheep_4 lstock_value_chicken_4 earn_4 tot_lstock_value_med_4 lstock_value_med_cow_4 lstock_value_med_goat_4 lstock_value_med_sheep_4 lstock_value_med_chicken_4 {
		local `var'l : var lab `var'
		local `var'l: subinstr local `var'l "(AFN)" "(2018 USD)", all
		gen `var'_18usd = `var'_ca18 / $exchange_rate_2018
		lab var `var'_18usd "``var'l'"
	}

* Save dataset will all the vars
	if	`c(stata_version)'>=14  { 
			saveold "${data_for_analysis_phonesvy}", replace v(13)
	}
	else  {
			save "${data_for_analysis_phonesvy}", replace v(13)		
	}
	

