/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	
Last udpate on: 

Written by:  	Yulia Belyakova			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct dataset with number of HH members, PM status (has PM/no PM),
				Language of interview, HH head gender, variables related to change in HH size from 
				previous data collection rounds.


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Variable construction 
				Part 2 - Variable construction for comparisons with other rounds 


	NPUTS:      Original data		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
				Profile data 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
				Fl1 roster        	"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"		
				Baseline roster		"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"
				Fl1 data for analysis	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

						
	OUTPUTS:     Wide data (unique ID hhid)		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/hh_composition_phonesvy.dta"


			Issues & Notes:
				1. "_all" variables constructed for HH size, PM status and language of interview. R1 info is taken as a base,
					and values are filled in from other rounds for HHs that were only surveyed in later rounds.
		
*******************************************************************************/

********************************************************************************
	** Part 0: Define globals
********************************************************************************

* Inputs 
global  roster_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
global 	phone_svy_profile		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
global  roster_final_fl1        "${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"		
global  roster_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/current_roster_bl_balancechecks.dta"
global  data_for_analysis_fl1	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"

* Output 
global  hh_composition			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/hh_composition_phonesvy.dta"


********************************************************************************
	** Part 1: Variable construction
********************************************************************************

* Women Headed HHs
	* Merge on PM status (whether HH has a PM or not)
	
	use "${roster_phonesvy}", clear 
		keep hhid round no_pm hh_mem
		duplicates drop 
		
		* Reshape wide 
	rename * *_
	rename (hhid_ round_) (hhid round)
	reshape wide no_pm_ hh_mem_, i(hhid) j(round)
	
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(a11_r*) assert(2 3) nogen
	rename a11_r* a11_*
	
* "Fill" in missingness by pooling data from all rounds
	* Majority of HHs would have answered these questions in R1, so we fill in for the ones that were only surveyed in 
	* later rounds (were missing from R1).

	foreach var in no_pm hh_mem a11 {
		gen 	`var'_all = `var'_1 if !mi(`var'_1)
		replace `var'_all = `var'_2 if mi(`var'_all) // this gets filled in for HHs *only* surveyed in R2
		replace `var'_all = `var'_3 if mi(`var'_all) // this gets filled in for HHs *only* surveyed in R4
		replace `var'_all = `var'_4 if mi(`var'_all) // this gets filled in for HHs *only* surveyed in R3
		
		order `var'_all, after(`var'_4)
	}
		
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment) assert(2 3) keep(3) nogen	
	
	
********************************************************************************
	** Part 2: Variable construction for comparisons with other rounds 
********************************************************************************
	
	merge 1:1 hhid using "${data_for_analysis_fl1}", keepusing(hh_head_gender) keep(3) nogen
	
	preserve 
		use "${roster_final_fl1}", clear 
		keep hhid b3
		duplicates drop 
		rename b3 hh_mem_fl1 
		tempfile hh_mem_fl1
		save `hh_mem_fl1'
	restore 
	
	preserve 
		use "${roster_bl}", clear 
		keep hhid b3
		duplicates drop 
		rename b3 hh_mem_bl
		tempfile hh_mem_bl
		save `hh_mem_bl'
	restore 
	
	merge 1:1 hhid using "`hh_mem_fl1'", nogen keep(3)
	merge 1:1 hhid using "`hh_mem_bl'", nogen keep(1 3)
	
	gen hh_mem_inc_bl = (hh_mem_all > hh_mem_bl)
	replace hh_mem_inc_bl = . if hh_mem_bl == . | hh_mem_all == . 
	
	gen hh_mem_inc_fl1 = (hh_mem_fl1 > hh_mem_bl)
	replace hh_mem_inc_fl1 = . if hh_mem_fl1 == . | hh_mem_bl == . 
	
	gen hh_mem_inc_phone = (hh_mem_all > hh_mem_fl1)
	replace hh_mem_inc_phone = . if hh_mem_fl1 == . | hh_mem_all == . 

	lab var hh_mem_inc_fl1 "Household Size Increased From Baseline to Follow-Up"
	lab var hh_mem_inc_phone "Household Size Increased From Follow-Up to Endline"
	lab var hh_mem_inc_bl "Household Size Increased From Baseline to Endline"
	lab var hh_mem_all "Household Size"
	
	gen no_pm_fl1 = (hh_head_gender == 2)
	recode no_pm_? (100 = 1)
	recode a11_? (-97 = .o)
	
	lab var no_pm_all "Primary Woman Is Household Head"
	lab var no_pm_fl1 "PW is HHH at Midline"
	lab var a11_all "Language of the interview"
	
	forval i=1/4 {
		foreach var in no_pm hh_mem a11 {
			local `var'_l: var lab `var'_all
			lab var `var'_`i' "``var'_l' round (`i')" 
		}
	}
	
	save "${hh_composition}", replace  

/*1.	If X is a variable indicating whether HHhead is a women at midline (=1), 0 otherwise (except missing that goes to missing)
*2.	If Y is a variable indicating whether HHhead is a women at endline  (=1), 0 otherwise (except missing that goes to missing)

bys treatment: tab no_pm_fl1 no_pm //if ultra_poor == 1 

bys treatment: sum no_pm_fl1 no_pm //if ultra_poor == 1 


bys treatment: sum hh_mem_fl1 hh_mem if no_pm_fl1 == 1 & no_pm == 0

