** Round 3 

	* Input 
	gl livestock_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_roster_phonesvy.dta"

	* Output 
	gl livestock_assets_r3_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_assets_r3_phonesvy.dta" // wide data 



use "${livestock_phonesvy}", clear

keep hhid livestock round k6 k7_r3 k35_a k35_1-k35__99 r44*
keep if round == 3 

/* Questions asked by type of livestock:

	Any livestock owned (past 3 years) (by type)
	Any livestock still owned (currently) (by type)
	Reason livestock no longer owned (currently) (by type)
	Reason for sale (if sold) (by type)
*/
	gen 	lstock_yes_3yrs = .
		replace lstock_yes_3yrs = 1 if k6 > 0 & !mi(k6) 			
		replace lstock_yes_3yrs = 0 if k6 == 0  				  
		
	foreach missing in ".d" ".r" {	
		replace lstock_yes_3yrs = `missing' if k6 == `missing' & lstock_yes_3yrs == .
		}
		
	gen 	lstock_stillown_3yrs = .
		replace lstock_stillown_3yrs = 1 if k7_r3 > 0 & !mi(k7_r3) 			
		replace lstock_stillown_3yrs = 0 if k7_r3 == 0  				  
		
	foreach missing in ".d" ".r" {	
		replace lstock_stillown_3yrs = `missing' if k7_r3 == `missing' & lstock_stillown_3yrs == .
		}		
	
	* Is your heard bigger now, compared to its max size in the past 3 years? 	  
	#delimit;
		lab define k35_a_lab 
		1	"Many more"
		2	"A few more"
		3	"About the same number"
		4	"A few less"
		5	"A lot less", modify;
	#delimit cr
	
	lab val k35_a k35_a_lab
	
	tab k35_a, gen(k35_a_)	
	
		
* Reshape 		
	drop k6 k7_r3 k35_a
	rename * *_
	
	rename (hhid_ livestock_ round_) (hhid livestock round)
	reshape wide lstock_yes_3yrs_ lstock_stillown_3yrs_ k35_1_ k35_2_ k35_3_ k35_4_ k35__97_ k35__99_ r44_1_ r44_2_ r44_3_ r44_4_ r44__97_ r44__99_ k35_a_1_ k35_a_2_ k35_a_3_ k35_a_4_ k35_a_5_, i(hhid round) j(livestock)

* Labeling and renaming
	loc	lstock1		cow 
	loc	lstock2		goat
	loc	lstock3		sheep
	loc	lstock4		chicken
	
	loc lstock_yes_3yrs_l 		"HH owns any (past 3 years)"
	loc lstock_stillown_3yrs_l 	"HH still owns (from past 3 years)"
	loc k35_1_l "Died"
	loc k35_2_l "Sold"
	loc k35_3_l "Gifted"
	loc k35_4_l "Consumed (ate)"
	loc k35__97_l "Other"
	loc k35__99_l "Don't know'"
	loc r44_1_l "Bought cows after sold"
	loc r44_2_l "Bought goats after sold"
	loc r44_3_l "Bought sheep after sold"
	loc r44_4_l "Bought chickens after sold"
	loc r44__97_l "Bought other after sold"
	loc r44__99_l "Bought Don't know after sold"
	loc k35_a_1_l "Many more"
	loc k35_a_2_l "A few more" 
	loc k35_a_3_l "About the same number"
	loc k35_a_4_l "A few less"
	loc k35_a_5_l "A lot less"

	loc vars "lstock_yes_3yrs lstock_stillown_3yrs k35_1 k35_2 k35_3 k35_4 k35__97 k35__99 r44_1 r44_2 r44_3 r44_4 r44__97 r44__99 k35_a_1 k35_a_2 k35_a_3 k35_a_4 k35_a_5" 
	
	foreach var of local vars {
		forval lstocknum=1/4 {
			rename `var'_`lstocknum' `var'_`lstock`lstocknum''
			lab var `var'_`lstock`lstocknum'' "``var'_l' `lstock`lstocknum''"
		}
	}
	
	save "${livestock_assets_r3_phonesvy}", replace 

	
