/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Feb 26, 2019
Last udpate on: Feb 26, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	R1 appears to be missing data from one district. 
				I thought it was conducted over the phone but I do not see the data for the 
				last district anywhwre (not in Encrypted folder and not in Backup).
		
				
				R2 lettuce is still pretty weird, come back to it.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/


********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs

	* Market clean
		gl market_clean				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/market_clean_phonesvy.dta"
		gl market_imputed_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/market_imputed_fl1.dta"

* Outputs
		gl market_imputed_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/market_imputed_phonesvy.dta"



********************************************************************************
** Part 1: Calculate price per KG (since consumption is in KGs)
********************************************************************************	
	
	use "${market_clean}", clear 
		
	gen price = ms1_a
		replace price = ms1_a/ms1_a_conv_gr*1000 if !mi(ms1_a_conv_gr)
		replace price = ms1_a/ms1_a_conv_kg 	 if !mi(ms1_a_conv_kg)
				
********************************************************************************
** Part 2: Recode items for the merge with consumption data
********************************************************************************		

gen 		item_type = 3	if inrange(item,1,5)
	replace item_type = 4	if inrange(item,6,10)
	replace item_type = 5 	if inrange(item,11,15)
	replace item_type = 7 	if inrange(item,16,20)
	replace item_type = 8 	if inrange(item,21,26)

	recode item (3=100) (4=3) (5=7) 					 		if item_type == 3 // bread
	recode item (100=4)									 		if item_type == 3 // bread
	recode item (6=14)  (7=15)  (8=16)  (9=17)  (10=18)  		if item_type == 4 // meet
	recode item (11=24) (12=26) (13=27) (14=29) (15=33)  		if item_type == 5 // dairy
	recode item (16=41) (17=44) (18=45) (19=50) (20=64)	 		if item_type == 7 // veg
	recode item (21=66) (22=72) (23=99) (24=76) (25=84) (26=80) if item_type == 8 // fruit (in R2 - R4, mandarin = 99)

	* Naan and Eggs were left in pieces in midline; variable for inflation calculation 			
	gen price_midlinecomp = price
		replace price_midlinecomp = ms1_a if inlist(item,4,33)
		
********************************************************************************
** Part 3: Take the mean of the 2 enumerator values per district 
********************************************************************************		
	
	egen price_mean = mean(price), by(vc3 item round)
	* Variable for inflation calculation 
	egen price_midlinecomp_mean = mean(price_midlinecomp), by(vc3 item round)
	
	assert price_mean == price_midlinecomp_mean if !inlist(item,4,33)
	cap noi assert price_mean != price_midlinecomp_mean if inlist(item,4,33) // 6 obs from round 1, we are not using it
	
* Rename variables 		
	rename vc3 district 	
		
* Labels
	lab var item "Item"
	lab var price "Price per KG (in Afhganis)"
	lab var price_mean "Price per KG (in Afhganis), mean across enums"
	lab var price_midlinecomp "Price for Midline comparison (egg, naan in pieces)"
	lab var price_midlinecomp_mean "Price for Midline comparison (egg, naan in pieces), mean across enums"
	lab var item_type "Item type"
	order item_type, after(district)
	
	lab def item_type_l 3 "Bread" 4 "Meat" 5 "Dairy" 7 "Vegetables" 8 "Fruits"
	label val item_type item_type_l
	
	#delimit ;
	label define item_lab
		1 "Rice (high quality)"
		2 "Rice (low quality)"
		3 "Wheat flour"
		4 "Naan not made at home"
		7 "Beans"
		14 "Beef"
		15 "Veal"
		16 "Mutton"
		17 "Goat"
		18 "Chicken"
		24 "Milk (fresh)"
		26 "Yogurt"
		27 "Curd (chaka)"
		29 "Dogh"
		33 "Eggs"
		41 "Potato"
		44 "Tomato"
		45 "Okra"
		50 "Pumpkin"
		64 "Other vegetables (green pepper)"
		66 "Apple"
		72 "Orange"
		76 "Banana"
		80 "Mango"
		84 "Other fruit (lettuce)"
		99 "Mandarin" , modify;
	#delimit cr
	lab val item item_lab
	
	* Check potentially werid values that remain 
	tabstat price if round == 1 , by(item) s(min p50 mean max)
	tabstat price if round == 2, by(item) s(min p50 mean max)
	*Other fruit (let |        20      67.5  95.20833  222.2222
	tabstat price if round == 3, by(item) s(min p50 mean max)
	* Other fruit (let |  71.42857      87.5   95.3869  133.3333
	tabstat price if round == 4, by(item) s(min p50 mean max)
	*  Banana |        40  183.3333  174.6181     312.5
	* Other fruit (let |       100       200    193.75       300

	* Compare between rounds also 
	list item if mi(ms1_a_conv_kg) & mi(ms1_a_conv_gr) & ms1_a_unit == 3 
	
preserve 
	keep district item round price_mean price_midlinecomp_mean
	duplicates drop
	rename (price_mean price_midlinecomp_mean) (price_mean_r price_midlinecomp_mean_r)
	reshape wide price_mean_r price_midlinecomp_mean_r, i(district item) j(round)
	
	tempfile phonesvy_prices
	save `phonesvy_prices'
	
	use "${market_imputed_fl1}", clear 
	keep district item price
	
	merge 1:1 district item using "`phonesvy_prices'", assert (1 3) keep(3) nogen
	
	sort item district
	
	label var price "Follow-up 1 (Afs)"
	label var price_mean_r1 "R1 (Afs)"
	label var price_mean_r2 "R2 (Afs)"
	label var price_mean_r3 "R3 (Afs)"
	label var price_mean_r4 "R4 (Afs)"
	
	*export excel using "C:/Users/WB570123/Dropbox/DataWork/Phone_Survey/Output/Interim/market_check2_new.xlsx", firstrow(varlab) replace 
restore 	

* Save

	if	`c(stata_version)'>=14	{
		saveold "${market_imputed_phonesvy}", replace v(13)
	}
	else {
		save "${market_imputed_phonesvy}", replace
	}