* Globals 

* Input 
global assets_data        		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/assets_roster_phonesvy.dta"

* Output 
global non_assets_data        	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/other_assets_phonesvy.dta"


* non-DHS assets 
use "${assets_data}", clear
	
	*Merging to get ultrapoor id
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment PRA_lottery attrition_r*) assert(2 3) keep(3) nogen
	
	* Keep DHS assets only for now (and "none", asset == 0)
	keep if dhs == 0 | asset == 0 
	
	* Keep relevant variables
	keep hhid round asset l1_a l1_b attrition*  PRA_lottery treatment ultra_poor
	
	* l1_b is asked in r3 
	rename (l1_a l1_b) (l1_a_ l1_b_)
	
	reshape wide l1_a_ l1_b_, i(hhid asset) j(round)
	
	missings dropvars, force 
	
	* l1_a asked in R3 of HHs that were not survyed in R2
	gen asset_yes =  l1_a_2
		replace asset_yes = l1_a_3 if mi(asset_yes) & !mi(l1_a_3)
		
	* Reshape wide so we get one row per HH	
	drop l1_a_2 l1_a_3
	
	* Deal with HHs that don't have any assets 
	gen no_assets = (asset_yes == 1 & asset == 0)
	bys hhid : egen no_assets_tot = total(no_assets)
	drop no_assets
	rename no_assets_tot no_assets
	lab var no_assets "HH has none of these assets"

	separate l1_b_3, by(asset) veryshortlabel gen(l1_b_3_)
	separate asset_yes, by(asset) veryshortlabel gen(asset_yes_)
	
	drop asset asset_yes l1_b_3
	
	unab vars: l1_b_3_0 - asset_yes_49

	foreach var of local vars {
	    local `var'_l: var lab `var'
	}
	
	collapse (sum) l1_b_3_0 - asset_yes_49 (mean) no_assets treatment PRA_lottery attrition_r2 attrition_r3, by(hhid)
	
	foreach var of local vars {
	    lab var `var' "``var'_l'"
	}
	
	unab num_assets: l1_b_3_20 - l1_b_3_49
 
	 foreach var of local num_assets {
		local `var'_l: variable label `var'
		lab var `var' "Uses for IGA: ``var'_l'"
	 }
	 
	  unab own_assets: asset_yes_20 - asset_yes_49
	  
	 foreach var of local own_assets {
		local `var'_l: variable label `var'
		lab var `var' "HH owns: ``var'_l'"
	 }
	 
	* Number of assets owned 
	egen asset_num = rsum(asset_yes_*), missing 
		replace asset_num = 0 if asset_yes_0 == 1 // None 
		lab var asset_num "Number of other productive assets owned (of 30)"
	
	* Any asset owned (Yes/No dummy)
	gen asset_yes = asset_num
		replace asset_yes = 1 if asset_num > 0 & !mi(asset_num)
		lab var asset_yes "Any other productive assets owned"
	
	unique hhid if mi(asset_yes) // 73 HHs have data on whether or not the asset was used for IGA, but do not have a Yes/No own asset answer 
		// maybe a survey coding error 
	assert attrition_r2 == 1 if mi(asset_yes) // these were never surveyed in R2
	
	* Number of assets used for IGA (unconditional)
	egen num_asset_produse = rsum(l1_b_3*), missing
		replace num_asset_produse = 0 if l1_b_3_0 == 1 // None
		lab var num_asset_produse "Number of other productive assets owned and used for IGA (of 30)"
	
	* Any asset used for IGA (Yes/No dummy)
	gen asset_yes_produse = num_asset_produse
		replace asset_yes_produse = 1 if num_asset_produse > 0 & !mi(num_asset_produse)
		lab var asset_yes_produse "Any other productive assets used for IGA"

	
	save "${non_assets_data}", replace 
		