* Create total HH income - everything with Ag, using imputed HH paid income 


* Inputs 
	gl timeuse_hh_phonesvy 				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_hh_phonesvy.dta"	
	gl livestock_revenue_index_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_revenue_index_phonesvy.dta"
	gl crop_production_index_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/crop_production_index_phonesvy.dta"
	gl business_rev_earnings_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/business_rev_earnings_phonesvy.dta"
	gl phone_svy_profile   				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

	* Panel data 
	gl livestock_revenue_long_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/livestock_revenue_index_long_phonesvy.dta"  
	gl business_rev_earn_long_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/business_rev_earnings_long_phonesvy.dta"  
	gl crop_production_phonesvy_long	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/crop_production_index_phonesvy_long.dta"
	gl timeuse_hh_long_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/time_activities_hh_long_phonesvy.dta"   

		
* Outputs 
	gl revenues_income_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/revenues_income_phonesvy.dta"
	gl revenues_income_long_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/revenues_income_long_phonesvy.dta"

use "${livestock_revenue_index_phonesvy}", clear 
	merge 1:1 hhid using "${crop_production_index_phonesvy}", nogen
	merge 1:1 hhid using "${business_rev_earnings_phonesvy}", nogen
	merge 1:1 hhid using "${timeuse_hh_phonesvy}", keepusing(tot_hh_pay_imp_1 tot_hh_pay_imp_3 tot_pf_pay_imp_1 tot_pm_pay_imp_1 ) nogen

	merge 1:1 hhid using "${phone_svy_profile}", assert(2 3) keep(3) nogen  keepusing(attrition_r* treatment ultra_poor PRA_lottery)
	
	* Indicator 1 - this is the main indicator
	egen tot_hh_income_1 = rowtotal(tot_hh_pay_imp_1 tot_lstock_rev_1 tot_crop_rev_imp_2 tot_biz_rev_imp_1), missing
	
	* do not include HHs with only crop revenue (R2), it is weird 
	replace tot_hh_income_1 = . if attrition_r1 == 1
	lab var tot_hh_income_1 "Total Household Income and Revenues (AFN) (round 1,2)"
	
	* Indicator 1 without crop revenue
	egen tot_hh_income_noag_1 = rowtotal(tot_hh_pay_imp_1 tot_lstock_rev_1 tot_biz_rev_imp_1), missing
	* do not include HHs with only crop revenue (R2), it is weird 
	replace tot_hh_income_noag_1 = . if attrition_r1 == 1
	lab var tot_hh_income_noag_1 "Total Household Income and Revenues (AFN) (round 1) - no Ag"
	
	* Indicator 2 (without crop revenue)
	egen tot_hh_income_4 = rowtotal(tot_hh_pay_imp_3 tot_lstock_rev_4 tot_biz_rev_imp_4), missing
	* do not include HHs missing R4 variables 
	replace tot_hh_income_4 = . if (attrition_r4 == 1 | attrition_r3 == 1)
	lab var tot_hh_income_4 "Total Household Income and Revenues (AFN) (round 3,4) - no Ag"

	* Variable with number of income sources, capped at 4
	foreach var in tot_pf_pay_imp_1 tot_pm_pay_imp_1 tot_hh_pay_imp_1 tot_lstock_rev_1 tot_crop_rev_imp_2 tot_biz_rev_imp_1 tot_hh_pay_imp_3 tot_lstock_rev_4 tot_biz_rev_imp_4 {
		gen has_`var' = (`var'>0 & !mi(`var'))
			replace has_`var' = . if `var' == .
	}
	
	egen num_inc_source_1 = rowtotal(has_tot_pf_pay_imp_1 has_tot_pm_pay_imp_1 has_tot_lstock_rev_1 has_tot_crop_rev_imp_2 has_tot_biz_rev_imp_1), missing // has_tot_hh_pay_imp_1
	lab var num_inc_source_1 "Number of income sources (out of 5) (round 1,2)"
	* do not include HHs with only crop revenue (R2), it is weird 
	replace num_inc_source_1 = . if attrition_r1 == 1
	
	egen num_inc_source_4 = rowtotal(has_tot_hh_pay_imp_3 has_tot_lstock_rev_4 has_tot_biz_rev_imp_4), missing 
	lab var num_inc_source_4 "Number of income sources (out of 3) (round 3,4)"
	* do not include HHs missing R4 variables 
	replace num_inc_source_4 = . if (attrition_r4 == 1 | attrition_r3 == 1)
	
	
	* Save dataset
	save "${revenues_income_phonesvy}", replace  
	
	
* Prepapre the panel data version 	
	use "${livestock_revenue_long_phonesvy}", clear 
		merge 1:1 hhid round using "${business_rev_earn_long_phonesvy}", nogen 
		merge 1:1 hhid round using "${timeuse_hh_long_phonesvy}", nogen keepusing(tot_hh_pay_imp)
		merge 1:1 hhid round using "${crop_production_phonesvy_long}", nogen
	
	* Impute PM+PW Labor Income for R4 (from R3)
	preserve 
		keep hhid round tot_hh_pay_imp
		keep if round == 3
		duplicates drop 
		drop round 
		rename tot_hh_pay_imp tot_hh_pay_imp_3
		
		tempfile hh_pay_imp_3
		save `hh_pay_imp_3'
		
	restore
	
	merge m:1 hhid using `hh_pay_imp_3', assert(1 3) nogen
	
	gen tot_hh_pay_imp2 = tot_hh_pay_imp
		replace tot_hh_pay_imp2 = tot_hh_pay_imp_3 if mi(tot_hh_pay_imp2) & round == 4 & attrition_r4 == 0 & !mi(tot_hh_pay_imp_3)

	sum tot_hh_pay_imp2 tot_hh_pay_imp
	
	* Create total HH income variable without Ag and HH pay	, since we only have these two components cleanly in R1 and R4 
	* do not include tot_pmpw_pay_imp, but include imputed Ag
	egen tot_hh_income = rowtotal(tot_lstock_rev tot_biz_rev tot_hh_pay_imp2), missing
		replace tot_hh_income = . if !inlist(round,1,4)
	lab var tot_hh_income "Total Household Income and Revenues (AFN) - imputed Ag, HH pay (pooled)"
	
* Save dataset
	save "${revenues_income_long_phonesvy}", replace 