/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	Feb 24, 2020
Last udpate on: October 18, 2021

Written by:  	Thomas Escande			

Revision: 		Yulia Belyakova

********************************************************************************	

THIS DO FILE: 	Takes the dataset "current roster" and construct some of the variables that will be useful later on


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1 - Basic cleaning and preparing dataset
				Part 2 - 
  

*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

	clear all
	set more off
	set maxvar 20000

	* Input files
		gl all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"
		gl phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		gl current_roster_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"

	*Ouput
		gl roster_final_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/current_roster_final_phonesvy.dta"		
	
********************************************************************************
** Part 1: Merge to have lady of the household and primary man number
********************************************************************************

	use "${current_roster_phonesvy}", clear
		cap drop __0000*
	
	merge m:1 hhid using "${phone_svy_profile}", keepusing(treatment  PRA_lottery ultra_poor) keep(3) assert(2 3) nogen //Some households from the profile were not part of the follow up. Only keep the ones that merge
	
********************************************************************************
** Part 2: Specific variables like interactions for analysis later on
********************************************************************************
*Variable indicating if household has only a primary woman (ie no primary man)

*Create variable = 1 if no primary man in household	
	assert !mi(no_pm)
	egen pm = total(no_pm), by(hhid round)
		replace pm = 1 if pm == 0
		replace pm = 0 if pm > 1 

	gen hh_only_pf = 1 - pm
	lab var hh_only_pf "Households with only primary females"
	
*Dummy variable for whether member is male or female children 6-14 (0==woman 6-14) (1==male 6-14)
	gen     kid_6_14_m = 0 if child_age > 5 & child_age < 15 & !mi(child_age) & child_sex == 2 //Is children 6-14 female
	replace kid_6_14_m = 1 if child_age > 5 & child_age < 15 & !mi(child_age) & child_sex == 1 //Is children 6-14 male
	lab var kid_6_14_m "Male"
	
*Interaction
	gen t_kid_6_14_m = treatment * kid_6_14_m
	lab var t_kid_6_14_m "Treatment x Male"
	
*Dummy variable for whether member is male or female children 15-17 (0==woman 15-17) (1==male 15-17 )
	gen     kid_15_17_m = 0 if child_age >= 15 & child_age <= 17 & !mi(child_age) & child_sex == 2 //Is children 15-17 female
	replace kid_15_17_m = 1 if child_age >= 15 & child_age <= 17 & !mi(child_age) & child_sex == 1 //Is children 15-17 male
	lab var kid_15_17_m "Male"
	
*Interaction
	gen t_kid_15_17_m = treatment * kid_15_17_m
	lab var t_kid_15_17_m "Treatment x Male"
	
*Dummy variable for whether member is male or female children 15-18 (0==woman 15-18) (1==male 15-18 )
	gen     kid_15_18_m = 0 if child_age >= 15 & child_age <= 18 & !mi(child_age) & child_sex == 2 //Is children 15-18 female
	replace kid_15_18_m = 1 if child_age >= 15 & child_age <= 18 & !mi(child_age) & child_sex == 1 //Is children 15-18 male
	lab var kid_15_18_m "Male"
	
*Interaction
	gen t_kid_15_18_m = treatment * kid_15_18_m
	lab var t_kid_15_18_m "Treatment x Male"

*Dummy variable for whether member is male or female children 6-17 (0==woman 6-17) (1==male 6-17 )
	gen     kid_6_17_m = 0 if child_age > 5 & child_age <= 17 & !mi(child_age) & child_sex == 2 //Is children 6-17 female
	replace kid_6_17_m = 1 if child_age > 5 & child_age <= 17 & !mi(child_age) & child_sex == 1 //Is children 6-17 male
	lab var kid_6_17_m "Male"
	
*Interaction
	gen t_kid_6_17_m = treatment * kid_6_17_m
	lab var t_kid_6_17_m "Treatment x Male"
	
*Dummy variable for whether member is male or female children school age 6-18 (0==woman) (1==male)
	gen     kid_6_18_m = 0 if (inrange(child_age,6,18) | x6!=. | b15b!=. ) & child_sex == 2 //Is children 6-18 female
	replace kid_6_18_m = 1 if (inrange(child_age,6,18) | x6!=. | b15b!=. ) & child_sex == 1 //Is children 6-18 male
	lab var kid_6_18_m "Male"
	
*Interaction
	gen t_kid_6_18_m = treatment * kid_6_18_m
	lab var t_kid_6_18_m "Treatment x Male"
	
	* Save data
		if	`c(stata_version)'>=14	{
			saveold "${roster_final_phonesvy}", replace v(13)
		}
		else {
			save "${roster_final_phonesvy}", replace
		}	
