* Construct extra variables used for balance checks 

global all_HH_nopii_bl 			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
global current_roster_fl1 		"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_fl1.dta"
global data_for_analysis_fl1	"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
* NB: this version of time activities does not include changes to wages done by Thomas on the AEJ branch 
global time_activities_up 		"${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_up_fl1.dta"

global data_for_analysis_bl	"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"


* Output
gl data_for_analysis_fl1_phonesvy "${TUP_DB}/Phone_Survey/DataSets/Intermediate/data_for_analysis_fl1_phonesvy.dta"
gl data_for_analysis_bl_phonesvy  "${TUP_DB}/Phone_Survey/DataSets/Intermediate/data_for_analysis_bl_phonesvy.dta"

	use "${all_HH_nopii_bl}", clear
		
	* Generating additional variables
	* HH head is female
		gen hhhead_female = (hh_head_gender==2)
			lab var hhhead_female "Primary Woman Is Household Head"
		keep hhid hhhead_female
		
		tempfile hhhead_female
		save `hhhead_female'
	
	* Roster 
	use "${current_roster_fl1}", clear 
	
		*Create variables necessary to the analysis
		*First merge with data analysis bl to get the position of primary male / female in the roster
		
		merge m:1 hhid using "$all_HH_nopii_bl", assert(3) nogen keepusing(hhh_name2 lady_hh2)
			rename (hhh_name2 lady_hh2) (position_pm position_pf)
		
		gen pf = (position_pf == member) //They are all female, checked
		gen pm = (position_pm == member) //They are all male, checked	
		
	*Dummy variable for whether member is primary man (pm) or primary female (pf) (0==woman) (1==man)
		gen     pf_pm = 0 if  pf == 1 //Is primary female
		replace pf_pm = 1 if  pm == 1 //Is primary man
		lab var pf_pm "Male"
		
		*Literacy variable
		gen 	literacy = 0
		replace literacy = 1   if b13 == 3
		replace literacy = b13 if b13 == .d | b13 == .r | b13 == .
		label var literacy "Literacy Rate"
		
		gen literacy_pf = literacy if pf == 1
		gen literacy_pm = literacy if pm == 1
		
		* Illiteracy
			foreach var in literacy  {
				lab var `var'_pf "Primary Woman"
				lab var `var'_pm "Primary Man"
			}
			gen		illiteracy_pf = 1 if literacy_pf == 0
			replace illiteracy_pf = 0 if literacy_pf == 1
			gen		illiteracy_pm = 1 if literacy_pm == 0
			replace illiteracy_pm = 0 if literacy_pm == 1
			lab var illiteracy_pm "Primary Man Is Illiterate"
			lab var illiteracy_pf "Primary Woman Is Illiterate"	
			
		foreach var in literacy {
			lab var `var'_pm "Primary Man"
			lab var `var'_pf "Primary Woman"
		}

		collapse (max) illiteracy_pf illiteracy_pm, by(hhid)
		
		lab var illiteracy_pm "Primary Man Is Illiterate"
		lab var illiteracy_pf "Primary Woman Is Illiterate"	
	
		tempfile literacy
		save `literacy'
		
		use "${time_activities_up}", clear 
			keep hhid did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork
			
			collapse (max) did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork, by(hhid)
			
			lab var did_livestock "HH Livestock"
			lab var did_ownFarming "HH Agriculture"
			lab var did_ownBiz "HH Non-Agricultural Business"
			lab var did_oFarm "Casual Labor: Agricultural"
			lab var did_maid "Casual Labor: Maid Services"
			lab var did_outWork "Casual Labor: Non-Agricultural"
			lab var did_salEmp "Salaried or Formal Employment"
			lab var did_oPaidWork "Other Paid Work"
			
			tempfile activities
			save `activities'
		
		use "${data_for_analysis_fl1}", clear 
			merge 1:1 hhid using "`hhhead_female'", assert(3) nogen
			merge 1:1 hhid using "`literacy'", assert(3) nogen
			merge 1:1 hhid using "`activities'", assert(1 3) nogen
			
		* This should be original follow-up construction (no phone survey)	
		clonevar psy_5index_z_f = psy_indexC_sdC_fl1
		clonevar fin_index_sdC_bl = fin_index_sdC_fl1	
		
		cap drop tot_hh_income tot_hh_income_ppp
		egen tot_hh_income = rowtotal(tot_lstock_revenue tot_crop_revenue tot_biz_revenue), missing
		gen tot_hh_income_ppp = tot_hh_income/$ppp_2021
		lab var tot_hh_income_ppp "Total Household Income and Revenues, Excluding Paid Labor (US\textdollar)"
			
			save "${data_for_analysis_fl1_phonesvy}", replace 
			

* Baseline 
	use "${data_for_analysis_bl}", clear 
	
		clonevar loan = m5
		
		winsor2 loan if loan>0 , s(_win) c(0 95) by(ultra_poor treatment) 
		replace loan_win = 0 if loan == 0
		
		gen loan_ppp = loan*${ppp_factor}
		gen loan_win_ppp = loan_win*${ppp_factor}

		lab var loan_ppp "HH Total Outstanding Cash Loans (US\textdollar)"
		lab var loan_win_ppp "HH Total Outstanding Cash Loans (US\textdollar) - Winsorized"
		
		gen tot_hh_pay_ppp = .
		
		egen tot_hh_income = rowtotal(tot_lstock_revenue tot_crop_revenue tot_biz_revenue), missing
		gen tot_hh_income_ppp = tot_hh_income*${ppp_factor}
		lab var tot_hh_income_ppp "Total Household Income and Revenues, Excluding Paid Labor (US\textdollar)"
		
		lab var tot_hh_pay_ppp "Paid Labor Income (US\textdollar)"
		lab var tot_crop_revenue_ppp "HH Agriculture Revenue (US\textdollar)"
		lab var tot_biz_revenue_ppp "HH Non-Agricultural Business Revenue (US\textdollar)"
		lab var fin_index_sdC_bl "Financial Inclusion Index"
		lab var saving_ppp " HH Total Savings (US\textdollar)"
		lab var saving_win_ppp " HH Total Savings (US\textdollar) - Winsorized"
		
			save "${data_for_analysis_bl_phonesvy}", replace 


			
			