* Input 
	gl phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"	 
	gl wellbeing_index 				"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta"  
	gl sample_indicators_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta"  
	gl wellbeing_index_nup_phonesvy "${TUP_DB}/Phone_Survey/DataSets/Intermediate/wellbeing_index_nup_phonesvy.dta" 
 
	* Output in Followup_1_Phone folder  
	gl wellbeing_index_bl_phonesvy		"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/wellbeing_index_bl.dta"	 
	gl wellbeing_index_ses_bl_phonesvy	"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/wellbeing_index_ses_bl.dta"	 
 
* Controls globals  
	global controls i.PRA_lottery  
	global panel_controls i.PRA_lottery ib(4).round 		 
	 
********************************************************************************************************************  
** Part 1: Constructing Index for ultra poor only, standardized by control group  
***********************************************************************************************************************  
 
	use "${wellbeing_index}", clear  
	 
		merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition* anyround all_rounds) keep(3) nogen // 47 HHs are missing BL data 
	 
	* Merge on endline sample indicators   
		merge 1:1 hhid using "${sample_indicators_phonesvy}", nogen keepusing(psy_indexC_sdC_s)  
			rename psy_indexC_sdC_s sample   
 
	keep if sample == 1 		 
	 
	assert (anyround == 1 | mi(anyround))  
	 
	* UP HHs only	 
	keep if ultra_poor == 1  
	 
	* Control dummy 
	gen 	control = treatment==0 
	replace control = 0 if mi(treatment) 
	lab var control "HH is part of control group"	 
		 
	global allcategories satisf hap cesd 
	 
	rename *_f * 
	drop *index* *score_z* 
	 
	*Control vs treatment  
		foreach suffix in "" _m {  
			foreach groupvar in $allcategories {  
				egen `groupvar'_z_sdC`suffix'_bl = weightave(`groupvar'_score`suffix'), normby(control)  
  
				*Labelization of scores  
				if "`groupvar'"=="satisf" {  
					global detail "Life satisfaction (WVS)"  
				}  
				if "`groupvar'"=="cesd" {  
					global detail "Depression (CESD)"  
				}  
				if "`groupvar'"=="hap" {  
					global detail "Happiness (WVS)"  
				}  
 
				  
				if "`suffix'" == "_m" {  
					label var `groupvar'_z_sdC`suffix'_bl "$detail standardized score (control) - Man of HH"  
					}  
				else  {  
					label var `groupvar'_z_sdC`suffix'_bl "$detail standardized score (control)"   
					}  
			}   
			  
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				  
				egen psy_indexC_sdC`suffix'_bl = weightave(satisf_z_sdC`suffix'_bl hap_z_sdC`suffix'_bl cesd_z_sdC`suffix'_bl), normby(control)  
		}  
  
		  
	*Labelling final variables  
		label var psy_indexC_sdC_bl 		"Psychological Well-being Index (3 items) sd(control)"  
		label var psy_indexC_sdC_m_bl		"Psychological Well-being Index (3 items) sd(control) - Man of HH"  
 
	preserve 	 
		* Keep the phone survey sample : any round 
		keep if anyround == 1 		  
	 
		drop *index* *z_sdC* 
		 
		*Control vs treatment  
		foreach suffix in "" _m {  
			foreach groupvar in $allcategories {  
				egen `groupvar'_z_sdC`suffix'_bl_phone = weightave(`groupvar'_score`suffix'), normby(control)  
  
				*Labelization of scores  
				if "`groupvar'"=="satisf" {  
					global detail "Life satisfaction (WVS)"  
				}  
				if "`groupvar'"=="cesd" {  
					global detail "Depression (CESD)"  
				}  
				if "`groupvar'"=="hap" {  
					global detail "Happiness (WVS)"  
				}  
 
				  
				if "`suffix'" == "_m" {  
					label var `groupvar'_z_sdC`suffix'_bl_phone "$detail standardized score (control) - Man of HH"  
					}  
				else  {  
					label var `groupvar'_z_sdC`suffix'_bl_phone "$detail standardized score (control)"   
					}  
			}   
			  
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				  
				egen psy_indexC_sdC`suffix'_bl_phone = weightave(satisf_z_sdC`suffix'_bl_phone hap_z_sdC`suffix'_bl_phone cesd_z_sdC`suffix'_bl_phone), normby(control)  
		}  
  
		  
	*Labelling final variables  
		label var psy_indexC_sdC_bl_phone 		"Psychological Well-being Index (3 items) sd(control)"  
		label var psy_indexC_sdC_m_bl_phone		"Psychological Well-being Index (3 items) sd(control) - Man of HH"  
		 	 
		keep hhid psy_indexC_sdC_bl_phone psy_indexC_sdC_m_bl_phone 
		tempfile index_phone 
		save `index_phone' 
	restore  
		 
		merge 1:1 hhid using "`index_phone'", assert(1 3) nogen 
		 
preserve 	 
		* Keep the phone survey sample : any round 
		keep if all_rounds == 1 		  
	 
		drop *index* *z_sdC* 
		 
		*Control vs treatment  
		foreach suffix in "" _m {  
			foreach groupvar in $allcategories {  
				egen `groupvar'_z_sdC`suffix'_bl_phone_all = weightave(`groupvar'_score`suffix'), normby(control)  
  
				*Labelization of scores  
				if "`groupvar'"=="satisf" {  
					global detail "Life satisfaction (WVS)"  
				}  
				if "`groupvar'"=="cesd" {  
					global detail "Depression (CESD)"  
				}  
				if "`groupvar'"=="hap" {  
					global detail "Happiness (WVS)"  
				}  
 
				  
				if "`suffix'" == "_m" {  
					label var `groupvar'_z_sdC`suffix'_bl_phone_all "$detail standardized score (control) - Man of HH (all rounds)"  
					}  
				else  {  
					label var `groupvar'_z_sdC`suffix'_bl_phone_all "$detail standardized score (control) (all rounds)"   
					}  
			}   
			  
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				  
				egen psy_indexC_sdC`suffix'_bl_phone_all = weightave(satisf_z_sdC`suffix'_bl_phone_all hap_z_sdC`suffix'_bl_phone_all cesd_z_sdC`suffix'_bl_phone_all), normby(control)  
		}  
  
		  
	*Labelling final variables  
		label var psy_indexC_sdC_bl_phone_all 		"Psychological Well-being Index (3 items) sd(control) (all rounds)"  
		label var psy_indexC_sdC_m_bl_phone_all		"Psychological Well-being Index (3 items) sd(control) - Man of HH (all rounds)"  
		 	 
		keep hhid psy_indexC_sdC_bl_phone_all psy_indexC_sdC_m_bl_phone_all 
		tempfile index_phone_all 
		save `index_phone_all' 
	restore  
		 
		merge 1:1 hhid using "`index_phone_all'", assert(1 3) nogen		 
  
	*Saving dataset with index for ultra poor only standardized by control group  
		if	`c(stata_version)'>=14	{  
			saveold "${wellbeing_index_bl_phonesvy}", replace v(13)  
		}  
		else {  
			save "${wellbeing_index_bl_phonesvy}", replace  
		}	  
		
		 
********************************************************************************************************************  
** Part 2: Constructing Index for the full sample with NUP, standardized by control group  
******************************************************************************************************************* 		 
		 
use "${wellbeing_index}", clear 		 
 
merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition* anyround all_rounds) keep(3) nogen // 47 HHs are missing BL data 
	 
	* Merge on endline sample indicators   
		merge 1:1 hhid using "${wellbeing_index_nup_phonesvy}",  keepusing(psy_indexC_sdC_NUP) keep(3) nogen 
			gen sample = !mi(psy_indexC_sdC_NUP) 
 
	keep if sample == 1 		 
	 
	assert (anyround == 1 | mi(anyround))  
	 
	* Control/NUP dummy 
	gen      control_nup = 0  
			replace  control_nup = 1 if treatment == 0 &  ultra_poor == 1	  
		 
	global allcategories satisf hap cesd 
	 
	rename *_f * 
	drop *index* *score_z* 
	 
	*Control vs treatment  
		foreach suffix in "" _m {  
			foreach groupvar in $allcategories {  
				egen `groupvar'_z_sdC_NUP`suffix'_bl = weightave(`groupvar'_score`suffix'), normby(control_nup)  
  
				*Labelization of scores  
				if "`groupvar'"=="satisf" {  
					global detail "Life satisfaction (WVS)"  
				}  
				if "`groupvar'"=="cesd" {  
					global detail "Depression (CESD)"  
				}  
				if "`groupvar'"=="hap" {  
					global detail "Happiness (WVS)"  
				}  
 
				  
				if "`suffix'" == "_m" {  
					label var `groupvar'_z_sdC_NUP`suffix'_bl "$detail standardized score (control) - Man of HH"  
					}  
				else  {  
					label var `groupvar'_z_sdC_NUP`suffix'_bl "$detail standardized score (control)"   
					}  
			}   
			  
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				  
				egen psy_indexC_sdC_NUP`suffix'_bl = weightave(satisf_z_sdC_NUP`suffix'_bl hap_z_sdC_NUP`suffix'_bl cesd_z_sdC_NUP`suffix'_bl), normby(control_nup)  
		}  
  
		  
	*Labelling final variables  
		label var psy_indexC_sdC_NUP_bl 		"Psychological Well-being Index (3 items) sd(control)"  
		label var psy_indexC_sdC_NUP_m_bl		"Psychological Well-being Index (3 items) sd(control) - Man of HH"  
  
	*Saving dataset with index for ultra poor only standardized by control group  
		if	`c(stata_version)'>=14	{  
			saveold "${wellbeing_index_ses_bl_phonesvy}", replace v(13)  
		}  
		else {  
			save "${wellbeing_index_ses_bl_phonesvy}", replace  
		}	 