* Calculate PW psy well-being index for all survey rounds, standardized by UP at Baseline 	
	
	* Input
	gl phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"	
	gl wellbeing_index_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/wellbeing_index_bl.dta"
	gl wellbeing_index_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_ses_fl1.dta"
	gl sample_indicators_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 
	
		
	* Output in Followup_1_Phone folder 
	gl wellbeing_index_ses_bl_phonesvy	"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/wellbeing_index_ses_bl_phonesvy.dta"	
	
		
******************************************************************************************************************** 
* Constructing Index for ultra poor only, standardized by control group 
*********************************************************************************************************************** 

	use "${wellbeing_index_bl}", clear 
	
	keep hhid satisf_score_f hap_score_f cesd_score_f happy_i27_f cesd_f_md
	rename *_f *
	rename happy_i27 happy_i27_f
	
	gen wave = 0
	
	tempfile psy_bl
	save `psy_bl'
	
	use "${wellbeing_index_fl1}", clear 
	
	keep hhid satisf_score_fl1 hap_score_fl1 cesd_score_fl1 happy cesd_md
	
	rename *_fl1 *
	
	rename (happy cesd_md) (happy_i27_f cesd_f_md)
	
	gen wave = 1 
	
	tempfile psy_fl1
	save `psy_fl1'
	
	use "${wellbeing_index_phonesvy}", clear 
	
	keep hhid satisf_score hap_score cesd_score happy cesd_md
	
	egen todrop = rowmiss(satisf_score hap_score cesd_score)
	drop if todrop == 3
	drop todrop
	
	rename (happy cesd_md) (happy_i27_f cesd_f_md)
	
	gen wave = 2 
	
	append using "`psy_bl'"
	append using "`psy_fl1'"
	
	merge m:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment) keep(3) nogen 
	
	* Merge on endline sample indicators  
		merge 1:1 hhid using "${sample_indicators_phonesvy}", nogen keepusing(psy_indexC_sdC_s) 
			rename psy_indexC_sdC_s sample  

	keep if sample == 1 	 
	
	* Control dummy
	gen 	control_bl = (ultra_poor == 1 & wave == 0)
	lab var control_bl "HH is part of control group"	
		
	global allcategories satisf hap cesd
	
	*Control vs treatment 
		foreach suffix in "" { 
			foreach groupvar in $allcategories { 
				egen `groupvar'_z_sdC`suffix'bl = weightave(`groupvar'_score`suffix'), normby(control_bl) 
 
				*Labelization of scores 
				if "`groupvar'"=="satisf" { 
					global detail "Life satisfaction (WVS)" 
				} 
				if "`groupvar'"=="cesd" { 
					global detail "Depression (CESD)" 
				} 
				if "`groupvar'"=="hap" { 
					global detail "Happiness (WVS)" 
				} 

				label var `groupvar'_z_sdC`suffix'bl "$detail standardized score (control)"  
			
			}  
			 
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				 
				egen psy_indexC_sdC`suffix'bl = weightave(satisf_z_sdC`suffix'bl hap_z_sdC`suffix'bl cesd_z_sdC`suffix'bl), normby(control_bl) 
		} 
 
		 
	* Reshape wide 
		drop control_bl
		rename * *_
		rename (hhid_ wave_ treatment_ ultra_poor_) (hhid wave treatment ultra_poor)
		
		reshape wide satisf_score_ hap_score_ cesd_score_ satisf_z_sdCbl_ hap_z_sdCbl_ cesd_z_sdCbl_ psy_indexC_sdCbl_ happy_i27_f_ cesd_f_md_, i(hhid) j(wave)
		
		rename (*_0 *_1 *_2) (*_bl *_fl1 *_phonesvy)

		foreach suffix in "_bl" "_fl1" "_phonesvy" {
			rename satisf_score`suffix' satisf_score_f`suffix'
			
			lab var psy_indexC_sdCbl`suffix' "Psychological Well-being Index (3 Items)" 
			lab var satisf_z_sdCbl`suffix' "Life Satisfaction (WVS) Index" 
			lab var hap_z_sdCbl`suffix' "Happiness (WVS) Index"
			lab var cesd_z_sdCbl`suffix' "Depression (CESD) Index (Negatively Coded)"
			
			lab var happy_i27_f`suffix'		 "Primary Woman Is Very Happy or Quite Happy"
			lab var satisf_score_f`suffix' "Primary Woman Is Depressed (7-CESD $\geq$ 8)"
			lab var cesd_f_md`suffix' 	 "Primary Woman Is Depressed (7-CESD>=8)"
		}
 
	*Saving dataset with index for ultra poor only standardized by control group 
		if	`c(stata_version)'>=14	{ 
			saveold "${wellbeing_index_ses_bl_phonesvy}", replace v(13) 
		} 
		else { 
			save "${wellbeing_index_ses_bl_phonesvy}", replace 
		}	 