clear all
set more off
set maxvar 20000

	* Input
		gl asset_index_up_bl 			"${TUP_DB}/Baseline/DataSets/Intermediate/asset_index_up_bl.dta"
		gl phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"	
		gl sample_indicators_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 

	* Output
		gl asset_index_up 		"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/asset_index_up_bl.dta"

	* Controls globals 
		global controls i.PRA_lottery 
		global panel_controls i.PRA_lottery ib(4).round 		

********************************************************************************
	** Part 1: Basic cleaning
********************************************************************************
	
use "${asset_index_up_bl}", clear

		merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment fl1_sample phone_anytime phone_fl1 phone_initial_sample phone_verified call_status_r* attrition* no_round all_rounds anyround) keep(3) nogen // 47 HHs are missing BL data
	
	* Keep the phone survey sample  
		merge m:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* all_rounds) keep(3) nogen 
		 
	* Merge on endline sample indicators  
		merge 1:1 hhid using "${sample_indicators_phonesvy}", nogen keepusing(wealth_score_sdC_s) 
			rename wealth_score_sdC_s sample  
		
		keep if sample == 1 
		
		assert (anyround == 1 | mi(anyround)) 

		drop wealth_score property_score
		
		loc	assets	num_radio_CD  num_TV  num_DishTV  num_VCR_DVD  num_fridge  num_generator  num_matress  num_mobile_phone  num_non_mobilephone ///
					num_iron  num_bedframe  num_jewelry  num_mosquitonet  num_mosq_repel_candle  num_fan  num_camera ///
					/*num_other: Exclude for now, as they are extra assets but not sure that the ones who did not mention them actually don't have them or just did
					not mention them */
		loc property own_house_Land own_nonHouse_Land own_othHouse 

		pca `assets', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict wealth_score, score 
			lab var wealth_score "Asset-based wealth index (PCA) (hh assets excluding land/property)" 

		*Standardizing  
			egen wealth_score_sdC = weightave(wealth_score), normby(control)  
			local lab_wealth_score_sdC : variable label wealth_score 
			label var wealth_score_sdC "Standardized `lab_wealth_score'" 		
			
		pca `property', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict property_score, score 
			lab var property_score "Property-based index (PCA), owning dwelling and land" 

		preserve 	
			* Keep the phone survey sample: any round   			 			
			keep if anyround == 1 
		
			pca `assets', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict wealth_score_phone, score 
			lab var wealth_score_phone "Asset-based wealth index (PCA) (hh assets excluding land/property) (any round)" 
			 
		*Standardizing  
			drop wealth_score_sdC
			egen wealth_score_sdC_phone = weightave(wealth_score_phone), normby(control)  
			local lab_wealth_score_sdC_phone : variable label wealth_score_sdC_phone 
			label var wealth_score_sdC_phone "Standardized `lab_wealth_score_sdC_phone'" 	
				
		pca `property', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict property_score_phone, score 
			lab var property_score_phone "Property-based index (PCA), owning dwelling and land (any round)" 
			
			keep hhid wealth_score_phone property_score_phone wealth_score_sdC_phone
			tempfile index_phone
			save `index_phone'
	restore 
		
		merge 1:1 hhid using "`index_phone'", assert(1 3) nogen	
		
preserve 	
			* Keep the phone survey sample: all rounds 		 			
			keep if all_rounds == 1
			
			pca `assets', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict wealth_score_phone_all, score 
			lab var wealth_score_phone_all "Asset-based wealth index (PCA) (hh assets excluding land/property) (all rounds)" 
			 
		*Standardizing  
			drop wealth_score_sdC
			egen wealth_score_sdC_phone_all = weightave(wealth_score_phone_all), normby(control)  
			local lab_wealth_score_sdC_phone_all : variable label wealth_score_sdC_phone_all
			label var wealth_score_sdC_phone_all "Standardized `lab_wealth_score_sdC_phone'" 	
				
		pca `property', mineigen(1) means 

		* Generates the wealth distribution "wealthscore"
			predict property_score_phone_all, score 
			lab var property_score_phone_all "Property-based index (PCA), owning dwelling and land (all rounds)" 
			
			keep hhid wealth_score_phone_all property_score_phone_all wealth_score_sdC_phone_all
			tempfile index_phone_all
			save `index_phone_all'
	restore 
		
		merge 1:1 hhid using "`index_phone_all'", assert(1 3) nogen			
	
*Saving
			if	`c(stata_version)'>=14	{
				saveold "${asset_index_up}", replace v(13)
			}
			else {
				save "${asset_index_up}", replace
			}	


