	* Input
	gl data_for_analysis_bl			"${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"

	gl total_expenditure_phonesvy 	"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/total_expenditure_bl_phonesvy.dta"
	gl asset_index_up 				"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/asset_index_up_bl.dta"
	gl wellbeing_index_phonesvy		"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/wellbeing_index_bl.dta"	 
	gl foodsecurity_bl_phone 		"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/food_security_index_bl.dta"
	gl f_empowerment_bl_phone		"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/f_empowerment_bl.dta" 
	gl foodsecurity_bl 			    "${TUP_DB}/Baseline/DataSets/Intermediate/food_security_index_bl.dta"
	gl livestock_rev_index_bl_phonesvy	  "${TUP_DB}/Baseline_Phone/DataSets/Intermediate/livestock_rev_index_bl_phonesvy.dta"
	gl labor_bl_phonesvy 					"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/labor_bl_phonesvy.dta"
	gl sample_indicators_phonesvy			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 
		
* Controls globals 
	global controls i.PRA_lottery 
	global panel_controls i.PRA_lottery ib(4).round 		
		
		
	* Output in Followup_1_Phone folder 
	gl  data_for_analysis_bl_phonesvy	"${TUP_DB}/Baseline_Phone/DataSets/Final/data_for_analysis_bl_phonesvy.dta"
		
	* Outcomes with no changes in construction
 	use "${data_for_analysis_bl}", clear 
	
	* Merge endline profile data 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(fl1_sample attrition_r* anyround all_rounds PRA_lottery) keep(3) nogen
	
	* Merge on endline sample indicators 
	merge 1:1 hhid using "${sample_indicators_phonesvy}", nogen keep(1 3)

	keep hhid ultra_poor treatment PRA_lottery b3 loan saving saving_win ///
		did_labor_pf did_livestock did_ownFarming did_ownBiz did_mkt_outhh ///
		hhhead_female illiteracy_pf diarrhea_yes vaccinecard_yes ///
		tot_crop_revenue tot_biz_revenue happy_i27_f satisf_score_f cesd_f_md own_mobile_phone ///
		attrition_r* anyround all_rounds *_s
							
	* Merge on outcomes with changes in construction	
		merge 1:1 hhid using "${total_expenditure_phonesvy}", assert(2 3) keep(3) nogen
		merge 1:1 hhid using "${asset_index_up}", keep(1 3) keepusing(wealth_score* property_score*) nogen
		merge 1:1 hhid using "${wellbeing_index_phonesvy}", keep(1 3) keepusing(psy_indexC_sdC_bl_phone psy_indexC_sdC_m_bl_phone psy_indexC_sdC_bl_phone_all psy_indexC_sdC_m_bl_phone_all) nogen
		merge 1:1 hhid using "${foodsecurity_bl_phone}", keep(1 3) keepusing(index_sdC_food_sec_phone index_sdC_food_sec_phone_all) nogen
		merge 1:1 hhid using "${f_empowerment_bl_phone}", keep(1 3) keepusing(index_sdC_f_empowerment_3c index_sdC_f_emp_3c_phone_all) nogen
			rename index_sdC_f_empowerment_3c index_sdC_f_emp_3c_phone
		merge 1:1 hhid using "${foodsecurity_bl}",  assert(2 3) keep(3) keepusing(c14_7 c14_3_ac c14_5_ac) nogen
		merge 1:1 hhid using "${livestock_rev_index_bl_phonesvy}",  assert(2 3) keep(3) keepusing(tot_lstock_revenue) nogen
		merge 1:1 hhid using "${livestock_ass_index_bl_phonesvy}",  keep(1 3) keepusing(tot_lstock_value tot_lstock_value_med) nogen
			rename (tot_lstock_value tot_lstock_value_med) (tot_lstock_value_4 tot_lstock_value_med_4)
		merge 1:1 hhid using "${labor_bl_phonesvy}", keep(1 3) nogen // 1 HH missing earnings?

		* Fix -99 in c14_7 
		mvdecode c14_7, mv(-99=.r\-98=.d)

	* Add income and revenues 	
		 
		* Create total HH income
		** Indicator 1 (everything, with imputed HH income)
		egen tot_hh_income = rowtotal(tot_hh_pay_imp tot_lstock_revenue tot_crop_revenue tot_biz_revenue), missing
		lab var tot_hh_income "Total Income and Revenues (Indicator 1)"
		
		* Indicator 2	
		gen tot_inc_miss = 0
			replace tot_inc_miss = 1 if ((mi(tot_hh_pay) | mi(tot_biz_revenue)))
			lab var tot_inc_miss "HH pay (after member level imputation) or biz revenue is missing"
			tab tot_inc_miss
			
			reg tot_inc_miss treatment 
		
		egen tot_hh_inc_nomiss = rowtotal(tot_hh_pay tot_lstock_revenue tot_crop_revenue tot_biz_revenue) if !mi(tot_hh_pay) & !mi(tot_biz_revenue), missing

		* Winsorize value of livestock at 99th pct by treatment to be consistent with endline 
		foreach var in tot_lstock_value_4 {
			winsor2 `var', by(treatment) cuts(0 99) suff(_w99t)
			replace `var'_w99t = `var' if mi(`var'_w99t)
			local l_`var' : variable label `var'
			lab var `var'_w99t "`l_`var'' - Treatment Winsorized (99%)"
		}		
			
		* Overall Economy CPI variables 
		* later add if we can: tot_hh_income tot_hh_income_nomiss tot_hh_pay_imp
		local econ_cpi_vars "saving loan tot_hh_income tot_hh_inc_nomiss tot_hh_pay_imp tot_hh_pay tot_lstock_revenue tot_crop_revenue tot_biz_revenue tot_lstock_value_4 tot_lstock_value_med_4 tot_lstock_value_med_4_w99t"
		
		foreach var in `econ_cpi_vars' {
			cap confirm var `var'
			if !_rc { // if the variable exists 
				local l_`var' : variable label `var'
				gen `var'_ca18 = `var' * ($cpi_econ_fl1 / $cpi_econ_bl)
				lab var `var'_ca18 "`l_`var''"
			}
		}

		
	* Label
	lab var index_sdC_f_emp_3c_phone		  "Women's Empowerment Index (3 components)"
	lab var index_sdC_f_emp_3c_phone_all	  "Women's Empowerment Index (3 components)"
	lab var tot_lstock_value_4_ca18       "Total Value of TUP Livestock (2018 AFN)" 
	lab var tot_lstock_value_med_4_ca18 	"Total Value of TUP Livestock (2018 AFN)" 
	lab var tot_lstock_value_4       		"Total Value of TUP Livestock (AFN)" 
	lab var tot_lstock_value_med_4 		"Total Value of TUP Livestock (AFN)" 
	lab var index_sdC_food_sec_phone	"Food Security Index"	
	lab var index_sdC_food_sec_phone_all "Food Security Index"
	lab var wealth_score 				"HH Asset Ownership Index (PCA)"
	lab var wealth_score_sdC_phone		"HH Asset Ownership Index"
	lab var wealth_score_sdC_phone_all	"HH Asset Ownership Index"
	lab var property_score			    "Land and Dwelling Ownership Index (PCA)"
	lab var exp_tot_m_pc_ca18 			"Total Consumption per Capita (2018 AFN), Month"
	lab var loan_ca18 					"HH Total Outstanding Cash Loans (2018 AFN)"
	lab var saving_ca18 				"HH Total Savings (2018 AFN)"
	lab var psy_indexC_sdC_bl_phone		"Psychological Well-being Index (3 components)"
	lab var psy_indexC_sdC_bl_phone_all "Psychological Well-being Index (3 components)"
	lab var exp_tot_m_pc 				"Total Proxy Consumption Index (AFN), Month"			
	lab var exp_f_tot_m_pc 				"Proxy Food Consumption Index (AFN), Month"
	lab var exp_nf_tot_m_pc				"Proxy Non-Food Consumption Index (AFN), Month"
	lab var exp_tot_m_pc_noh			"Total Proxy Consumption Index (AFN), Month"
	lab var did_labor_pf 				"PW Did Market Work"
	lab var psy_indexC_sdC_m_bl_phone	"PM Psychological Well-being Index (3 components)"
	lab var psy_indexC_sdC_m_bl_phone_all	"PM Psychological Well-being Index (3 components)"	
	
	* In 2018 USD
	foreach var in exp_tot_m_pc exp_f_tot_m_pc tot_hh_income tot_hh_inc_nomiss tot_lstock_revenue tot_crop_revenue tot_biz_revenue tot_hh_pay_imp saving loan tot_lstock_value_med_4 tot_lstock_value_4 tot_lstock_value_4_w99t {
			local `var'_lab : var lab `var'
			local `var'_lab : subinstr local `var'_lab "(2018 AFN)" "(Nominal USD)", all
			local `var'_lab : subinstr local `var'_lab "(AFN)" "(Nominal USD)", all
			gen `var'_usd = `var' / $exchange_rate_2016
			lab var `var'_usd "``var'_lab'"
		}
	
	* Constant 2018 AFN divided by endline control mean
	foreach var in exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc exp_tot_m_pc_noh {
		local `var'_lab : var lab `var'
		local `var'_lab : subinstr local `var'_lab "(AFN)" "(Five-Year Follow-Up = 1)", all
		* The ${`var'_cmean} global is calculated in the data_for_analysis_phonesvy do-file!
		* Standardize to R1 of phone survey 
		gen `var'_ca21 = `var'_ca18 / ${`var'_1_ca18_cmean}
		lab var `var'_ca21 "`var'_lab"
	}	
	
	* Same for a robustness check subsample -- HHs surveyed in all rounds)
	foreach var in exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc exp_tot_m_pc_noh {
		local `var'_lab : var lab `var'
		local `var'_lab : subinstr local `var'_lab "(AFN)" "(Five-Year Follow-Up = 1)", all
		
		* The ${`var'_cmean} global is calculated in the data_for_analysis_phonesvy do-file!
		* Standardize to R1 of phone survey 
		gen `var'_all_ca21 = `var'_ca18 / ${`var'_1_ca18_allcm} if all_rounds == 1
		lab var `var'_all_ca21 "`var'_lab"
	}	
	
	* Baseline control 
		save "${data_for_analysis_bl_phonesvy}", replace 

