/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Apr 23, 2019
Last udpate on: Apr 23, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates female empowerment index based on discussion with Lupe and 
				in the following file: TUP_Afghanistan/Data Analysis/Others/Empowerment/female_empowerment_indicators_23Apr2019_adjusted2available.xlsx

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl f_empowerment_bl				"${TUP_DB}/Baseline/DataSets/Intermediate/f_empowerment_bl.dta" 
	gl f_empowerment_phonesvy	 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/f_empowerment_phonesvy.dta"
	gl sample_indicators_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 

* Outputs
	gl f_empowerment_bl_phone		"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/f_empowerment_bl.dta" 

* Controls globals 
	global controls i.PRA_lottery 
	global panel_controls i.PRA_lottery ib(4).round 	
	
* Select standartization 
	global normvar control // pashto 
	
********************************************************************************
	** Part 0: Prepare dataset
********************************************************************************

use "${f_empowerment_bl}", clear

	merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment  anyround all_rounds attrition_r4) keep(3) nogen
	merge 1:1 hhid using "${f_empowerment_phonesvy}", keepusing(has_daughter) keep(1 3) nogen
		
	* Merge on endline sample indicators  
	merge 1:1 hhid using "${sample_indicators_phonesvy}", nogen keepusing(index_sdC_f_emp_3c_1_s) 
		rename index_sdC_f_emp_3c_1_s sample  

	keep if sample == 1 		
	
	assert (anyround == 1 | mi(anyround)) 
	
	drop index*
	
********************************************************************************
	** Part 1: Household expenses
********************************************************************************
	
/* 1. Major Say in Food Expenditures and What to Cook (2):

	h1: What to cook on a daily basis
	h2: Buying groceries */
	
* Local for survey vars related 
	loc foodexp_survey_vars "h1 h2"
	loc foodexp_vars "h1_ac h2_ac"
	loc foodexp_vars_r "h1_ac_r h2_ac_r"
	tabm `foodexp_survey_vars', m
	
/* 2. Major Say in Home Improvements/Repairs (1):

	h8: Making home improvements/repair
*/
	loc homeexp_survey_vars "h8"
	loc homeexp_vars "h8_ac"
	loc homeexp_vars_r "h8_ac_r"
	tab `homeexp_survey_vars', m

/* 3. Major Say in Managing Household Finances (1):
		
	h7: Managing household finances
*/
	loc homefin_survey_vars "h7"
	loc homefin_vars "h7_ac"
	loc homefin_vars_r "h7_ac_r"
	tab `homefin_survey_vars', m

/* 4. Major Say in Children's School Attendance (2):

	h9: Whether your daughter should attend school
	h10: Whether your son should attend school
*/
	loc chischool_survey_vars "h9 h10"
	loc chischool_vars "h9_ac h10_ac"
	loc chischool_vars_r "h9_ac_r h10_ac_r"
	tabm `chischool_survey_vars', m

/* 5. Major Say in Children's Health Seeking (1):

	h13: Consulting a doctor when your child is ill
*/
	loc chihealth_survey_vars "h13"
	loc chihealth_vars "h13_ac"
	loc chihealth_vars_r "h13_ac_r"	
	tab `chihealth_survey_vars', m

/* 6. Major Say in Children's Marriage (2):

	h11: Marriage of daughters
	h12: Marriage of sons
*/
	loc chimarr_survey_vars "h11 h12"
	loc chimarr_vars "h11_ac h12_ac"
	loc chimarr_vars_r "h11_ac_r h12_ac_r"
	tabm `chimarr_survey_vars', m

/* 7. Major Say in Buying or Selling Land or Property (1):

	h6: Buying or selling land or property
*/
	loc homesale_survey_vars "h6"
	loc homesale_vars "h6_ac"
	loc homesale_vars_r "h6_ac_r"
	tab `homesale_survey_vars', m

/* 8. Major Say in Other Non-food Expenditures (3):

	h3: Buying clothing
	h4: Buying expensive items (i.e. carpet, jewelry)
	h5: Buying small items (i.e. detergent, soap)
*/
	loc otherexp_survey_vars "h3 h4 h5"
	loc otherexp_vars "h3_ac h4_ac h5_ac"
	loc otherexp_vars_r "h3_ac_r h4_ac_r h5_ac_r"
	tabm `otherexp_survey_vars', m

/* 9. Major Say in Her Fertility (1):

		h14: How many children to have
*/
	loc fert_survey_vars "h14"
	loc fert_vars "h14_ac"
	loc fert_vars_r "h14_ac_r"
	tab `fert_survey_vars', m

/* 10. Major Say in Her Taking a Loan, Opening a Business, and Working Outside of Home (3):

	h28: If you wanted to take out a loan
	h31: If you wanted to pursue a job outside the home
	h24: If you wanted to open a new business
*/	
	loc h24_survey_vars "h24"
	loc h24_vars "h24_ac"
	loc h24_vars_r "h24_ac_r"
	loc h28_survey_vars "h28"
	loc h28_vars "h28_ac"
	loc h28_vars_r "h28_ac_r"
	loc h31_survey_vars "h31"
	loc h31_vars "h31_ac"
	loc h31_vars_r "h31_ac_r"
	
	loc decide_survey_vars `foodexp_survey_vars' `homeexp_survey_vars' `homefin_survey_vars' `homesale_survey_vars' `chischool_survey_vars' `chihealth_survey_vars' `chimarr_survey_vars' `otherexp_survey_vars' `fert_survey_vars' 	`h24_survey_vars' `h28_survey_vars' `h31_survey_vars'
		

********************************************************************************
	** Part 4: Taking advantage of economic opportunities
********************************************************************************
	
	loc work_vars owner_manager_pf did_labor_pf
	loc inputs_vars h30
	
********************************************************************************
	** Part 6: Social Capital/Voice outside of the HH = Political involvement Index
********************************************************************************

* Local for survey vars related to political involment
	loc community_vars "n1 n2" 
	
********************************************************************************
	** Part 5: Aspirations for daughters / Social norms [R4]
********************************************************************************
	loc educ_vars ed_level_yr_d ed_help_d
	loc marriage_vars age_marriage_d	
		
********************************************************************************
	** Part 7: Construction of indices - full sample
********************************************************************************

* Decisionmaking
	loc foodexp_l		"Food Expenditures and What to Cook"
	loc homeexp_l 		"Home Improvements/Repairs"
	loc homefin_l 		"Managing Household Finances"
	loc chischool_l 	"Children's School Attendance"
	loc chihealth_l 	"Children's Health Seeking"
	loc chimarr_l 		"Children's Marriage"
	loc homesale_l		"Buying or Selling Land or Property"
	loc fert_l 			"Her Fertility"
	loc fert_l 			"Her Fertility"
	loc h28_l 		"Her Taking a Loan"
	loc h31_l 		"Her Working Outside of Home"
	loc h24_l 		"Her Opening a Business"
	
	* Econ opp 
	loc work_l "Participation in Market Work and Running a Business"
	loc inputs_l "Access to Resources and Inputs"
	
	* Political and Social Capital
	loc community_l "Community Participation"
	
	* Aspirations 
	loc educ_l 		"Daughters' Education"
	loc marriage_l 	"Daughter's Marriage in Adulthood"
	
	gl all 	   "foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31 work inputs community"
	gl all_dau "foodexp homeexp homefin chischool chihealth chimarr homesale otherexp fert h24 h28 h31 work inputs community educ marriage" 
	
	* Drop if there is no LHH in the household
	drop if  respondent_gender == 1
	
	* Generate indices for the overall control group 
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index' = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index' "``index'_l' Index sd(${normvar})"	
		}	
		
	* Decisionmaking index
		loc decide_index "index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert index_sdC_h24 index_sdC_h28 index_sdC_h31"
		egen index_sdC_all_decisions = weightave(`decide_index'), normby(${normvar})
		lab var index_sdC_all_decisions "Decision-making Index sd(${normvar})"
		
	* Econ Opp Index
		loc econ_opp_index "index_sdC_work index_sdC_inputs"
		egen index_sdC_role_prod_act = weightave(`econ_opp_index'), normby(${normvar})
		lab var index_sdC_role_prod_act "Economic Opportunities Index sd(${normvar})"
		
	* Social Capital Index
		loc soc_cap_index "index_sdC_community"
		gen index_sdC_social_capital = index_sdC_community
		lab var index_sdC_social_capital "Social Involvement Index sd(${normvar})"
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital) //Social Norm only to be added for a subsample
		loc all_index_3 "index_sdC_all_decisions index_sdC_role_prod_act index_sdC_social_capital"
		egen index_sdC_f_empowerment_3c = weightave(`all_index_3'), normby(${normvar})
		lab var index_sdC_f_empowerment_3c "Women's Empowerment Index sd(${normvar}) (3 dimensions)"

	* Merging treatment and PRA
		merge m:1 hhid using "${phone_svy_profile}", keepus(treatment PRA_lottery) assert(2 3) keep(1 3) nogen	
		
		lab var foodexp "Food Expenditures and What to Cook"
		lab var h8_ac "Home Improvements/Repairs"
		lab var h7_ac "Managing Household Finances"
		lab var h6_ac "Buying or Selling Land or Property"
		lab var otherexp "Other Non-food Expenditures"
		lab var chischool "Children's School Attendance"
		lab var h13_ac "Children's Health Seeking"
		lab var chimarr "Children's Marriage"
		lab var h14_ac "Her Fertility"
		lab var h28_ac "Her Taking a Loan"
		lab var h24_ac"Her Opening a Business"
		lab var h31_ac "Her Working Outside of Home"
		lab var n2 "PW Approached Village Leaders About Issues"
		lab var did_labor_pf "PW Does Market Work"
		lab var h30 "PW Has Financial Assets in Her Own Name"
		lab var index_sdC_all_decisions "Decision-Making Index"
		lab var index_sdC_role_prod_act "Economic Opportunities Index"
		lab var index_sdC_social_capital "Social Involvement Index"
		lab var index_sdC_f_empowerment_3c "Women's Empowerment Index (3 dimensions)"

		
/********************************************************************************
	** Construction of indices for the phone survey sample
********************************************************************************

preserve 	
		drop index* 
		
	* Generate indices for the overall control group 
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_phone = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_phone "``index'_l' Index sd(${normvar})"	
		}	
	
	* Decisionmaking index
		loc decide_index_phone "index_sdC_foodexp_phone index_sdC_homeexp_phone index_sdC_homefin_phone index_sdC_chischool_phone index_sdC_chihealth_phone index_sdC_chimarr_phone index_sdC_homesale_phone index_sdC_otherexp_phone index_sdC_fert_phone index_sdC_h24_phone index_sdC_h28_phone index_sdC_h31_phone"
		egen index_sdC_all_decisions_phone = weightave(`decide_index_phone'), normby(${normvar})
		lab var index_sdC_all_decisions_phone "Decision-making Index sd(${normvar})"
		
	* Econ Opp Index
		loc econ_opp_index_phone "index_sdC_work_phone index_sdC_inputs_phone"
		egen index_sdC_role_prod_act_phone = weightave(`econ_opp_index_phone'), normby(${normvar})
		lab var index_sdC_role_prod_act_phone "Economic Opportunities Index sd(${normvar})"
		
	* Social Capital Index
		loc soc_cap_index_phone "index_sdC_community_phone"
		gen index_sdC_social_capital_phone = index_sdC_community_phone
		lab var index_sdC_social_capital_phone "Social Involvement Index sd(${normvar})"
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital)
		loc all_index_3_phone "index_sdC_all_decisions_phone index_sdC_role_prod_act_phone index_sdC_social_capital_phone"
		egen index_sdC_f_empowerment_3c_phone = weightave(`all_index_3_phone'), normby(${normvar})
		lab var index_sdC_f_empowerment_3c_phone "Women's Empowerment Index sd(${normvar}) (3 dimensions)"

		keep hhid *_phone 
		tempfile index_phone
		save `index_phone'
restore 	

		merge 1:1 hhid using "`index_phone'", assert(1 3) nogen*/
		
preserve 	
	drop *index*

	keep if has_daughter > 0 & !mi(has_daughter) & dau_bl == 1 // keep HHs with a young daughter at baseline AND phone survey
	keep if attrition_r4 == 0

	* Create indices
		foreach index in $all_dau {
			display "`index'"
			des ``index'_vars'
			egen index_sdUP_`index'_dau = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdUP_`index'_dau  "``index'_l' Index sd(${normvar} - HH with daughters)"	
		}	

* Decisionmaking index
	loc decide_index_dau "index_sdUP_foodexp_dau index_sdUP_homeexp_dau index_sdUP_homefin_dau index_sdUP_chischool_dau index_sdUP_chihealth_dau index_sdUP_chimarr_dau index_sdUP_homesale_dau index_sdUP_otherexp_dau index_sdUP_fert_dau index_sdUP_h24_dau index_sdUP_h28_dau index_sdUP_h31_dau"
	egen index_sdUP_all_decisions_dau = weightave(`decide_index_dau'), normby(${normvar})
	lab var index_sdUP_all_decisions_dau "Women's Decisionmaking Index sd(${normvar})"
	
* Econ Opp Index
	loc econ_opp_index_dau "index_sdUP_work_dau index_sdUP_inputs_dau"
	egen index_sdUP_role_prod_act_dau = weightave(`econ_opp_index_dau'), normby(${normvar})
	lab var index_sdUP_role_prod_act_dau "Economic Opportunities Index sd(${normvar})"

* Social Capital Index
	loc soc_cap_index_dau "index_sdUP_community_dau"
	egen index_sdUP_social_capital_dau = weightave(`soc_cap_index_dau'), normby(${normvar})
	lab var index_sdUP_social_capital_dau "Social Capital Index sd(${normvar})"

* Social Norms Index
	loc soc_norms_index_dau "index_sdUP_educ_dau index_sdUP_marriage_dau"
	egen index_sdUP_social_norms_dau = weightave(`soc_norms_index_dau'), normby(${normvar})
	lab var index_sdUP_social_norms_dau "Aspirations for Daughters Index sd(${normvar})"

* Total index (4 dimensions: decisionmaking, econ opp, social norms, social capital)
	loc all_index_dau "index_sdUP_all_decisions_dau index_sdUP_role_prod_act_dau index_sdUP_social_capital_dau index_sdUP_social_norms_dau" 
	egen index_sdUP_f_emp_dau = weightave(`all_index_dau'), normby(${normvar})
	lab var index_sdUP_f_emp_dau "Women's Empowerment Index sd(${normvar}) (4 dimensions)"	
	
keep hhid 	index_sdUP_social_norms_dau index_sdUP_f_emp_dau* index_sdUP_all_decisions_dau index_sdUP_role_prod_act_dau* index_sdUP_social_capital_dau has_daughter
	
tempfile we_aspiration_daughter_phone
save `we_aspiration_daughter_phone'
restore 	


* For HHs surveyed in all phone survey rounds 
preserve 	
	drop *index*
	
	keep if all_rounds == 1 

	* Generate indices for the overall control group 
		foreach index in $all {
			display "`index'"
			des ``index'_vars'
			egen index_sdC_`index'_phone_all = weightave(``index'_vars'), normby(${normvar})
			lab var index_sdC_`index'_phone_all "``index'_l' Index sd(${normvar}) (all rounds)"	
		}	
	
	* Decisionmaking index
		loc decide_index_all "index_sdC_foodexp_phone_all index_sdC_homeexp_phone_all index_sdC_homefin_phone_all index_sdC_chischool_phone_all index_sdC_chihealth_phone_all index_sdC_chimarr_phone_all index_sdC_homesale_phone_all index_sdC_otherexp_phone_all index_sdC_fert_phone_all index_sdC_h24_phone_all index_sdC_h28_phone_all index_sdC_h31_phone_all"
		egen index_sdC_all_dec_phone_all = weightave(`decide_index_all'), normby(${normvar})
		lab var index_sdC_all_dec_phone_all "Decision-making Index sd(${normvar}) (all rounds)"
		
	* Econ Opp Index
		loc econ_opp_index_all "index_sdC_work_phone_all index_sdC_inputs_phone_all"
		egen index_sdC_role_prod_phone_all = weightave(`econ_opp_index_all'), normby(${normvar})
		lab var index_sdC_role_prod_phone_all "Economic Opportunities Index sd(${normvar} (all rounds))"
		
	* Social Capital Index
		loc soc_cap_index_all "index_sdC_community_phone_all"
		gen index_sdC_so_cap_phone_all = index_sdC_community_phone_all
		lab var index_sdC_so_cap_phone_all "Social Involvement Index sd(${normvar}) (all rounds)"
		
	* Total index (3 dimensions: decisionmaking, econ opp, social capital)
		loc all_index_3_all "index_sdC_all_dec_phone_all index_sdC_role_prod_phone_all index_sdC_so_cap_phone_all"
		egen index_sdC_f_emp_3c_phone_all = weightave(`all_index_3_all'), normby(${normvar})
		lab var index_sdC_f_emp_3c_phone_all "Women's Empowerment Index sd(${normvar}) (3 dimensions) (all rounds)"

		keep hhid *_phone_all 
		tempfile index_phone_all
		save `index_phone_all'
restore 	

		merge 1:1 hhid using "`we_aspiration_daughter_phone'", assert(1 3) nogen
		merge 1:1 hhid using "`index_phone_all'", assert(1 3) nogen
		
* Save data 
		if	`c(stata_version)'>=14	{			
			saveold "${f_empowerment_bl_phone}", replace v(13) 
		}
		else {
			save "${f_empowerment_bl_phone}", replace
		}		
