/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Feb 19, 2017
Last udpate on: March 23, 2019

Written by:  	Lupe Bedoya (gbedoya@worldbank.org, guadalupe.bedoya@gmail.com)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Construct labor variables


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

****************************************************************************
*** Part 0: Create directories and paths
****************************************************************************

* Inputs
	gl productive_act_bl 	"${TUP_DB}/Baseline/DataSets/Intermediate/k_e_timeuse_bl.dta"	
	gl labor_bl 		   "${TUP_DB}/Baseline/DataSets/Intermediate/labor_bl.dta"
	gl phone_svy_profile   "${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"

* Outputs
	gl labor_bl_phonesvy 	"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/labor_bl_phonesvy.dta"

	
* Get the looking for work indicator 
use "${productive_act_bl}", clear 
	keep hhid member k5_1
	duplicates drop
	isid hhid member 
	
	* Clean -99 
	mvdecode k5_1, mv(-99 = .d \ -98 = .r)
	
	tempfile look_for_work
	save `look_for_work'
	
	use "${labor_bl}", clear	
	
	merge 1:1 hhid member using "`look_for_work'", assert(3) nogen
	
* Keep only PM and PF for comparison with Phone survey 
		drop pm
		gen pm = (member == position_pm & b6 == 1)
		gen pw = (member == position_pf & b6 == 2)
		
		keep if pm == 1 | pw == 1 // 2493
		
		recode pm (1=2)
		drop member 
		gen member = pm 
			replace member = pw if member != 2
			tab member 
	
		* All Other Work variable 
		gen did_oWork		= (did_oFarm == 1 | did_maid == 1 | did_outWork == 1 | did_salEmp == 1 | did_oPaidWork == 1)
		replace did_oWork 	= .d if did_oFarm == .d | did_maid == .d | did_outWork == .d | did_salEmp == .d | did_oPaidWork == .d 
		replace did_oWork 	= .r if did_oFarm == .r | did_maid == .r | did_outWork == .r | did_salEmp == .r | did_oPaidWork == .r 
		label var did_oWork "Did any other work in last 4 weeks" 	
		
		*Employment
		gen employment = 0 
			replace employment = 1 if (k30_0_1 == 1 | k30_0_2 == 1 |k30_0_3 == 1 |k30_0_4 == 1 |k30_0_5 == 1 |k30_0_6 == 1 |k30_0_7 == 1 |k30_0_8 == 1) & b8_bl > 14  & !mi(b8_bl)
			label var employment "Paid employment or self employment"
	
		*Labor participation: of Working age and working or have been looking for a job in the past 2 weeks (For Age : ILO definiton 15 and plus - See excel file on definition)
		gen labor_particip = 0
			replace labor_particip = 1 if (employment == 1 | k5_1 == 1) & b8_bl > 14 & !mi(b8_bl) 
			label var labor_particip "Labor participation: working or looking for a job"
		
		* Imputing Don't knows for PM and PW in the same way we do in Endline
	
		** Check whether missingness is random between T and C 
		gen tot_earnings_act_4w_miss = mi(tot_earnings_act_4w)
			reg tot_earnings_act_4w_miss treatment if member == 1
			reg tot_earnings_act_4w_miss treatment if member == 2
			
			bys treatment member: sum tot_earnings_act_4w_miss
			
		** Same check but if we only look at those missing conditional on having done Other Work (paid work)	
		gen tot_earnings_act_4w_miss_oW = mi(tot_earnings_act_4w) & did_oWork == 1 
			reg tot_earnings_act_4w_miss_oW treatment if member == 1
			reg tot_earnings_act_4w_miss_oW treatment if member == 2
			
			bys treatment member: sum tot_earnings_act_4w_miss_oW

	* Impute PM income when DK and PM did at least one type of market work that would be paid. Take the mean of PM labor income, by treatment and other work group, and impute with that.
	
	* Get the mean by: treatment member did_oWork
	egen mean_pay_win = mean(tot_earnings_act_4w), by(treatment member did_oWork)
	
	tab mean_pay_win member if did_oWork == 0	
	tab mean_pay_win member if did_oWork == 1
	
	* Impute for all, regardless of whether they did Other Work
	gen tot_earnings_act_4w_imp = tot_earnings_act_4w
		replace tot_earnings_act_4w_imp = mean_pay_win if mi(tot_earnings_act_4w)
	
	bys member: sum tot_earnings_act_4w tot_earnings_act_4w_imp if ultra_poor == 1 

	gen tot_hh_pay_imp_dum = mi(tot_earnings_act_4w)
	lab var tot_hh_pay_imp_dum "Earnings is missing"
		
**** Without imputation first
	
		*Create flags for the presence of .d or .r in the household  
		egen miss_d = total(cond(tot_earnings_act_4w==.d,1,0)), by(hhid) //Counting missing don't know 
		egen miss_r = total(cond(tot_earnings_act_4w==.r,1,0)), by(hhid) //Counting missing don't answer  
		
		bys hhid : egen tot_hh_pay = sum(tot_earnings_act_4w), m 				 
			replace tot_hh_pay = .d if miss_d > 0 & !mi(miss_d) 
			replace tot_hh_pay = .r if miss_r > 0 & !mi(miss_r) 
			label var tot_hh_pay "HH Paid Labor, (4 weeks)" 
	
** Now with winsorization and imputation 	
	*Earnings from Household from all paying activities
	bys hhid: egen tot_hh_pay_imp = sum(tot_earnings_act_4w_imp), m 	
		label var tot_hh_pay_imp "HH Paid Labor, (4 weeks) - Imputed"	
		
		bys treatment: sum tot_hh_pay tot_hh_pay_imp
	
		* Primary female
	preserve
		keep if member == 1 
		isid hhid
		keep hhid pm employment k5_1 labor_particip did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork ///
			tot_earnings_act_4w tot_earnings_act_4w_imp tot_hh_pay* did_oWork treatment
		
		rename * *_pf
		rename (hhid_pf tot_hh_pay_pf tot_hh_pay_imp_pf treatment_pf) (hhid tot_hh_pay tot_hh_pay_imp treatment)
		
		* Share of women receiving any income 
		gen any_income_pf = (tot_earnings_act_4w_imp_pf > 0 & !mi(tot_earnings_act_4w_imp_pf))
		lab var any_income_pf "PW received any income"
		tab any_income_pf treatment, col
		
		lab var tot_earnings_act_4w_pf "Paid Labor Income - PW"
		lab var tot_earnings_act_4w_imp_pf "Paid Labor Income - PW, Imputed"
		rename (tot_earnings_act_4w_pf tot_earnings_act_4w_imp_pf) (tot_pf_pay tot_pf_pay_imp)
		 
		tempfile time_pf
		save	`time_pf'
	restore
	
	* Primary male
		keep if member == 2
		isid hhid
		keep hhid pm employment k5_1 labor_particip did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork ///
			tot_earnings_act_4w tot_earnings_act_4w_imp tot_hh_pay* did_oWork treatment
		
		rename * *_pm
		rename (hhid_pm tot_hh_pay_pm tot_hh_pay_imp_pm treatment_pm) (hhid tot_hh_pay tot_hh_pay_imp treatment)
		
		* Share of women receiving any income 
		gen any_income_pm = (tot_earnings_act_4w_imp_pm > 0 & !mi(tot_earnings_act_4w_imp_pm))
		lab var any_income_pm "PM received any income"
		tab any_income_pm treatment, col
		
		lab var tot_earnings_act_4w_pm "Paid Labor Income - PW"
		lab var tot_earnings_act_4w_imp_pm "Paid Labor Income - PW, Imputed"
		
		rename (tot_earnings_act_4w_pm tot_earnings_act_4w_imp_pm) (tot_pm_pay tot_pm_pay_imp)
	
		tempfile time_pm
		save	`time_pm'
		
	* Merge
		use `time_pf', clear
		merge 1:1 hhid using `time_pm', nogen update replace 
		
		foreach group in pf pm {
			*label var did_labor_nohh_`group'	"Any Type of Work"
			label var did_livestock_`group' 	"HH Livestock"
			label var did_ownFarming_`group'  	"HH Agriculture"
			label var did_ownBiz_`group'  		"HH Non-Agricultural Business"
			label var did_oWork_`group'  		"Other Work"
			label var labor_particip_`group' 	"Labor Participation"	
		}
	
	if	`c(stata_version)'>=14	{
		saveold "${labor_bl_phonesvy}", replace v(13)
	}
	else {
		save "${labor_bl_phonesvy}", replace
	}		
