* Inputs
	gl phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"	
	gl foodsecurity_bl 				"${TUP_DB}/Baseline/DataSets/Intermediate/food_security_index_bl.dta"
	gl sample_indicators_phonesvy	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 

* Outputs
	gl foodsecurity_bl_phone 	"${TUP_DB}/Baseline_Phone/DataSets/Intermediate/food_security_index_bl.dta"

* Controls globals 
	global controls i.PRA_lottery 
	global panel_controls i.PRA_lottery ib(4).round 	
	

	use "${foodsecurity_bl}", clear

	merge 1:1 hhid using "${phone_svy_profile}", keepusing(ultra_poor treatment fl1_sample attrition_r* anyround all_rounds) keep(3) nogen // 47 HHs are missing BL data
	
	* Merge on endline sample indicators  
		merge 1:1 hhid using "${sample_indicators_phonesvy}", nogen keepusing(index_sdC_food_sec_s) 
			rename index_sdC_food_sec_s sample  

	keep if sample == 1 		
	
	assert (anyround == 1 | mi(anyround)) 
	
	* UP HHs only	
	keep if ultra_poor == 1 
	
	* Control dummy
	gen 	control = treatment==0
	replace control = 0 if mi(treatment)
	lab var control "HH is part of control group"	
	
	drop index*
	
	loc food_sec_l "Food security"
	loc sd_var_l "Control"
	loc sd_var "control"
	
	loc food_sec_vars "c14_7 c14_3_ac c14_5_ac"
	
	egen index_sdC_food_sec = weightave(`food_sec_vars'), normby(`sd_var')
	lab var index_sdC_food_sec "`food_sec_l' Index sd(`sd_var_l')"
		
* Re-estimate indices for the phone survey sample 
	preserve 
		* Keep the phone survey sample: any round 		 
		keep if anyround == 1 		 
				
		egen index_sdC_food_sec_phone = weightave(`food_sec_vars'), normby(`sd_var')
		lab var index_sdC_food_sec_phone "`food_sec_l' Index sd(`sd_var_l')"
			
		keep hhid index_sdC_food_sec_phone
		
		tempfile index_vars
		save `index_vars'
	restore 	
	
		merge 1:1 hhid using "`index_vars'", assert(1 3) nogen
		
preserve 
		* Keep the phone survey sample: all rounds 		 
		keep if all_rounds == 1 		 
				
		egen index_sdC_food_sec_phone_all = weightave(`food_sec_vars'), normby(`sd_var')
		lab var index_sdC_food_sec_phone_all "`food_sec_l' Index sd(`sd_var_l') (all rounds)"
			
		keep hhid index_sdC_food_sec_phone_all
		
		tempfile index_vars_all
		save `index_vars_all'
	restore 	
	
		merge 1:1 hhid using "`index_vars_all'", assert(1 3) nogen		
		
* Save datasets

		if	`c(stata_version)'>=14	{
			saveold "${foodsecurity_bl_phone}", replace v(13)
		}
		else {
			save "${foodsecurity_bl_phone}", replace
		}

