/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 11, 2019
Last udpate on: Mar 11, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Constructs the following variables: value of livestock, livestock revenue, agricultural revenue, and non-agricultural business revenue.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	gl livestock_bl			  	  "${TUP_DB}/Baseline/DataSets/Intermediate/k_a_livestock_bl.dta"

* Outputs
	gl livestock_ass_index_bl_phonesvy	  "${TUP_DB}/Baseline_Phone/DataSets/Intermediate/livestock_ass_index_bl_phonesvy.dta"
	gl livestock_rev_index_bl_phonesvy	  "${TUP_DB}/Baseline_Phone/DataSets/Intermediate/livestock_rev_index_bl_phonesvy.dta"
	
********************************************************************************
	** Part 1: Livestock
********************************************************************************

*-----------------*
* Livestock value *
*-----------------*

use "${livestock_bl}", clear

* Keep the phone survey sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* ultra_poor treatment) keep(3) nogen
	
* Drop if "none" or "don't know"
	tab livestock if k6 == 1, m
	tab livestock if k6 == 1, m nol

* Drop household without this information (no MHHH survey -- or targeting households, and 3 with "Don't know")
	tab k6 if livestock == 1, m
	tab k6, m
	drop if mi(k6)
	
* Keep only the 4 relevant types
	keep if inlist(livestock,1,5,6,7)
	
* Does the household own?
	gen lstock_yes = k6
	
* Quantity owned
	gen 	lstock_num = k7 
	replace lstock_num = 0 if k6==0
	
** Quantity owned in Livestock Units (LU)		
	/* Conversion factors taken from Annex 1 of https://www.fao.org/3/i2294e/i2294e00.pdf, "Other" region:
			cattle 	= 0.6
			sheep 	= 0.1 
			goats 	= 0.1
			chicken = 0.01
			
		These are meant for international comparisons, hence cow is not 1, but 0.6. */
		
		gen lstock_unit = .
			replace lstock_unit = 0.6 	* lstock_num if livestock == 1 // cow 
			replace lstock_unit = 0.1 	* lstock_num if inlist(livestock,5,6) // goat / sheep
			replace lstock_unit = 0.01 	* lstock_num if livestock == 7 
		
		* Now in terms of cows 
		gen lstock_unit_cow = .
			replace lstock_unit_cow = 0.6/0.6 	* lstock_num if livestock == 1 // cow 
			replace lstock_unit_cow = 0.1/0.6 	* lstock_num if inlist(livestock,5,6) // goat / sheep
			replace lstock_unit_cow = 0.01/0.6 	* lstock_num if livestock == 7 //chicken 
* Livestock value : using the median, and using the actual value given by the HH	

		* Find median unit value
		bys livestock: egen unit_value_median = median(k8) if k8>0 
		bys livestock: egen unit_value_med = max(unit_value_median)
		drop unit_value_median

	* Reported unit value 	
		gen unit_value = k8

	* Replacing outliers and don't know / don't answer in k8. We will follow what we do elsewhere, replacing with the mean (not including by treatment as too few observations otherwise)
		bys livestock ultra_poor: egen mean_unit_value = mean(k8) if k8 > 0 
		replace unit_value = mean_unit_value if k8 == .o  | k8 == .d | k8 == .r
		drop  mean_unit_value  ultra_poor treatment 

	* Find unit value in terms of cows [use actualy reported values]
		gen value_cow = unit_value if livestock== 1
		egen value_cow_max = max(value_cow) 
		gen unit_value_cow = unit_value/(value_cow_max)
		drop value_cow value_cow_max

	* Find livestock value
		gen lstock_value = unit_value * lstock_num
		gen lstock_value_cow = unit_value_cow*lstock_num

	* Livestock value with median imputation
		gen lstock_value_med = unit_value_med*lstock_num

	* Replace with .d and .r for the corresponding missing values for the number of livestock 
		replace lstock_value   		= .d if lstock_num == .d & lstock_yes==1
		replace lstock_value_cow 	= .d if lstock_num == .d & lstock_yes==1
		replace lstock_unit         = .d if lstock_num == .d & lstock_yes==1
		replace lstock_value_med  	= .d if lstock_num == .d & lstock_yes==1

		replace lstock_value 		= 0 if  lstock_value == . & lstock_yes==0
		replace lstock_value_cow 	= 0 if  lstock_value == 0
		replace lstock_unit 		= 0 if  lstock_value == 0 
		replace lstock_value_med 	= 0 if lstock_yes==0	

		keep hhid livestock lstock_yes lstock_num lstock_unit lstock_unit_cow unit_value unit_value_med unit_value_cow lstock_value lstock_value_cow lstock_value_med
		
		rename * *_
		rename (hhid_ livestock_) (hhid livestock)
	
	* Reshape
		reshape wide lstock_yes_ lstock_num_ lstock_unit_ lstock_unit_cow_ unit_value_ unit_value_med_ unit_value_cow_ lstock_value_ lstock_value_cow_ lstock_value_med_, i(hhid) j(livestock)

	* Generate total value of livestock
		egen tot_lstock_value 		= rowtotal(lstock_value_1 lstock_value_5 lstock_value_6 lstock_value_7), m
		egen tot_lstock_value_cow 	= rowtotal(lstock_value_cow_1 lstock_value_cow_5 lstock_value_cow_6 lstock_value_cow_7), m

		lab var tot_lstock_value 		"Total livestock value (AFN)"
		lab var tot_lstock_value_cow 	"Total livestock value (Cows)"

	* Using median
		egen tot_lstock_value_med 		= rowtotal(lstock_value_med_1 lstock_value_med_5 lstock_value_med_6 lstock_value_med_7), m
		lab var tot_lstock_value_med 		"Total livestock value (AFN), median imputed"
	* Generate total units of livestock in LU 
		egen tot_lstock_unit = rowtotal(lstock_unit_1 lstock_unit_5 lstock_unit_6 lstock_unit_7), m
		lab var tot_lstock_unit			"Total Livestock Units (LU)"
		
		* Generate total units of livestock in LU in terms of cows 
		egen tot_lstock_unit_cow = rowtotal(lstock_unit_cow_1 lstock_unit_cow_5 lstock_unit_cow_6 lstock_unit_cow_7), m
		lab var tot_lstock_unit_cow		"Total Livestock Units (LU) in Cows "
	* Labeling and renaming
		loc	lstock1		cow 
		loc	lstock5		goat
		loc	lstock6		sheep
		loc	lstock7		chicken
		
		loc lstock_yes_l 			"HH owns any"
		loc lstock_num_l 			"Number of owned"
		
		loc vars "lstock_yes lstock_num"
		
		foreach var of local vars {
			foreach lstocknum in "1" "5" "6" "7" {
				rename `var'_`lstocknum' `var'_`lstock`lstocknum''
				lab var `var'_`lstock`lstocknum'' "``var'_l' `lstock`lstocknum''"
			}
		}
		
* Generate if has any TUP livestock
	egen 	tup_lstock_yes = rowtotal(lstock_yes_cow lstock_yes_goat lstock_yes_sheep), missing
	replace tup_lstock_yes = 1 if tup_lstock_yes > 1 & !mi(tup_lstock_yes)	
	lab var tup_lstock_yes "Household Owns Any TUP Livestock"
	
* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_ass_index_bl_phonesvy}", replace v(13)
	}
	else {
		save "${livestock_ass_index_bl_phonesvy}", replace
	}		

*-------------------*
* Livestock revenue *
*-------------------*
	
* 1. Revenues from sales in livestock and costs
*----------------------------------------------
	use "${livestock_bl}", clear
		
* Generate variable for costs
	gen 	lstock_cost = k14
	keep hhid lstock_cost
	duplicates drop
	replace	lstock_cost = 0 if lstock_cost==.

* Gen total revenue
	egen 	tot_lstock_revenue = rowtotal(lstock_cost)
	lab var tot_lstock_revenue "Total livestock revenue (past 4 weeks, Afghanis)"
			
* Save
	if	`c(stata_version)'>=14	{
		saveold "${livestock_rev_index_bl_phonesvy}", replace v(13)
	}
	else {
		save "${livestock_rev_index_bl_phonesvy}", replace
	}
	