	* Input
	gl phone_svy_profile   				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"	
	gl wellbeing_index_up 				"${TUP_DB}/Followup_1/DataSets/Intermediate/wellbeing_index_up_fl1.dta" 
	gl sample_indicators_phonesvy 		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 

	* Output in Followup_1_Phone folder 
	gl wellbeing_index_up_fl1_phonesvy		"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/wellbeing_index_up_fl1.dta"	
		
* Controls globals 
	global controls i.PRA_lottery 
	global panel_controls i.PRA_lottery ib(4).round 		
		
******************************************************************************************************************** 
** Part 4: Constructing Index for ultra poor only, standardized by control group 
*********************************************************************************************************************** 

	use "${wellbeing_index_up}", clear 

	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* all_rounds) keep(3) nogen
	
	global allcategories satisf hap cesd
	
	drop *_sd* 
	
	*Control vs treatment 
		foreach suffix in "" _m _hhh { 
			foreach groupvar in $allcategories { 
				egen `groupvar'_z_sdC`suffix'_fl1_full = weightave(`groupvar'_score`suffix'_fl1), normby(control) 
 
				*Labelization of scores 
				if "`groupvar'"=="satisf" { 
					global detail "Life satisfaction (WVS)" 
				} 
				if "`groupvar'"=="cesd" { 
					global detail "Depression (CESD)" 
				} 
				if "`groupvar'"=="hap" { 
					global detail "Happiness (WVS)" 
				} 

				 
				if "`suffix'" == "_m" { 
					label var `groupvar'_z_sdC`suffix'_fl1_full "$detail standardized score (control) - Man of HH" 
					} 
				else if "`suffix'" == "_hhh" { 
					label var `groupvar'_z_sdC`suffix'_fl1_full "$detail standardized score (control) - Head of HH"  
					} 
				else  { 
					label var `groupvar'_z_sdC`suffix'_fl1_full "$detail standardized score (control)"  
					} 
			}  
			 
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				 
				egen psy_indexC_sdC`suffix'_fl1_full = weightave(satisf_z_sdC`suffix'_fl1_full hap_z_sdC`suffix'_fl1_full cesd_z_sdC`suffix'_fl1_full), normby(control) 
		} 
		 
	* Merge on endline sample indicators  
	merge 1:1 hhid using "${sample_indicators_phonesvy}", keep(1 3) nogen keepusing(psy_indexC_sdC_s) 
		rename psy_indexC_sdC_s sample  
	
preserve 	
	
	global allcategories satisf hap cesd
	
	drop *_sd* 
	
	* Keep phone survey sample based on regression
	keep if sample == 1 	
		
	assert (anyround == 1 | mi(anyround)) 
	
	*Control vs treatment 
		foreach suffix in "" _m _hhh { 
			foreach groupvar in $allcategories { 
				egen `groupvar'_z_sdC`suffix'_fl1 = weightave(`groupvar'_score`suffix'_fl1), normby(control) 
 
				*Labelization of scores 
				if "`groupvar'"=="satisf" { 
					global detail "Life satisfaction (WVS)" 
				} 
				if "`groupvar'"=="cesd" { 
					global detail "Depression (CESD)" 
				} 
				if "`groupvar'"=="hap" { 
					global detail "Happiness (WVS)" 
				} 

				 
				if "`suffix'" == "_m" { 
					label var `groupvar'_z_sdC`suffix'_fl1 "$detail standardized score (control) - Man of HH" 
					} 
				else if "`suffix'" == "_hhh" { 
					label var `groupvar'_z_sdC`suffix'_fl1 "$detail standardized score (control) - Head of HH"  
					} 
				else  { 
					label var `groupvar'_z_sdC`suffix'_fl1 "$detail standardized score (control)"  
					} 
			}  
			 
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				 
				egen psy_indexC_sdC`suffix'_fl1 = weightave(satisf_z_sdC`suffix'_fl1 hap_z_sdC`suffix'_fl1 cesd_z_sdC`suffix'_fl1), normby(control) 
		} 
		
		keep hhid *sdC* 
		tempfile index_phone_sample
		save `index_phone_sample'
restore 		 
		 
	* Merge on phone survy sample indices 
	merge 1:1 hhid using "`index_phone_sample'", assert(1 3) nogen
	
	* For a subsample of HHs surveyed in all rounds 
	preserve 
		drop *_sd* 
		
		keep if all_rounds == 1 
		
	*Control vs treatment 
		foreach suffix in "" _m _hhh { 
			foreach groupvar in $allcategories { 
				egen `groupvar'_z_sdC`suffix'_all_fl1 = weightave(`groupvar'_score`suffix'_fl1), normby(control) 
 
				*Labelization of scores 
				if "`groupvar'"=="satisf" { 
					global detail "Life satisfaction (WVS)" 
				} 
				if "`groupvar'"=="cesd" { 
					global detail "Depression (CESD)" 
				} 
				if "`groupvar'"=="hap" { 
					global detail "Happiness (WVS)" 
				} 

				 
				if "`suffix'" == "_m" { 
					label var `groupvar'_z_sdC`suffix'_all_fl1 "$detail standardized score (control) - Man of HH" 
					} 
				else if "`suffix'" == "_hhh" { 
					label var `groupvar'_z_sdC`suffix'_all_fl1 "$detail standardized score (control) - Head of HH"  
					} 
				else  { 
					label var `groupvar'_z_sdC`suffix'_all_fl1 "$detail standardized score (control)"  
					} 
			}  
			 
			*Creating the index with 3 items available in the Phone Survey. Standardized with respect to the control group. 				 
				egen psy_indexC_sdC`suffix'_all_fl1 = weightave(satisf_z_sdC`suffix'_all_fl1 hap_z_sdC`suffix'_all_fl1 cesd_z_sdC`suffix'_all_fl1), normby(control) 
				
				tempfile index_all
				save `index_all'
				
		} 
	restore 	
		 
	* Merge on phone survy sample indices 
	merge 1:1 hhid using "`index_phone_sample'", assert(1 3) nogen
	merge 1:1 hhid using "`index_all'", assert(1 3) nogen
		 
	*Labelling final variables 
		label var psy_indexC_sdC_fl1 		"Psychological Well-being Index (3 items) sd(control)" 
		label var psy_indexC_sdC_m_fl1 		"Psychological Well-being Index (3 items) sd(control) - Man of HH" 
		label var psy_indexC_sdC_hhh_fl1 	"Psychological Well-being Index (3 items) sd(control) - Head of HH" 

		label var psy_indexC_sdC_fl1_full 		"Psychological Well-being Index (3 items) sd(control), full fl1 sample" 
		label var psy_indexC_sdC_m_fl1_full 	"Psychological Well-being Index (3 items) sd(control) - Man of HH, full fl1 sample" 
		label var psy_indexC_sdC_hhh_fl1_full 	"Psychological Well-being Index (3 items) sd(control) - Head of HH, full fl1 sample" 
		
	*Saving dataset with index for ultra poor only standardized by control group 
		if	`c(stata_version)'>=14	{ 
			saveold "${wellbeing_index_up_fl1_phonesvy}", replace v(13) 
		} 
		else { 
			save "${wellbeing_index_up_fl1_phonesvy}", replace 
		}	 
		
