	* Input 
	gl phone_svy_profile   			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"		
	gl food_consumption_all			"${TUP_DB}/Followup_1/DataSets/Intermediate/food_consumption_all_fl1.dta"
	gl current_roster_fl1 			"${TUP_DB}/Followup_1/DataSets/Intermediate/br_hhmemcurrent_fl1.dta"
	gl nonfood_consumption_fl1		"${TUP_DB}/Followup_1/DataSets/Intermediate/c_c_nonfoodconsumption_fl1.dta"
	
	
	* Output in Followup_1_Phone folder 
	gl total_expenditure_phonesvy 	"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/total_expenditure_fl1_phonesvy.dta"
	

** Food expenditures 
	use "${food_consumption_all}", clear 
	
	* Keep the 25 food items that are included in the Phone Survey
		keep if inlist(item,1,2,3,4,7,14,15,16,17,18,24,26,27,29,33,41,44,45,50,64,66,72,76,80,84)
		
		* Calculate total in-house food expenditure	
		bys hhid: egen exp_f_tot_m_pc = sum(exp_f_m_pc_item)
		lab var exp_f_tot_m_pc "Food expenditure (Afghani, per capita, per month) - Phone Survey"
		
		
		gen exp_f_tot_m_pc_ca18 = exp_f_tot_m_pc * ($cpi_food_fl1 / $cpi_food_fl1)
		lab var exp_f_tot_m_pc_ca18 "Food expenditure (2018 AFN, per capita, per month) - Phone Survey"

		keep hhid exp_f_tot_m_pc exp_f_tot_m_pc_ca18
		duplicates drop hhid, force
				
		tempfile food_exp
		save	`food_exp'

** Non-food expenditures 
		use "${nonfood_consumption_fl1}", clear 
		
		* Bring ultra-poor variable 
		merge m:1 hhid using "${phone_svy_profile}", keep(3) nogen keepus(ultra_poor treatment)
		
		* Keep only items used in the Phone survey
		keep if inlist(item,7,21,36,37,38) 
		
	* Get number of HH members
		preserve
			use "${current_roster_fl1}", clear
			keep hhid b3 
			duplicates drop hhid, force
			tempfile b3
			save	`b3'
		restore
		merge m:1 hhid using `b3', assert(2 3) nogen keep(3)
		
	* Generate montly expenditure
		gen 	exp_nf_m = c12 if item <= 20
		replace exp_nf_m = c13/12 if item > 20
		replace exp_nf_m = .d if c13 == .d
		replace exp_nf_m = .o if c13 == .o
		replace exp_nf_m = .r if c13 == .r
		
	* Generate monthly expenditure per capita
		gen 	exp_nf_m_pc = exp_nf_m/b3

	* Winsorize health 97% item (by treatment group, item, round)			
		winsor2 exp_nf_m_pc, by(item treatment) cuts(0 97) suff(_w97t)
		replace exp_nf_m_pc_w97t = exp_nf_m_pc if mi(exp_nf_m_pc_w97t)
		local l_exp_nf_m_pc : variable label exp_nf_m_pc
		lab var exp_nf_m_pc_w97t "`l_exp_nf_m_pc - Treatment Winsorized (97%)"
	
	* Replace health with winsorized version in the main variable before the imputation
		replace exp_nf_m_pc = exp_nf_m_pc_w97t if item == 38	
	
	foreach suffix in "_pc" {
	* Rename variable
		rename exp_nf_m`suffix' exp_nf_m`suffix'_raw
		clonevar exp_nf_m`suffix' = exp_nf_m`suffix'_raw	
	
	* Replace missings with group averages (grouped by HH size and treatment)
		bys item treatment b3: egen exp_mean`suffix' = mean(exp_nf_m`suffix') if exp_nf_m`suffix'>0
		bys item treatment b3: egen exp_mean_2`suffix' = mean(exp_nf_m`suffix')
		bys item treatment b3: egen exp_pc_mean`suffix' = mean(exp_mean`suffix')
		sum exp_mean_2`suffix' if mi(exp_pc_mean`suffix')
		replace exp_pc_mean`suffix' = exp_mean_2`suffix' if mi(exp_pc_mean`suffix')
		replace exp_nf_m`suffix' = exp_pc_mean`suffix' if mi(exp_nf_m`suffix')

		drop exp_mean`suffix' exp_mean_2`suffix' exp_pc_mean`suffix'	
	}
	
	* Calculate total non-food expenditure (without soap)
	preserve 
		drop if item == 7
		
		foreach suffix in "" {
			bys hhid: egen exp_nf_tot_m_pc_nos`suffix' = sum(exp_nf_m_pc`suffix')
			gen exp_nf_tot_m_pc_nos`suffix'_ca18 = exp_nf_tot_m_pc_nos`suffix' * ($cpi_non_food_fl1 / $cpi_non_food_fl1)
		}
		
		keep hhid exp_nf_tot_m_pc_nos exp_nf_tot_m_pc_nos_ca18  
		duplicates drop 
		
		tempfile nosoap
		save `nosoap'
	restore 
	
	merge m:1 hhid using `nosoap', assert(3) nogen
	
	* Calculate total non-food expenditure (without health)
	preserve 
		drop if item == 38 
		
		foreach suffix in "" {
			bys hhid: egen exp_nf_tot_m_pc_noh`suffix' = sum(exp_nf_m_pc`suffix')
			gen exp_nf_tot_m_pc_noh`suffix'_ca18 = exp_nf_tot_m_pc_noh`suffix' * ($cpi_non_food_fl1 / $cpi_non_food_fl1)
		}
		
		keep hhid exp_nf_tot_m_pc_noh exp_nf_tot_m_pc_noh_ca18 
		duplicates drop 
		
		tempfile noh
		save `noh'
	restore 
	
	merge m:1 hhid using `noh', assert(3) nogen 
	
	* Calculate total non-food expenditure (with soap and health)
	foreach suffix in "" {
			bys hhid: egen exp_nf_tot_m_pc`suffix' = sum(exp_nf_m_pc`suffix')
			gen exp_nf_tot_m_pc`suffix'_ca18 = exp_nf_tot_m_pc`suffix' * ($cpi_non_food_fl1 / $cpi_non_food_fl1)
		}

	* Winsorize at 99% item (by treatment group)	
		lab var exp_nf_m "Montly expenditure per item"
		lab var exp_nf_m_pc "Montly expenditure per capita per item"
		lab var exp_nf_tot_m_pc "Non-food expenditure (Afghani, per capita, per month) - Phone Survey"
		lab var exp_nf_tot_m_pc_ca18 "Non-food expenditure (2018 AFN, per capita, per month) - Phone Survey"
		lab var exp_nf_tot_m_pc_noh_ca18 "Non-food expenditure (2018 AFN, per capita, per month - no health) - Phone Survey"
		
		preserve 
			keep hhid item exp_nf_m_pc 
			rename (exp_nf_m_pc ) (exp_nf_m_pc_ )
			reshape wide exp_nf_m_pc_ , i(hhid) j(item)
			
		foreach suffix in "" {
			lab var exp_nf_m_pc`suffix'_7 "Soap"
			lab var exp_nf_m_pc`suffix'_21 "House construction and repair"
			lab var exp_nf_m_pc`suffix'_36 "Weddings and funerals, haj"
			lab var exp_nf_m_pc`suffix'_37 "Annual celebrations"
			lab var exp_nf_m_pc`suffix'_38 "Health services"
			
			foreach var in exp_nf_m_pc`suffix'_7 exp_nf_m_pc`suffix'_21 exp_nf_m_pc`suffix'_36 exp_nf_m_pc`suffix'_37 exp_nf_m_pc`suffix'_38 {
			cap confirm var `var'
			if !_rc { // if the variable exists 
			local l_`var' : variable label `var'
			gen `var'_ca18 = `var' * ($cpi_non_food_fl1 / $cpi_non_food_fl1)
			lab var `var'_ca18 "`l_`var''"
			}
		}
	}	
			
			tempfile nonfood_detail
			save `nonfood_detail'
		restore 
		
		keep hhid exp_nf_tot_m_pc exp_nf_tot_m_pc_ca18  *noh* *nos*
		duplicates drop hhid, force
				
		merge 1:1 hhid using "`nonfood_detail'", assert(3) nogen
		
** Combine food and non-food total expenditure 
		merge 1:1 hhid using "`food_exp'", assert(3) nogen
		
		* Use Food consumption without winsorization and Non-food consumtpion with 95% winsorization 
		egen exp_tot_m_pc = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc)
		lab var exp_tot_m_pc "Total (food & non-food) monthly expenditure per capita"	
		
		egen exp_tot_m_pc_ca18 = rowtotal(exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc_ca18)
		lab var exp_tot_m_pc_ca18 "Total (food & non-food) monthly expenditure per capita, 2018 AFN"	
		
		* No health totals 
		egen exp_tot_m_pc_noh = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc_noh)
		lab var exp_tot_m_pc_noh "Total (food & non-food) monthly expenditure per capita"	
		
		egen exp_tot_m_pc_noh_ca18 = rowtotal(exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc_noh_ca18)
		lab var exp_tot_m_pc_noh_ca18 "Total (food & non-food) monthly expenditure per capita, 2018 AFN"
		
		* No soap totals 
		egen exp_tot_m_pc_nos = rowtotal(exp_f_tot_m_pc exp_nf_tot_m_pc_nos)
		lab var exp_tot_m_pc_nos "Total (food & non-food) monthly expenditure per capita (no soap)"	
		
		egen exp_tot_m_pc_nos_ca18 = rowtotal(exp_f_tot_m_pc_ca18 exp_nf_tot_m_pc_nos_ca18)
		lab var exp_tot_m_pc_nos_ca18 "Total (food & non-food) monthly expenditure per capita, 2018 AFN  (no soap)"
		
	* Save
	if	`c(stata_version)'>=14	{
		saveold "${total_expenditure_phonesvy}", replace v(13)
	}
	else {
		save "${total_expenditure_phonesvy}", replace
	}		