* Construct Food Security index at midline for the endline sample 

	* Input 	
	gl foodsecurity 		"${TUP_DB}/Followup_1/DataSets/Intermediate/food_security_index_fl1.dta"
	gl phone_svy_profile	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"	
	gl sample_indicators_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta" 
	
	* Output in Followup_1_Phone folder 
	gl foodsecurity_phonesvy 	"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/food_security_index_fl1.dta"

	* Controls globals 
		global controls i.PRA_lottery 
		global panel_controls i.PRA_lottery ib(4).round 	
	
	use "${foodsecurity}", clear
		merge 1:1 hhid using "${phone_svy_profile}", keepus(treatment ultra_poor PRA_lottery) keep(1 3) nogen
		
* Full fl1 sample first 
	
	* Local for survey vars related to political involment
	loc food_sec_vars "c14_7 c14_3_ac c14_5_ac"
	loc food_sec2_vars "c14_7 c14_3_ac c14_5_ac c14_1_ac"

	drop index_*
	
* Control dummy
	gen 	control = treatment==0
	replace control = . if mi(treatment)
	lab var control "HH is part of control group"
		
	
********************************************************************************
	** Part 2a: Construct indices for full midline sample 
********************************************************************************
	
	loc food_sec_l "Food security"
	loc food_sec2_l "Food security (with enough food to eat)"
	loc sd_var_l "Control"
	loc sd_var "control"
	
	gl all "food_sec food_sec2"
	
	foreach index in $all {
		foreach var of local `index'_vars {
			lab var `var' "``var'_l'"
		}
		preserve
			keep if ultra_poor == 1
			egen index_sdC_`index'_full = weightave(``index'_vars'), normby(`sd_var')
			lab var index_sdC_`index'_full "``index'_l' Index sd(`sd_var_l'), full fl1 sample"
			keep hhid index_sdC_`index'_full 
			tempfile index_sdC_`index'_full
			save	`index_sdC_`index'_full'
					
		restore
		
		preserve
			egen index_sdUP_`index'_full = weightave(``index'_vars'), normby(ultra_poor)
			lab var index_sdUP_`index'_full "``index'_l' Index sd(Ultra-Poor), full fl1 sample"	
			keep hhid index_sdUP_`index'_full
			tempfile index_sdUP_`index'_full
			save	`index_sdUP_`index'_full'
		restore 
	}
		
	
	* Keep the phone survey sample 
	merge 1:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* all_rounds) keep(3) nogen	
	
	* Merge on endline sample indicators  
	merge 1:1 hhid using "${sample_indicators_phonesvy}", assert(1 3) nogen keepusing(index_sdC_food_sec_s) 
		rename index_sdC_food_sec_s sample  

	keep if sample == 1 	
		
	assert (anyround == 1 | mi(anyround)) 
	
********************************************************************************
	** Part 2b: Construct indices for Endline sample
********************************************************************************

	foreach index in $all {
		foreach var of local `index'_vars {
			lab var `var' "``var'_l'"
		}
		preserve
			keep if ultra_poor == 1
			egen index_sdC_`index' = weightave(``index'_vars'), normby(`sd_var')
			lab var index_sdC_`index' "``index'_l' Index sd(`sd_var_l')"
			keep hhid index_sdC_`index' 
			tempfile index_sdC_`index'
			save	`index_sdC_`index''
					
		restore
		
		preserve
			keep if ultra_poor == 1 & all_rounds == 1 
			egen index_sdC_`index'_all = weightave(``index'_vars'), normby(`sd_var')
			lab var index_sdC_`index'_all "``index'_l' Index sd(`sd_var_l') (all rounds)"
			keep hhid index_sdC_`index'_all 
			tempfile index_sdC_`index'_all
			save	`index_sdC_`index'_all'
					
		restore
		
		egen index_sdUP_`index' = weightave(``index'_vars'), normby(ultra_poor)
		lab var index_sdUP_`index' "``index'_l' Index sd(Ultra-Poor)"	
	}

	merge 1:1 hhid using `index_sdC_food_sec', assert(1 3) nogen
	merge 1:1 hhid using `index_sdC_food_sec2', assert(1 3) nogen
	merge 1:1 hhid using `index_sdC_food_sec_all', assert(1 3) nogen
	
	merge 1:1 hhid using `index_sdC_food_sec_full', nogen
	merge 1:1 hhid using `index_sdC_food_sec2_full', nogen
	merge 1:1 hhid using `index_sdUP_food_sec_full', nogen
	merge 1:1 hhid using `index_sdUP_food_sec2_full', nogen
	
	* Make sure we have all profile data 
	merge 1:1 hhid using "${phone_svy_profile}", keepusing(treatment ultra_poor PRA_lottery) update replace keep(3 4) nogen
	
* Save dataset
			keep hhid `foodsec_survey_vars'  `food_sec_vars' `food_sec2_vars' index_sdC_food_sec* index_sdC_food_sec2* index_sdUP_food_sec* index_sdUP_food_sec2* treatment PRA_lottery
			
			if	`c(stata_version)'>=14	{
				saveold "${foodsecurity_phonesvy}", replace v(13)
			}
			else {
				save "${foodsecurity_phonesvy}", replace
			}
				