	* Input
	gl phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"			
	gl time_activities_ses "${TUP_DB}/Followup_1/DataSets/Intermediate/time_activities_ses_fl1.dta" 

	* Output in Followup_1_Phone folder 
	gl time_activities_ses_phonesvy		"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/time_activities_ses_fl1.dta"
	
	
	use "${time_activities_ses}", clear 
		
		* Keep only PM and PF for comparison with Phone survey 
		drop pm
		gen pm = (member == hhh_name2 & b6 == 1)
		gen pw = (member == lady_hh2 & b6 == 2)
		
		keep if pm == 1 | pw == 1 // 2493
		
		recode pm (1=2)
		drop member 
		gen member = pm 
			replace member = pw if member != 2
			tab member 
	
		* All Other Work variable 
		gen did_oWork		= (did_oFarm == 1 | did_maid == 1 | did_outWork == 1 | did_salEmp == 1 | did_oPaidWork == 1)
		replace did_oWork 	= .d if did_oFarm == .d | did_maid == .d | did_outWork == .d | did_salEmp == .d | did_oPaidWork == .d 
		replace did_oWork 	= .r if did_oFarm == .r | did_maid == .r | did_outWork == .r | did_salEmp == .r | did_oPaidWork == .r 
		label var did_oWork "Did any other work in last 4 weeks" 	
		
		
		
		* Hours worked inside and outside the HH for PM and PW (include 0s for those that did not work)
		egen tot_k30_out_hrs_4w = rowtotal(hr_oFarm_4w hr_maid_4w hr_outWork_4w hr_salEmp_4w hr_oPaidWork_4w)
		egen tot_k30_in_hrs_4w = rowtotal(hr_livestock_4w hr_ownFarming_4w hr_ownBiz_4w)

		bys member: sum tot_k30_*_hrs_4w
		
		* Earnings from PM and PW from all paying activities 
		drop tot_hh_pay
		
		* Imputing Don't knows for PM and PW in the same was we do in Midline
	
		** Check whether missingness is random between T and C 
		gen tot_earnings_act_4w_miss = mi(tot_earnings_act_4w)
			reg tot_earnings_act_4w_miss treatment if member == 1
			reg tot_earnings_act_4w_miss treatment if member == 2
			
			bys treatment member: sum tot_earnings_act_4w_miss
			
		** Same check but if we only look at those missing conditional on having done Other Work (paid work)	
		gen tot_earnings_act_4w_miss_oW = mi(tot_earnings_act_4w) & did_oWork == 1 
			reg tot_earnings_act_4w_miss_oW treatment if member == 1
			reg tot_earnings_act_4w_miss_oW treatment if member == 2
			
			bys treatment member: sum tot_earnings_act_4w_miss_oW

	* Impute PM income when DK and PM did at least one type of market work that would be paid. Take the mean of PM labor income, by treatment and other work group, and impute with that.
	
	* Get the mean by: treatment member did_oWork
	egen mean_pay_win = mean(tot_earnings_act_4w), by(treatment member did_oWork)
	
	tab mean_pay_win member if did_oWork == 0	
	tab mean_pay_win member if did_oWork == 1
	
	* Impute for all, regardless of whether they did Other Work
	gen tot_earnings_act_4w_imp = tot_earnings_act_4w
		replace tot_earnings_act_4w_imp = mean_pay_win if mi(tot_earnings_act_4w)
	
	bys member: sum tot_earnings_act_4w tot_earnings_act_4w_imp if ultra_poor == 1 

	gen tot_hh_pay_imp_dum = mi(tot_earnings_act_4w)
	lab var tot_hh_pay_imp_dum "Earnings is missing"
		
**** Without imputation first
	
		*Create flags for the presence of .d or .r in the household  
		egen miss_d = total(cond(tot_earnings_act_4w==.d,1,0)), by(hhid) //Counting missing don't know 
		egen miss_r = total(cond(tot_earnings_act_4w==.r,1,0)), by(hhid) //Counting missing don't answer  
		
		bys hhid : egen tot_hh_pay = sum(tot_earnings_act_4w), m			 
			replace tot_hh_pay = .d if miss_d > 0 & !mi(miss_d) 
			replace tot_hh_pay = .r if miss_r > 0 & !mi(miss_r) 
			label var tot_hh_pay "HH Paid Labor, (4 weeks)" 
	
** Now with winsorization and imputation 	
	*Earnings from Household from all paying activities
	bys hhid: egen tot_hh_pay_imp = sum(tot_earnings_act_4w_imp), m 	
		label var tot_hh_pay_imp "HH Paid Labor, (4 weeks) - Imputed"	
		
		bys treatment: sum tot_hh_pay tot_hh_pay_imp
	
		* Primary female
	preserve
		keep if member == 1 
		isid hhid
		keep hhid pm labor_particip did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork ///
			tot_earnings_act_4w tot_earnings_act_4w_imp tot_hh_pay* did_labor_nohh did_oWork k5_1 employment treatment tot_k30_out_hrs_4w tot_k30_in_hrs_4w
		
		rename * *_pf
		rename (hhid_pf tot_hh_pay_pf tot_hh_pay_imp_pf treatment_pf) (hhid tot_hh_pay tot_hh_pay_imp treatment)
		
		* Share of women receiving any income 
		gen any_income_pf = (tot_earnings_act_4w_imp_pf > 0 & !mi(tot_earnings_act_4w_imp_pf))
		lab var any_income_pf "PW received any income"
		tab any_income_pf treatment, col
		
		lab var tot_earnings_act_4w_pf "Paid Labor Income - PW"
		lab var tot_earnings_act_4w_imp_pf "Paid Labor Income - PW, Imputed"
		rename (tot_earnings_act_4w_pf tot_earnings_act_4w_imp_pf) (tot_pf_pay tot_pf_pay_imp)
		
		lab var tot_k30_out_hrs_4w_pf "Hours Worked Outside the HH"
		lab var tot_k30_in_hrs_4w_pf "Hours Worked Inside the HH"
		 
		tempfile time_pf
		save	`time_pf'
	restore
	
	* Primary male
		keep if member == 2
		isid hhid
		keep hhid pm labor_particip did_livestock did_ownFarming did_ownBiz did_oFarm did_maid did_outWork did_salEmp did_oPaidWork ///
			tot_earnings_act_4w tot_earnings_act_4w_imp tot_hh_pay* did_labor_nohh did_oWork k5_1 employment treatment tot_k30_out_hrs_4w tot_k30_in_hrs_4w
		
		rename * *_pm
		rename (hhid_pm tot_hh_pay_pm tot_hh_pay_imp_pm treatment_pm) (hhid tot_hh_pay tot_hh_pay_imp treatment)
		
		* Share of women receiving any income 
		gen any_income_pm = (tot_earnings_act_4w_imp_pm > 0 & !mi(tot_earnings_act_4w_imp_pm))
		lab var any_income_pm "PM received any income"
		tab any_income_pm treatment, col
		
		lab var tot_earnings_act_4w_pm "Paid Labor Income - PW"
		lab var tot_earnings_act_4w_imp_pm "Paid Labor Income - PW, Imputed"
		
		rename (tot_earnings_act_4w_pm tot_earnings_act_4w_imp_pm) (tot_pm_pay tot_pm_pay_imp)
	
		lab var tot_k30_out_hrs_4w_pm "Hours Worked Outside the HH"
		lab var tot_k30_in_hrs_4w_pm "Hours Worked Inside the HH"
	
		tempfile time_pm
		save	`time_pm'
		
	* Merge
		use `time_pf', clear
		merge 1:1 hhid using `time_pm', nogen update replace 
		
		foreach group in pf pm {
			label var did_labor_nohh_`group'	"Any Type of Work"
			label var did_livestock_`group' 	"HH Livestock"
			label var did_ownFarming_`group'  	"HH Agriculture"
			label var did_ownBiz_`group'  		"HH Non-Agricultural Business"
			label var did_oWork_`group'  		"Other Work"
			label var labor_particip_`group' 	"Labor Participation"	
		}
		
		save "${time_activities_ses_phonesvy}", replace 
	