/*******************************************************************************	

Project:  		AFG-TUP
Created on:  	February 12, 2019
Last udpate on: June 18, 2019

Written by:  	Thomas Escande			

Revision: 		

********************************************************************************	

THIS DO FILE: 	Construct the psychological well being index for the follow up 1


CONTENT:		Part 0 - Create globals for directories and files 
				Part 1a - Recoding psychological well being questions and creating variables to allow comparisons
				Part 1b - Invert so that "positive" outcomes go with higher values for all variables (this requires to look into individual questions for each measure)
				Part 2 - Constructing Cortisol variables, naive one and as the residuals of the regression of cortisol on confounders 
				Part 3 - Psychological Well Being Indices Construction - General
				Part 4 - Constructing Index for ultra poor only, standardized by control group
				Part 5 - Constructing Index for ultra poor only, standardized by female
				


INPUTS:  		"${TUP_DB}/Followup_1/DataSets/Intermediate/all_wellbeing_clean_nopii_fl1.dta"
				"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
				"${TUP_DB}/Followup_1/DataSets/Intermediate/cortisol_results_fl1.dta"

						
OUTPUTS:     	
				* Dropbox files: Latest versions created by person in charge 
						"${TUP_DB}/Followup_1/DataSets/Final/wellbeing_index_ses_fl1.dta"
						"${TUP_DB}/Followup_1/DataSets/Final/wellbeing_index_up_fl1.dta"
						"${TUP_DB}/Followup_1/DataSets/Final/wellbeing_index_gender_fl1.dta"
				
				* Github files: 
						"${fl1_dt}/Final/wellbeing_index_ses_fl1.dta"
						"${fl1_dt}/Final/wellbeing_index_up_fl1.dta"
						"${fl1_dt}/Final/wellbeing_index_gender_fl1.dta"
						

Note: 			You will need to save the ado file that Johannes created (_gweightave.ado), which is an extension to
				egen, in your personal ado folder (find it by typing "sysdir"). Then you will be able to use
				For Mac you should be able to get there by: (1) opening Finder; (2) click ÔGoÕ in the menu bar; (3) press ÔoptionÕ - this will make ÔLibraryÕ 
				appear; and (4) follow the path indicated in the ÔPERSONALÕ directory (if personal doesn't exist, just create it.)
				For information on the command search for the _gweightave instructions.docx in Dropbox (egen indexvariable = weightave(varlist), normby(vartostandardize))
				You can also refer to Anderson (2008), p. 1485, and the GD paper's pre-analysis plan (the version online, p. 13).


*******************************************************************************/

********************************************************************************
** Part 0: Create globals for directories and files 
********************************************************************************

clear all
set more off


	* Input files
		global inputdata 			"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		global cortisol 			"${TUP_DB}/Followup_1/DataSets/Intermediate/cortisol_results_fl1.dta"
		global roster_final 		"${TUP_DB}/Followup_1/DataSets/Intermediate/current_roster_final_fl1.dta"		
		global phone_svy_profile   	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
		global sample_indicators_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta"


		* Output files: 
		global wellbeing_index_ses_fl1_phones "${TUP_DB}/Followup_1_PhoneSample/DataSets/Intermediate/wellbeing_index_ses_fl1_phones.dta"
		global wellbeing_index_up_fl1_phones 	"${TUP_DB}/Followup_1_PhoneSample/DataSets/Intermediate/wellbeing_index_up_fl1_phones.dta"
		global wellbeing_index_gender_fl1_ps 	"${TUP_DB}/Followup_1_PhoneSample/DataSets/Intermediate/wellbeing_index_gender_fl1_ps.dta"
		global wellbeing_index_gen_pmpw_fl1_ps 	"${TUP_DB}/Followup_1_PhoneSample/DataSets/Intermediate/wellbeing_index_gen_pmpw_fl1_ps.dta"

		* Globals for variables
		global id  hhid survey
		global psy_f i5 i7 i10 i11 i12 i16 i23 i25 i26 i27 i28_a i28_b i28_c i28_d i28_e i28_f ///
						i28_g i28_h i28_i i28_j i34 i35 i37 i38 i39 i43 i44 i45 i46 i47 

		global psy_m i5_m i7_m i10_m i11_m i12_m i16_m i23_m i25_m i26_m i27_m i28_a_m i28_b_m i28_c_m i28_d_m i28_e_m i28_f_m ///
						i28_g_m i28_h_m i28_i_m i28_j_m i34_m i35_m i37_m  i38_m i39_m i43_m i44_m i45_m i46_m i47_m
		global cortisol_var time_collection* a18* a18_v* a19* a16* a17*
		global time_var time_collection a18_v a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 a17
		global time_var2 time_collection a18_v a16_1 a16_2 a16_3 a16_4 a16_5 a16_6 
			
	* Controls globals 
		global controls i.PRA_lottery 
		global panel_controls i.PRA_lottery ib(4).round 			
			
		use "${inputdata}", clear
	
		keep $id $psy_f $psy_m $cortisol_var a8_m_gender_v_m a5 a6 hh_head_gender respondent_gender time_endinteraction*

		* Keep the phone survey sample 
		merge m:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r* treatment PRA_lottery) keep(3) nogen
		
	* Merge on endline sample indicators 
	merge 1:1 hhid using "${sample_indicators_phonesvy}", assert(1 3) nogen keepusing(psy_indexC_sdC_s)
			rename psy_indexC_sdC_s sample 
	
	keep if sample == 1 
		
		
********************************************************************************
	** Part 1: Cleaning and checking the time variables linked to the cortisol analysis 
********************************************************************************
	
		*Putting time variables in hours 
	foreach var in $time_var {
		foreach suffix in "" "_m" {
			gen hour_`var'`suffix' = hh(`var'`suffix') + mm(`var'`suffix') / 60
			sum hour_`var'
			label var hour_`var'`suffix' "`var'`suffix' in hours"			
		}
	} 
	
		*Testing for the correction of time collection 
		gen test_time	 	= hour_a18_v   - hour_time_collection 	if a18 	 == 0
		gen test_time_m 	= hour_a18_v_m - hour_time_collection_m if a18_m == 0

		*Three values look really off: hhid 1221 1614 1816. For these, we keep the time collection as it is more consistent with the survey time.  
		gen saliva_time_hour = hour_time_collection 
		replace saliva_time_hour = hour_a18_v if a18 == 0 & (hhid != 1221 & hhid != 1614 & hhid != 1816)
		label var saliva_time_hour "Time of saliva collection in hour"

		gen saliva_time_hour_m = hour_time_collection_m 
		replace saliva_time_hour_m = hour_a18_v_m if a18_m == 0 
		label var saliva_time_hour_m "Time of saliva collection in hour"

		*Putting to missing or mean waking up time after 10 - Mostly to use for robustness checks
	foreach suffix in "" "_m" {
		gen issue_a17`suffix' = 0 
		replace issue_a17`suffix' = 1 if hour_a17`suffix' > 10 & !mi(hour_a17`suffix') /*17 observations to missing*/
		gen hour_a17_mis`suffix' = hour_a17`suffix' if !(issue_a17`suffix' == 1)
		label var hour_a17_mis`suffix' "Waking up time with doubtful observations put to missing"
	
		gen hour_a17_mean`suffix' = hour_a17`suffix'	
		sum hour_a17`suffix' if issue_a17`suffix' == 0
		replace hour_a17_mean`suffix' = `r(mean)' if issue_a17`suffix' == 1
		label var hour_a17_mean`suffix' "Waking up time with doubtful observations imputed with the mean"
	}

		*Checking on all the other time questions, making sure that nothing happened after the end of the interaction
	foreach suffix in "" "_m" {
		gen hour_time_endinteraction`suffix' = hh(time_endinteraction`suffix') + mm(time_endinteraction`suffix') / 60
		
		foreach var in $time_var2 {
			gen issue_`var'`suffix' = 0
			replace issue_`var'`suffix' = 1 if hour_time_endinteraction`suffix' < hour_`var'`suffix' & !mi(hour_`var'`suffix')
			label var issue_`var'`suffix' "`var' recorded as done after the interaction - inconsistent"
			tab issue_`var'`suffix'
		}
	}

		*Replacing to missing the time variables that are recorded as happening after interaction
	foreach var in $time_var2 { 
		gen hour_`var'_mis`suffix' = hour_`var'`suffix' if !(issue_`var'`suffix' == 1)	
		label var hour_`var'_mis`suffix' "`var' with doubtful observations put to missing"
		rename hour_`var'`suffix' hour_`var'_nomiss`suffix'
		rename hour_`var'_mis`suffix' hour_`var'`suffix'
	}
	
*******************************************************************************************************
	** Part 1a: Recoding psychological well being questions and creating variables to allow comparisons
*******************************************************************************************************
		*globals including main questions per indices
	
		global satisf_wvs i5
		global cesd i7 i10 i11 i12 i16  i23 i25
		global trust i26
		global hap_wvs i27
		global lotr i28_a i28_b i28_c i28_d i28_e i28_f i28_g i28_h i28_i i28_j
		global rses i34 i35 i37 i38 i39 i43
		global cohen i44 i45 i46 i47
	
		*Changing the scale to get a scale similar to the one used in Johannes Give Directly (GD) paper - Only for cohen, ranking from 1 to 5 instead of 0 to 4
		*See PWB_comparison_GD-fl-bl for details
			label define cohenlab 1 "Never" 2 "Almost never" 3 "Sometimes" 4 "Fairly often" 5 "Very often"

			foreach x in cohen   {
				foreach y of global `x' {			
					recode `y'* (0 = 1) (1 = 2) (2 = 3) (3 = 4) (4 = 5), pre(new) test
					rename `y'* old`y'* 
					rename new`y'* `y'*
					lab values `y'* cohenlab					
			}
		}	

	*CESD international comparison: from 0 to 21, higher score meaning higher depression
		label define cesdint 0 "Rarely or none of the time ( < 1 day)" 1 "Some or a little of the time (1-2 days)" 2 "Occasionally or a moderate amount of ti" 3 "All of the time (5-7 days)" 

	foreach var in $cesd {
		recode `var'* (4 = 3) (3 = 2) (2 = 1) (1 = 0) , pre(int_score_) test

		lab values int_score_`var'* cesdint
		label var int_score_`var' 	"CESD `var' for international comparison (0 to 3)"
		label var int_score_`var'_m "CESD `var' for international comparison (0 to 3)"
	}

	*Happiness for international comparison: dummy = 1 if chose "Quite happy" or "Very happy"
	foreach var in $hap_wvs {
		gen happy = (`var'<=2) if !mi(`var')
		lab var happy  "LHH Very happy or quite happy (1/0)"	

		gen happy_m = (`var'_m<=2) if !mi(`var'_m)
		lab var happy_m "HH Very happy or quite happy (1/0)"	
	}


*******************************************************************************************************
	** Part 1b: Invert so that "positive" outcomes go with higher values for all variables (this requires to look into individual questions for each measure)
********************************************************************************************************
*Details

		* satisf_wvs: 10 = very satisfied, 1 = very dissatisfied - No change needed
	
		* cesd: 1 = rarely or none of the time to 4 = all of the time - 
		*		i7 : inverse / i10 : inverse / i11 : inverse / i12 : inverse / i16 : inverse / i23 : inverse / i25: inverse

		*trust_wvs: 1 = Most people can be trusted / 2 = Should be careful with people - inverse

		*hap_wvs: 1 = very happy to 4 = Not at all happy - inverse

		*lotr: 1 = strongly agree to 5 = strongly disagree -
		* 	i28_a : inverse / i28_b not scored / i28_c : No change / i28_d : inverse / i28_e : Not scored / i28_f Not scored / i28_g : No change
		* 	i28_h Not scored / i28_i : No change / i28_j : inverse

		*rses: 1 = strongly agree to 5 = strongly disagree -
		* 	i34: inverse / i35 : inverse / i37 : inverse / i38 : No change / i39 : inverse / i43 : No change 

		*cohen: 1 = Never to 5 very often
		* 	i44: inverse / i45: No change / i46: No change / i47: inverse


		*Invert for cesd
			lab define cesd_inv 4 "Rarely or none of the time (<1 day)" 3 "Some or a little of the time (1-2 days)" 2 "Occasionally or a moderate (amount of time (3-4 days))" 1 "All of the time (5-7 days)"

		foreach var in $cesd {
			rename 	`var' 		`var'_origin
			rename 	`var'_m 	`var'_m_origin

			gen `var'		= 5 - `var'_origin
			gen `var'_m 	= 5 - `var'_m_origin
				
			label values `var' 		cesd_inv
			label var    `var' 		"cesd inversed for index computation"
			label values `var'_m 	cesd_inv
			label var    `var'_m 	"cesd inversed for index computation"
		}

		*Invert Trust			
			lab define trust_inv 0 "Need to be very careful in dealing with people" 1 "Most people can be trusted"
	
		foreach var in $trust  {		
			rename 	`var' 		`var'_origin
			rename 	`var'_m 	`var'_m_origin

			gen `var'_m  = 0 		if `var'_m_origin 	== 2
			gen `var'	 = 0 		if `var'_origin 	== 2
			
			replace `var'_m  = 1 	if `var'_m_origin 	== 1
			replace `var'	 = 1 	if `var'_origin 	== 1
			
			lab values `var'	trust_inv
			lab values `var'_m trust_inv	
		}
							
		*Invert Happiness
			lab define hap_inv 4 "Very happy" 3	"Quite happy" 2	"Not very happy" 1	"Not at all happy"

		foreach var in $hap_wvs {
			rename 	`var' 		`var'_origin
			rename 	`var'_m 	`var'_m_origin

			gen `var'		= 5 - `var'_origin
			gen `var'_m 	= 5 - `var'_m_origin
				
			label values `var' 		hap_inv
			label var    `var' 		"Happiness inversed for index computation"
			label values `var'_m 	hap_inv
			label var    `var'_m 	"Happiness inversed for index computation"
		}	

		*lotr:
			lab define lotr_inv  5 "Strongly agree" 4  "Agree" 3  "Neither agree nor disagree" 2  "Disagree" 1  "Strongly disagree"

		foreach suf in _a _d _j {
			rename 	i28`suf' 		i28`suf'_origin
			rename 	i28`suf'_m 		i28`suf'_m_origin	

			gen i28`suf'   = 6 - i28`suf'_origin
			gen i28`suf'_m = 6 - i28`suf'_m_origin

			lab values i28`suf' 	lotr_inv
			lab values i28`suf'_m 	lotr_inv	
		}

		*rses: 
			lab define rses_inv 5 "Strongly agree" 4 "Agree" 3	"Neither agree nor disagree" 2	"Disagree"  1	"Strongly disagree"

		foreach var in 	i34 i35 i37 i39 {
			rename 	`var' 		`var'_origin
			rename 	`var'_m 		`var'_m_origin	

			gen `var'   = 6 - `var'_origin
			gen `var'_m = 6 - `var'_m_origin

			lab values `var' 	rses_inv
			lab values `var'_m 	rses_inv	
		}

		*cohen
			lab define cohen_inv 5  "Never" 4  "Almost never" 3  "Sometimes" 2  "Fairly often" 1  "Very often"
		foreach var in 	i44 i47 {
			rename 	`var' 			`var'_origin
			rename 	`var'_m 		`var'_m_origin	

			gen `var'   = 6 - `var'_origin
			gen `var'_m = 6 - `var'_m_origin

			lab values `var' 	cohen_inv
			lab values `var'_m 	cohen_inv
		}
			
		
***********************************************************************************************************************
** Part 2: Constructing Cortisol variables, naive one and as the residuals of the regression of cortisol on confounders 
***********************************************************************************************************************

	*Merging to have cortisol
		merge 1:1 hhid using "$inputdata", keepusing(cortisol_result cortisol_result_m) keep(3)
		
	*Taking the log of cortisol result and create Winsorized equivalent for robustness checks 
		gen lcortisol 	= ln(cortisol_result)
		gen lcortisol_m = ln(cortisol_result_m) 
		winsor2 lcortisol, suffix(_w) cuts(1 99)
		winsor2 lcortisol_m, suffix(_w) cuts(1 99)
		rename lcortisol_m_w lcortisol_w_m
		
		label var lcortisol 		"Log cortisol (no controls)"
		label var lcortisol_m 		"Log cortisol (no controls)"
		label var lcortisol_w 		"Log cortisol (Winsorized)"
		label var lcortisol_w_m 	"Log cortisol (Winsorized)"

	*Standardized the cortisol
		egen std_lcortisol = std(lcortisol)
		label var std_lcortisol "Log cortisol (no controls) - standardized"

		egen std_lcortisol_m = std(lcortisol_m)
		label var std_lcortisol_m "Log cortisol (no controls) - standardized"

	*Create _hhh variable which is for the head of the household, irrespective of whether the head of the household is a female or a male
	foreach var of varlist lcortisol_w std_lcortisol a19_1 a19_2 a19_3 a19_4 a19_5 a19_6 hour_a16_1 hour_a16_2 hour_a16_3 hour_a16_4 hour_a16_5 hour_a16_6 saliva_time_hour hour_a17_mis hour_a17_mean lcortisol {
		gen `var'_hhh = `var'_m 
		replace `var'_hhh = `var' if hh_head_gender == 2
	}
	

		label var lcortisol_hhh 		"Log cortisol  (no controls)"
		label var lcortisol_w_hhh 		"Log cortisol  (Winsorized)"
		label var std_lcortisol_hhh 	"Log cortisol (no controls) - standardized"

	*Compute residuals of the OLS regression of log cortisol on levels on confounders - see Give Directly or TUP paper for more details
	* Computing dummies for the main confounders for female, male and head of the household: 
	
	foreach suffix in "" "_m" "_hhh" {
	
	*Ingested food
		gen food`suffix' = 0 if !mi(a19_1`suffix')
		replace food`suffix' = 1 if a19_1`suffix' == 1 & hour_a16_1`suffix' + 2 >= saliva_time_hour`suffix' & !mi(hour_a16_1`suffix') & !mi(saliva_time_hour`suffix')
	
	*Smoked Tobacco
		gen tobacco`suffix' = 0 if !mi(a19_2`suffix')
		replace tobacco`suffix' = 1 if a19_2`suffix' == 1 & hour_a16_2`suffix' + 2 >= saliva_time_hour`suffix' & !mi(hour_a16_2`suffix') & !mi(saliva_time_hour`suffix')
	
	*Drank tea
		gen tea`suffix' = 0 if !mi(a19_3`suffix')
		replace tea`suffix' = 1 if a19_3`suffix' == 1 & hour_a16_3`suffix' + 2 >= saliva_time_hour`suffix' & !mi(hour_a16_3`suffix') & !mi(saliva_time_hour`suffix')
	
	*Did physical activity
		gen activity`suffix' = a19_4`suffix'

	*Took medicaments 
		gen med`suffix' = 0 if !mi(a19_5`suffix')
		replace med`suffix' = 1 if a19_5`suffix' == 1 & hour_a16_5`suffix' + 2 >= saliva_time_hour`suffix' & !mi(hour_a16_5`suffix') & !mi(saliva_time_hour`suffix')
	
	*Chewed tobacco
		gen tobacco_chew`suffix' = 0 if !mi(a19_6`suffix')
		replace tobacco_chew`suffix' = 1 if a19_6`suffix' == 1 & hour_a16_6`suffix' + 2 >= saliva_time_hour`suffix' & !mi(hour_a16_6`suffix') & !mi(saliva_time_hour`suffix')

	*Time elapsed since waking up (to saliva collection) rounded to the full hour
		gen time_up`suffix' 	= round(saliva_time_hour`suffix' - hour_a17_mean`suffix')
		gen time_up_mis`suffix' = round(saliva_time_hour`suffix' - hour_a17_mis`suffix')

	*Estimating residuals of the OLS regression of log cortisol on confounders
		reg lcortisol`suffix'  time_up`suffix'  activity`suffix' food`suffix' tobacco`suffix' tea`suffix' med`suffix' tobacco_chew`suffix', r
			predict lcortisol_clean`suffix', res
			label var lcortisol_clean`suffix' "Log cortisol (with controls)"
			
		*Standardize the result
			egen std_lcortisol_clean`suffix' = std(lcortisol_clean`suffix')
			label var std_lcortisol_clean`suffix' "Log cortisol (with controls) - standardized"
			
	*Same specification as before but this time using the Time elapsed since waking up variable with missings for weird observations
		reg lcortisol`suffix'  time_up_mis`suffix'  activity`suffix' food`suffix' tobacco`suffix' tea`suffix' med`suffix' tobacco_chew`suffix', r
			predict lcortisol_clean_mis`suffix', res
			label var lcortisol_clean_mis`suffix' "Log cortisol (with controls, imputing values for controls)"

	*Checking the correaltion between the measures using imputations or not
		reg lcortisol_clean`suffix' lcortisol_clean_mis`suffix' //Almost perfect correlation, will only use lcortisol_clean from now on 
		
		
	*Estimating residuals of the OLS regression of winsorized log cortisol on confounders
		reg lcortisol_w`suffix'   time_up`suffix'  activity`suffix' food`suffix' tobacco`suffix' tea`suffix' med`suffix' tobacco_chew`suffix', r
			predict lcortisol_clean_w`suffix' , res
			label var lcortisol_clean_w`suffix' "Log cortisol (with controls, winsorized cortisol)"
}
	*Inverting it to have higher number equal less stress
		gen lcortisol_clean_inv = -lcortisol_clean
label var lcortisol_clean_inv "Log Cortisol (with Controls, Negatively Coded)"
		gen lcortisol_clean_m_inv = -lcortisol_clean_m
label var lcortisol_clean_m_inv "Log Cortisol (with Controls, Negatively Coded)"
		gen lcortisol_clean_hhh_inv = -lcortisol_clean_hhh 
		
			
***********************************************************************************************************************
** Part 3: Psychological Well Being Indices Construction 
***********************************************************************************************************************
	*Creating control variable to use with the gweightave function
		gen 	control = 0 if treatment == 1
		replace control = 1 if treatment == 0 

	*Setting globals with variables included in main indices
		global id  hhid survey

		global satisf 		i5
		global cesd 		i7 i10 i11 i12 i16  i23 i25
		global trust 		i26
		global hap 			i27
		global lotr 		i28_a i28_c i28_d i28_g i28_i i28_j
		global lotr_total	i28_a i28_b i28_c i28_d i28_e i28_f i28_g i28_h i28_i i28_j
		global rses 		i34 i35 i37 i38 i39 i43
		global cohen 		i44 i45 i46 i47
		global cortisol 	lcortisol lcortisol_w lcortisol_clean lcortisol_clean_w
		global cortisol_m 	lcortisol_m lcortisol_w_m lcortisol_clean_m lcortisol_clean_w_m

		global psy_f i5 i7 i10 i11 i12 i16 i23 i25 i26 i27 i28_a i28_b i28_c i28_d i28_e i28_f ///
						i28_g i28_h i28_i i28_j i34 i35 i37 i38 i39 i43 i44 i45 i46 i47 


		global psy_m i5_m i7_m i10_m i11_m i12_m i16_m i23_m i25_m i26_m i27_m i28_a_m i28_b_m i28_c_m i28_d_m i28_e_m i28_f_m ///
						i28_g_m i28_h_m i28_i_m i28_j_m i34_m i35_m i37_m  i38_m i39_m i43_m i44_m i45_m i46_m i47_m



	*Create variables for head of the household, who is the man if there is one and the lady of the household otherwise (Only for UP)
		foreach var in $psy_f {
			gen `var'_hhh 		= `var'_m if a8_m_gender_v_m == 1
			replace `var'_hhh	= `var'   if mi(a8_m_gender_v_m) & survey == 1 
		}


	*Construction of  specific CESD index for international comparison: from 0 to 21, higher score meaning higher depression
	*Construction is made with a gen so that if any of the variables is missing, the whole index goes to missing (10 out of 2500 in total / 7 UP out of 1159 )
		gen cesd_ts 	= int_score_i7 + int_score_i10 + int_score_i11 + int_score_i12 + int_score_i16 + int_score_i23 + int_score_i25
		gen cesd_ts_m 	= int_score_i7_m + int_score_i10_m + int_score_i11_m + int_score_i12_m + int_score_i16_m + int_score_i23_m + int_score_i25_m

	*Dummy for international comparison: Major depression is defined as CESD score being more than 8
		gen cesd_md = 1 	if (cesd_ts >= 8 & !mi(cesd_ts))
		replace cesd_md = 0 if (cesd_ts < 8 & !mi(cesd_ts))

		gen cesd_md_m = 1 	if (cesd_ts_m >= 8 & !mi(cesd_ts_m))
		replace cesd_md_m = 0 if (cesd_ts_m < 8 & !mi(cesd_ts_m))
			
		lab var cesd_ts 	"CESD total score (0-21)"
		lab var cesd_ts_m	"CESD total score (0-21) - HHH"
		lab var cesd_md 	"CESD Major depression 1/0 (=1 if score>=8) "	
		lab var cesd_md_m 	"CESD Major depression 1/0 (=1 if score>=8) - HHH"
		
	*Ultra Poor as a dummy to be used for the standardization
		gen 	ultra_poor = survey
		replace ultra_poor = 0 if survey == 3

		global allcategories satisf trust hap cesd lotr rses cohen 

	*Creating a single score per category by adding all the questions

		global psy_score
		global psy_score_m
		global psy_score_hhh

		foreach suffix in "" _m _hhh {
			foreach groupvar in $allcategories  {
				gen `groupvar'_score`suffix'_fl1 = 0

				global psy_score`suffix' ${psy_score`suffix'} `groupvar'_score`suffix'_fl1

				foreach var of global `groupvar' {
					replace `groupvar'_score`suffix'_fl1 = `groupvar'_score`suffix'_fl1 + `var'`suffix' /*Score is missing if one question is missing*/
				}	

				*Labelization of scores
		if "`groupvar'"=="satisf" {
			global detail "Life satisfaction (WVS)"
		}
		if "`groupvar'"=="cesd" {
			global detail "Depression (CESD)"
		}
		if "`groupvar'"=="trust" {
			global detail "Trust (WVS)"
		}
		if "`groupvar'"=="hap" {
			global detail "Happiness (WVS)"
		}
		if "`groupvar'"=="lotr" {
			global detail "Life Satisfaction (WVS)"
		}
		if "`groupvar'"=="rses" {
			global detail "Self-Esteem"
		}
		if "`groupvar'"=="cohen" {
			global detail "Stress (Cohen - out of 20)"
		}
		if "`groupvar'"=="cortisol" {
			global detail "Cortisol Level"
		}

				if "`suffix'" == "_m" {
					label var `groupvar'_score`suffix'_fl1 "$detail total score - Man of HH "
					}
				else if "`suffix'" == "_hhh" {
					label var `groupvar'_score`suffix'_fl1 "$detail total score - Man of HH" 
					}
				else {
					label var `groupvar'_score`suffix'_fl1 "$detail total score" 
					}
			} 
		}

	*Replacing for scores with just one variable
		foreach suffix in "" _m _hhh {
					replace satisf_score`suffix'_fl1 = i5`suffix'
					replace trust_score`suffix'_fl1 = i26`suffix'
					replace hap_score`suffix'_fl1 = i27`suffix'
				}

	*standardization of indices - Different standardization: non UP vs UP, treated vs non treated (in ultra poor sample), male vs female (later)
	*non UP vs UP /*For Head of the household, only ultra poors are being asked that question so the indices here for _m are not very interesting*/
		foreach suffix in ""  {
			foreach groupvar in $allcategories {

				egen `groupvar'_z_sdUP`suffix'_fl1 = weightave(`groupvar'_score`suffix'_fl1), normby(ultra_poor)

	*Labelization of scores
		if "`groupvar'"=="satisf" {
			global detail "Life satisfaction (WVS)"
		}
		if "`groupvar'"=="cesd" {
			global detail "Depression (CESD)"
		}
		if "`groupvar'"=="trust" {
			global detail "Trust (WVS)"
		}
		if "`groupvar'"=="hap" {
			global detail "Happiness (WVS)"
		}
		if "`groupvar'"=="lotr" {
			global detail "Life Satisfaction (WVS)"
		}
		if "`groupvar'"=="rses" {
			global detail "Self-Esteem"
		}
		if "`groupvar'"=="cohen" {
			global detail "Stress (Cohen)"
		}
		if "`groupvar'"=="cortisol" {
			global detail "Cortisol Level"
		}
		
				if "`suffix'" == "_m" {
					label var `groupvar'_z_sdUP`suffix'_fl1 " $detail standardized score (ultrapoor) - Man of HH"
					}
				else {
					label var `groupvar'_z_sdUP`suffix'_fl1 "$detail standardized score (ultrapoor)" 
					}
			} 
				*Creating the index with 5 items (all available) and 4 items (all available at baseline). Standardized with respect to ultra poor. 
				egen psy_index5_sdUP`suffix'_fl1 = weightave(satisf_z_sdUP`suffix'_fl1 hap_z_sdUP`suffix'_fl1 cesd_z_sdUP`suffix'_fl1 rses_z_sdUP`suffix'_fl1 cohen_z_sdUP`suffix'_fl1), normby(ultra_poor)
				egen psy_index4_sdUP`suffix'_fl1 = weightave(satisf_z_sdUP`suffix'_fl1 hap_z_sdUP`suffix'_fl1 cesd_z_sdUP`suffix'_fl1 rses_z_sdUP`suffix'_fl1), normby(ultra_poor)
		}

		*Label final variables
		label var psy_index5_sdUP_fl1 		"Psychological Well-being Index(5 item) sd(ultrapoor)"
		label var psy_index4_sdUP_fl1 		"Psychological Well-being Index(4 item) sd(ultrapoor)"

		
*This time, standardizing by control ultra poor to have it comparable */
gen      ultra_poor_control = 0 
replace  ultra_poor_control = 1 if control == 1 &  ultra_poor == 1

		foreach suffix in ""  {
			foreach groupvar in $allcategories {

				egen `groupvar'_z_sdUP_C`suffix'_fl1 = weightave(`groupvar'_score`suffix'_fl1), normby(ultra_poor_control)

	*Labelization of scores
		if "`groupvar'"=="satisf" {
			global detail "Life satisfaction (WVS)"
		}
		if "`groupvar'"=="cesd" {
			global detail "Depression (CESD)"
		}
		if "`groupvar'"=="trust" {
			global detail "Trust (WVS)"
		}
		if "`groupvar'"=="hap" {
			global detail "Happiness (WVS)"
		}
		if "`groupvar'"=="lotr" {
			global detail "Life Satisfaction (WVS)"
		}
		if "`groupvar'"=="rses" {
			global detail "Self-Esteem"
		}
		if "`groupvar'"=="cohen" {
			global detail "Stress (Cohen)"
		}
		if "`groupvar'"=="cortisol" {
			global detail "Cortisol Level"
		}
		
				if "`suffix'" == "_m" {
					label var `groupvar'_z_sdUP_C`suffix'_fl1 " $detail standardized score (ultra_poor_control) - Man of HH"
					}
				else {
					label var `groupvar'_z_sdUP_C`suffix'_fl1 "$detail standardized score (ultra_poor_control)" 
					}
			} 
				*Creating the index with 5 items (all available) and 4 items (all available at baseline). Standardized with respect to ultra poor. 
				egen psy_index5_sdUP_C`suffix'_fl1 = weightave(satisf_z_sdUP_C`suffix'_fl1 hap_z_sdUP_C`suffix'_fl1 cesd_z_sdUP_C`suffix'_fl1 rses_z_sdUP_C`suffix'_fl1 cohen_z_sdUP_C`suffix'_fl1), normby(ultra_poor_control)
				egen psy_index4_sdUP_C`suffix'_fl1 = weightave(satisf_z_sdUP_C`suffix'_fl1 hap_z_sdUP_C`suffix'_fl1 cesd_z_sdUP_C`suffix'_fl1 rses_z_sdUP_C`suffix'_fl1), normby(ultra_poor_control)
		}

		*Label final variables
		label var psy_index5_sdUP_C_fl1 		"Psychological Well-being Index(5 item) sd(ultra_poor_control)"
		label var psy_index4_sdUP_C_fl1 		"Psychological Well-being Index(4 item) sd(ultra_poor_control)"
		

		*Saving dataset with index including ultra poor and non ultra poor standardized by ultra poor
				if	`c(stata_version)'>=14	{
				saveold "${wellbeing_index_ses_fl1_phones}", replace v(13)
			}
				else {
				save "${wellbeing_index_ses_fl1_phones}", replace
			}	

***********************************************************************************************************************
** Part 4: Constructing Index for ultra poor only, standardized by control group
***********************************************************************************************************************

	*Keep only ultra poor as comamnd weightave does not deal well with the 'if' condition
		keep if ultra_poor == 1
		
	*Control vs treatment
		foreach suffix in "" _m _hhh {
			foreach groupvar in $allcategories {
				egen `groupvar'_z_sdC`suffix'_fl1 = weightave(`groupvar'_score`suffix'_fl1), normby(control)

				*Labelization of scores
				if "`groupvar'"=="satisf" {
					global detail "Life satisfaction (WVS)"
				}
				if "`groupvar'"=="cesd" {
					global detail "Depression (CESD)"
				}
				if "`groupvar'"=="trust" {
					global detail "Trust (WVS)"
				}
				if "`groupvar'"=="hap" {
					global detail "Happiness (WVS)"
				}
				if "`groupvar'"=="lotr" {
					global detail "Life Satisfaction (WVS)"
				}
				if "`groupvar'"=="rses" {
					global detail "Self-Esteem"
				}
				if "`groupvar'"=="cohen" {
					global detail "Stress (Cohen)"
				}
				if "`groupvar'"=="cortisol" {
					global detail "Cortisol Level"
				}
				
				
				if "`suffix'" == "_m" {
					label var `groupvar'_z_sdC`suffix'_fl1 "$detail standardized score (control) - Man of HH"
					}
				else if "`suffix'" == "_hhh" {
					label var `groupvar'_z_sdC`suffix'_fl1 "$detail standardized score (control) - Head of HH" 
					}
				else  {
					label var `groupvar'_z_sdC`suffix'_fl1 "$detail standardized score (control)" 
					}
			} 
			
			*Creating the index with 5 items (all available) and 5 items + cortisol. Standardized with respect to the control group. 				
				egen psy_index5_sdC`suffix'_fl1 = weightave(satisf_z_sdC`suffix'_fl1 hap_z_sdC`suffix'_fl1 cesd_z_sdC`suffix'_fl1 rses_z_sdC`suffix'_fl1 cohen_z_sdC`suffix'_fl1), normby(control)
				egen psy_indexC_sdC`suffix'_fl1 = weightave(lcortisol_clean`suffix'_inv satisf_z_sdC`suffix'_fl1 hap_z_sdC`suffix'_fl1 cesd_z_sdC`suffix'_fl1 rses_z_sdC`suffix'_fl1  cohen_z_sdC`suffix'_fl1), normby(control)
				egen psy_index2_sdC`suffix'_fl1 = weightave(hap_z_sdC`suffix'_fl1 cohen_z_sdC`suffix'_fl1), normby(control)
		}

		
	*Labelling final variables
		label var psy_index5_sdC_fl1 		"Psychological Well-being Index(5 item) sd(control)"
		label var psy_index5_sdC_m_fl1 		"Psychological Well-being Index(5 item) sd(control) - Man of HH"
		label var psy_index5_sdC_hhh_fl1 	"Psychological Well-being Index(5 item) sd(control) - Head of HH"

		label var psy_indexC_sdC_fl1 		"Psychological Well-being Index(5 + cortisol) sd(control)"
		label var psy_indexC_sdC_m_fl1 		"Psychological Well-being Index(5 + cortisol) sd(control) - Man of HH"
		label var psy_indexC_sdC_hhh_fl1 	"Psychological Well-being Index(5 + cortisol) sd(control) - Head of HH"


	*Saving dataset with index for ultra poor only standardized by control group
		if	`c(stata_version)'>=14	{
			saveold "${wellbeing_index_up_fl1_phones}", replace v(13)
		}
		else {
			save "${wellbeing_index_up_fl1_phones}", replace
		}	


********************************************************************************
** Part 5: Constructing Index for ultra poor only, standardized by female or female control
********************************************************************************
	*Keep only the score variables. This index can only be constructed for ultra poor as primary males of non ultra poor households were not surveyed. 

		keep $id $psy_score $psy_score_m $cortisol $cortisol_m ultra_poor control a8_m_gender_v_m a5 a6 cesd_md cesd_ts cesd_md_m cesd_ts_m lcortisol_clean_inv lcortisol_clean_m_inv
		drop ultra_poor survey
		
		rename lcortisol_clean_m_inv lcortisol_clean_inv_m

		foreach groupvar in $allcategories  {
			rename `groupvar'_score_fl1  	`groupvar'_score1
			rename `groupvar'_score_m_fl1 	`groupvar'_score2
		}

		foreach groupvar in $cortisol lcortisol_clean_inv {
			rename `groupvar' 		`groupvar'1
			rename `groupvar'_m 	`groupvar'2			
		}

		rename cesd_md 		cesd_md1
		rename cesd_md_m 	cesd_md2
		rename cesd_ts 		cesd_ts1
		rename cesd_ts_m 	cesd_ts2
		
	*Reshape to have one variable for male and one variable for female
		reshape long satisf_score trust_score hap_score cesd_score lotr_score rses_score cohen_score lcortisol lcortisol_w lcortisol_clean lcortisol_clean_inv lcortisol_clean_w  cesd_md cesd_ts, i(hhid control a8_m_gender_v_m a5 a6) j(female)
		replace female = 0 if female == 2
		replace female = . if mi(satisf_score) & mi(trust_score) & mi(hap_score) & mi(cesd_score) & mi(lotr_score) & mi(rses_score) & mi(cohen_score) & female == 0 //When male was not surveyed or we have no information
		label define  hh 1 "LHH" 0 "MHH"
		label values female hh
		
	*generate a variable that is 1 for female control, 0 otherwise, which will be used later on for the standardization. 
		gen 	female_C = 1 if female == 1 & control == 1
		replace female_C = 0 if female == 0 | control == 0

		foreach groupvar in $allcategories {
			egen `groupvar'_z_sdf_fl1 = weightave(`groupvar'_score), normby(female)
			label var `groupvar'_z_sdf_fl1 "`groupvar' standardized score (women)" 
			
			egen `groupvar'_z_sdfC_fl1 = weightave(`groupvar'_score), normby(female_C)
			label var `groupvar'_z_sdfC_fl1 "`groupvar' standardized score (Control women)" 
		} 
		
		*Creating the index with 5 items (all available) and 5 items + cortisol. Standardized with respect to primary woman / Control primary woman	
		egen psy_index5_sdf_fl1 = weightave(satisf_z_sdf_fl1 hap_z_sdf_fl1 cesd_z_sdf_fl1 rses_z_sdf_fl1 cohen_z_sdf_fl1), normby(female)
		egen psy_indexC_sdf_fl1 = weightave(lcortisol_clean_inv satisf_z_sdf_fl1 hap_z_sdf_fl1 cesd_z_sdf_fl1 rses_z_sdf_fl1 cohen_z_sdf_fl1), normby(female)
		
		egen psy_index5_sdfC_fl1 = weightave(satisf_z_sdfC_fl1 hap_z_sdfC_fl1 cesd_z_sdfC_fl1 rses_z_sdfC_fl1 cohen_z_sdfC_fl1), normby(female_C)
		egen psy_indexC_sdfC_fl1 = weightave(lcortisol_clean_inv satisf_z_sdfC_fl1 hap_z_sdfC_fl1 cesd_z_sdfC_fl1 rses_z_sdfC_fl1 cohen_z_sdfC_fl1), normby(female_C)
	
		*Doing the same standardization within the treatment and control group

		*Doing it on the subsample
		preserve 
		keep if control == 0 
		
			*Treatment group
				foreach groupvar in $allcategories {
					egen `groupvar'_z_sdft_fl1 = weightave(`groupvar'_score) , normby(female)
					label var `groupvar'_z_sdft_fl1 "`groupvar' standardized score (women) - Treatment only" 
				} 
			
				*Creating the index with 5 items (all available) and 5 items + cortisol within treatment group. Standardized with respect to primary woman 
				egen psy_index5_sdft_fl1 = weightave(satisf_z_sdft_fl1 hap_z_sdft_fl1 cesd_z_sdft_fl1 rses_z_sdft_fl1 cohen_z_sdft_fl1) if control == 0 , normby(female)
				egen psy_indexC_sdft_fl1 = weightave(lcortisol_clean_inv satisf_z_sdft_fl1 hap_z_sdft_fl1 cesd_z_sdft_fl1 rses_z_sdft_fl1 cohen_z_sdft_fl1) if control == 0 , normby(female)
		keep hhid female psy_index5_sdft_fl1 psy_indexC_sdft_fl1 *_z_sdft_fl1
		tempfile treatment_psy
		save `treatment_psy'
		restore
		
		
		*Control group
		preserve 
		keep if control == 1 
			
				foreach groupvar in $allcategories {
					egen `groupvar'_z_sdfc_fl1 = weightave(`groupvar'_score)  , normby(female) 
					label var `groupvar'_z_sdfc_fl1 "`groupvar' standardized score (women) - Control only " 
				} 
			
			*Creating the index with 5 items (all available) and 5 items + cortisol within control group. Standardized with respect to primary woman 
			egen psy_index5_sdfc_fl1 = weightave(satisf_z_sdfc_fl1 hap_z_sdfc_fl1 cesd_z_sdfc_fl1 rses_z_sdfc_fl1 cohen_z_sdfc_fl1) if control == 1 , normby(female)
			egen psy_indexC_sdfc_fl1 = weightave(lcortisol_clean_inv satisf_z_sdfc_fl1 hap_z_sdfc_fl1 cesd_z_sdfc_fl1 rses_z_sdfc_fl1 cohen_z_sdfc_fl1) if control == 1 , normby(female)
		keep hhid female psy_index5_sdfc_fl1 psy_indexC_sdfc_fl1 *_z_sdfc_fl1
		tempfile control_psy
		save `control_psy'
		restore
		merge 1:1 hhid female using `treatment_psy', assert(1 3) nogen
		merge 1:1 hhid female using `control_psy'  , assert(1 3) nogen		
			
		*Label main variables
			label var psy_index5_sdf_fl1 "Psychological Well-being Index(5 item) sd(women) - Ultra Poor"
			label var psy_indexC_sdf_fl1 "Psychological Well-being Index(4 item) sd(women) - Ultra Poor"
			
			label var psy_index5_sdfC_fl1 "Psychological Well-being Index(5 item) sd(women-control)"
			label var psy_indexC_sdfC_fl1 "Psychological Well-being Index(4 item) sd(women-control)"

			label var psy_index5_sdft_fl1 "Psychological Well-being Index(5 item) sd(women) - Treatment Group"
			label var psy_indexC_sdft_fl1 "Psychological Well-being Index(4 item) sd(women) - Treatment Group"

			label var psy_index5_sdfc_fl1 "Psychological Well-being Index(5 item) sd(women) - Control Group"
			label var psy_indexC_sdfc_fl1 "Psychological Well-being Index(4 item) sd(women) - Control Group"
			
			tempfile psychological_gender
			save `psychological_gender'

		*Merging with roster to have the different indicators
			use "$roster_final", clear
			keep hhid treatment PRA_lottery hh_only_pf ultra_poor
			duplicates drop hhid, force
			
			merge 1:m hhid using `psychological_gender', assert(1 3) keep(3) nogen //We are matching with non UP, only keep UP
		
		*Need to differentiate between when male is missing because no male in the household or male is missing because he did not answer
			replace female = 0 if hh_only_pf != 1 & mi(female)
			drop if mi(female) //No information, just missing observations anyway
			gen pf_pm = 1 - female
			gen t_pf_pm = pf_pm * treatment
			label var pf_pm 	"Man"
			label var t_pf_pm 	"Treatment x Man"			
				
			
		*Saving dataset with index for ultra poor only standardized by female	
				if	`c(stata_version)'>=14	{
				saveold "${wellbeing_index_gender_fl1_ps}", replace v(13)
			}
			else {
				save "${wellbeing_index_gender_fl1_ps}", replace
			}	

			
********************************************************************************************************************
** Part 6: Constructing Index for ultra poor only, standardized by female or female control - HHs with both PM and PW 
********************************************************************************************************************		
use "${wellbeing_index_up_fl1_phones}", clear 		
		
	* There are 3 households with no LHH, so we have to drop those HHs 
		drop if respondent_gender == 1
	* Drop if there is no PM (i.e., HHH is female) - for ethnic heterogeneity analysis only 
		drop if hh_head_gender == 2			
		
*Keep only the score variables. This index can only be constructed for ultra poor as primary males of non ultra poor households were not surveyed. 

		keep $id $psy_score $psy_score_m $cortisol $cortisol_m ultra_poor control a8_m_gender_v_m a5 a6 cesd_md cesd_ts cesd_md_m cesd_ts_m lcortisol_clean_inv lcortisol_clean_m_inv
		drop ultra_poor survey
		
		rename lcortisol_clean_m_inv lcortisol_clean_inv_m

		foreach groupvar in $allcategories  {
			rename `groupvar'_score_fl1  	`groupvar'_score1
			rename `groupvar'_score_m_fl1 	`groupvar'_score2
		}

		foreach groupvar in $cortisol lcortisol_clean_inv {
			rename `groupvar' 		`groupvar'1
			rename `groupvar'_m 	`groupvar'2			
		}

		rename cesd_md 		cesd_md1
		rename cesd_md_m 	cesd_md2
		rename cesd_ts 		cesd_ts1
		rename cesd_ts_m 	cesd_ts2
		
	*Reshape to have one variable for male and one variable for female
		reshape long satisf_score trust_score hap_score cesd_score lotr_score rses_score cohen_score lcortisol lcortisol_w lcortisol_clean lcortisol_clean_inv lcortisol_clean_w  cesd_md cesd_ts, i(hhid control a8_m_gender_v_m a5 a6) j(female)
		replace female = 0 if female == 2
		replace female = . if mi(satisf_score) & mi(trust_score) & mi(hap_score) & mi(cesd_score) & mi(lotr_score) & mi(rses_score) & mi(cohen_score) & female == 0 //When male was not surveyed or we have no information
		label define  hh 1 "LHH" 0 "MHH"
		label values female hh
		
	*generate a variable that is 1 for female control, 0 otherwise, which will be used later on for the standardization. 
		gen 	female_C = 1 if female == 1 & control == 1
		replace female_C = 0 if female == 0 | control == 0

		foreach groupvar in $allcategories {
			egen `groupvar'_z_sdf_fl1 = weightave(`groupvar'_score), normby(female)
			label var `groupvar'_z_sdf_fl1 "`groupvar' standardized score (women)" 
			
			egen `groupvar'_z_sdfC_fl1 = weightave(`groupvar'_score), normby(female_C)
			label var `groupvar'_z_sdfC_fl1 "`groupvar' standardized score (Control women)" 
		} 
		
		*Creating the index with 5 items (all available) and 5 items + cortisol. Standardized with respect to primary woman / Control primary woman	
		egen psy_index5_sdf_fl1 = weightave(satisf_z_sdf_fl1 hap_z_sdf_fl1 cesd_z_sdf_fl1 rses_z_sdf_fl1 cohen_z_sdf_fl1), normby(female)
		egen psy_indexC_sdf_fl1 = weightave(lcortisol_clean_inv satisf_z_sdf_fl1 hap_z_sdf_fl1 cesd_z_sdf_fl1 rses_z_sdf_fl1 cohen_z_sdf_fl1), normby(female)
		
		egen psy_index5_sdfC_fl1 = weightave(satisf_z_sdfC_fl1 hap_z_sdfC_fl1 cesd_z_sdfC_fl1 rses_z_sdfC_fl1 cohen_z_sdfC_fl1), normby(female_C)
		egen psy_indexC_sdfC_fl1 = weightave(lcortisol_clean_inv satisf_z_sdfC_fl1 hap_z_sdfC_fl1 cesd_z_sdfC_fl1 rses_z_sdfC_fl1 cohen_z_sdfC_fl1), normby(female_C)
	
		*Doing the same standardization within the treatment and control group

		*Doing it on the subsample
		preserve 
		keep if control == 0 
		
			*Treatment group
				foreach groupvar in $allcategories {
					egen `groupvar'_z_sdft_fl1 = weightave(`groupvar'_score) , normby(female)
					label var `groupvar'_z_sdft_fl1 "`groupvar' standardized score (women) - Treatment only" 
				} 
			
				*Creating the index with 5 items (all available) and 5 items + cortisol within treatment group. Standardized with respect to primary woman 
				egen psy_index5_sdft_fl1 = weightave(satisf_z_sdft_fl1 hap_z_sdft_fl1 cesd_z_sdft_fl1 rses_z_sdft_fl1 cohen_z_sdft_fl1) if control == 0 , normby(female)
				egen psy_indexC_sdft_fl1 = weightave(lcortisol_clean_inv satisf_z_sdft_fl1 hap_z_sdft_fl1 cesd_z_sdft_fl1 rses_z_sdft_fl1 cohen_z_sdft_fl1) if control == 0 , normby(female)
		keep hhid female psy_index5_sdft_fl1 psy_indexC_sdft_fl1 *_z_sdft_fl1
		tempfile treatment_psy
		save `treatment_psy'
		restore
		
		
		*Control group
		preserve 
		keep if control == 1 
			
				foreach groupvar in $allcategories {
					egen `groupvar'_z_sdfc_fl1 = weightave(`groupvar'_score)  , normby(female) 
					label var `groupvar'_z_sdfc_fl1 "`groupvar' standardized score (women) - Control only " 
				} 
			
			*Creating the index with 5 items (all available) and 5 items + cortisol within control group. Standardized with respect to primary woman 
			egen psy_index5_sdfc_fl1 = weightave(satisf_z_sdfc_fl1 hap_z_sdfc_fl1 cesd_z_sdfc_fl1 rses_z_sdfc_fl1 cohen_z_sdfc_fl1) if control == 1 , normby(female)
			egen psy_indexC_sdfc_fl1 = weightave(lcortisol_clean_inv satisf_z_sdfc_fl1 hap_z_sdfc_fl1 cesd_z_sdfc_fl1 rses_z_sdfc_fl1 cohen_z_sdfc_fl1) if control == 1 , normby(female)
		keep hhid female psy_index5_sdfc_fl1 psy_indexC_sdfc_fl1 *_z_sdfc_fl1
		tempfile control_psy
		save `control_psy'
		restore
		merge 1:1 hhid female using `treatment_psy', assert(1 3) nogen
		merge 1:1 hhid female using `control_psy'  , assert(1 3) nogen		
			
		*Label main variables
			label var psy_index5_sdf_fl1 "Psychological Well-being Index(5 item) sd(women) - Ultra Poor"
			label var psy_indexC_sdf_fl1 "Psychological Well-being Index(4 item) sd(women) - Ultra Poor"
			
			label var psy_index5_sdfC_fl1 "Psychological Well-being Index(5 item) sd(women-control)"
			label var psy_indexC_sdfC_fl1 "Psychological Well-being Index(4 item) sd(women-control)"

			label var psy_index5_sdft_fl1 "Psychological Well-being Index(5 item) sd(women) - Treatment Group"
			label var psy_indexC_sdft_fl1 "Psychological Well-being Index(4 item) sd(women) - Treatment Group"

			label var psy_index5_sdfc_fl1 "Psychological Well-being Index(5 item) sd(women) - Control Group"
			label var psy_indexC_sdfc_fl1 "Psychological Well-being Index(4 item) sd(women) - Control Group"
			
			tempfile psychological_gender
			save `psychological_gender'

		*Merging with roster to have the different indicators
			use "$roster_final", clear
			keep hhid treatment PRA_lottery hh_only_pf ultra_poor
			duplicates drop hhid, force
			
			merge 1:m hhid using `psychological_gender', assert(1 3) keep(3) nogen //We are matching with non UP, only keep UP
		
		*Need to differentiate between when male is missing because no male in the household or male is missing because he did not answer
			replace female = 0 if hh_only_pf != 1 & mi(female)
			drop if mi(female) //No information, just missing observations anyway
			gen pf_pm = 1 - female
			gen t_pf_pm = pf_pm * treatment
			label var pf_pm 	"Man"
			label var t_pf_pm 	"Treatment x Man"			
				
			
		*Saving dataset with index for ultra poor only standardized by female	
				if	`c(stata_version)'>=14	{
				saveold "${wellbeing_index_gen_pmpw_fl1_ps}", replace v(13)
			}
			else {
				save "${wellbeing_index_gen_pmpw_fl1_ps}", replace
			}	
*********************************End of dofile***********************************************************************