/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Mar 13, 2019
Last udpate on: Mar 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Produces a dataset with follow-up 1 indicators for the endline sample (indices).
					For other variables (non-indices), the correct endline sample is specified in the 
					analysis do-files.

CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************
clear all
set more off
set maxvar 20000
* Inputs
	gl data_for_analysis_fl1			"${TUP_DB}/Followup_1/DataSets/Final/data_for_analysis_fl1.dta"
	
	gl phone_svy_profile   				"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
	gl f_empowerment_fl1_phonesample	"${TUP_DB}/Followup_1_PhoneSample/DataSets/Intermediate/f_empowerment_fl1_phonesample.dta"
	gl asset_index_up_phonesvy   "${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/asset_index_up_fl1.dta"
	gl foodsecurity_phonesvy 	"${TUP_DB}/Followup_1_Phone/DataSets/Intermediate/food_security_index_fl1.dta"
	gl wellbeing_index_up_fl1_phones 	"${TUP_DB}/Followup_1_PhoneSample/DataSets/Intermediate/wellbeing_index_up_fl1_phones.dta"
	gl sample_indicators_phonesvy		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/sample_indicators_phonesvy.dta"

* Outputs
	gl data_for_analysis_fl1_phones		"${TUP_DB}/Followup_1_PhoneSample/DataSets/Final/data_for_analysis_fl1_phones.dta"

	
********************************************************************************
	** Part 1: Merge dataset with indices
********************************************************************************

	use "${data_for_analysis_fl1}", clear

* Keep the phone survey sample 
	merge m:1 hhid using "${phone_svy_profile}", keepus(anyround attrition_r*) keep(3) nogen
	
* Food Security
	loc foodsec_vars "index_sdC_food_sec index_sdC_food_sec2 index_sdUP_food_sec index_sdUP_food_sec2"
	drop `foodsec_vars'
	merge 1:1 hhid using "${foodsecurity_phonesvy}", keepus(`foodsec_vars') assert(1 3) nogen
	
* Psy well being
	loc wellbeing_vars "psy_indexC_sdC_fl1"
	drop `wellbeing_vars'	
	merge 1:1 hhid using "${wellbeing_index_up_fl1_phones}", keepus(`wellbeing_vars') assert(1 3) nogen

* Household assets
	loc hhassets_vars "wealth_score_sdC wealth_score property_score"
	drop `hhassets_vars'
	merge 1:1 hhid using "${asset_index_up_phonesvy}", keepus(`hhassets_vars') assert(1 3) nogen
	
* Female empowerment
	loc empowerment_vars "index_sdC_all_decisions index_sdC_foodexp index_sdC_homeexp index_sdC_homefin index_sdC_chischool index_sdC_chihealth index_sdC_chimarr index_sdC_homesale index_sdC_otherexp index_sdC_fert h1_ac h2_ac h3_ac h4_ac h5_ac h6_ac h7_ac h8_ac h9_ac h10_ac h11_ac h12_ac h13_ac h14_ac h28_ac h31_ac h24_ac h30 mobile_yes_pf loan_yes_pf index_sdC_role_prod_act index_sdC_work index_sdC_inputs did_labor_pf owner_manager_pf index_sdC_social_norms_dau index_sdC_educ index_sdC_marriage ed_level_d ed_level_s ed_help_d age_marriage_d index_sdC_social_capital index_sdC_tazkira index_sdC_political index_sdC_community s21 s10 n1 n2 index_sdC_f_emp_3c index_sdC_f_emp_3c_r index_sdC_role_prod_act index_sdC_social_capital index_sdC_all_decisions_m index_sdC_foodexp_m index_sdC_homeexp_m index_sdC_homefin_m index_sdC_chischool_m index_sdC_chihealth_m index_sdC_chimarr_m index_sdC_homesale_m index_sdC_otherexp_m index_sdC_fert_m index_sdC_role_prod_act_m index_sdC_social_norms_m index_sdC_social_capital_m index_sdC_f_emp_3c_m index_sdC_work_m index_sdC_inputs_m index_sdC_tazkira_m index_sdC_political_m index_sdC_community_m index_sdC_educ_m index_sdC_marriage_m index_sdC_all_decisions_w index_sdC_foodexp_w index_sdC_homeexp_w index_sdC_homefin_w index_sdC_chischool_w index_sdC_chihealth_w index_sdC_chimarr_w index_sdC_homesale_w index_sdC_otherexp_w index_sdC_fert_w index_sdC_role_prod_act_w index_sdC_social_norms_w index_sdC_social_capital_w index_sdC_f_emp_3c_w index_sdC_work_w index_sdC_inputs_w index_sdC_tazkira_w index_sdC_political_w index_sdC_community_w index_sdC_educ_w index_sdC_marriage_w index_Z_all_decisions index_Z_role_prod_act index_Z_social_capital index_Z_decisions_eco index_Z_f_emp_3c voted index_sdC_h28 index_sdC_h28_m index_sdC_h28_w index_sdC_h31 index_sdC_h31_m index_sdC_h31_w index_sdC_h24 index_sdC_h24_m index_sdC_h24_w occupation_d" 
	drop `empowerment_vars'
	merge 1:1 hhid using "${f_empowerment_fl1_phonesample}", keepus(`empowerment_vars') assert(1 3) nogen   
 
* Merge on endline sample indicators 
	merge 1:1 hhid using "${sample_indicators_phonesvy}", assert(1 3) nogen
	
* Save dataset will all the vars
	if	`c(stata_version)'>=14	{
		saveold "${data_for_analysis_fl1_phones}", replace v(13)
	}
	else {
		save "${data_for_analysis_fl1_phones}", replace
	}
