	set graphics off
	
	gl total_expenditure_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/total_expenditure_fl1_phonesubset.dta"
	gl food_consumption_all_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/food_consumption_all_fl1_phonesubset.dta"
	gl nonfood_consumption_all_fl1	"${TUP_DB}/Followup_1/DataSets/Intermediate/nonfood_consumption_all_fl1_phonesubset.dta"
	
	gl total_expenditure		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/total_expenditure_phonesvy.dta"
	gl food_consumption_all		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/food_consumption_all_phonesvy.dta"
	gl nonfood_consumption_all	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/nonfood_consumption_all_phonesvy.dta"

	* To save graphs 
	gl output "${TUP_DB}/Phone_Survey/Output/Interim/"
	
	* Get consumption variables 
	use "${total_expenditure_fl1}", clear 
		keep hhid exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc ///
			exp_f_m_pc_dairy exp_f_m_pc_fruit exp_f_m_pc_grain exp_f_m_pc_meat_fish exp_f_m_pc_veg ///
			exp_nf_m_hhrepair_pc exp_nf_m_medical_pc exp_nf_m_celeb_pc exp_nf_m_wedd_pc exp_nf_m_hh_items_pc ultra_poor
		
		rename * *_fl1
		rename hhid_fl1 hhid 
		
		tempfile fl1
		save `fl1'
		
	use "${total_expenditure}", clear 
		keep hhid exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc ///
			exp_f_m_pc_dairy exp_f_m_pc_fruit exp_f_m_pc_grain exp_f_m_pc_meat_fish exp_f_m_pc_veg ///
			exp_nf_m_hhrepair_pc exp_nf_m_medical_pc exp_nf_m_celeb_pc exp_nf_m_wedd_pc exp_nf_m_hh_items_pc ultra_poor
			
		merge 1:1 hhid using "`fl1'", keep(3) // 1736 complete interviews from R1 
		
		keep if ultra_poor == 1 // 749 UP 
		stop
	* Take natural logs of totals 
		local totals  exp_tot_m_pc exp_f_tot_m_pc exp_nf_tot_m_pc exp_tot_m_pc_fl1 exp_f_tot_m_pc_fl1 exp_nf_tot_m_pc_fl1 ///
			exp_nf_m_hhrepair_pc exp_nf_m_medical_pc exp_nf_m_celeb_pc exp_nf_m_wedd_pc exp_nf_m_hh_items_pc ///
			exp_nf_m_hhrepair_pc_fl1 exp_nf_m_medical_pc_fl1 exp_nf_m_celeb_pc_fl1 exp_nf_m_wedd_pc_fl1 exp_nf_m_hh_items_pc_fl1
		
		foreach var of local totals {
		    *replace `var' = 0.0000000001 if `var' == 0
			gen `var'_ln = ln(`var')
			
		}
	stop
		
	* Graph (Afs)
	
		* Total consumption
	local var_lab: var lab exp_tot_m_pc_fl1
	kdensity exp_tot_m_pc, addplot(kdensity exp_tot_m_pc_fl1) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) ///	
		title("`var_lab'") xtitle("") 
	*qui graph save "${output}/exp_tot_m_pc.gph" , replace
	qui graph export "${output}/exp_tot_m_pc_2021prices.pdf", replace as(pdf)
		
		* Food 
	local var_lab: var lab exp_f_tot_m_pc
	kdensity exp_f_tot_m_pc, addplot(kdensity exp_f_tot_m_pc_fl1) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) ///
		title("`var_lab'") xtitle("") 
	*qui graph save "${output}/exp_f_tot_m_pc.gph" , replace
	qui graph export "${output}/exp_f_tot_m_pc_2021prices.pdf", replace as(pdf)

		* Non-Food 
	local var_lab: var lab exp_nf_tot_m_pc
	kdensity exp_nf_tot_m_pc, addplot(kdensity exp_nf_tot_m_pc_fl1) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) ///
		title("`var_lab'") xtitle("") 
	*qui graph save "${output}/exp_nf_tot_m_pc.gph" , replace	
	qui graph export "${output}/exp_nf_tot_m_pc_2021prices.pdf", replace as(pdf) 
	
	
	
	
	* Graph in logs (ln)
	
	* Total consumption
	local var_lab: var lab exp_tot_m_pc_fl1
	kdensity exp_tot_m_pc_ln, addplot(kdensity exp_tot_m_pc_fl1_ln) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) ///	
		title("Nat log `var_lab'") xtitle("") 
	*qui graph save "${output}/exp_tot_m_pc.gph" , replace
	qui graph export "${output}/ln_exp_tot_m_pc_2021prices.pdf", replace as(pdf)
		
		* Food 
	local var_lab: var lab exp_f_tot_m_pc
	kdensity exp_f_tot_m_pc_ln, addplot(kdensity exp_f_tot_m_pc_fl1_ln) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) ///
		title("Nat log `var_lab'") xtitle("") 
	*qui graph save "${output}/exp_f_tot_m_pc.gph" , replace
	qui graph export "${output}/ln_exp_f_tot_m_pc_2021prices.pdf", replace as(pdf)

		* Non-Food 
	local var_lab: var lab exp_nf_tot_m_pc
	kdensity exp_nf_tot_m_pc_ln, addplot(kdensity exp_nf_tot_m_pc_fl1_ln) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) ///
		title("Nat log `var_lab'") xtitle("") 
	*qui graph save "${output}/exp_nf_tot_m_pc.gph" , replace	
	qui graph export "${output}/ln_exp_nf_tot_m_pc_2021prices_.pdf", replace as(pdf)
	

		/* Food detail 
	foreach var of varlist exp_f_m_pc_dairy exp_f_m_pc_fruit exp_f_m_pc_grain exp_f_m_pc_meat_fish exp_f_m_pc_veg {
		local `var'_lab: var lab `var'
		kdensity `var', addplot(kdensity `var'_fl1) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) title("`var_lab'") xtitle("")
		*qui graph save "${output}/`var'.gph" , replace
		qui graph export "${output}/graph detail/`var'_2021prices.pdf", replace as(pdf)
	} */
	
		* Non-food detail 
	foreach var of varlist /*exp_nf_m_hhrepair_pc exp_nf_m_medical_pc exp_nf_m_celeb_pc*/ exp_nf_m_wedd_pc exp_nf_m_hh_items_pc {
		local `var'_lab: var lab `var'
		kdensity `var'_ln, addplot(kdensity `var'_fl1_ln) legend(ring(0) pos(2) label(1 "Phone Survey") label(2 "Follow-up 1")) ///
				title("Nat log ``var'_lab'") xtitle("") 
		*qui graph save "${output}/`var'.gph" , replace	
		qui graph export "${output}/graph detail/ln_`var'_2021prices_nooutliers_no0.pdf", replace as(pdf)
	}
	
	/*graph combine "${output}/exp_tot_m_pc.gph" ///
		"${output}/exp_f_tot_m_pc.gph" ///
		"${output}/exp_nf_tot_m_pc.gph", col(1)
	

	
	
	
	
	