global 	food_consumption			"${TUP_DB}\Phone_Survey\DataSets\Intermediate\foodcons_roster_phonesvy.dta" 
global 	roster						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"

set graphics off

use "${food_consumption}", clear 

* Get number of HH members from the HH roster (from R1 specifically)
	preserve
		use "${roster}", clear
		* Keep R1 for now
		*keep if round == 1 
		keep hhid hh_mem round
		duplicates drop hhid round, force
		tempfile hh_mem
		save	`hh_mem'
	restore
	
	merge m:1 hhid round using `hh_mem', assert(2 3) nogen keep(3)
	merge m:1 hhid using "${profile_info}", keepusing(ultra_poor) keep(3) assert(2 3) nogen

* Generate consumption pc 
	replace c_a = 0 if c == 0
		gen consumed_qty_pc = c_a/hh_mem
		lab var consumed_qty_pc "Quantity consumed per capita" 
		
 
	keep if round == 4 
	
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/food_consumption_stats.xlsx", modify sheet(summary_r4)
	putexcel A1 = "Food consumption (in KGs per capita) summary stats", font(bold)
	putexcel A2 = "Item", font(bold, 10)
	
	* Include Ramadan // if ramadan == 0 
	tabstat consumed_qty_pc if ultra_poor == 1 & c == 1, by(item) stat(min p5 p25 p50 mean p75 p95 max) format(%9.2f) save 
	return list
	
	matrix def item1 = r(Stat1)'
	matrix list item1
	putexcel A3 = "`r(name1)'"
	putexcel B2 = matrix(item1), colnames nformat("number_d2")
	
	local row = 4
	
	forval i = 2/24 {
		matrix item`i' = r(Stat`i')'
		
		putexcel A`row' = "`r(name`i')'"
		matrix list item`i'
		putexcel B`row' = matrix(item`i'), nformat(#.00)
		
		local row = `row' + 1
	}

	* Add N obs in col. J
	tabstat consumed_qty_pc if ultra_poor == 1 & c == 1, by(item) stat(N) format(%9.0f) save 
	return list 
	
	putexcel J2 = "N (non-0) obs"
	
	local row = 3
	
	forval i = 1/24 {
		matrix item`i' = r(Stat`i')'
		
		matrix list item`i'
		putexcel J`row' = matrix(item`i'), nformat(#)
		
		local row = `row' + 1
	}
	
	* Add number of observations flagged as an outlier in cols. L+
	local col_n = 76
	
	foreach var in flag_fl1_lo flag_p50minus3XSD_lo flag_fl1_hi flag_p50plus3XSD_hi {
		
		tabstat `var' if ultra_poor == 1 & c == 1, by(item) stat(mean) format(%9.0f) save 
		return list 
		
		local var_lab : var label `var'
		
		local row = 3
		local col = char(`col_n')
		
		putexcel `col'2 = "`var_lab'"
		
		forval i = 1/24 {
			matrix item`i' = r(Stat`i')'
			
			matrix list item`i'
			putexcel `col'`row' = matrix(item`i'), nformat("percent")
						
			local row = `row' + 1
		}
		
			local col_n = `col_n' + 1
	}

/* Add percentile distributions for other rounds (fl1, r1, r3 and r4)
	preserve 
		collapse fl1_min r*_min fl1_p1 r*_p1 fl1_p5 r*_p5 fl1_p50 r*_p50 fl1_p95 r*_p95 fl1_p99 r*_p99 fl1_max r*_max, by(item ultra_poor)
			keep if ultra_poor == 1 
			export excel using "${TUP_DB}/Phone_Survey/Output/Interim/food_consumption_stats.xlsx", cell(A1) sheetmodify sheet(rounds_comparison) firstrow(var)
	restore 
	
/*------------------------------------------------------------------------------*
* Check if the proportion of high / low outliers based on above rules is 
* equal between T & C (do a simpe T-test w/unequal variances) (doing this after
* manually removing some very high outliers)
*------------------------------------------------------------------------------*

	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/food_consumption_stats.xlsx", modify sheet(ttest)
	
	putexcel A1 = "T-test for the proportion of high and low outliers in T and C groups (unequal variances)", font(bold)
	putexcel B2 = "C mean", font(bold, 10) vcenter
	putexcel C2 = "T mean", font(bold, 10) vcenter
	putexcel D2 = "C - T diff", font(bold, 10) vcenter
	putexcel E2 = "P-val diff", font(bold, 10) vcenter
	
	local i = 3 
	set trace off
	foreach var in flag_p50plus3XSD_hi flag_fl1_hi flag_fl1_lo {
		ttest `var' if mi(flag_outlier), by(treatment) unequal
		local `var'_lab: var lab `var'
		local diff = `r(mu_1)' - `r(mu_2)'
		
		putexcel A`i' = "``var'_lab'"
		putexcel B`i' = `r(mu_1)', 	nformat(#.0000)
		putexcel C`i' = `r(mu_2)', 	nformat(#.0000)
		putexcel D`i' = `diff', 	nformat(#.0000)
		putexcel E`i' = `r(p)', 	nformat(#.0000)
		
		local i = `i' + 1 	
	}
	
	
*------------------------------------------------------------------------------*
* Graph quantities by item 
*------------------------------------------------------------------------------*
		local value_label_item: value label item
		foreach item of numlist 1/84 {
			local l_`item' : label `value_label_item' `item'
			di "`l_`item''"
			
			count if item == `item' & consumed_qty_pc>0 & !mi(consumed_qty_pc) & ultra_poor == 1
		
			if `r(N)' > 0 {
				hist consumed_qty_pc 	if item == `item' & consumed_qty_pc>0 & !mi(consumed_qty_pc) & ultra_poor == 1, percent ///
					title("`l_`item'' - Ultra-poor") note(N=`r(N)') bin(25)
				}
				
			putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/food_consumption_stats.xlsx", sheet("`l_`item''") modify
			graph export "`l_`item''.png", replace
			putexcel A1 = picture("`l_`item''.png")
			
			erase "`l_`item''.png"
		}
	
		putexcel save