global 	nonfood_consumption			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/nonfoodcons_roster_phonesvy.dta"
global 	roster						"${TUP_DB}/Phone_Survey/DataSets/Intermediate/roster_phonesvy.dta"
global 	phone_svy_profile			"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"
global 	profile_info 				"${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"

set graphics off

use "${nonfood_consumption}", clear 

* Create one variable for c12 and c13: we're analyzing by item so it doesn't matter c12 is monthly and c13 yearly
	br hhid hhid item c12 c13
	gen 	non_food = c12
	replace non_food = c13 if item >= 21
	
* Keep round 1 only
	keep if round == 1 
	
* Get number of HH members from the HH roster (from R1 specifically)
	preserve
		use "${roster}", clear
		* Keep R1 for now
		keep if round == 1 
		keep hhid hh_mem
		duplicates drop hhid, force
		tempfile hh_mem
		save	`hh_mem'
	restore
	
	merge m:1 hhid using `hh_mem', assert(2 3) keep(3) nogen // _m == 2 for 7 HHs with partial interviews that are missing expenditures module but have HH size info 
	merge m:1 hhid using "${profile_info}", keepusing(ultra_poor) keep(3) nogen
	merge m:1 hhid using "${phone_svy_profile}", keepusing(enu_r1 treatment) keep(3) nogen
	
* Generate consumption pc 
	gen nonfood_exp_pc = non_food/hh_mem
	lab var nonfood_exp_pc "Non-food expsnditure per capita (Afs)" 
		
	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/nonfood_consumption_stats.xlsx", modify sheet(summary)
	putexcel A1 = "Non-food consumption (in Afs per capita) summary stats (post-removal of high gross outliers, excluding Ramadan)", font(bold)
	putexcel A2 = "Item", font(bold, 10)
	
	* Exclude Ramadan
	tabstat nonfood_exp_pc if ramadan == 0 & ultra_poor == 1 & !mi(nonfood_exp_pc) & nonfood_exp_pc > 0, by(item) stat(min p5 p25 p50 mean p75 p95 max) format(%9.2f) save 
	return list
	
	matrix def item1 = r(Stat1)'
	matrix list item1
	putexcel A3 = "`r(name1)'"
	putexcel B2 = matrix(item1), colnames nformat(#.00)
	
	local row = 4
	
	forval i = 2/5 {
		matrix item`i' = r(Stat`i')'
		
		putexcel A`row' = "`r(name`i')'"
		matrix list item`i'
		putexcel B`row' = matrix(item`i'), nformat("number_d2")
		
		local row = `row' + 1
	}

	* Add N
	tabstat nonfood_exp_pc if ramadan == 0 & ultra_poor == 1 & !mi(nonfood_exp_pc) & nonfood_exp_pc > 0, by(item) stat(N) format(%9.0f) save 
	return list 
	
	putexcel J2 = "N"
	
	local row = 3
	
	forval i = 1/24 {
		matrix item`i' = r(Stat`i')'
		
		matrix list item`i'
		putexcel J`row' = matrix(item`i'), nformat(#)
		
		local row = `row' + 1
	}
	
	* Add number of observations flagged as an outlier in cols. L+
	local col_n = 76
	
	foreach var in flag_fl1_lo flag_p50minus3XSD_lo flag_fl1_hi flag_p50plus3XSD_hi {
		
		tabstat `var' if ramadan == 0 & ultra_poor == 1 & !mi(nonfood_exp_pc) & nonfood_exp_pc > 0, by(item) stat(mean) format(%9.0f) save 
		return list 
		
		local var_lab : var label `var'
		
		local row = 3
		local col = char(`col_n')
		
		putexcel `col'2 = "`var_lab'"
		
		forval i = 1/24 {
			matrix item`i' = r(Stat`i')'
			
			matrix list item`i'
			putexcel `col'`row' = matrix(item`i'), nformat("percent")
						
			local row = `row' + 1
		}
		
			local col_n = `col_n' + 1
	}

	
*------------------------------------------------------------------------------*
* Check if the proportion of high / low outliers based on above rules is 
* equal between T & C (do a simpe T-test w/unequal variances) (doing this after
* manually removing some very high outliers)
*------------------------------------------------------------------------------*

	putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/nonfood_consumption_stats.xlsx", modify sheet(ttest)
	
	putexcel A1 = "T-test for the proportion of high and low outliers in T and C groups (unequal variances)", font(bold)
	putexcel B2 = "C mean", font(bold, 10) vcenter
	putexcel C2 = "T mean", font(bold, 10) vcenter
	putexcel D2 = "C - T diff", font(bold, 10) vcenter
	putexcel E2 = "P-val diff", font(bold, 10) vcenter
	
	local i = 3 
	set trace off
	foreach var in flag_p50plus3XSD_hi flag_fl1_hi flag_fl1_lo {
		ttest `var' if mi(flag_outlier), by(treatment) unequal
		local `var'_lab: var lab `var'
		local diff = `r(mu_1)' - `r(mu_2)'
		
		putexcel A`i' = "``var'_lab'"
		putexcel B`i' = `r(mu_1)', 	nformat(#.0000)
		putexcel C`i' = `r(mu_2)', 	nformat(#.0000)
		putexcel D`i' = `diff', 	nformat(#.0000)
		putexcel E`i' = `r(p)', 	nformat(#.0000)
		
		local i = `i' + 1 	
	}
	
	
* Add percentile distributions for other rounds (fl1, r1, r3 and r4)
	preserve 
		collapse fl1_min r*_min fl1_p1 r*_p1 fl1_p5 r*_p5 fl1_p50 r*_p50 fl1_p95 r*_p95 fl1_p99 r*_p99 fl1_max r*_max, by(item ultra_poor)
			keep if ultra_poor == 1 
			export excel using "${TUP_DB}/Phone_Survey/Output/Interim/nonfood_consumption_stats.xlsx", cell(A1) sheetmodify sheet(rounds_comparison) firstrow(var)
	restore 
	
	
	
*------------------------------------------------------------------------------*
* Graph quantities by item 
*------------------------------------------------------------------------------*

		local value_label_item: value label item
		foreach item of numlist 7 21 36 37 38 {
			local l_`item' : label `value_label_item' `item'
			local l_`item' = subinstr("`l_`item''","(","",.)
			local l_`item' = subinstr("`l_`item''",")","",.)
			local l_`item' = substr("`l_`item''",1,30) // some lables too long
			di "`l_`item''"
			
			count if item == `item' & nonfood_exp_pc>0 & !mi(nonfood_exp_pc) & ultra_poor == 1
		
			if `r(N)' > 0 {
				hist nonfood_exp_pc 	if item == `item' & nonfood_exp_pc>0 & !mi(nonfood_exp_pc) & ultra_poor == 1, percent ///
					title("`l_`item'' - Ultra-poor") note(N=`r(N)') bin(25)
				}
				
			putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/nonfood_consumption_stats.xlsx", sheet("`l_`item''") modify
			graph export "`l_`item''.png", replace
			putexcel A1 = picture("`l_`item''.png")
			
			erase "`l_`item''.png"
		}
	
		putexcel save