/** Shocks - descriptives 

	R1 is asked since April 2020
	R2 is asked since date of R1 survey or since April 2020 (if there is no R1 survey)
	R4 is asked about last 4 weeks 

*/			
	
set graphics off 	
	
global 	shocks						"${TUP_DB}\Phone_Survey\DataSets\Intermediate\shocks_roster_phonesvy.dta"
global  phone_svy_profile   		"${TUP_DB}/Phone_Survey/DataSets/Intermediate/phone_svy_profile.dta"


use "${shocks}", clear 
	merge m:1 hhid using "${phone_svy_profile}", keep(3) keepusing(treatment ultra_poor PRA_lottery call_status_r1 date_r*) nogen


	
	* Check recall periods 
	preserve 
		
		cap drop date_apr1
		gen date_apr1 = date("1apr2020", "DMY")
		format date_apr1 %td

		keep hhid date* call_status_r1
		duplicates drop 
		
		gen recall_r1 = date_r1 - date_apr1
		sum recall_r1, d
		
		gen recall_r2 = date_r2 - date_apr1
		sum recall_r2 if call_status_r1!=1, d
		
		* Avg number of days between R1 and R2 surveys 
		gen days = date_r2 - date_r1
		br date_r1 date_r2 days if !mi(days)
		sum days, d
		
	restore 
	
	assert call_status == 2 if g1 == .
	* Drop partial interviews w/o shocks data, and HHs that responded DK/Refuse (23 HHs or a little over 1%)
	unique hhid if mi(g1)
	drop if mi(g1)
	stop
	* How many types of shocks did people experience? 
	preserve 
		bys hhid round: egen numshock = total(g1_a) 
		gen none = (g1_a == 1 & shock == 0) 
		bys hhid round: egen none_max = max(none)
		replace numshock = 0 if none_max == 1 
		
		keep hhid round treatment numshock g1 call_status_r1
		duplicates drop
		isid hhid round
		
		local i = 25 
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks.xlsx", modify sheet(g1)

		tabstat numshock if round == 1 & g1 == 1, by(treatment) stat(mean max N) save
		return list 
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat numshock if round == 2 & call_status_r1!=1 & g1 == 1, by(treatment) stat(mean max N) save // since April
			local i = `i' + 1
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat numshock if round == 2 & call_status_r1==1 & g1 == 1, by(treatment) stat(mean max N) save // since R1 survey 
			local i = `i' + 1
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat numshock if round == 4 & g1 == 1, by(treatment) stat(mean max N) save
			local i = `i' + 1
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
	restore 
	
	* Experienced any shock
	preserve
			
		collapse g1 call_status_r1, by(hhid round treatment)
		
		
		** new 
		drop if round == 4 

		gen shock_r1 = (g1 == 1 & round == 1)
		gen shock_r2_april = (g1 == 1 & round == 2 & call_status_r1 != 1)
		gen shock_r2 = (g1 == 1 & round == 2 & call_status_r1 == 1)
		
		//bys hhid: egen shock_r1 = max(shock_r1_temp)
		//bys hhid: egen shock_r2_april = max(shock_r2_april_temp)
		//bys hhid: egen shock_r2 = max(shock_r2_temp)
		
		//drop *_temp

		* STOP
		
		//tabstat shock_r1 if round == 2 & call_status_r1 == 1 , by(treatment) stat(mean N) save
		
		collapse (max) shock_r1 shock_r2_april shock_r2 treatment, by(hhid)
		merge 1:1 hhid using "${phone_svy_profile}", keep(3) keepusing(call_status_r1 call_status_r2) nogen
		
		keep if !mi(treatment)
		
		tabstat shock_r2 if shock_r1 == 1, by(treatment) stat(mean N)
		tabstat shock_r1 if shock_r2 == 1, by(treatment) stat(mean N)
		
		* This is the same result as in the table (correct)
		tabstat shock_r1 shock_r2_april shock_r2, by(treatment) stat(mean N)

		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks.xlsx", modify sheet(g1)

		tabstat g1 if round == 1, by(treatment) stat(mean N) save
		return list 
		
			local i = 2 
			putexcel A`i' = "Round 1"
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
			
		tabstat g1 if round == 2 & call_status_r1 != 1, by(treatment) stat(mean N)  save
		return list // since April
		
			local i = `i' + 1
			putexcel A`i' = "Round 2 - Since April 2020"
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
	
		tabstat g1 if round == 2 & call_status_r1 == 1, by(treatment) stat(mean N)  save
		return list // since date of last survey - find out what it is on average 
		
			local i = `i' + 1
			putexcel A`i' = "Round 2 - Since date of last survey"
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat g1 if round == 4, by(treatment) stat(mean N)  save
		return list 
	
			local i = `i' + 1
			putexcel A`i' = "Round 4 - last 4 weeks"
			putexcel B`i' = "`r(name1)'"
			putexcel C`i' = matrix(r(Stat1)'), nformat("number_d2")
		
			local i = `i' + 1
			putexcel B`i' = "`r(name2)'"
			putexcel C`i' = matrix(r(Stat2)'), nformat("number_d2")
	
	restore 
	
	* Nature of shock 
	preserve 
		keep hhid round shock g1_a treatment call_status_r1
		
		rename g1_a g1_a_
		recode shock (-97=97)
		reshape wide g1_a_, i(hhid round) j(shock)
			
		lab var 	g1_a_0	"No shock"
		lab var 	g1_a_1	"Lost a job or cannot find work (outside of HH)"
		lab var 	g1_a_2	"Household livestock got sick or died "
		lab var 	g1_a_3	"Household business had to close"
		lab var 	g1_a_4	"Household business had a loss"
		lab var 	g1_a_5	"Severe illness or injury of a HH member (including accidents)"
		lab var 	g1_a_6	"Death of a HH member"
		lab var 	g1_a_7	"Weather or natural disaster shock (e.g., drought, flood, storm, earthquake)"
		lab var 	g1_a_8	"Theft"
		lab var 	g1_a_9	"Other violence/crime event"
		lab var 	g1_a_10	"Rise in food prices"
		lab var 	g1_a_11	"Lower crop yield"
		lab var 	g1_a_12	"Loss of household asset"
		lab var 	g1_a_97	"Other"
		lab var 	g1_a_13	"Household forced to move"
		lab var 	g1_a_14	"Imprisonment of a HH member"
		lab var 	g1_a_15	"Destruction of house / other property (due to conflict or accident)"
		lab var 	g1_a_16	"HH member had to pay compensation"

		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks.xlsx", modify sheet(g1_a)
		
		tabstat g1_a_* if round == 1, by(treatment) stat(mean N) save 
		return list 
		
		local i = 4
		putexcel B`i' = matrix(r(Stat1)'), nformat("number_d2")
		putexcel D`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat g1_a_* if round == 2 & call_status_r1 != 1, by(treatment) stat(mean N) save // since April
		
		return list 
		putexcel G`i' = matrix(r(Stat1)'), nformat("number_d2")
		putexcel I`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat g1_a_* if round == 2 & call_status_r1 == 1, by(treatment) stat(mean N) save // since last survey in R1 
		
		return list 
		putexcel L`i' = matrix(r(Stat1)'), nformat("number_d2")
		putexcel N`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat g1_a_* if round == 4, by(treatment) stat(mean N) save
		
		return list 
		putexcel Q`i' = matrix(r(Stat1)'), nformat("number_d2")
		putexcel S`i' = matrix(r(Stat2)'), nformat("number_d2")
	
	restore
	
	* When did the event ocur? 
		* Overall
	preserve 
		keep hhid round shock g1 g1_a g4_a_* g4 treatment call_status_r1
		keep if g1_a == 1 
		
		gen g4_a_mult = .
			forval i = 1/16 {
				replace g4_a_mult = `i' if g4_a_`i' == 1 
			}
		
		#delimit;
		label define mo_lab
			1 	"April 2020"
			2	"May 2020"
			3	"June 2020"
			4	"July 2020"
			5	"August 2020"
			6	"September 2020"
			7	"October 2020"
			8	"November 2020"
			9	"December 2020"
			10	"January 2021"
			11	"February 2021"
			12	"March 2021"
			13	"April 2021"
			14	"May 2021"
			15	"June 2021"
			16	"All months", modify;
		#delimit cr
		
		label val g4_a_mult mo_lab
		
		isid hhid round shock
		
		* All shocks 		
			* create a separate Round category for HHs in R2 that were not surveyed in R1 
			replace round = 3 if (round == 2 & call_status_r1 != 1) // since April
			
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks.xlsx", modify sheet(g4_a_TEST)
	
		tabplot g4_a_mult treatment if round == 1, horizontal percent(treatment) xtitle("treatment group") ytitle("") title("all shocks") subtitle("Round 1: shocks since April 2020") showval(format(%2.0f)) 
			graph export "all_shocks_R1.png", replace
			putexcel A1 = picture("all_shocks_R1.png")
			erase "all_shocks_R1.png"
			
		tabplot g4_a_mult treatment if round == 2, horizontal percent(treatment) xtitle("treatment group") ytitle("") title("all shocks") subtitle("Round 2: shocks since last round") showval(format(%2.0f)) 
			graph export "all_shocks_R2.png", replace
			putexcel M1 = picture("all_shocks_R2.png")
			erase "all_shocks_R2.png"
		
		tabplot g4_a_mult treatment if round == 3, horizontal percent(treatment) xtitle("treatment group") ytitle("") title("all shocks") subtitle("Round 2: shocks since April 2020") showval(format(%2.0f))
			graph export "all_shocks_R3.png", replace
			putexcel AD1 = picture("all_shocks_R3.png")
			erase "all_shocks_R3.png"
		
		
		* Worst shock 
		tabplot g4_a_mult treatment if round == 1 & shock == g4, horizontal percent(treatment) xtitle("treatment group") ytitle("") title("worst shock") subtitle("Round 1: shocks since April 2020") showval(format(%2.0f)) 
			graph export "worst_shock_R1.png", replace
			putexcel A50 = picture("worst_shock_R1.png")
			erase "worst_shock_R1.png"
			
		tabplot g4_a_mult treatment if round == 2 & shock == g4, horizontal percent(treatment) xtitle("treatment group") ytitle("") title("worst shock") subtitle("Round 2: shocks since last round") showval(format(%2.0f)) 
			graph export "worst_shock_R2.png", replace
			putexcel M50 = picture("worst_shock_R2.png")
			erase "worst_shock_R2.png"
		
		tabplot g4_a_mult treatment if round == 3 & shock == g4, horizontal percent(treatment) xtitle("treatment group") ytitle("") title("worst shock") subtitle("Round 2: shocks since April 2020") showval(format(%2.0f))
			graph export "worst_shock_R3.png", replace
			putexcel AD50 = picture("worst_shock_R3.png")
			erase "worst_shock_R3.png"

	restore 
	
	* Worst / most severe event questions 
		keep hhid round g1 g4 g2_* g3 g5 treatment call_status_r1
		duplicates drop 
		isid hhid round 
		
		* Which was the worst? 
		tabmiss g4 if g1 == 1 & round != 4 // there are 12 HHs with missing info on the worst shock - likely due to TPM corrections 
			* where TPM added a second shock selection and surveyor only had 1 in the original form (so g4 was not asked)
		
		bys treatment: tab g4 if round == 1 & g1 == 1, m
		bys treatment: tab g4 if round == 2 & call_status_r1 != 1 & g1 == 1, m // since April
		bys treatment: tab g4 if round == 2 & call_status_r1 == 1 & g1 == 1, m // since last survey in R1 	
		
		* What did you do to cope with the worst event?
		putexcel set "${TUP_DB}/Phone_Survey/Output/Interim/shocks.xlsx", modify sheet(g2)

		
		tabstat g2_* if round == 1, by(treatment) stat(mean N) save 
		return list 
		
		local i = 6
		putexcel B`i' = matrix(r(Stat1)'), nformat("number_d2")
		putexcel D`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat g2_* if round == 2 & call_status_r1 != 1, by(treatment) stat(mean N) save // since April
		return list 
		putexcel G`i' = matrix(r(Stat1)'), nformat("number_d2")
		putexcel I`i' = matrix(r(Stat2)'), nformat("number_d2")
		
		tabstat g2_* if round == 2 & call_status_r1 == 1, by(treatment) stat(mean N) save // since last survey in R1 
		return list 
		putexcel L`i' = matrix(r(Stat1)'), nformat("number_d2")
		putexcel N`i' = matrix(r(Stat2)'), nformat("number_d2") */
		
		* Did your HH recover? 
		bys treatment: tab g3 if round == 1
		bys treatment: tab g3 if round == 2 & call_status_r1 != 1, m // since April
		bys treatment: tab g3 if round == 2 & call_status_r1 == 1, m // since last survey in R1 	
		bys treatment: tab g3 if round == 4, m
		
		
		
	
	/* Combine rounds 1 & 2 since R2 was mostly asked "since date of the last survey" (meaning R1), or since April 2020 (if a HH was missed in R1)
		* This way we get a picture of shocks from April 2020 to date of R2 survey 
	drop call_status pilot*
	keep if round != 4	
	rename *__* *_*
	rename * *_
	rename (hhid_ round_ PRA_lottery_ treatment_ ultra_poor_ shock_) (hhid round PRA_lottery treatment ultra_poor shock) 
	
	unab reshapevars: g1_ g1_a_ g2_?_ g2_??_  g3_ g4_a_* g4_ g5_
	
	reshape wide `reshapevars', i(hhid shock) j(round)
		
	* Combine data from both rounds	
	egen g1 = rowmax(g1_1 g1_2)
	egen g1_a = rowmax(g1_a_1 g1_a_2)
	

	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	