********************************************************************************
*
* 	Descriptive statistics on Tazkira ID ownership in R1 and R2 of the Phone Survey 
*
*
*
********************************************************************************

gl all_hhlevel_phonesvy 	"${TUP_DB}/Phone_Survey/DataSets/Intermediate/all_hhlevel_phonesvy.dta"

	use "${all_hhlevel_phonesvy}", clear 

* Keep R1 + R2 data only 
	keep if round == 1 | round == 2  
* Keep complete interviews (there is one partial interview that does have tazkira data, but we will likely not use that HH for anything else so excluding here as well)
	keep if call_status == 1 

* This was asked in R1 and in R4 in the "long" survey
		keep hhid round z1_1-z5_0 no_pm ultra_poor treatment
			
	* Reshape wide 
		rename * *_
		rename (hhid_ round_) (hhid round)
		reshape wide z1_1_ z1_2_ z1_3_ z1_4_ z1_5_ z1_6_ z1_0_ z2_ z3_ z4_1_ z4_2_ z4_3_ z4_4_ z4_5_ z4_6_ z4_0_ z5_1_ z5_2_ z5_3_ z5_4_ z5_5_ z5_6_ z5_7_ z5_0_ z6_ z7_ no_pm_, i(hhid) j(round)
	
	* Use this rule for now, but we may want to do something like with business ownership above -- i.e., 
	* if PW "ever" spoke to a village leader about an issue - for the handful of HHs surveyed in more than 1 round with questions n1, n2
	* Tazkira is in theory asked only once; it is asked twice for about 20 HHs (documented this in another do-file - find where);
	* The reponses to this question (z2) are consistent with the exception of 1 HH, for which I assume that the first answer in R1 takes precedence
	* over the second inconsistent answer in a later round 
	
	* "Fill" in missingness by pooling data from all rounds for 
		* Majority of HHs would have answered these questions in R1, so we fill in for the ones that were only surveyed in 
		* later rounds (were missing from R1).
	foreach var in z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z2 z3 z4_1 z4_2 z4_3 z4_4 z4_5 z4_6 z4_0 z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 z6 z7 no_pm {
		gen 	`var' = `var'_1 if !mi(`var'_1)
				replace `var' = `var'_2 if mi(`var')
		drop `var'_1 `var'_2 
	}
	


********************************** Have a Tazkira *********************************
* Do you have a tazkira?
* Does PM have a tazkira?

	recode z2 (2=1)
	recode z3 (2=1)
	
	gen z2_mi = (mi(z2))
	gen z1_mi = (mi(z1_1))
	gen z4_mi = (mi(z4_1) & z2 == 1)
	
	gen z6_mi = (mi(z6) & z2 == 1)
	gen z7_mi = (mi(z7) & z3 == 1)
	gen z5_mi = (mi(z5_1) & z2 == 0)
	
	* z6 and z5 we added to the survey a bit later on so there is missingness in those questions 
	tabm z2_mi z1_mi z4_mi z6_mi z7_mi z5_mi

	assert !mi(z3) if no_pm != 100
	
* By UP
preserve
	gen count = (z2_mi == 0)
 		
	collapse (mean) mean_z2=z2 mean_z3=z3 mean_z6=z6 mean_z7=z7 mean_z2_mi=z2_mi (sum) z2 z3 z6 z7 z2_mi count, by(ultra_poor)
		
	longshape mean_z2 mean_z3 mean_z6 mean_z7 mean_z2_mi z2 z3 z6 z7 z2_mi count, i(ultra_poor) j(ownership) replace 
		drop _ownership
	
	gen mean = (inlist(ownership,2,3,4,5,6))
	
	reshape wide y, i(ownership) j(ultra_poor)
		rename (y0 y1) (nup up)
			
			recode ownership (7=2) (8=3) (9=4) (10=5) (11=6)
				reshape wide nup up, i(ownership) j(mean)
				
				rename (nup0 up0 nup1 up1) (n_nup n_up mean_nup mean_up)

		tempfile hastz_up
		save `hastz_up'
restore
	
* By T/C	
preserve 
	gen count = (z2_mi == 0)
	
	keep if ultra_poor == 1 
		drop ultra_poor
	
	collapse (mean) mean_z2=z2 mean_z3=z3 mean_z6=z6 mean_z7=z7 mean_z2_mi=z2_mi (sum) z2 z3 z6 z7 z2_mi count, by(treatment)
	
	longshape mean_z2 mean_z3 mean_z6 mean_z7 mean_z2_mi z2 z3 z6 z7 z2_mi count, i(treatment) j(ownership) replace 
		drop _ownership
		
	gen mean = (inlist(ownership,2,3,4,5,6))
	
	reshape wide y, i(ownership) j(treatment)
		rename (y0 y1) (control treatment)
		
			recode ownership (7=2) (8=3) (9=4) (10=5) (11=6)
				reshape wide control treatment, i(ownership) j(mean)
				
				rename (control0 treatment0 control1 treatment1) (n_c n_t mean_c mean_t)
				
		tempfile hastz_treat
		save `hastz_treat'
restore 

* Totals (all)
preserve
	gen count = (z2_mi == 0)

	collapse (mean) mean_z2=z2 mean_z3=z3 mean_z6=z6 mean_z7=z7 mean_z2_mi=z2_mi (sum) z2 z3 z6 z7 z2_mi count
	
	gen n = _n
	
	longshape mean_z2 mean_z3 mean_z6 mean_z7 mean_z2_mi z2 z3 z6 z7 z2_mi count, i(n) j(ownership) replace 
		drop _ownership n
		
	gen mean = (inlist(ownership,2,3,4,5,6))
		
		recode ownership (7=2) (8=3) (9=4) (10=5) (11=6)
		
	reshape wide y, i(ownership) j(mean)
		rename (y0 y1) (n_tot mean_tot)
	
		tempfile hastz_tot
		save `hastz_tot'
restore

preserve	
		use "`hastz_treat'", clear 
			merge 1:1 ownership using "`hastz_up'", assert(3) nogen
			merge 1:1 ownership using "`hastz_tot'", assert(3) nogen
			
			order ownership n_c mean_c n_t mean_t n_up mean_up n_nup mean_nup n_tot mean_tot
					
					/*1 = 8 count
					2 = 1 PW
					3 = 7 Missing
					4 PM
					5 = 3 PW E-tazkira
					6 PM E-tazkira*/
									
					recode ownership (1=8) (2=1) (3=7) (5=2) (4=3) (6=4) (7=5) (8=6)
				
					sort ownership
				
					label define ownership 1 "Primary Woman (PW) has a tazkira" 2 "PW has E-tazkira (sample of PW with a tazkira)*" ///
						3 "Primary Man (PM) has a tazkira" 4 "PM has E-tazkira (sample of PM with a tazkira)**" ///
							7 "Missing" 8 "N", modify
					label val ownership ownership
					
					label var ownership "Tazkira ownership"
					label var n_c "N"
					label var mean_c "%"
					label var n_t "N"
					label var mean_t "%"
					label var n_up "N"
					label var mean_up "%"
					label var n_nup "N"
					label var mean_nup "%"
					label var n_tot "N"
					label var mean_tot "%"
						
			export excel "${TUP_DB}/Phone_Survey/Output/Interim/tazkira.xlsx", ///
					sheet(has_tazkira, modify) firstrow(varl) 
restore 	


******************* Done any of the activities? (FULL sample)*******************
	
	label var z1_1 "Open an account in a bank"
	label var z1_2 "Buy or register a SIM card"
	label var z1_3 "Vote in the last presidential election"
	label var z1_4 "Register land or property"
	label var z1_5 "Access health services"
	label var z1_6 "Receive assistance from the government "
	label var z1_0 "None of the above"
	
		
	* Assume an activity was done if tazkira was used for said activity
		forval i = 0/6 {
			replace z1_`i' = 1 if z4_`i' == 1
		}

* By UP
preserve 
	gen count = (z1_mi == 0)
	
		collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(ultra_poor)
		
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(ultra_poor) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(ultra_poor)
		rename (y0 y1) (nup up)

			recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide nup up, i(activity) j(mean)
				
				rename (nup0 up0 nup1 up1) (n_nup n_up mean_nup mean_up)
				
				recode activity (1=11) (9=10) (2=9)
				sort activity

		tempfile act_up
		save `act_up'
restore

* By T/C
preserve 
	gen count = (z1_mi == 0)
	
	keep if ultra_poor == 1 
		drop ultra_poor
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(treatment)
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(treatment) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(treatment)
		rename (y0 y1) (control treatment)
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide control treatment, i(activity) j(mean)
				
				rename (control0 treatment0 control1 treatment1) (n_c n_t mean_c mean_t)
				
				recode activity (1=11) (9=10) (2=9)
				
		tempfile act_treat
		save `act_treat'
		
restore

* Totals (all)	
preserve
	gen count = (z1_mi == 0)
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count
	
	gen n = _n
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(n) j(activity) replace 
		drop _activity n
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
			
		reshape wide y, i(activity) j(mean)
			rename (y0 y1) (n_tot mean_tot)
			
			recode activity (1=11) (9=10) (2=9)
		
		tempfile act_tot
		save `act_tot'
restore

preserve	
		use "`act_treat'", clear 
			merge 1:1 activity using "`act_up'", assert(3) nogen
			merge 1:1 activity using "`act_tot'", assert(3) nogen
			
			order activity n_c mean_c n_t mean_t n_up mean_up n_nup mean_nup n_tot mean_tot
			label drop activity 
			
	
					sort activity 
			
					label define activity 3 "Open an account in a bank" 4 "Buy or register a SIM card" ///
						5 "Vote in the last presidential election" 6 "Register land or property" 7 "Access health services" ///
							8 "Receive assistance from the government" 9 "None of the above" 10 "Missing" 11 "N", modify
					label val activity activity
				
					label var activity "Activity"
					label var n_c "N"
					label var mean_c "%"
					label var n_t "N"
					label var mean_t "%"
					label var n_up "N"
					label var mean_up "%"
					label var n_nup "N"
					label var mean_nup "%"
					label var n_tot "N"
					label var mean_tot "%"
						
			export excel "${TUP_DB}/Phone_Survey/Output/Interim/tazkira.xlsx", ///
					sheet(activity, modify) firstrow(varl) 
restore 	
	
	

*************** Done any of the activities (NO tazkira subsample) **************
 
* By UP
preserve 
	gen count = (z2_mi == 0)
	
	keep if z2 == 0
	
		collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(ultra_poor)
		
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(ultra_poor) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(ultra_poor)
		rename (y0 y1) (nup up)

			recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide nup up, i(activity) j(mean)
				
				rename (nup0 up0 nup1 up1) (n_nup n_up mean_nup mean_up)
				
				recode activity (1=11) (9=10) (2=9)

		tempfile noact_up
		save `noact_up'
restore

* By T/C
preserve 
	gen count = (z2_mi == 0)
	
	keep if ultra_poor == 1 
		drop ultra_poor
		
			keep if z2 == 0
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(treatment)
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(treatment) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(treatment)
		rename (y0 y1) (control treatment)
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide control treatment, i(activity) j(mean)
				
				rename (control0 treatment0 control1 treatment1) (n_c n_t mean_c mean_t)
				
				recode activity (1=11) (9=10) (2=9)
				
		tempfile noact_treat
		save `noact_treat'
		
restore

* Totals (all)	
preserve
	gen count = (z2_mi == 0)
	
	keep if z2 == 0
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count
	
	gen n = _n
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(n) j(activity) replace 
		drop _activity n
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
			
		reshape wide y, i(activity) j(mean)
			rename (y0 y1) (n_tot mean_tot)
			
			recode activity (1=11) (9=10) (2=9)
		
		tempfile noact_tot
		save `noact_tot'
restore

preserve	
		use "`noact_treat'", clear 
			merge 1:1 activity using "`noact_up'", assert(3) nogen
			merge 1:1 activity using "`noact_tot'", assert(3) nogen
			
			order activity n_c mean_c n_t mean_t n_up mean_up n_nup mean_nup n_tot mean_tot
					
					sort activity
				
					label define activity 3 "Open an account in a bank" 4 "Buy or register a SIM card" ///
						5 "Vote in the last presidential election" 6 "Register land or property" 7 "Access health services" ///
							8 "Receive assistance from the government" 9 "None of the above" 10 "Missing" 11 "N", modify
					label val activity activity
					
					label var activity "Activity"
					label var n_c "N"
					label var mean_c "%"
					label var n_t "N"
					label var mean_t "%"
					label var n_up "N"
					label var mean_up "%"
					label var n_nup "N"
					label var mean_nup "%"
					label var n_tot "N"
					label var mean_tot "%"
						
			export excel "${TUP_DB}/Phone_Survey/Output/Interim/tazkira.xlsx", ///
					sheet(activity_no_tazkira, modify) firstrow(varl) 
restore 	


*************** Done any of the activities (TAZKIRA subsample) **************
 
* By UP
preserve 
	gen count = (z2_mi == 0)
	
	keep if z2 == 1
	
		collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(ultra_poor)
		
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(ultra_poor) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(ultra_poor)
		rename (y0 y1) (nup up)

			recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide nup up, i(activity) j(mean)
				
				rename (nup0 up0 nup1 up1) (n_nup n_up mean_nup mean_up)
				
				recode activity (1=11) (9=10) (2=9)

		tempfile noact_up
		save `noact_up'
restore

* By T/C
preserve 
	gen count = (z2_mi == 0)
	
	keep if ultra_poor == 1 
		drop ultra_poor
		
			keep if z2 == 1
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(treatment)
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(treatment) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(treatment)
		rename (y0 y1) (control treatment)
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide control treatment, i(activity) j(mean)
				
				rename (control0 treatment0 control1 treatment1) (n_c n_t mean_c mean_t)
				
				recode activity (1=11) (9=10) (2=9)
				
		tempfile noact_treat
		save `noact_treat'
		
restore

* Totals (all)	
preserve
	gen count = (z2_mi == 0)
	
	keep if z2 == 1
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count
	
	gen n = _n
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(n) j(activity) replace 
		drop _activity n
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
			
		reshape wide y, i(activity) j(mean)
			rename (y0 y1) (n_tot mean_tot)
			
			recode activity (1=11) (9=10) (2=9)
		
		tempfile noact_tot
		save `noact_tot'
restore

preserve	
		use "`noact_treat'", clear 
			merge 1:1 activity using "`noact_up'", assert(3) nogen
			merge 1:1 activity using "`noact_tot'", assert(3) nogen
			
			order activity n_c mean_c n_t mean_t n_up mean_up n_nup mean_nup n_tot mean_tot
					
					sort activity
				
					label define activity 3 "Open an account in a bank" 4 "Buy or register a SIM card" ///
						5 "Vote in the last presidential election" 6 "Register land or property" 7 "Access health services" ///
							8 "Receive assistance from the government" 9 "None of the above" 10 "Missing" 11 "N", modify
					label val activity activity
					
					label var activity "Activity"
					label var n_c "N"
					label var mean_c "%"
					label var n_t "N"
					label var mean_t "%"
					label var n_up "N"
					label var mean_up "%"
					label var n_nup "N"
					label var mean_nup "%"
					label var n_tot "N"
					label var mean_tot "%"
						
			export excel "${TUP_DB}/Phone_Survey/Output/Interim/tazkira.xlsx", ///
					sheet(activity_tazkira_new, modify) firstrow(varl) 
restore 	

*************** Done any of the activities (TAZKIRA subsample) **************
 
* By UP
preserve 
	gen count = (z2_mi == 0)
	
	keep if z2 == 0
	
		collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(ultra_poor)
		
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(ultra_poor) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(ultra_poor)
		rename (y0 y1) (nup up)

			recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide nup up, i(activity) j(mean)
				
				rename (nup0 up0 nup1 up1) (n_nup n_up mean_nup mean_up)
				
				recode activity (1=11) (9=10) (2=9)

		tempfile noact_up
		save `noact_up'
restore

* By T/C
preserve 
	gen count = (z2_mi == 0)
	
	keep if ultra_poor == 1 
		drop ultra_poor
		
			keep if z2 == 0
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, by(treatment)
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(treatment) j(activity) replace 
		drop _activity
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(activity) j(treatment)
		rename (y0 y1) (control treatment)
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide control treatment, i(activity) j(mean)
				
				rename (control0 treatment0 control1 treatment1) (n_c n_t mean_c mean_t)
				
				recode activity (1=11) (9=10) (2=9)
				
		tempfile noact_treat
		save `noact_treat'
		
restore

* Totals (all)	
preserve
	gen count = (z2_mi == 0)
	
	keep if z2 == 0
	
	collapse (mean) mean_z1_1=z1_1 mean_z1_2=z1_2 mean_z1_3=z1_3 mean_z1_4=z1_4 mean_z1_5=z1_5 mean_z1_6=z1_6 mean_z1_0=z1_0 mean_z1_mi=z1_mi (sum) z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count
	
	gen n = _n
	
	longshape mean_z1_1 mean_z1_2 mean_z1_3 mean_z1_4 mean_z1_5 mean_z1_6 mean_z1_0 mean_z1_mi z1_1 z1_2 z1_3 z1_4 z1_5 z1_6 z1_0 z1_mi count, i(n) j(activity) replace 
		drop _activity n
		
	gen mean = (inlist(activity,2,3,4,5,6,7,8,9))
		
		recode activity (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
			
		reshape wide y, i(activity) j(mean)
			rename (y0 y1) (n_tot mean_tot)
			
			recode activity (1=11) (9=10) (2=9)
		
		tempfile noact_tot
		save `noact_tot'
restore

preserve	
		use "`noact_treat'", clear 
			merge 1:1 activity using "`noact_up'", assert(3) nogen
			merge 1:1 activity using "`noact_tot'", assert(3) nogen
			
			order activity n_c mean_c n_t mean_t n_up mean_up n_nup mean_nup n_tot mean_tot
					
					sort activity
				
					label define activity 3 "Open an account in a bank" 4 "Buy or register a SIM card" ///
						5 "Vote in the last presidential election" 6 "Register land or property" 7 "Access health services" ///
							8 "Receive assistance from the government" 9 "None of the above" 10 "Missing" 11 "N", modify
					label val activity activity
					
					label var activity "Activity"
					label var n_c "N"
					label var mean_c "%"
					label var n_t "N"
					label var mean_t "%"
					label var n_up "N"
					label var mean_up "%"
					label var n_nup "N"
					label var mean_nup "%"
					label var n_tot "N"
					label var mean_tot "%"
						
			export excel "${TUP_DB}/Phone_Survey/Output/Interim/tazkira.xlsx", ///
					sheet(activity_no_tazkira, modify) firstrow(varl) 
restore 	


		

	
************* Reasons you don't have a tazkira? (NO tazkira subsample) *********

	label var z5_1 "I applied but haven’t received it"
	label var z5_2 "I do not know how to apply"
	label var z5_3 "It costs too much to apply"
	label var z5_4 "I would need to travel too far to apply "
	label var z5_5 "The application process is too complicated"
	label var z5_6 "I need someone to go with me to apply"
	label var z5_7 "I don’t want to take or someone taking a picture of my face"
	label var z5_0 "I don’t need an ID"
	
* By UP
preserve 	
	gen count = 1 // no missingness in z5

		collapse (mean) mean_z5_1=z5_1 mean_z5_2=z5_2 mean_z5_3=z5_3 mean_z5_4=z5_4 mean_z5_5=z5_5 mean_z5_6=z5_6 mean_z5_7=z5_7 mean_z5_0=z5_0 (sum) z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 count, by(ultra_poor)
		
	longshape mean_z5_1 mean_z5_2 mean_z5_3 mean_z5_4 mean_z5_5 mean_z5_6 mean_z5_7 mean_z5_0 z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 count, i(ultra_poor) j(reason) replace 
		drop _reason
		
	gen mean = (inlist(reason,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(reason) j(ultra_poor)
		rename (y0 y1) (nup up)

			recode reason (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide nup up, i(reason) j(mean)
				
				rename (nup0 up0 nup1 up1) (n_nup n_up mean_nup mean_up)
				
				recode reason (2=10) (1=11)

		tempfile reas_up
		save `reas_up'
restore

* By T/C
preserve 
	gen count = 1 // no missingness in z5

	keep if ultra_poor == 1 
		drop ultra_poor
	
	collapse (mean) mean_z5_1=z5_1 mean_z5_2=z5_2 mean_z5_3=z5_3 mean_z5_4=z5_4 mean_z5_5=z5_5 mean_z5_6=z5_6 mean_z5_7=z5_7 mean_z5_0=z5_0 (sum) z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 count, by(treatment)
	
	longshape mean_z5_1 mean_z5_2 mean_z5_3 mean_z5_4 mean_z5_5 mean_z5_6 mean_z5_7 mean_z5_0 z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 count, i(treatment) j(reason) replace 
		drop _reason
		
	gen mean = (inlist(reason,2,3,4,5,6,7,8,9))
	
	reshape wide y, i(reason) j(treatment)
		rename (y0 y1) (control treatment)
		
		recode reason (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
				reshape wide control treatment, i(reason) j(mean)
				
				rename (control0 treatment0 control1 treatment1) (n_c n_t mean_c mean_t)
				
				recode reason (2=10) (1=11)
				
		tempfile reas_treat
		save `reas_treat'
restore

* Totals (all)	
preserve	
	gen count = 1 // no missingness in z5

	collapse (mean) mean_z5_1=z5_1 mean_z5_2=z5_2 mean_z5_3=z5_3 mean_z5_4=z5_4 mean_z5_5=z5_5 mean_z5_6=z5_6 mean_z5_7=z5_7 mean_z5_0=z5_0 (sum) z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 count
	
	gen n = _n
	
	longshape mean_z5_1 mean_z5_2 mean_z5_3 mean_z5_4 mean_z5_5 mean_z5_6 mean_z5_7 mean_z5_0 z5_1 z5_2 z5_3 z5_4 z5_5 z5_6 z5_7 z5_0 count, i(n) j(reason) replace 
		drop _reason n
		
	gen mean = (inlist(reason,2,3,4,5,6,7,8,9))
		
		recode reason (10=2) (11=3) (12=4) (13=5) (14=6) (15=7) (16=8) (17=9)
			
	
			recode reason (2=10) (1=11)
			
			reshape wide y, i(reason) j(mean)
			rename (y0 y1) (n_tot mean_tot)
			
			recode reason (2=10) (1=11)
		
		tempfile reas_tot
		save `reas_tot'
restore

preserve	
		use "`reas_treat'", clear 
			merge 1:1 reason using "`reas_up'", assert(3) nogen
			merge 1:1 reason using "`reas_tot'", assert(3) nogen
			
			order reason n_c mean_c n_t mean_t n_up mean_up n_nup mean_nup n_tot mean_tot
					
					sort reason
				
					label define reason 3 "I applied but haven’t received it" 4 "I do not know how to apply" ///
						5 "It costs too much to apply" 6 "I would need to travel too far to apply" 7 "The application process is too complicated" ///
							8 "I need someone to go with me to apply" 9 "I don’t want to take or someone taking a picture of my face" ///
							10 "I don’t need an ID" 11 "N", modify
					label val reason reason
					
					label var reason "Reason for not having a tazkira"
					label var n_c "N"
					label var mean_c "%"
					label var n_t "N"
					label var mean_t "%"
					label var n_up "N"
					label var mean_up "%"
					label var n_nup "N"
					label var mean_nup "%"
					label var n_tot "N"
					label var mean_tot "%"
	
					export excel "${TUP_DB}/Phone_Survey/Output/Interim/tazkira.xlsx", ///
						sheet(reason_no_tazkira, modify) firstrow(varl) 
restore 	
	
		

/*** Tazkira questions from mobile data section
br z2 z1_2 z4_2 v2_tazkira_1_current v2_tazkira_3_current v2_network_time_current if v2_tazkira_1_current == 1 


v2_tazkira_1_1 v2_tazkira_3_1
v2_tazkira_1_2 v2_tazkira_3_2
v2_tazkira_1_3 v2_tazkira_3_3
v2_tazkira_1_4 v2_tazkira_3_4
