  * ******************************************************************** *
   * ******************************************************************** *
   *                                                                      *
   *                ENDLINE (FOLLOW UP 2)                                 *
   *               MASTER DO_FILE                                         *
   *                                                                      *
   * ******************************************************************** *
   * ******************************************************************** *

       /*
       ** PURPOSE:      This master do file run all the cleaning and construction do files for the Endline (second follow up) survey was conducted over the phone in four different rounds from late January to June 2021 approximately five years after the asset transfer/ four years after the end of the intervention

       ** OUTLINE:      PART 0: Standardize settings and install packages
                        PART 1: Preparing folder path globals
                        PART 2: Run the master do files for each high level task

       ** IDS VAR:       hhid       //Uniquely identifies households

       ** NOTES:

       ** WRITEN BY:    Yulia Belyakova (ybelyakova@worldbank.org)
						Thomas Escande (tescande@worldbank.org)

       */

*iefolder*0*StandardSettings****************************************************
*iefolder will not work properly if the line above is edited

   * ******************************************************************** *
   *
   *       PART 0:  INSTALL PACKAGES AND STANDARDIZE SETTINGS
   *
   *           -Install packages needed to run all dofiles called
   *            by this master dofile.
   *           -Use ieboilstart to harmonize settings across users
   *
   * ******************************************************************** *

   * ******************************************************************** *
   *
   *       PART 1:  PREPARING FOLDER PATH GLOBALS
   *
   *           -Set the global box to point to the project folder
   *            on each collaborators computer.
   *           -Set other locals that point to other folders of interest.
   *
   * ******************************************************************** *


*iefolder*1*FolderGlobals*master************************************************
*iefolder will not work properly if the line above is edited

   global mastData               "$dataWorkFolder/MasterData" 

*iefolder*1*FolderGlobals*rawData***********************************************
*iefolder will not work properly if the line above is edited

   global encryptFolder          "$dataWorkFolder/EncryptedData" 

*iefolder*1*FolderGlobals*Followup_1********************************************
*iefolder will not work properly if the line above is edited

   *Phone_Survey folder globals
   global Phone_Survey           "$dataWorkFolder/Phone_Survey" 
   global Phone_Survey_encrypt   "$encryptFolder/Round Phone_Survey Encrypted" 
   global Phone_Survey_dt        "$Phone_Survey/DataSets" 
   global Phone_Survey_do        "$Phone_Survey/Dofiles" 
   global Phone_Survey_out       "$Phone_Survey/Output" 



   * Set all non-folder path globals that are constant accross
   * the project. Examples are conversion rates used in unit
   * standardization, differnt set of control variables,
   * ado file paths etc.

   
   do							"$dataWorkFolder/global_setup.do"
   
     * ******************************************************************** *
   *
   *       PART 3: - RUN DOFILES CALLED BY THIS MASTER DO FILE
   *
   *           -A task master dofile has been created for each high
   *            level task (cleaning, construct, analyze). By 
   *            running all of them all data work associated with the 
   *            Followup_1 should be replicated, including output of 
   *            tablets, graphs, etc.
   *           -Feel free to add to this list if you have other high
   *            level tasks relevant to your project.
   *
   * ******************************************************************** *

******************************************************************************** 
********************************************************************************
	** Endline Phone Survey DO FILES
********************************************************************************
******************************************************************************** 
   
*********************************************************************************
* 0. Construct dataset with key HH info (treatment assignment, survey outcomes in
* 		rounds, etc.)
*********************************************************************************
	
/*********************************************************************************
* I. Initial cleaning per Round
*********************************************************************************
	
	* R1
	do "${Phone_Survey_do}/Cleaning/phone_svy_clean_r1.do"

	* R2
	do "${Phone_Survey_do}/Cleaning/phone_svy_clean_r2.do"

	* R3
	do "${Phone_Survey_do}/Cleaning/phone_svy_clean_r3.do"

	* R4
	do "${Phone_Survey_do}/Cleaning/phone_svy_clean_r4.do"
	
	* Market survey 
	do "${Phone_Survey_do}/Cleaning/market_survey_clean.do"

	* Profile data 
	do "${Phone_Survey_do}/Cleaning/phone_svy_profile_clean.do"
	
	* Add village survey here

*********************************************************************************
* II. Prepare roster (long format) datasets
*********************************************************************************

	* 1. HH roster and children's education
	do "${Phone_Survey_do}/Cleaning/roster_clean.do"

	* 2. Food consumption
	do "${Phone_Survey_do}/Cleaning/food_consumption_roster_clean.do"
		* This do-file runs "foodcons_roster_outliers.do"

	* 3. Non-food consumption
	do "${Phone_Survey_do}/Cleaning/nonfood_consumption_roster_clean.do"
		* This do-files runs "nonfood_consumption_outliers.do"
		
	* 4. Livestock
	do "${Phone_Survey_do}/Cleaning/livestock_roster_clean.do"

	* 5. Crops / ag businesses
	do "${Phone_Survey_do}/Cleaning/crops_roster_clean.do"

	* 6. Assets
	do "${Phone_Survey_do}/Cleaning/assets_roster_clean.do"

	* 7. Time use / labor 
	do "${Phone_Survey_do}/Cleaning/timeuse_roster_clean.do"

	* 8. Time use / labor (hours)
	do "${Phone_Survey_do}/Cleaning/timeuse_hours_clean.do"

	* 9. Shocks
	do "${Phone_Survey_do}/Cleaning/shocks_roster_clean.do"

	* 10. Mobile data
	do "${Phone_Survey_do}/Cleaning/mobile_roster_clean.do"
	
	* 11. Clean HH-level outcomes
	do "${Phone_Survey_do}/Cleaning/all_hhlevel_phonesvy.do"
		* This do-file runs "savings_loans_outliers_clean.do" 
		* At this point, remove roster variables from the resulting dataset like we do for MDC in fl1,
		* so there is no duplication.
		
	* 12. Migration
	do "${Phone_Survey_do}/Cleaning/migration_clean.do" */
	
	
*********************************************************************************
* II. Construction of outcomes 
*********************************************************************************
	
	*** Profile data 
	do "${Profile_do}/Construct/phone_svy_profile_construct.do"	
	
	* 1. Market survey 
	do "${Phone_Survey_do}/Construction/market_survey_construct_phonesvy.do"
	
	* 2. HH roster 
	do "${Phone_Survey_do}/Construction/roster_phonesvy.do"
	
	* 4. Time use 
	do "${Phone_Survey_do}/Construction/time_activities_construct_phonesvy.do"
	
	* 5a. Asset index 
	do "${Phone_Survey_do}/Construction/asset_index_construct_phonesvy.do"
	
	* 5b. Other assets
	do "${Phone_Survey_do}/Construction/other_asset_construct_phonesvy.do"
	
	* 6. Productive assets 
	do "${Phone_Survey_do}/Construction/productive_assests_construct_phonesvy.do"
	
	* 7. Income and Revenues 
	do "${Phone_Survey_do}/Construction/revenues_income_construct_phonesvy.do"
	
	* 8. Political involvment and Food security indices
	do "${Phone_Survey_do}/Construction/polinvolvement_foodsecurity_construct_phonesvy.do"
	
	* 9. Expenditure 
	do "${Phone_Survey_do}/Construction/consumption_construct_phonesvy.do"
	
			/* Move this piece to the globals do-file eventually:
			cpi_food_bl, cpi_food_fl1, cpi_food_phone globals are saved in the following do-files: 		Github/AFG-TUP/DataWork/Phone_Survey/Dofiles/Analysis/consumption_cpi_calculation_bl.do */

			 * CPI calcualtion
				*do "${Phone_Survey_do}/Analysis/consumption_cpi_calculation_bl.do" runs within "consumption_construct_phonesvy.do"
				
				gl cpi_econ_bl = $cpi_food_bl * 0.6 + $cpi_non_food_bl * 0.4
				gl cpi_econ_fl1 = 100
				gl cpi_econ_phone = $cpi_food_phone * 0.6 + $cpi_non_food_phone * 0.4
		
	
	* 9(a). Consumption index construction (divide by endline control mean)
	do "${Phone_Survey_do}/Construction/consumption_index_construct_phonesvy.do"	
		
	* 10. Empowerment indices
	do "${Phone_Survey_do}/Construction/female_empowerment_construct_phonesvy.do"
	* This do-file runs "hh_composition.do"
	
	* 11. Financial indices
	do "${Phone_Survey_do}/Construction/Financial_index_construct_phonesvy.do"
	
	* 12. Psy well-being indices 
	do "${Phone_Survey_do}/Construction/LHH_MHHH_Psywellbeing_construct_phonesvy.do"
	
	* 13. Shocks construction 
	do "${Phone_Survey_do}/Construction/shocks_construct_phonesvy.do"
	
	* 14. HH composition variables construction 
	do "${Phone_Survey_do}/Construction/hh_composition.do"

	* 16 . Schooling - after Bl covariates since those are merged on to the Schooling dataset 
	do "${Phone_Survey_do}/Construction/schooling_construct_phonesvy.do"
	
	* 17. Food consumption shares ot total food expense 
	do "${Phone_Survey_do}/Construction/consumption_shares_phonesvy.do"
	
	* 18. Migration
	do "${Phone_Survey_do}/Construction/migration_construct_phonesvy.do"
	
	* 19. Health
	do "${Phone_Survey_do}/Construction/health_construct_phonesvy.do"
	
	* 20. Other variables 
	do "${Phone_Survey_do}/Construction/other_construct_phonesvy.do"
	
	* 21. Sample dummy indicators (merged with midline data to get precise endline sample)
	do "${Phone_Survey_do}/Construction/sample_indicator_construct_phonesvy.do"
	
*********************************************************************************
* III. All other datasets for the Endline paper (baseline, midline)
*********************************************************************************
	
	do "${Phone_Survey_do}/master_construction_bl_fl1_phonesvy.do"
	
	/* Runs do-file that generates baseline covariates: 
		do "${Phone_Survey_do}/Construction/covariates_main_construct_bl.do"
		**do "${Phone_Survey_do}/Construction/covariates_construct_bl.do"
		this includes the full set we will not likely use, so it does not run */

*********************************************************************************
* IV. Final endline analysis dataset
*********************************************************************************
	
	* 1. Cross-section data 
	do "${Phone_Survey_do}/Construction/data_for_analysis_phonesvy.do"

	* 2. Panel data 
	do "${Phone_Survey_do}/Construction/panel_data_for_analysis_phonesvy.do"


	
	
	
	
	
	
	
	
	
	