* Created by: Maria Camila Ayala	
* Purpose: This do file cleans variables in the PRA dataset and makes corrections and imputations on some variables.

* Inputs
	gl PRA_merged "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/PRA_merged_with_all datasets.dta"
	
	gl PRA_clean "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/PRA_merged_with_all_cleaned.dta"
	gl PRA_clean_nopii "${TUP_DB}/Profile_and_merging/DataSets/Final/PRA_merged_with_all_cleaned_nopii.dta"
	gl sample "${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	gl baseline "${TUP_DB}/Baseline/DataSets/Final/data_for_analysis_bl.dta"
	


use "${PRA_merged}", clear
rename (treatment ultra_poor CDCID) (treatment_PRA ultra_poor_PRA CDCID_PRA)

* Merge sample
	merge 1:1 uniqueid using "${sample}", assert(1 3) keepus(hhid bl_key treatment ultra_poor bl_oth_hh bl_oth_hh_why CDCID)
	assert CDCID == CDCID_PRA if _merge == 3
	drop CDCID
	rename CDCID_PRA CDCID 
	
* Identify villages that are part of our sample
	bys CDCID: egen keep_village = max(_merge)
	replace keep_village = 0 if keep_village == 1
	replace keep_village = 1 if keep_village == 3
	rename _merge merge_sample
	lab var keep_village "This village is part of the 80 villages from final sample"
	
*----------------------------------*
* Cleaning Wealth Ranking Category *
*----------------------------------*

	* Original Wealth ranking 
	
		rename WealthRankingCategory ranking
		tab ranking
		gen 	WealthRankingCategory = .
		replace WealthRankingCategory = 2 if regexm(ranking, "Poor")
		replace WealthRankingCategory = 2 if regexm(ranking, "poor")
			
		replace	WealthRankingCategory = 1 if regexm(ranking, "Ultra")
		replace	WealthRankingCategory = 1 if regexm(ranking, "ultra")
		replace WealthRankingCategory = 1 if regexm(ranking, "Ultara")
			
		replace WealthRankingCategory = 3 if regexm(ranking, "Better")
		replace WealthRankingCategory = 3 if regexm(ranking, "Batter")	
			
		replace WealthRankingCategory = 4 if regexm(ranking, "Well")
		replace WealthRankingCategory = 4 if regexm(ranking, "well")
		lab def ranking 1 "Ultra-poor" 2 "Poor" 3 "Better-off" 4 "Well-off" ,replace
		lab val WealthRankingCategory ranking
		tab ranking WealthRankingCategory, m
			
		lab var WealthRankingCategory "Wealth Ranking Category - Original"
		order WealthRankingCategory, after(ranking)
		drop ranking
		
		* Now we compare to the final ultra-poor. Those HH that are UP, we replace the WealthRankingCategory
		* as they had to be UP at some point. We assume these households were typing errors in the admin
		* records or re-classified after the PRA. 
			tab WealthRankingCategory ultra_poor, m
			replace WealthRankingCategory = 1 if ultra_poor == 1
			tab WealthRankingCategory ultra_poor, m
		
* Fix ultra-poor for weights
	tab ultra_poor // the ones in our final sample --> the universe
	replace ultra_poor = 0 if mi(ultra_poor) & !mi(WealthRankingCategory)
	tab ultra_poor, m 

* Identify the ones in baseline		
	merge m:1 hhid using  "${baseline}", gen(merge_baseline) assert(1 3) keepus(village exp_tot_m_pc)
	/*
		Result                           # of obs.
		-----------------------------------------
		not matched                        24,306
			from master                    24,306  (merge_baseline==1)
			from using                          0  (merge_baseline==2)

		matched                             2,852  (merge_baseline==3)
		-----------------------------------------
	*/

	rename village village_bl
	gen 	in_bl = 0 if merge_baseline == 1 & merge_sample == 3
	replace in_bl = 1 if merge_baseline == 3 & merge_sample == 3
	lab var in_bl "HH was surveyed in Baseline"
	
	tempfile PRA_all
	save	`PRA_all'
	
*----------------------------*
* Imputation of CWR category *
*----------------------------*

* We impute using the average consumption of the households by village and wealth rank category

	* 23 households that are part of our sample that don't have a wealth ranking category
	* We impute using consumption
		count if mi(WealthRankingCategory) & merge_sample == 3 
		assert r(N) == 23
		count if mi(WealthRankingCategory) & merge_sample == 3 & in_bl == 1 // only for 22 we have baseline data
		assert r(N) == 22
	
	* Generate averages of consumption per wealth ranking category	
		preserve
			keep if in_bl == 1
			collapse (sum) total_bl = in_bl (mean) mean_exp = exp_tot_m_pc, by(CDCID WealthRankingCategory)
			drop if mi(WealthRankingCategory)
			tempfile average_exp
			save 	`average_exp'
		restore
		
	* Merge average_exp
		merge m:1 CDCID WealthRankingCategory using `average_exp', assert(1 3)
	
	* Make imputations for the 23 without wealth rank category
		sort CDCID WealthRankingCategory
		br CDCID WealthRankingCategory hhid _merge
		bys CDCID: egen flag = max(_merge)
		tab CDCID if flag == 3 & mi(WealthRankingCategory) & merge_sample == 3 // Most of the villages have only one case, only one has 4 cases and 2 villages has 2 cases
		
	* Gen number of cases by village
		bys CDCID: egen count_miss = total(mi(WealthRankingCategory) & merge_sample == 3)
				
	* Gen distance from the average consumption of missing to the average
		sort CDCID WealthRankingCategory hhid 
		br CDCID hhid WealthRankingCategory exp_tot_m_pc if count_miss == 1
		gen temp = exp_tot_m_pc if mi(WealthRankingCategory)
		bys CDCID: egen miss_exp_tot = max(temp)
		gen dist = mean_exp-miss_exp_tot
		drop flag temp 
		
	* Imputation
		tab CDCID if count_miss==1
		gl br_vars "hhid WealthRankingCategory exp_tot_m_pc mean_exp miss_exp_tot dist"
		* Village 1
			sort CDCID WealthRankingCategory
			br $br_vars if in_bl == 1 & CDCID == "16-1602-0021"
			replace WealthRankingCategory = 2 if hhid == 6386
		* Village 2
			br $br_vars if in_bl == 1 & CDCID == "16-1605-0014"
			replace WealthRankingCategory = 2 if hhid == 5798	
		* Village 3
			br $br_vars if in_bl == 1 & CDCID == "16-1605-0028"
			replace WealthRankingCategory = 3 if hhid == 6447			
		* Village 4
			br $br_vars if in_bl == 1 & CDCID == "16-1605-0032"
			replace WealthRankingCategory = 1 if hhid == 5108			
		* Village 5
			br $br_vars if in_bl == 1 & CDCID == "16-1612-0005"
			replace WealthRankingCategory = 2 if hhid == 5530		
		* Village 6 
			br $br_vars if in_bl == 1 & CDCID == "16-1612-0007"
			replace WealthRankingCategory = 2 if hhid == 5240	
		* Village 7
			br $br_vars if in_bl == 1 & CDCID == "16-1612-0010"
			replace WealthRankingCategory = 4 if hhid == 6120	
		* Village 8
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0029" // no baseline				
		* Village 9
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0032"
			replace WealthRankingCategory = 4 if hhid == 5598	
		* Village 10
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0034"
			replace WealthRankingCategory = 1 if hhid == 6078	
		* Village 11
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0038"
			replace WealthRankingCategory = 1 if hhid == 6566		
		* Village 12
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0049"
			replace WealthRankingCategory = 1 if hhid == 5010	
		* Village 13
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0057"
			replace WealthRankingCategory = 3 if hhid == 5291			
		* Village 14
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0074"
			replace WealthRankingCategory = 1 if hhid == 5298		
		* Village 15
			br $br_vars if in_bl == 1 & CDCID == "16-1614-0084"
			replace WealthRankingCategory = 2 if hhid == 6316			
			
	* For household with two missing
		tab CDCID if count_miss==2
		* Village 16
			
			br $br_vars if in_bl == 1 & CDCID == "16-1605-0005"
				drop dist miss_exp_tot
				gen temp = exp_tot_m_pc if mi(WealthRankingCategory)
				bys CDCID: egen miss_exp_tot = max(temp)
				gen dist_6077 = mean_exp-miss_exp_tot
				drop miss_exp_tot		
				bys CDCID: egen miss_exp_tot = min(temp)
				gen dist_5767 = mean_exp-miss_exp_tot
				drop temp		
		
			replace WealthRankingCategory = 1 if hhid == 6077		
			replace WealthRankingCategory = 1 if hhid == 5767	
			drop dist_6077 
			rename dist_5767 dist
			
		* Village 17
			br $br_vars if in_bl == 1 & CDCID == "16-1612-0013"	
				drop miss_exp_tot dist
				gen temp = exp_tot_m_pc if mi(WealthRankingCategory)
				bys CDCID: egen miss_exp_tot = max(temp)
				gen dist_5547 = mean_exp-miss_exp_tot
				drop miss_exp_tot		
				bys CDCID: egen miss_exp_tot = min(temp)
				gen dist_5020 = mean_exp-miss_exp_tot
				drop temp
				
			replace WealthRankingCategory = 3 if hhid == 5547	
			replace WealthRankingCategory = 1 if hhid == 5020	
			drop dist_5547 
			rename dist_5020 dist

	* For household with four missing
		tab CDCID if count_miss==4	
		
		br $br_vars if in_bl == 1 & CDCID == "16-1605-0001"
		drop miss_exp_tot dist
			foreach hh in 6515 6676 6292 6461 {
				gen temp = exp_tot_m_pc if hhid == `hh'
				bys CDCID: egen miss_exp_tot = max(temp)
				gen dist_`hh' = mean_exp-miss_exp_tot
				drop temp miss_exp_tot
			}
			
		replace WealthRankingCategory = 1 if hhid == 6515				
		replace WealthRankingCategory = 1 if hhid == 6676				
		replace WealthRankingCategory = 1 if hhid == 6292			
		replace WealthRankingCategory = 4 if hhid == 6461	
		drop dist*
		
	* Tag imputted households	
		loc hhid_imputted 6386 5798 6447 5108 5530 5240 6120 5598 6078 6566 5010 5291 5298 6316 6077 5767 5547 5020 6515 6676 6292 6461
		gen WRC_imputted = .
		foreach hh of local hhid_imputted {
		    replace WRC_imputted = 1 if hhid == `hh'
		}
		lab var WRC_imputted "Wealth Ranking Category was imputted based on baseline consumption"
		
	* Drop unnecessary vars
		drop merge_baseline merge_sample total_bl mean_exp _merge count_miss
		order hhid
		
*----------------------------------------*
* Create other CWR variables for weights *
*----------------------------------------*
		
	*---------------------*
	* 1. Four categories: *
	*---------------------*
	
	* Ultra-poor, Near-Ultra-Poor, Poor, Better-off/Well-off 
	* Near-Ultra-Poor: Originally Ultra-poor but didn't pass the verification
		gen WealthRankingCategory_v = .
		lab var WealthRankingCategory_v "Wealth Ranking Category - After verification"
		lab def ranking_v 1 "Ultra-poor" 2 "Near-Ultra-Poor" 3 "Poor" 4 "Better-off/Well-off" , replace
		lab val WealthRankingCategory_v ranking_v
		
		replace WealthRankingCategory_v = 1 if WealthRankingCategory == 1
		replace WealthRankingCategory_v = 3 if WealthRankingCategory == 2
		replace WealthRankingCategory_v = 4 if inlist(WealthRankingCategory, 3, 4)
		
	* Ultra-poor in Wealth Ranking but not selected at the end, go to "Near poor"
		tab WealthRankingCategory_v ultra_poor, m
		replace WealthRankingCategory_v = 2 if WealthRankingCategory == 1 & ultra_poor == 0
		tab WealthRankingCategory_v ultra_poor, m
		tab WealthRankingCategory_v, m
		tab WealthRankingCategory_v
		
*---------------------*
* Additional cleaning *
*---------------------*
		
	* District
		gen 	district = .
		lab def district_l 1 "Dowlat Abad District" 2 "Dehdadi District" 3 "Nahre Shahee District" 4 "Khulm District"
		lab val district district_l
		replace district = 1 if regexm(District, "Dawlatabad")
		replace district = 2 if regexm(District, "Dehadi")
		replace district = 2 if regexm(District, "Dehdadi")
		replace district = 3 if regexm(District, "Nahr")
		replace district = 4 if regexm(District, "Khulm")
		tab district District, m
	
	* IdentifiedasUltraPoorYeso 
		rename IdentifiedasUltraPoorYeso identifiedUP
		tab identifiedUP
		gen 	IdentifiedasUltraPoorYeso = .
		replace IdentifiedasUltraPoorYeso = 1 if regexm(identifiedUP, "YES")
		replace IdentifiedasUltraPoorYeso = 1 if regexm(identifiedUP, "Yes")
		replace IdentifiedasUltraPoorYeso = 0 if regexm(identifiedUP, "No")
		replace IdentifiedasUltraPoorYeso = 0 if regexm(identifiedUP, "NO")
		replace IdentifiedasUltraPoorYeso = 0 if regexm(identifiedUP, "0")
		lab def yesno2 1 "Yes" 0 "No"
		lab val IdentifiedasUltraPoorYeso yesno2
		tab identifiedUP IdentifiedasUltraPoorYeso , m
		order IdentifiedasUltraPoorYeso, after(identifiedUP)
		lab var IdentifiedasUltraPoorYeso "Identified as Ultra-Poor (Yes) or (No)"
		drop identifiedUP 
		
	*  FinalHouseholdSelectedYesor
		rename  FinalHouseholdSelectedYesor selected
		tab selected
		gen 	FinalHouseholdSelectedYesor = .
		replace FinalHouseholdSelectedYesor = 1 if regexm(selected, "YES")
		replace FinalHouseholdSelectedYesor = 1 if regexm(selected, "Yes")
		replace FinalHouseholdSelectedYesor = 0 if regexm(selected, "No")
		replace FinalHouseholdSelectedYesor = 0 if regexm(selected, "NO")		
		lab val FinalHouseholdSelectedYesor yesno2
		tab selected FinalHouseholdSelectedYesor, m
		order FinalHouseholdSelectedYesor, after(selected)
		drop selected
		lab var FinalHouseholdSelectedYesor "Final Household Selected (Yes or No)"
		
		tab FinalHouseholdSelectedYesor ultra_poor if WealthRankingCategory == 1, m
		
			/*			
					 Final |
				 Household |
				  Selected |
				   (Yes or |   HH is ultra-poor
					   No) |         0          1 |     Total
				-----------+----------------------+----------
						No |     9,861          3 |     9,864 
					   Yes |       712      1,213 |     1,925 
						 . |       198          3 |       201     --> we send these to their respective categories of selected or not
				-----------+----------------------+----------
					 Total |    10,771      1,219 |    11,990 
					 
			*/
		
		replace FinalHouseholdSelectedYesor = 1 if ultra_poor == 1 & FinalHouseholdSelectedYesor == . & WealthRankingCategory == 1 // 3 households
		replace FinalHouseholdSelectedYesor = 0 if ultra_poor == 0 & FinalHouseholdSelectedYesor == . & WealthRankingCategory == 1 // 198 households
		replace FinalHouseholdSelectedYesor = 1 if ultra_poor == 1 & FinalHouseholdSelectedYesor == 0 & WealthRankingCategory == 1 // 3 households
		
		
	* AfterFinalVerification
		rename AfterFinalVerification verif
		tab verif
		gen 	AfterFinalVerification = . 
		replace AfterFinalVerification = 1 if  regexm(verif, "Selected")
		replace AfterFinalVerification = 0 if  regexm(verif, "Rejected")
		lab def selected 1 "Selected" 0 "Rejected"
		lab val AfterFinalVerification selected
		tab verif AfterFinalVerification, m
		order AfterFinalVerification, after(verif)
		drop verif 
		lab var AfterFinalVerification "After Final Verification"
		
		tab AfterFinalVerification ultra_poor if WealthRankingCategory == 1 & FinalHouseholdSelectedYesor == 1, m
				/*		

				 After |
				 Final |
			Verificati |   HH is ultra-poor
					on |         0          1 |     Total
			-----------+----------------------+----------
			  Rejected |       549          0 |       549 
			  Selected |       163      1,213 |     1,376 
					 . |         0          6 |         6 --> replace these six
			-----------+----------------------+----------
				 Total |       712      1,219 |     1,931 

				*/
		replace AfterFinalVerification = 1 if ultra_poor == 1 & AfterFinalVerification == . & WealthRankingCategory == 1 & FinalHouseholdSelectedYesor == 1		
		
	* Save dataset
		save "${PRA_clean}", replace	
		merge m:1 CDCID using "${villages_all_list}", keep(1 3)
		drop _merge
		
	* Anonymize PRA
		encode Village, gen(PRA_anonymized)
		lab var PRA_anonymized "PRA anonymized"
		label drop PRA_anonymized
		
	* Anonymized
		order hhid uniqueid district village WealthRankingCategory PRA_anonymized WRC_imputted WealthRankingCategory_v keep_village ultra_poor Totaloutof6 FinalHouseholdSelectedYesor AfterFinalVerification comments_PRA treatment
		keep hhid uniqueid district village WealthRankingCategory PRA_anonymized WRC_imputted WealthRankingCategory_v keep_village ultra_poor Totaloutof6 FinalHouseholdSelectedYesor AfterFinalVerification comments_PRA treatment
		save "${PRA_clean_nopii}", replace	