	/*****************************************************************
	PROJECT: 		TUP_AFG, Targeting Ultra Poor in Afghanistan
					
	TITLE:			Merge_PRA_with_all datasets.do
				
	AUTHOR: 		Rebecca de Guttry (rdeguttry@worldbank.org, rebecca_deguttry@hotmail.com)
					Maria Camila Ayala (mayalaguerrero@worldbank.org, mc.ayala94@gmail.com)

	DATE CREATED:	Jun 20, 2018

	LAST EDITED:	Dec 4, 2018, by Maria Camila Ayala 

	DESCRIPTION: 	The purpose of this do-file is to generate a list of HHs to be surveyed 
					during follow-up. This do-file merges: 
						1) old TUP eligibility (22Feb2016)
						2) final TUP eligibility (10Mar2016)
						3) baseline
						4) lottery dataset
						5) implementation records
					Exports the csv dataset to be preloaded for follow-up
		
	ORGANIZATION:	1 - Merge full PRA, old and  final (10Mar2016) TUP eligibility, and lottery
					2 - Merge full PRA with implementation records
					3 - Import baseline and allids and generate IDs for matching
					4 - Merge baseline to list of all ids ever assigned
					5 - Merge bl with full PRA listing
					
	INPUTS: 		N/A

	OUTPUTS: 		N/A

	NOTE:			
	******************************************************************/
	
	clear all
	do	"${dataWorkFolder}/Profile_and_merging/Dofiles/Cleaning/PRA_clean_beforemerge.do" // defines program for cleaning PRA raw data

	* INPUTS
		* Baseline
			global bl_prep "${TUP_DB_PII}/Baseline/DataSets/Final/bl_analysis_prep.dta"
		* Targeting TUP IE
			global Targ_TUP_IE "/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Analysis/TUP Baseline/Data/Intermediate/Targeting/Targeting_TUP_IE.dta"
		
		* Old TUP eligible (22Feb2016)
			global sample "/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Analysis/Sample/"
			loc old "${sample}/Sample_Original folder_Garima/Villages/List_of_households_to_be_interviewed20160224/Sample/STATA/Constructed_data/TUP_eligible_hh.dta"
		* Final TUP eligible for implementation (10th March)
			loc final "${sample}/Sample_Original folder_Garima/STATA/Constructed_data/Tup_eligible_hh_final_implementation.dta"
		* CDCIDS for which surveys completed by VAU before 10th March
			loc CDCID_Mar10 "${sample}/Sample_Original folder_Garima/STATA/Raw_data/CDCID_surveysdone.dta"
		* Final households for survey
			loc tup_el_final_survey "${sample}/Sample_Original folder_Garima/STATA/Constructed_data/Tup_eligible_hh_final_survey_post10Mar.dta"
		
		* Sample and results for hhid verification exercise on baseline data
			*loc hhid_verification "${bl}/Making_comprehensive_tup_list_with_flags/Raw_data/HHID_verification_exercise.xlsx"
		* Full PRA
			loc PRA "/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Analysis/PRA/Data/Raw/CHA_10Mar_all.dta"
		* Lottery
			loc lottery "/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Analysis/Sample/Data/Raw/Lottery Outcomes/outcomes_withcomments"
		* Implementation
			loc im "${TUP_DB_PII}/Monitoring/DataSets/Raw/Monitoring_all.dta"
		* Villages in sample
			global sample_village 	"${DB_PII_Profile}/DataSets/Intermediate/village_names.dta"
		
		* All HHIDs constructed
			global allIDs "/Volumes/Camila/Dropbox/World Bank/TUP/TUP_Afghanistan/Data Analysis/PRA/Data/Raw/all_hhids_infolder_constructed.dta"
		
		
		* VAU's explanations for missing households with Garima's comments
			*loc miss_bl_comments "/Users/Rebecca/Dropbox/TUP_Afghanistan_April2016/Data_Analysis/Baseline/Making_comprehensive_tup_list_with_flags/Raw_data/missing_interviews_25apr_remarks.xlsx"
	
		* Lottery plan
			global lottery_plan "${DB_PII_Profile}/DataSets/Intermediate/no_tup_el_by_PRA-Lottery-Plan-Final_REVISED_20Apr.dta"
			global fl1_IDs 		"${DB_PII_Profile}/DataSets/Intermediate/fl_hhid_do not touch.dta"	
		
	* OUTPUTS
		global PRA_merged "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/PRA_merged_with_all datasets.dta"
		
/*-------------------------------------------------------------------------------------------------------------------------
	1 - Merge full PRA, old and  final (10Mar2016) TUP eligibility, and lottery
--------------------------------------------------------------------------------------------------------------------------*/

	use "${bl_prep}",clear


**** 1.1 - Import and generate unique IDs 
	
	
	/* RdG: Convert Excel files to .dta files to speed up do-file
		 
		 * All
			*import excel "${PRA_data_raw}/CHA_10Mar_all.xlsx", sheet("Sheet1") firstrow clear
			*rename VillageCode CDCID
			*save "${PRA_data_raw}/CHA_10Mar_all", replace
		 
		 * Lottery	
			import excel "${sample_data_raw}/Lottery Outcomes/Lottery outcome_all districts_May15_comments based on pictures.xlsx", sheet("hhlist_final_implementation") firstrow clear
			save "${sample_data_raw}/Lottery Outcomes/outcomes_withcomments", replace
		
		* Implementation records
			tempfile all
			loc vars_tokeep "SNo No NewNumber Village VillageCode Masjid HeadofHH NameofHH FatherSpauseName Totaloutof6 NameofTraineeforAnimalReari RelationshipwithHH WasPresentatPWR Treatment Control Remarks"
			
			foreach district in Dehdadi Dawlatabad Nahr Khulm { 
				disp "Importing `district'"
				import excel "${im_raw}/Monitoring_all.xlsx", sheet(`district') firstrow clear
				if "`district'"=="Nahr" {
					gen HeadofHH="" // missing in this dataset
				}
				if "`district'"=="Dehdadi" {
					replace Totaloutof6="" if Totaloutof6=="s"
				}
				destring Totaloutof6,replace
				keep `vars_tokeep'
				tostring Remarks, replace
				gen District="`district'"
					lab var District "District"
				if "`district'"!="Dehdadi" {
					append using `all'
				}
				save `all',replace
			}
			save "${im_raw}/Monitoring_all.dta", replace
*/

use "`lottery'",clear

foreach dataset in "PRA" "old" "final"  "lottery"  "im" { // also process $im to generate mergeids
	
	use "``dataset''",clear
	
	* Keep only if in sample
		*merge m:m CDCID using "${PRA_data_raw}/Village_names.dta", assert(1 3) keep(1 3) nogen
		
	* Rename variables and make slight adjustments to each dataset
		if "`dataset'"=="PRA" {
			rename	(HeadofHH		NameofHH	FatherSpauseName	RelationshipwithHH 	Remarks 	) ///
					(hhhead_gender	hhhead_name	father_spouse_name	relationship_hhhead comments_PRA)
			sort SNo
					
			* Drop observations marked as duplicate in PRA
				drop if inlist(comments_PRA,"Repeated","Repeated ")
		}
		if "`dataset'"=="old" {
			rename	(NameofHH	FatherSpauseName		RelationshipwithHH 	) ///
					(hhhead_name	father_spouse_name	relationship_hhhead )
			rename	(Remarks 			SNo			  	No 		 			)			  ///
					(comments_old_elig 	SNo_old_elig	No_old_elig 	 	)	
			sort SNo_old_elig
		}
		if "`dataset'"=="final" {
			rename	(village_name 	hhid 				SNo				No  			Remarks) ///
					(Village		hhid_final_elig		SNo_final_elig	No_final_elig 	comments_final_elig)
			sort SNo_final_elig
		}
		if "`dataset'"=="lottery" {
			
			* Two HHs that are there twice (evident if you look at it)
				drop if Village=="Tally Gak"
				replace Village="Tally Gak" if Village=="Taly Gak "
			
			rename	(Gender			NameofHHHead	FatherSpousename	RelationshipwithHH 	) ///
					(hhhead_gender	hhhead_name	 	father_spouse_name	relationship_hhhead )
			rename 	(hhid 			Selecteddrawnfrombin1ifs 	Putinbin1ifputinbin0	) ///
					(hhid_lottery 	treatment 					putinbin				)
			rename 	(Hasthishouseholdmovedawayfr 	Comments 	 					) ///
					(moved_lottery				 	comments_lottery_verification	)	
			
			* One HH that was automatically selected in treatment but is not reflected in lottery dataset (checked and it is also in implementation records)
				replace putinbin="0" if CDCID=="16-1614-0036" & hhhead_name=="Hikmatullah" & father_spouse_name=="Haji Habibullah"
				replace treatment=1 if CDCID=="16-1614-0036" & hhhead_name=="Hikmatullah" & father_spouse_name=="Haji Habibullah"
			*  HHs that are wrong in lottery (this is based on pictures, NARC files, and implementation records)
				replace treatment=0 if Village=="Dehnaw" & hhhead_name=="Maqsad ullah" & father_spouse_name=="Abdul rasul "
				replace treatment=0 if Village=="Oljato" & hhhead_name=="Ramazan " & father_spouse_name=="Nazar" 
		}
		if "`dataset'"=="im" {
			
			rename	(NameofHH	 	FatherSpauseName		RelationshipwithHH 	) ///
					(hhhead_name	father_spouse_name		relationship_hhhead )
			rename	(SNo			No  		 	Remarks 		VillageCode 	NameofTraineeforAnimalReari ) ///
					(SNo_im 		No_im		  	comments_im 	CDCID 			beneficiary_name 				)
			
			* Drop empty observations
				assert mi(hhhead_name) & mi(father_spouse_name) if mi(CDCID)
				drop if mi(CDCID)
			
			* Quality control
				assert !mi(beneficiary_name)
			
			* Keep only those in our villages
				merge m:m CDCID using "${sample_village}", nogen keep(3)
					
			* SNo
				*assert !mi(SNo) // 3 are missing SNo
				gen flag_miss_SNo_im = mi(SNo_im)
					lab var flag_miss_SNo_im "HH is missing SNo in im dataset, which is used for matching"

			* Generate separate mergeid only for implementation matching
				gen	mergeid_im	=	CDCID	 + "-" + string(SNo_im)
					duplicates tag mergeid_im,gen(dup)
					replace mergeid_im = mergeid_im + "-" + string(NewNumber) if dup!=0
					lab var mergeid_im "ID used for matching b/w bl and im: CDCID+SNo (+No/NewNumber if duplicate)"
					isid mergeid_im
					
			* Manually replace mergeid_im for those obvious slightly different that were figured out
				replace mergeid_im="16-1614-0016-578" if mergeid_im=="16-1614-0016-578-12" //  because it is one of those where we had to add newnum because mergeid was not unique
				replace mergeid_im="16-1602-0004-1012" if mergeid_im=="16-1602-0003-1012" // I am not sure why this is as is, but I suspect it is due to manual cleaning somewhere in PRA
				replace mergeid_im="16-1614-0057-871" if mergeid_im=="16-1614-0069-871" // Looks like this changed village // Flag afterwards 
		}
	
	* Generate unique ID
		gen mergeid_PRA=upper(Village)+"-"+upper(hhhead_name)+"-"+upper(father_spouse_name)
			lab var mergeid_PRA "ID used when merging any dataset to original PRA data"
		duplicates tag mergeid_PRA,gen(duplicate_PRA)
			replace duplicate_PRA=(duplicate_PRA!=0)
			lab var duplicate_PRA "HH not unique in village and names"
		bys mergeid_PRA: replace mergeid_PRA=mergeid_PRA + "-" + string(_n) if _n!=1
		isid mergeid_PRA
		
		if inlist("`dataset'","old") { // changes to account for slight (obvious) changes only in the old TUP eligibility dataset
			replace mergeid_PRA="JOI ARAB - 1-WIDOW-FAIZ" if mergeid_PRA=="JOI ARAB - 1-WAHID-FAIZ"
			replace mergeid_PRA="JOI ARAB - 1-WIDOW-QAYOOM" if mergeid_PRA=="JOI ARAB - 1-WAHID-QAYOOM"
			replace mergeid_PRA="JOI ARAB - 1-WIDOW-SAYED MOHAMMAD" if mergeid_PRA=="JOI ARAB - 1-WAHID-SAYED MOHAMMAD"
			replace mergeid_PRA="CHARBAGH SAYEDAN WATANI - 2-DIN MOHAMMAD -IMAM SOFI" if mergeid_PRA=="CHARBAGH SAYEDAN WATANI - 2-DIM MOHAMMAD -IMAM SOFI"
		}
		
		tempfile `dataset'
		save ``dataset''
 }

**** 1.2 - Merge full PRA, old and final (10Mar2016) TUP eligibility, and lottery
	
	* Start with PRA 
		use `PRA'
	
	* Old eligibility (before 10Mar2016)
		merge 1:1 mergeid_PRA using `old',gen(merge_old) keepus(CDCID District Village Masjid SNo_old_elig No_old_elig comments_old_elig Masjid)
			lab var merge_old "Merge results between full PRA and old (pre-10Mar2016) TUP eligibility dataset"
			lab define merge_old	1 "Only in PRA" ///
									2 "Only in old TUP eligibility dataset" ///
									3 "Merged"
			lab val merge_old merge_old 
			/*
			    Result                           # of obs.
				-----------------------------------------
				not matched                        25,803
					from master                    25,801  (merge_old==1)
					from using                          2  (merge_old==2)

				matched                             1,483  (merge_old==3)
				-----------------------------------------
			*/
	
	* Final eligibility (after 10Mar2016)
		merge 1:1 mergeid_PRA using `final',gen(merge_final) keepus(CDCID District Village Masjid hhid_final_elig SNo_final_elig No_final_elig comments_final_elig) assert(1 3)
			lab var merge_final "Merge results between full PRA and old (pre-10Mar2016) TUP eligibility dataset"
			lab define merge_final	1 "Only in PRA" ///
									2 "Only in final TUP eligibility dataset" ///
									3 "Merged"
			lab val merge_final merge_final 
			/*
			    Result                           # of obs.
				-----------------------------------------
				not matched                        26,048
					from master                    26,048  (merge_final==1)
					from using                          0  (merge_final==2)

				matched                             1,238  (merge_final==3)
				-----------------------------------------
			*/
	
	* Lottery outcomes
		merge 1:1 mergeid_PRA using `lottery',gen(merge_lottery) keepus(CDCID District Village Masjid hhid_lottery hhhead_name father_spouse_name treatment putinbin moved_lottery comments_lottery_verification) // assert(1 3)
			lab var merge_lottery "Merge results between full PRA and lottery dataset"
			lab define merge_lottery	1 "Only in PRA" ///
										2 "Only in lottery" ///
										3 "Merged"
			lab val merge_lottery merge_lottery 
			/*
			    Result                           # of obs.
				-----------------------------------------
				not matched                        26,053
					from master                    26,052  (merge_lottery==1)
					from using                          1  (merge_lottery==2)

				matched                             1,234  (merge_lottery==3)
				-----------------------------------------
			*/
			
	* Villages already completed by VAU on 10Mar2016
		merge m:1 CDCID using "`CDCID_Mar10'",gen(CDCID_bef_10mar) assert(1 3)
			lab var CDCID_bef_10mar "HH is in village (from PRA) where data collection was completed before 10Mar2016"
			recode CDCID_bef_10mar (3=1) (1=0)
			lab define yesno 0 "No" 1 "Yes"
			lab val CDCID_bef_10mar yesno
			/*
			    Result                           # of obs.
				-----------------------------------------
				not matched                        16,943
					from master                    16,943  (CDCID_bef_10mar==1)
					from using                          0  (CDCID_bef_10mar==2)

				matched                            10,344  (CDCID_bef_10mar==3)
				-----------------------------------------
			*/

 * Generate indicators
	
	* Final ultra poor status
		assert inlist(merge_final,1,3) if !mi(merge_final)
		gen ultra_poor=(merge_final==3)
			lab var ultra_poor "HH is ultra-poor (based on final 10Mar2016 records)"
	
	* Status change before and after 10 Mar 2016
		gen elig_bef_aft = .
			lab var elig_bef_aft "HH UP status before and after 10Mar2016"
			replace elig_bef_aft = 0 if merge_old==3 & merge_final==3
			replace elig_bef_aft = 1 if merge_old!=3 & merge_final==3
			replace elig_bef_aft = 2 if merge_old==3 & merge_final!=3
			lab define elig_bef_aft		0 "No difference (always eligible)" ///
										1 "Added on 10Mar2016" ///
										2 "Rejected on 10Mar2016"
			lab val elig_bef_aft elig_bef_aft
	
	* Flag for HH inconsistencies across datasets
		gen hh_tracking_flag = ""
			lab var hh_tracking_flag "Flag for HH inconsistencies across datasets"
			replace hh_tracking_flag = hh_tracking_flag + "**Only in old eligibility data. " if merge_old==2 & merge_final==1 & merge_lottery==1
			replace hh_tracking_flag = hh_tracking_flag + "**In final eligible HHs data but not in lottery data. " if merge_old==2 & merge_final==1 & merge_lottery==1
			replace hh_tracking_flag = hh_tracking_flag + "**In old and final eligiblity data but not in lottery data. " if merge_old==3 & merge_final==3 & merge_lottery==1
			replace hh_tracking_flag = hh_tracking_flag + "**Only in lottery data. " if merge_old==. & merge_final==. & merge_lottery==2
		
	* Explanations for missing surveys
	/*
		preserve
			keep if !mi(hhid_final_elig)
			isid hhid_final_elig
			
			import excel using "`miss_bl_comments'", sheet("Sheet1") firstrow clear
			rename 	(hhid 				MissingDetailprovidedbyVAU 	RemarksGarima	 		) ///
					(hhid_final_elig 	comments_miss_bl_VAU 		comments_miss_bl_Garima )
			keep hhid_final_elig comments_miss_bl_VAU comments_miss_bl_Garima
			isid hhid_final_elig
			tempfile miss_bl_comments
			save `miss_bl_comments', replace
		restore
		
		merge m:1 hhid_final_elig using `miss_bl_comments', keepus(comments_miss_bl_VAU comments_miss_bl_Garima) keep(1 3) nogen
			lab var comments_miss_bl_VAU "VAU's explanation of why the HHs were not surveyed in baseline"
			lab var comments_miss_bl_Garima "Garima's response to VAU's explanation of why the HHs were not surveyed in baseline"
	*/

			
			
/*-------------------------------------------------------------------------------------------------------------------------
	2 - Merge full PRA with implementation records
--------------------------------------------------------------------------------------------------------------------------*/
	
 * Save those HHs that were never UP separately
	preserve
		keep if ultra_poor!=1 & !inlist(3,merge_old,merge_lottery) & !inlist(2,merge_old,merge_lottery) 
		// not in final list of ultra_poor + not in initial list of TUP eligible HHs + not in lottery dataset 
		tempfile never_up
		save `never_up'
	restore

 * Keep only HHs that were ever UP and generate mergeid for implementation records only		
	keep if ultra_poor==1 | inlist(3,merge_old,merge_lottery) | inlist(2,merge_old,merge_lottery) 
	
	gen mergeid_im = CDCID + "-" + string(SNo)  // not yet isid
		tempvar dup1
		duplicates tag mergeid_im, gen(`dup1') 
		replace mergeid_im = mergeid_im + "-" + Masjid if `dup1'!=0 // to make isid
		isid mergeid_im
 
 * Merge PRA with implementation records (first round)
	merge 1:1 mergeid_im using `im',gen(merge_im) keepus(CDCID District Village Masjid SNo_im No_im NewNumber comments_im  mergeid_im hhhead_name father_spouse_name mergeid_PRA beneficiary_name) 
		// RdG (original comment): first round merges 503 and leaves 59 unmerged
		// Camila (04Dec2018): After re-running this do file, it merges 502 and 60 are unmerged
		/*
		Result                           # of obs.
		-----------------------------------------
		not matched                         1,241
			from master                     1,181	(merge_im==1)
			from using                         60	(merge_im==2)

		matched                               502	(merge_im==3)
		-----------------------------------------
		*/
	
 * Try merging the unmatched HHs in implementation records (63) with remaing other unmatched HHs in PRA (previously unmerged + never tagged as UP)
	* Save merged
		preserve
			keep if merge_im==3
			tempfile merged_im_round1
			save `merged_im_round1'
	* Save unmerged from implementation
		restore,preserve
			keep if merge_im==2
			drop merge_im // we will re-generate this
			tempfile unnmerged_im_round1
			save `unnmerged_im_round1'
		restore
	* Append unmerged from PRA and never UP
		keep if merge_im==1
		drop merge_im // we will regenerate this
		append using `never_up'
		
	* Regenerate mergeids	
		drop mergeid_im
		gen mergeid_im = CDCID + "-" + string(SNo)  // not yet isid
			tempvar dup2
			duplicates tag mergeid_im, gen(`dup2') 
			replace mergeid_im = mergeid_im + "-" + Masjid if `dup2'!=0 // to make isid
			isid mergeid_im
			
		merge 1:1 mergeid_im  using `unnmerged_im_round1',gen(merge_im) keepus(CDCID District Village Masjid SNo_im No_im NewNumber comments_im  mergeid_im hhhead_name father_spouse_name mergeid_PRA beneficiary_name) 
			// RdG (original comment): only 1 additional was merged, 58 remain unmerged
		/*
		    Result                           # of obs.
			-----------------------------------------
			not matched                        26,841
				from master                    26,783  (merge_im==1)
				from using                         58  (merge_im==2)

			matched                                 1  (merge_im==3)
			-----------------------------------------
		*/
	
	* Combined merge results from round 1 and 2
		append using `merged_im_round1' 
			lab var merge_im "Merge results between full PRA and implementation records"
			lab define merge_im		1 "Only in PRA" ///
									2 "Only in implementation records" ///
									3 "Merged"
			lab val merge_im merge_im 

	* Update tracking issues
		replace hh_tracking_flag = hh_tracking_flag + "**Won lottery but does not exist in the implementation records. " if merge_im==1 & treatment==1
		replace hh_tracking_flag = hh_tracking_flag + "**Included in implementation records but was not selected in lottery (control ultra-poor household). " if merge_im==3 & treatment==0
		replace hh_tracking_flag = hh_tracking_flag + "**Exists in implementation records but did not participate to lottery and was not listed in PRA. "  if merge_im==2 & mi(treatment)
		replace hh_tracking_flag = hh_tracking_flag + "**May have moved to other village during implementation. " if  mergeid_im=="16-1614-0057-871"

	* Save
		tempfile PRA_all_w_merging
		save `PRA_all_w_merging'

		
		
/*------------------------------------------------------------------------------
	3 - Import baseline and allids and generate IDs for matching			 									
------------------------------------------------------------------------------*/

**** 1.1 - Prepare baseline
	
	use "${bl_prep}", clear

	* Rename hhid and CDCID + generate wrong hhid indicator
		rename (HHID_survey CDCID_svy) (hhid CDCID)
		gen hhid_bl_wrong = mi(hhhead_name) 
			lab var hhid_bl_wrong "Wrong hhid used in bl survey (SurveyCTO could not preload data)"
	
	* Targeting: retrieve original hhid and original preloaded HH names
		
		/* 	Background: hhids are edited in the targeting cleaning do-file, for example by
			adding a B suffix, with no explanation, and this makes the matching impossible. */
		
		* Prepare targeting
		preserve
			 use "${Targ_TUP_IE}", clear
			rename 	(hh_id		 	hhhead_name_file 	father_spouse_name_file) ///
					(hhid_targ		hhhead_name_targ	father_spouse_name_targ)
			tempfile targeting
			save `targeting'
		restore
		
		* Merge and replace
		merge 1:1 KEY using `targeting',keepus(hhid_targ hhhead_name_targ father_spouse_name_targ) gen(merge_targeting) keep(1 3) // exclude 2 as some targeting svys have been dropped
		replace hhid=hhid_targ if merge_targeting==3
		replace hhhead_name=hhhead_name_targ if  merge_targeting==3
		replace father_spouse_name=father_spouse_name_targ if  merge_targeting==3
		drop father_spouse_name_targ hhhead_name_targ 
			/*
				Result                           # of obs.
				-----------------------------------------
				not matched                         1,196
					from master                     1,196  (merge_targeting==1)
					from using                          0  (merge_targeting==2)

				matched                             1,833  (merge_targeting==3)
				-----------------------------------------
			*/
			
		* Generate indicator on survey administered being a targeting survey
		gen targeting_svy=(merge_targeting==3)
			lab var targeting_svy "Targeting survey was administered"
		drop merge_targeting
		 
	* Replace IDs that are very clearly wrong 
		replace hhid = subinstr(hhid," ","",.) // 9 IDs with space (e.g., NTA 1004110 instead of NTA1004110)
		replace hhid = "TA200195" if hhid=="Ta2oo195" // an ID where "o" was used instead of "0"
		replace hhid = "TA2000511" if hhid=="TA200511" & CDCID=="16-1612-0005" //  missing a 0
		replace hhid = "TA2000512" if hhid=="TA200512" & CDCID=="16-1612-0005" //  missing a 0
		replace hhid = "TA2000517" if hhid=="TA200517" & CDCID=="16-1612-0005" //  missing a 0
		replace hhid = "TA2000519" if hhid=="TA200519" & CDCID=="16-1612-0005" //  missing a 0
		replace hhid = "TA200056" if hhid=="TA20056" & CDCID=="16-1612-0005" //  missing a 0
		replace hhid = "TA200058" if hhid=="TA20058" & CDCID=="16-1612-0005" //  missing a 0
		replace hhid = "TA200059" if hhid=="TA20059" & CDCID=="16-1612-0005" //  missing a 0
		
		replace hhid = upper(hhid)
		
	* Save		
		 tempfile bl_start
		 save `bl_start'
 
**** 1.2 - Prepare list of all ids ever assigned
	
	/* 	Background: the list of all ids ever assigned was re-constructed by compiling 
		all excels ever outputted in the TUP folder */
	
	* import excel "${PRA_data_raw}/all_hhids_infolder_constructed.xlsx", sheet("Sheet1") firstrow clear
	* save "${PRA_data_raw}/all_hhids_infolder_constructed.dta", replace
	
	* Use dta to speed up do-file
	use "${allIDs}", clear
	
	* For one village keep only hhids assigned in certain files. 
		/* 	This is because in different files, hhids were assigned to different hhs.
			This prevents 18 surveys in this village from matching. Yet, looking at
			others that could be matched, it is obvious that CHA only used certain files
			when visiting households. I suggest these to be double checked by Mohammad,
			as it is the only thing that is uncertain, but the likelihood that this
			is right is high. */
			
		drop if CDCID=="16-1605-1001" & !inlist(file,"TUP_Eligible_HH_12Mar_updated.xlsx","Targeting_hhlist_12Mar_updated.xlsx","hhlist_12Mar.csv","targeting_plus_replacement_12Mar.csv" )
														
	* Drop perfect duplicates
		bys District Village CDCID Masjid hhid HeadofHH hhhead_name father_spouse_name RelationshipwithHH: keep if _n==1
	
	* Save
		tempfile allids_start
		save `allids_start'
	
**** 1.3 Generate mergeids
	
	loc allids_add_vars "District Village Masjid HeadofHH RelationshipwithHH file"
	loc bl_add_vars "ultra_poor hhid_bl_wrong KEY date targeting_svy CDCID*"
	
	foreach dataset in "allids" "bl" {
		
		disp "Analyzing `dataset' dataset"
		
		use ``dataset'_start', clear
	
		* Clean " ", ".", and "/" in names
			foreach	strvar	in	CDCID hhhead_name father_spouse_name	{
				replace	`strvar'	=	trim(itrim(`strvar'))
				replace `strvar' = subinstr(`strvar', ".", "",.) 
				replace `strvar' = subinstr(`strvar', "/", "",.) 
			}
			replace father_spouse_name=trim(itrim(father_spouse_name)) // for some reason this is not working in the loop
			
		* mergeid1: hhid+names
			gen mergeid1 = upper(hhid) + "-" + upper(hhhead_name) + "-" + upper(father_spouse_name)
					lab var mergeid1 "mergeid1: hhid+names"
			* Only necessary manual corrections are put here
				replace mergeid1="N11001181-MOHAMMAD SAFI-GHULAM ALI"		if mergeid1=="N11001181-MOHAMMAD SAFI-GHULA ALI"
				replace mergeid1="N300141-SAYED ABDUL WAHID-NIAHMATULLAH"	if mergeid1=="N300141-SAYED ABDUL WAHID-NIAGHMATULLAH"
				replace mergeid1="N300274-WIDOW-ACHALDI"					if mergeid1=="N300274-WIDOWACHALDI-"
			* Replace mergeid1 for those that would otherwise be counted as unique when they are not
			/* Background:	One HH ID was used twice, but once with no preloaded data, 
							and once with. If nothing is done, this HH is matched as unique
							using mergeid1. We add here the preloaded data to make sure that
							it is not counted as unique */
				replace mergeid1="TA2000519-ZAHIR-ZAKIR"					if mergeid1=="TA2000519--"

			duplicates tag mergeid1,gen(dup1_mergeid1) 
				lab var dup1_mergeid1 "HH duplicate in hhid, hhhead_name, and father_spouse_name"
			
			replace mergeid1=mergeid1+"-"+CDCID if dup1_mergeid1!=0
			
			duplicates tag mergeid1,gen(dup2_mergeid1) 
				lab var dup1_mergeid1 "HH duplicate in hhid, hhhead_name, father_spouse_name, and CDCID"
				bys mergeid1: gen rank=string(_n)
			
			replace mergeid1=mergeid1+rank if dup2_mergeid1!=0
			
			isid mergeid1 // first one must be isid
				
				
		* mergeid2: CDCID + hhid
			gen mergeid2 = CDCID + "-" + upper(hhid)
				lab var mergeid2 "mergeid2: CDCID+hhid"
		
		* mergeid3: CDCID + hhid_num
			destring hhid, ignore(ABNRSTanort) gen(hhid_num) // characters to be ignored found with "charlist hhid"
			gen mergeid3 = CDCID + "-" + string(hhid_num)
				lab var mergeid3 "mergeid3: CDCID + hhid_num"
		
		* Rename important variables to be able to compare them to check on merge results
			foreach var in hhhead_name father_spouse_name CDCID {
				rename `var' `var'_`dataset'
			}
		
		* Keep only necessary variables
				keep hhid mergeid?  *_`dataset' ``dataset'_add_vars' 
		
		* Save
			tempfile `dataset'
			save ``dataset'', replace
	}
 

/*------------------------------------------------------------------------------
	4 - Merge baseline to list of all ids ever assigned
------------------------------------------------------------------------------*/

 * Set locals
	loc is_all "1,2,3"
	loc is_bl 1
	loc is_allids 2
	loc is_matched 3
	
**** 2.1 - Match with mergeid1
	
	* Merge 
	use `bl', clear
	merge 1:1 mergeid1 using `allids', gen(merge_mergeid1) // matches 2,847 – 183 to go
	/*
		Result                           # of obs.
		-----------------------------------------
		not matched                         5,074
			from master                       183  (merge_mergeid1==1)
			from using                      4,891  (merge_mergeid1==2)

		matched                             2,846  (merge_mergeid1==3)
		-----------------------------------------
	*/
	
	* Save each merging result separately (all results, matched, bl only, and allids only)
		foreach result in all matched bl allids  {
			preserve
				
				keep mergeid1 mergeid2 mergeid3 KEY merge_mergeid1
				keep if inlist(merge_mergeid1,`is_`result'')
				
				tempfile merge1_`result'
				save `merge1_`result''
				
				* Prepare unmerged ones for next round: keep only if unique in mergeid2 or mergeid3
						if 	"`result'"=="allids" {
							gen mergeid1_allids = mergeid1 
						}
						if inlist("`result'","bl","allids") { 
							forval id = 2/3 {
								duplicates tag mergeid`id',gen(dup`id')
								drop if dup`id'!=0
								tempfile merge1_`result'_isid`id'
								save `merge1_`result'_isid`id''
							}
					}
				restore
		}

**** 2.2 - Match with mergeid2 and mergeid3
	
	* First, merge separately
		forval id=2/3 {
			use `merge1_bl_isid`id'', clear
			merge 1:1 mergeid`id' using `merge1_allids_isid`id'',gen(merge_mergeid`id') 
				// mergeid2 matches 144, mergeid3 matches 15
				/*
					 Result                           # of obs.
					-----------------------------------------
					not matched                         2,207
						from master                       130  (merge_mergeid2==1)
						from using                      2,077  (merge_mergeid2==2)

					matched                                41  (merge_mergeid2==3)
					-----------------------------------------


					Result                           # of obs.
					-----------------------------------------
					not matched                         1,041
						from master                        27  (merge_mergeid3==1)
						from using                      1,014  (merge_mergeid3==2)

					matched                               144  (merge_mergeid3==3)
					-----------------------------------------				
				*/
			gen mergeid1_using_mergeid`id'=mergeid1
			keep if merge_mergeid`id'==3
			tempfile merge`id'_matched
			save `merge`id'_matched'
		}

	* Then combine the mergeid2 and mergeid3 results and assert that they match the same way (by checking preloaded names)
		use `merge2_matched', clear
		merge 1:1 KEY using `merge3_matched',gen(merge_mergeid2_mergeid3)  
		assert mergeid1_using_mergeid2==mergeid1_using_mergeid3  if merge_mergeid2_mergeid3==3 // success
		
		keep if inlist(3,merge_mergeid2,merge_mergeid3)
		replace mergeid1=mergeid1_allids
		keep mergeid1 KEY merge_mergeid3 merge_mergeid2_mergeid3 
		
		tempfile merge_mergeid2_3
		save `merge_mergeid2_3'

**** 2.3 - Combine all matching results
	
	* Append all matching results
		use `merge1_matched', clear // from round 1
		append using `merge_mergeid2_3' 
	
		merge 1:1 KEY using `bl',gen(final_merge)
		/*
		    Result                           # of obs.
			-----------------------------------------
			not matched                            13
				from master                         0  (final_merge==1)
				from using                         13  (final_merge==2)

			matched                             3,016  (final_merge==3)
			-----------------------------------------
		*/
		
	* Generate indicators for matching results	
		gen merged_bl_PRA=(final_merge==3) // 3,017 merged / 12 unmerged
			lab var merged_bl_PRA "Survey could be matched"
		gen merged_bl_PRA_id=.
			replace merged_bl_PRA_id = 1 if merged_bl_PRA==1 & mi(merge_mergeid2_mergeid3)
			replace merged_bl_PRA_id = 2 if merged_bl_PRA==1 & merge_mergeid2_mergeid3==1 
			replace merged_bl_PRA_id = 3 if merged_bl_PRA==1 & merge_mergeid2_mergeid3==2 
			replace merged_bl_PRA_id = 4 if merged_bl_PRA==1 & merge_mergeid2_mergeid3==3 
			lab define mergeid 1 "mergeid1" 2 "mergeid2" 3 "mergeid3" 4 "mergeid2 & mergeid3"
			lab val merged_bl_PRA_id mergeid 
			lab var merged_bl_PRA_id "mergeid used for matching bl survey to PRA"
		
		keep mergeid1 KEY merged_bl_PRA merged_bl_PRA_id targeting_svy ultra_poor CDCID_bl hhid_bl_wrong
		
	* Save merged and unmerged results separately
		preserve
			keep if merged_bl_PRA==0 // 13 HHs
			gen CDCID = CDCID_bl
			tempfile unmerged_bl_allids
			save `unmerged_bl_allids'
		restore
	
	
/*------------------------------------------------------------------------------
	5 - Merge bl with full PRA listing
------------------------------------------------------------------------------*/
	
**** Prepare matched HHs for merging with PRA
	keep if merged_bl_PRA==1
	
	merge 1:1 mergeid1 using `allids', assert(2 3) keep(3) nogen
	
	foreach var in CDCID hhhead_name father_spouse_name {
		rename `var'_allids `var'
	}
	
	*PRA_clean_beforemerge // always to be run when dealing with raw PRA-based data 
	
	rename HeadofHH hhhead_gender_s
	rename RelationshipwithHH relationship_hhhead

	keep District Village CDCID Masjid hhid  hhhead_name father_spouse_name relationship_hhhead targeting_svy ultra_poor KEY
	* Clean " ", ".", and "/" in names
		foreach	strvar	in	CDCID hhhead_name father_spouse_name Village	{
			replace	`strvar'	=	trim(itrim(`strvar'))
			replace `strvar' = subinstr(`strvar', ".", "",.) 
			replace `strvar' = subinstr(`strvar', "/", "",.) 
		}
		replace father_spouse_name=trim(itrim(father_spouse_name)) // for some reason this is not working in the loop

	gen mergeid_PRA_bl=upper(Village)+"-"+upper(hhhead_name)+"-"+upper(father_spouse_name)+"-"+upper(relationship_hhhead)
		* Create override var to distinguish between two pairs that would otherwise be duplicate
		gen noreplace=.
			*replace noreplace=1 if Village=="Polbabo - 4" & hhhead_name=="Mohammad Amin" & father_spouse_name=="Shir Mohammad" // we have one NP and one UP?

		replace mergeid_PRA_bl="SARI DEH-RAHAMATULLAH-ABDULLAH-" if mergeid_PRA_bl=="SARI DE-RAHAMATULLAH-ABDULLAH-" // slightly different PRA name
		replace mergeid_PRA_bl="PAY MASHAD AFGHANIA - 2-MOHAMMAD YAAR-MALIK-HIMSELF" if mergeid_PRA_bl=="PAY MASHAD AFGHANIA - 2-MOHAMMAD YAAR-MALIK-"
		replace mergeid_PRA_bl="KANDA BAGHAT-SHAHZADA-HABIBULLAH-FATHER" if mergeid_PRA_bl=="KANDA BAGHAT-SHAHZADA-HABIBULLAH-FATHER"
		replace mergeid_PRA_bl="LANGAR KHANA KHORD - 2-HABIBULLAH-CHAR YAR-" if mergeid_PRA_bl=="LANGAR KHANA KHORD - 2-HABIBULLAH-CHAR YAR-HIMSELF"

	replace mergeid_PRA_bl=mergeid_PRA_bl+"-"+"NP" if targeting_svy==1 & noreplace!=1
	tempvar duplicate
	duplicates tag mergeid_PRA_bl,gen(`duplicate')
		/* 1 pair of mergeid_PRA_bl duplicates with mergeid_PRA_bl=="BABA SEDIQ-WIDOW-CHARI--NP"
			---> 	In PRA there are 3, of which 1 is flagged as repeated. Both the other
					 two are NP: only difference is in "Ownership of land" indicator. */
	replace mergeid_PRA_bl=mergeid_PRA_bl+string(_n) if `duplicate'!=0 // must make it ISID
	* Save
		tempfile merged_bl_allids
		save `merged_bl_allids'
	
**** Prepare PRA for merging
	use `PRA_all_w_merging', clear
		
	*keep District Village CDCID Masjid hhhead_gender  hhhead_name father_spouse_name relationship_hhhead ultra_poor SNo CDCID
	
	*drop if mi(District)
	PRA_clean_beforemerge
	
	gen mergeid_PRA_bl=upper(Village)+"-"+upper(hhhead_name)+"-"+upper(father_spouse_name)+"-"+upper(relationship_hhhead)
		replace mergeid_PRA_bl=mergeid_PRA_bl+"-"+"NP" if ultra_poor==0
	
	duplicates tag mergeid_PRA_bl,gen(duplicate_PRA_all)
		lab var duplicate_PRA_all "Duplicate across all vars in PRA"

**** First, run m:1 to see which will not merge because they are duplicate in the PRA
	preserve
		merge m:1 mergeid_PRA_bl using `merged_bl_allids',keepus(mergeid_PRA_bl Village hhhead_name father_spouse_name Masjid CDCID KEY ultra_poor targeting_svy) gen(merge_PRA_bl)
			lab define merge_PRA_bl 1 "Only in bl" 2 "Only in PRA" 3 "Matched bl/PRA"
			lab val merge_PRA_bl  merge_PRA_bl
		
		keep if merge_PRA_bl==2 | (duplicate_PRA_all!=0 & merge_PRA_bl==3)
		*export delimited using "$bl_out_tab/Others/Unmatched_bl_PRA.csv", replace	
			// An xlsx version of this file has been commented by RdG on 29Jun2018
	restore
	
	keep if duplicate_PRA_all==0 // not important now
	 
*** Finally, merge
	merge 1:1 mergeid_PRA_bl using `merged_bl_allids',keepus(hhid mergeid_PRA_bl Village hhhead_name father_spouse_name Masjid CDCID KEY ultra_poor targeting_svy) gen(merge_bl)
		lab var merge_bl "Merge results between PRA and bl"
		lab define merge_bl 1 "Only in PRA" 2 "Only in bl" 3 "Matched bl/PRA"
		lab val merge_bl  merge_bl
		/*
			Result                           # of obs.
			-----------------------------------------
			not matched                        24,159
				from master                    24,132  (merge_bl==1)
				from using                         27  (merge_bl==2)

			matched                             2,989  (merge_bl==3)
			-----------------------------------------
		*/

 * Update issue var
	replace hh_tracking_flag = hh_tracking_flag + "Bl survey could not be matched to PRA (duplicate in bl or PRA)" if merge_bl==2

 * Append unmerged 	
	append using `unmerged_bl_allids',gen(appended)
	replace hh_tracking_flag = hh_tracking_flag + "Bl survey could not be matched to PRA (due to completely wrong HHIDs entered)" if merge_bl==2
 
 * Save final merged file
	drop _*
	rename hhid hhid_bl
	
 * Generate unique number here (do not replicate)
	*sort SNo No Village CDCID Masjid DateofPRA hhhead_gender hhhead_name father_spouse_name relationship_hhhead, stable
	*gen uniqueid = _n
		lab var uniqueid "Unique ID in PRA_merged dataset"
		order uniqueid
		
	save "${PRA_merged}", replace


	
/*------------------------------------------------------------------------------
	X - Old Garima to be merged
------------------------------------------------------------------------------*/
	 
 /*
		
***********************************************************************************************
	* * Step 6: Add flag for whether in the wrong hhid verification sample sent to Mohammad
***********************************************************************************************
	
	tempfile hhid_verifying
	
	preserve
		import excel $hhid_verification, sheet("Sheet1") firstrow clear
		rename hhid hhid_survey
		rename IsthepersonincolumnsCDthe Is_hh_head
		rename IsthepersonincolumnsCDano Is_another_hh_member
		keep hhid_survey Is_hh_head Is_another_hh_member
		save `hhid_verifying', replace
	restore
	
	* Merging m to one because hh not in the survey sample don't have a hhid_survey
	merge m:1 hhid_survey using `hhid_verifying'
	
	gen verifying_hhid_sample=1 if _merge==1
	replace verifying_hhid_sample=0 if verifying_hhid_sample!=1
	lab var verifying_hhid_sample "In hhid verification sample sent to Mohammad"
	
	gen wrong_id_discovered=1 if Is_hh_head=="0" & Is_another_hh_member==0
	replace wrong_id_discovered=0 if wrong_id_discovered!=1 & verifying_hhid_sample==1
	lab var wrong_id_discovered "Mohammad discovered that no person in hh matches name we provided"
		
	drop _merge

***********************************************************************************************
	* * Step 7: Add VAUs explanations for wrong id usage
***********************************************************************************************
	
	* There are three types of explanations provided by VAU
	* 1. The hh head listed by CHA is not a part of the hh (has moved away/or is some other family member not meeting our definition of hh member)
	* 2. The person is actually a part of the hh (even when Mohammad found they aren't)
	* 3. No explanation; they're asking the supervisor
	
	#delimit ;
		gen wrong_id_reason = 1 if 
		hhid_survey=="1003813" |
		hhid_survey=="400142" |
		hhid_survey=="4003656" |
		hhid_survey=="4003632" |
		hhid_survey=="200107" |
		hhid_survey=="N1100187" |
		hhid_survey=="N11001155" |
		hhid_survey=="N4001564" |
		hhid_survey=="N100336" |
		hhid_survey=="N2003517" |
		hhid_survey=="N1100193" |
		hhid_survey=="N4001536" 
	;
	#delimit cr
	
	#delimit ;
		replace wrong_id_reason = 2 if hhid_survey=="300543" |
			hhid_survey=="100021" |
			hhid_survey=="1000250" |
			hhid_survey=="4003615" |
			hhid_survey=="4003618" |
			hhid_survey=="N300644" |
			hhid_survey=="N300645" 
	;
	#delimit cr
	
	replace wrong_id_reason=3 if hhid_survey=="200199" | hhid_survey=="1000128" | hhid_surve=="N1100183"

	lab define reason 1 "Wrong hh head name" 2 "Is actually part of hh" 3 "No explanation"
	lab values wrong_id_reason reason
	lab var wrong_id_reason "Reason by VAU for why no person in hh matches name we provided"
	
	*Labeling relevant variables
	lab var hhhead_name "Name of hh head" 
	lab var father_spouse_name "Father/spouse name"
	lab var hhid_implementation "HHID sent for lottery to CHA/NARC"
	lab var hhid_survey "HHID used for all survey purposes with VAU"
	lab var hhid_old_22Feb "hhid assigned on list sent on 22 Feb (NOT IMPORTANT)"
	lab var gender_hhhead "Gender of hh head"
	lab var relationship_hhhead "Relationship with hh head"
	
	drop still_eligible_10Mar Tag2
	*Ordering relevant variables
	order hhhead_name father_spouse_name hhid_implementation hhid_survey  tup_el_22Feb implementation_sample rejected_10Mar added_10Mar survey_sample survey_done_before_10Mar survey_complete survey_missing confirmed_missing_CHA MissingDetailprovidedbyVAU RemarksGarima verifying_hhid_sample Is_hh_head Is_another_hh_member wrong_id_discovered wrong_id_reason
	save $tup_all_with_flags, replace
	
