/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Jan 22, 2019
Last udpate on: Jan 22, 2019

Written by:  	Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Creates profile data for the follow-up sample


CONTENT:		

INPUTS:     	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

global DB_PII_Profile "${TUP_DB_PII}/Profile_and_merging/"

* Inputs
	* PRA merged with all datasets. This dataset was created by Rebecca in the 
	* following do file in Github: DataWork/Profile_and_merging/Dofiles/Construct/Merge_PRA_with_all datasets.do
		gl PRA_merged "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/PRA_merged_with_all datasets.dta"
	
	* IDs created for Follow-up 1
		gl fl1_IDs "${DB_PII_Profile}/DataSets/Intermediate/fl_hhid_do not touch.dta"	
		
	* Lottery plan
		gl lottery_plan "${DB_PII_Profile}/DataSets/Intermediate/no_tup_el_by_PRA-Lottery-Plan-Final_REVISED_20Apr.dta"

	* Follow-up 1 sample
		gl fl1_sample "${DB_PII_Profile}/DataSets/Intermediate/Followup_Sample.dta"	
		
	* Results of verification excercise done by Mohammad 
		gl hh_verif "${DB_PII_Profile}/Output/Final/household_verification_20Dec2018_Mohammad.xlsx"

	* Follow-up 1 survey data appended and merged
		*gl fl1_all_HH_pii   "${TUP_DB_PII}/Followup_1/DataSets/Intermediate/fl1_all_HH_pii.dta"
		gl all_HH_interm_nopii_wflags_fl1 "${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_interm_nopii_withflags_fl1.dta"
		gl all_HH_interm_pii_wflags_fl1 "${TUP_DB_PII}/Followup_1/DataSets/Intermediate/all_HH_interm_pii_withflags_fl1.dta"
		global all_HH_nopii_fl1 					"${TUP_DB}/Followup_1/DataSets/Intermediate/all_HH_nopii_fl1.dta"
		
	* Weights
		gl weights "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights.dta"
		gl weights_CWR "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights_CWR.dta"

	* Baseline
		gl bl_compiled "${TUP_DB}/Baseline/DataSets/Intermediate/bl_compiled.dta"
		
* Outputs
	* Profile dataset
	*if "`c(username)'" == "mcayala" { // Outputs are saved in Dropbox
		global fl1_profile_info "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/fl1_profile_info.dta"
		global fl1_profile_info_nopii "${TUP_DB}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	 /*}
		if "`c(username)'" != "mcayala" { // Outputs are saved in local GitHub
		global fl1_profile_info "${Github}/Profile_and_merging/DataSets/Final/fl1_profile_info.dta"
		global fl1_profile_info_nopii "${Github}/Profile_and_merging/DataSets/Final/fl1_profile_info_nopii.dta"
	}*/	
	
*------------------------------------------------------------------------------*
*	1 - Merge Follow-up IDs to PRA_merged									   *
*------------------------------------------------------------------------------*
	
* I (Camila) followed the do file created by Rebecca and saved here:	
* TUP_Afghanistan/Data Analysis/Follow-Up/Follow Up R1/Dofiles/0_sample.do
	
	use "${PRA_merged}", clear
	
 * Keep only if in lottery or baseline
	keep if ((inlist(merge_lottery,2,3) | inlist(merge_bl,2,3)) | appended==1)

 * Tag type of survey
	gen survey = "Targeting" if !(inlist(merge_lottery,2,3))
		replace survey = "Ultra-poor"  if (inlist(merge_lottery,2,3))
		assert !mi(survey)

 * Drop PRAs with only 0 or 1 UP HHs (note that PRA is indicated as "Village" in most datasets)
	 
	preserve
	
	* Generate indicators for collapsing
		gen targ 	= (survey=="Targeting") 
		gen up 		= (survey=="Ultra-poor") 
		gen up_t 	= (survey=="Ultra-poor" & treatment==1)
		gen up_c 	= (survey=="Ultra-poor" & treatment==0)
		collapse (sum) targ up up_t up_c, by(Village)
		
	* Also check whether the number of UP and T and C matches those that were planned
		merge 1:1 Village using "${lottery_plan}"
		assert up_t==Treatment & up_c==Control if _merge==3 // perfectly matched what was planned to happen
	* Keep those villages with 0 or 1 UPs
		keep if (_merge==1 | up==0 | up==1) & Village!=""
	* Save list of PRAs to be dropped	
		tempfile PRA_todrop
		save `PRA_todrop'
	
	restore
	
	merge m:1 Village using `PRA_todrop',gen(todrop) assert(1 3) keepus(Village)
		
	drop if todrop==3

	* Drop other obs
		bys Village hhhead_name father_spouse_name: gen drop = 1 if Village=="Baba Sediq" & hhhead_name=="Widow" & father_spouse_name=="Chari" & _n==2
			replace drop=1 if targeting_svy==0 & survey=="Targeting" // ~These are UP surveys matched to a targeting survey, most likely a mismatch
			drop if drop==1
			drop drop
			
	* Complete district var
		replace District="Nahr" if mi(District) & substr(CDCID,1,7)=="16-1602" | CDCID=="16-1605-0014" 
		replace District="Dawlatabad" if mi(District) & substr(CDCID,1,7)=="16-1605" & CDCID!="16-1605-0014" 
		replace District="Dehadi" if mi(District) & substr(CDCID,1,7)=="16-1612"
		replace District="Khulm" if mi(District) & substr(CDCID,1,7)=="16-1614"
			assert inlist(District,"Nahr","Dawlatabad","Dehadi","Khulm")
			
	 * Regenerate IDs
		gen id_perm = Village + "-" + hhhead_name + "-" + father_spouse_name
			replace id_perm =  "UP" + "-" + id_perm if survey=="Ultra-poor"
			replace id_perm =  "NP" + "-" + id_perm if survey=="Targeting"
			duplicates tag id_perm,gen(tag)	
			replace id_perm = id_perm + "-" + KEY if tag!=0
			isid id_perm
		
		merge 1:1 id_perm using "${fl1_IDs}", keep(1 3)
		lab var hhid "HHID used in follow-up"
		
	* Now merge follow-up sample	
		merge 1:1 hhid using "${fl1_sample}", assert(1 3)  keep(3) nogen 
			/*
			    Result                           # of obs.
				-----------------------------------------
				not matched                             7
					from master                         7  (_merge==1)
					from using                          0  (_merge==2)

				matched                             2,899  (_merge==3)
				-----------------------------------------
			*/
		
		keep uniqueid hhid bl_key treatment bl_latitude bl_longitude bl_oth_hh bl_oth_hh_why NewNumber District
		
		tempfile PRA_ID_fl1
		save	`PRA_ID_fl1'
		
*------------------------------------------------------------------------------*
*	2 - Create profile dataset with relevant sample							   *
*------------------------------------------------------------------------------*
		
* The relevant sample will be: 1,219 Ultra-Poor households (728 control and 491 treatment)
		
	* Merge Follow-up IDs to PRA_merged
		use  "${PRA_merged}", clear
		merge 1:1 uniqueid using `PRA_ID_fl1', keep(3) assert(1 3) nogen
		order hhid, after(uniqueid)
		lab var hhid "HHID used in follow-up"
		*keep if !mi(treatment) // keep only ultra-poor for now

	* Check all the IDs are isid
		isid hhid
		duplicates report hhid_bl if !mi(hhid_bl)
		duplicates report District NewNumber if !mi(NewNumber)

	* Keep relevant variables
		keep hhid hhid_bl uniqueid Village District NewNumber
		encode Village, gen(village_lottery)
		lab var village_lottery "Village/PRA in loterry"
		drop Village
		rename village_lottery PRA_lottery
		
	* Now merge follow-up sample	
		merge 1:1 hhid using "${fl1_sample}", assert(2 3) keep(3) nogen 
		order hhid
		
	* Labels
		rename hhid_bl bl_hhid
		rename NewNumber im_NewNumber
		rename District im_District
		lab var bl_hhid "HHID used in baseline"
		lab var survey "Type of survery"
		lab var bl_key "Survey key (from bl LHH survey)"
		lab var im_NewNumber "New Number, implementation records"
		lab var im_District "District, implementation records"
		
	* Merge follow-up info
		merge 1:1 hhid using "${all_HH_nopii_fl1}", keepus(district village latitude longitude key) nogen 
		rename (district village latitude longitude key) (fl1_district fl1_village fl1_latitude fl1_longitude fl1_key)
		
		lab var fl1_district "District (from fl1 LHH survey)"
		lab var fl1_village "Village (from fl1 LHH survey)"
		lab var fl1_latitude "Latitude (from fl1 LHH survey)"
		lab var fl1_longitude "Longitude (from fl1 LHH survey)"
		lab var fl1_key "Survey key (from fl1 LHH survey)
	
	preserve
	
*------------------------------------------------------------------------------*
*	3 - Create important follow-up flags 									   *
*------------------------------------------------------------------------------*
		
* Based on the verification exercise done by Mohammad, we create the following flags:
* 1. HH is not the right household
* 2. HH head is not in the roster
* 3. CHA does not specify names

* Sheet 1: Import results of excercise done by Mohammad: sheet HHs to verify (T&C)
*--------------------------------------------------------------------------------

	import excel "${hh_verif}", sheet("HHs to verify (T&C)") cellrange(A2:X243) firstrow clear
	keep HouseholdIDDIME Istheheadofthehouseholdin Isthetraineebeneficiaryinco Additionalcomments 
	rename  (HouseholdIDDIME Istheheadofthehouseholdin Isthetraineebeneficiaryinco Additionalcomments) ///
			(hhid is_hh_head is_trainee comments)
	
	* Merge treatment status and some follow-up variables	
		merge 1:1 hhid using "${fl1_sample}", keepus(treatment) assert(2 3) keep(3) nogen
		merge 1:1 hhid using "${all_HH_interm_nopii_wflags_fl1}", keepus(r80 r81) assert(2 3) keep(3) nogen
	
	* Flag 1. HH is not the right household
		gen 	flag_no_right_hh = 0 if inlist(is_hh_head, "Yes", "No", "Not clear") & is_trainee == "Yes"
		replace flag_no_right_hh = 0 if is_hh_head == "Yes" & inlist(is_trainee, "No", "Not clear")
		replace flag_no_right_hh = 1 if is_hh_head == "No" & is_trainee == "No" 
		replace flag_no_right_hh = 2 if is_hh_head == "Not clear" & is_trainee == "No"
		replace flag_no_right_hh = 2 if is_hh_head == "No" & is_trainee == "Not clear"
		replace flag_no_right_hh = 2 if is_hh_head == "Not clear" & is_trainee == "Not clear"
		*replace flag_no_right_hh = 3 if is_hh_head == "Yes" & is_trainee == "No" //sent to 0 based on meeting
		lab def flag_no_right_hh_l 0 "0: Is the right household" 1 "1: Is NOT the right household" 2 "2: No way of verifying" 3 "3: To confirm"
		lab val flag_no_right_hh flag_no_right_hh_l
		lab var flag_no_right_hh "HH is not the right household"
		tab flag_no_right_hh
		count if flag_no_right_hh==1
		assert r(N) == 0
		
	* Flag 2. HH head is not in the roster
		gen 	flag_hhhead_not_in_roster = 0 if is_hh_head == "Yes"
		replace flag_hhhead_not_in_roster = 1 if is_hh_head == "No"
		replace flag_hhhead_not_in_roster = 2 if is_hh_head == "Not clear"
		lab def flag_hhhead_not_in_roster_l 0 "0: HH head is in the roster" 1 "1: HH head is NOT in the roster" 2 "2: Not clear"
		lab val flag_hhhead_not_in_roster flag_hhhead_not_in_roster_l
		lab var flag_hhhead_not_in_roster "HH head is not in the roster"
		tab flag_hhhead_not_in_roster treatment
	
	* Flag 3. CHA does not specify names
		gen 	flag_no_CHA_names = 1 if inlist(comments, "CHA list does not specify hh head's name") & is_trainee != "NA"
		replace flag_no_CHA_names = 2 if inlist(comments, "CHA list does not specify names") & is_trainee != "NA"
		replace flag_no_CHA_names = 3 if inlist(comments, "CHA list does not specify trainee's name") & is_trainee != "NA"
		lab def flag_no_CHA_names_l 1 "HH head's name not specified by CHA" 2 "No name specified by CHA" 3 "Trainee's name not specified by CHA"
		lab val flag_no_CHA_names flag_no_CHA_names_l
		lab var flag_no_CHA_names "CHA does not specify names"
		tab flag_no_CHA_names
	
	* Generate flag for robustenss
		gen		flag_robustness = 1 if flag_no_right_hh == 2
		replace flag_robustness = 1 if inlist(flag_hhhead_not_in_roster, 1, 2) & treatment == 0
		replace flag_robustness = . if flag_no_right_hh == 1
		lab var flag_robustness "Households =1 to take out for robustness checks"
		tab flag_robustness
	
		keep hhid flag_*
	
	tempfile sheet_hhs_verify_tandc
	save 	`sheet_hhs_verify_tandc'
	
* Sheet 2: Import results of excercise done by Mohammad: sheet "Treatment HHs list"
*--------------------------------------------------------------------------------

	import excel "${hh_verif}", sheet("Treatment HHs list") cellrange(A2:AC61) firstrow clear
 	keep HouseholdIDDIME IstherighthouseholdYes1N Anyimportantinconsistencies Additionalcomments
	rename  (HouseholdIDDIME IstherighthouseholdYes1N Anyimportantinconsistencies Additionalcomments) ///
			(hhid is_right_hh inconsistencies comments)
	drop if mi(hhid)
		
	* Merge treatment status and some follow-up variables	
		merge 1:1 hhid using "${fl1_sample}", keepus(treatment) assert(2 3) keep(3) nogen
		merge 1:1 hhid using "${all_HH_interm_nopii_wflags_fl1}", keepus(r80 r81 r3) assert(2 3) keep(3) nogen

 	* Flag 2. HH is not the right household
		*br inconsistencies if inlist(is_right_hh, "No ", "No", "No match") & !mi(inconsistencies)
		gen 	flag_no_right_hh = 0 if inlist(is_right_hh, "Yes", "yes")
		replace flag_no_right_hh = 0 if inlist(is_right_hh, "No ", "No", "No match") & !mi(inconsistencies)
		replace flag_no_right_hh = 1 if inlist(is_right_hh, "No ", "No", "No match") & mi(inconsistencies)
		replace flag_no_right_hh = 2 if inlist(is_right_hh, "Maybe")
		*replace flag_no_right_hh = 3 if inlist(is_right_hh, "No ", "No", "No match") & !mi(inconsistencies) // we sent this to one, since one name matches
		lab def flag_no_right_hh_l 0 "0: Is the right household" 1 "1: Is NOT the right household" ///
								  2 "2: No way of verifying" 3 "3: To confirm"
		lab val flag_no_right_hh flag_no_right_hh_l
		lab var flag_no_right_hh "HH is not the right household"
		tab flag_no_right_hh
	
	* Generate flag for robustenss
		gen		flag_robustness = (flag_no_right_hh == 2) 
		replace flag_robustness = . if flag_no_right_hh == 1
		lab var flag_robustness "Households =1 to take out for robustness checks"
		tab flag_robustness
		
	keep hhid flag_* 
	
	tempfile sheet_hhs_verify_treatment
	save 	`sheet_hhs_verify_treatment'

* Merge tags to profile data
	restore
	merge 1:1 hhid using `sheet_hhs_verify_tandc', assert(1 3) nogen
	merge 1:1 hhid using `sheet_hhs_verify_treatment', update assert(1 4) nogen 
	
* Replace flag_robustness to zero for the other households	
	replace flag_robustness = 0 if mi(flag_robustness) & flag_no_right_hh != 1
	tab flag_robustness treatment, m
	
* Generate ultra_poor variable
	gen 	ultra_poor = 1 if !mi(treatment)
	replace ultra_poor = 0 if mi(treatment)
	lab var ultra_poor "HH is ultra-poor"
	
* Merge weigths
	merge m:1 CDCID ultra_poor using "${weights}", assert(3) nogen keepus(pweight)
	mdesc pweight
	
* Merge weights at the CWR category
	merge m:1 hhid using "${weights_CWR}", assert(3) nogen
	
* Fix key for one household:
* Camila, 17Nov2019: For some reason the baseline key of this household is missing. I checked
*					 names in Dari and preloaded and it seems that it is the same household.
	count if !mi(bl_hhid) & mi(bl_key)
	assert r(N) == 1
	tab bl_hhid if !mi(bl_hhid) & mi(bl_key)
	replace bl_key = "uuid:1443abc2-4292-425c-9990-79e8f18a0aef" if bl_hhid == "N300142" 
	
	if	`c(stata_version)'>=14	{
		saveold "${fl1_profile_info}", replace v(13)
	}
	else {
		save "${fl1_profile_info}", replace
	}
	
* Anonymize

	drop father_spouse_name hhhead_name beneficiary_name bl_latitude bl_longitude fl1_latitude fl1_longitude 
	 label drop village_lottery
	 
	if	`c(stata_version)'>=14	{
		saveold "${fl1_profile_info_nopii}", replace v(13)
	}
	else {
		save "${fl1_profile_info_nopii}", replace
	}
		
