/*******************************************************************************	

Project:  		TUP - Afghanistan
Created on:  	Nov 13, 2018
Last udpate on: Feb 17, 2018

Written by:  	Rebecca de Guttry and
				Maria Camila Ayala (mayalaguerrero@worldbank.org)

Revision: 		

********************************************************************************			

THIS DO FILE: 	Anonymize village and district.


CONTENT:		Part 0: Create globals for directories and files 
				Part 1: Importing and basic SurveyCTO cleaning raw data
				Part 2: Define programs to be used for cleaning
				Part 3: Basic cleaning for each dataset
				Part 4: Merge and append of all HH-level surveys
				
INPUTS:   		
  	

OUTPUTS:     	

*******************************************************************************/

********************************************************************************
	** Part 0: Create globals for directories and files 
********************************************************************************

* Inputs
	* LHH, MHHH, Targeting surveys
		gl LHH_raw_fl1_pii "${TUP_DB_PII}/Followup_1/DataSets/Raw/LHH_raw_fl1_pii.dta"

	* Sample of villages (all villages where we did PRAs)
		gl sample_village 	"${DB_PII_Profile}/DataSets/Intermediate/village_names.dta"
		
* Outputs
	
		gl village_anonymized 				"${TUP_DB_PII}/Profile_and_merging\DataSets\Intermediate/village_anonymized.dta"
		gl district_anonymized 				"${TUP_DB_PII}/Profile_and_merging/DataSets/Intermediate/district_anonymized.dta"
		gl villages_all_list 				"${DB_PII_Profile}/DataSets/Final/villages_all_list.dta"
	

********************************************************************************
	** Part 1: Anonymize village and district
********************************************************************************

use "${LHH_raw_fl1_pii}", clear

/*
	* Create village and district anonymized
		* Village
			decode a6, gen(village_str)
			encode village_str, gen(village)
			lab drop village
				lab var village "Village (selected in survey)"
			preserve
				keep village a6
				duplicates drop village, force
				decode a6, gen(a6_label)
				lab var village "Village anonymized"
				save "${village_anonymized}", replace
			restore

		* District
			decode a5, gen(district_str)
			encode district_str, gen(district)
			lab drop district
				lab var district "District (selected in survey)"
			preserve
				keep district a5
				duplicates drop district, force
				save "${district_anonymized}", replace
			restore
*/

********************************************************************************
	** Part 2: Merge to the list of ALL villages names and 
********************************************************************************

* Open dataset with all the sample villages (where we did PRAs)
	use "${sample_village}", clear

* Merge village anonymized
	isid a6
	replace a6 = 89 if a6 == 1
	merge 1:1 a6 using "${village_anonymized}", nogen // 8 villages that do not merge from master data
	drop a6_label
	
* Create the code for village anonymized for the 8 that do not merge
	tab village // goes from 1 to 80 
	*br if village == .
	replace village = 81 if a6 == 7
	replace village = 82 if a6 == 21
	replace village = 83 if a6 == 26
	replace village = 84 if a6 == 31
	replace village = 85 if a6 == 35
	replace village = 86 if a6 == 53
	replace village = 87 if a6 == 59
	replace village = 88 if a6 == 61
	replace village = 89 if a6 == 61
	replace village = 90 if a6 == 61
	
	save "${villages_all_list}", replace

