use "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/PRA_merged_with_all_cleaned.dta", clear

* Keep relevant villages
	keep if keep_village == 1
	codebook CDCID
	
* Weights calculating using the 4 categories	
	tab WealthRankingCategory_v, m
	tempfile PRA_all
	save	`PRA_all'
	/*
		 Wealth Ranking |
	   Category - After |
		   verification |      Freq.     Percent        Cum.
	--------------------+-----------------------------------
			 Ultra-poor |      1,219        5.89        5.89
		Near-Ultra-Poor |      7,753       37.45       43.34
				   Poor |      6,799       32.84       76.18
	Better-off/Well-off |      4,852       23.44       99.62
					  . |         79        0.38      100.00
	--------------------+-----------------------------------
				  Total |     20,702      100.00
	*/
	
* Count households in each village and wealth ranking group
	preserve
		gen one = 1
		collapse (sum) total = one, by(CDCID WealthRankingCategory_v)
		tempfile total
		save 	`total'			
	restore
	
	collapse (sum) total_bl = in_bl, by(CDCID WealthRankingCategory_v)
	merge 1:1 CDCID WealthRankingCategory_v using `total', assert(3) nogen
		
* Generate weights
	gen pweight_CWR = total/total_bl
	lab var pweight_CWR "Weights at the village/wealth ranking category level (As of 21May2020)"
	
* Check weights
	egen tot = sum(total_bl * pweight_CWR)
	sum tot
	assert r(mean) == 20462 // there are some missing, so that's why we don't reach the 20,623 HHs. Less than 1%
	drop tot
	
* Save
	drop if mi(WealthRankingCategory_v)
	isid CDCID WealthRankingCategory_v
	save "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights_CWR_villagelevel.dta", replace
	
	*---------------------*
	* Merge to HH dataset *
	*---------------------*
	
		* Keep only HHs in our sample
			use `PRA_all', clear
			keep if !mi(hhid)
		
		* Merge weights	
			merge m:1 CDCID WealthRankingCategory_v using "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights_CWR_villagelevel.dta"
			drop if _merge == 2
				/*	 
					Result                           # of obs.
					-----------------------------------------
					not matched                             4
						from master                         1  (_merge==1) // One targeting HHs with no wealth ranking and no baseline that we couldn't impute to a category
						from using                          3  (_merge==2)

					matched                             2,898  (_merge==3)
					-----------------------------------------
				*/
	
		* Save
			keep hhid WealthRankingCategory WealthRankingCategory_v pweight_CWR
			save "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights_CWR.dta", replace

*--------------------*
* Weights UP vs. NUP *
*--------------------*

use "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/PRA_merged_with_all_cleaned.dta", clear

* Keep relevant villages
	keep if keep_village == 1
	codebook CDCID
	
* Weights calculating using the ultra_poor
	tab ultra_poor, m
	/*
		  HH is |
	 ultra-poor |      Freq.     Percent        Cum.
	------------+-----------------------------------
			  0 |     19,405       93.73       93.73
			  1 |      1,219        5.89       99.62
			  . |         78        0.38      100.00
	------------+-----------------------------------
		  Total |     20,702      100.00
	*/

* Count households in each village and ultra_poor group
	preserve
		gen one = 1
		collapse (sum) total = one, by(CDCID ultra_poor)
		tempfile total
		save 	`total'			
	restore
	
	collapse (sum) total_bl = in_bl, by(CDCID ultra_poor)
	merge 1:1 CDCID ultra_poor using `total', assert(3) nogen
	
* Generate weights
	gen pweight = total/total_bl
	lab var pweight "Weights at the village/ultra_poor level"
	
* Check weights
	egen tot = sum(total_bl * pweight)
	sum tot
	assert r(mean) == 20624 // there are some missing, so that's why we don't reach the 20,623 HHs. Less than 1%
	drop tot
	
* Save
	drop if mi(ultra_poor)
	isid CDCID ultra_poor
	save "${TUP_DB_PII}/Profile_and_merging/DataSets/Final/weights.dta", replace	

