   * ******************************************************************** *
   *
   *       SET UP STANDARDIZATION GLOBALS AND OTHER CONSTANTS
   *
   *           -Set globals used all across the projects
   *           -It is bad practice to define these at mutliple locations
   *
   * ******************************************************************** *

   * ******************************************************************** *
   * Set all conversion rates used in unit standardization 
   * ******************************************************************** *

   **Define all your conversion rates here instead of typing them each 
   * time you are converting amounts, for example - in unit standardization. 
   * We have already listed common conversion rates below, but you
   * might have to add rates specific to your project, or change the target 
   * unit if you are standardizing to other units than meters, hectares,
   * and kilograms.
   
   * Global to conver survey time to Afghan time
   	global time_diff 9.5

   * IPC
		gl ipc_16_18 = 105.6331498/100 
		gl ipc_17_18 = 100.626/100 
		gl ipc_14_18 = 109.5341587/100
		
	/* cpi_food_bl, cpi_food_fl1, cpi_food_phone globals are saved in the following do-files: 		Github/AFG-TUP/DataWork/Phone_Survey/Dofiles/Analysis/consumption_cpi_calculation_bl.do */

   * PPP conversion factors
		gl ppp_2018 = 19.520 
		gl ppp_factor = $ipc_16_18/$ppp_2018 
		gl ppp_2014 = 18.786
		gl ppp_2021 = 19.184 // estimate from https://www.imf.org/en/Publications/WEO/weo-database/2021/April/weo-report?c=512,&s=PPPEX,&sy=2014&ey=2026&ssm=0&scsm=1&scc=0&ssd=1&ssc=0&sic=0&sort=country&ds=.&br=1

	* See "CPI_calculations_LB.xlsx" for source data on the non-food consumption CPI
		gl cpi_non_food_bl = 96.62777
		gl cpi_non_food_fl1 = 100
		gl cpi_non_food_phone = 107.38938		
	
	*Exchange rate (1 USD = ) 
		gl exchange_rate_2021 = (77.42+77.44+77.49)/3 // 2021 data available only for March, April and May of 2021 from the IMF (https://data.imf.org/regular.aspx?key=61545850), so we take the average 
		gl exchange_rate_2020 = 76.81 // 2020 is the latest year availabe from https://data.imf.org/regular.aspx?key=61545850
		gl exchange_rate_2018 = 72.08 
		gl exchange_rate_2017 = 68.03 
		gl exchange_rate_2016 = 67.87 

   *Standardizing length to meters
       global foot     = 0.3048
       global mile     = 1609.34
       global km       = 1000
       global yard     = 0.9144
       global inch     = 0.0254

   *Standardizing area to hectares
       global sqfoot   = (1 / 107639)
       global sqmile   = (1 / 258.999)
       global sqmtr    = (1 / 10000)
       global sqkmtr   = (1 / 100)
       global acre     = 0.404686
	   global jerib    = 0.2 // 2000 m2 (from Wiki https://en.wikipedia.org/wiki/Afghan_units_of_measurement)
	   global biswa    = 0.01 // 100 m2 (from Wiki https://en.wikipedia.org/wiki/Afghan_units_of_measurement)

   *Standardizing weight to kilorgrams
       global pound    = 0.453592
       global gram     = 0.001
       global impTon   = 1016.05
       global usTon    = 907.1874996
       global mtrTon   = 1000

   * ******************************************************************** *
   * Set global lists of variables
   * ******************************************************************** *

   **This is a good location to create lists of variables to be used at 
   * multiple locations across the project. Examples of such lists might 
   * be different list of controls to be used across multiple regressions. 
   * By defining these lists here, you can easliy make updates and have 
   * those updates being applied to all regressions without a large risk 
   * of copy and paste errors.

       *Control Variables
       *Example: global household_controls       income female_headed
       *Example: global country_controls         GDP inflation unemployment

   * ******************************************************************** *
   * Set custom ado file path
   * ******************************************************************** *

   **It is possible to control exactly which version of each command that 
   * is used in the project. This prevents that different versions in 
   * installed commands leads to different results.

   
       global ado      "$dataWorkFolder/MasterData/ado"
           adopath ++  "$ado" 
           *adopath ++  "$ado/m" 
           *adopath ++  "$ado/b" 
   
   * ******************************************************************** *
   * Anything else
   * ******************************************************************** *

   **Everything that is constant may be included here. One example of
   * something not constant that should be included here is exchange
   * rates. It is best practice to have one global with the exchange rate
   * here, and reference this each time a currency conversion is done. If 
   * the currency exchange rate needs to be updated, then it only has to
   * be done at one place for the whole project.
